@@ -19,11 +19,10 @@
 
 #include "mailcommon/job/backupjob.h"
 #include <KConfigGroup>
-#include <Akonadi/Collection>
-#include <KUrl>
+#include <Collection>
+#include <QUrl>
 #include <QDate>
 
-
 class ArchiveMailInfo
 {
 public:
@@ -32,7 +31,7 @@ public:
     ArchiveMailInfo(const ArchiveMailInfo &info);
     ~ArchiveMailInfo();
 
-    ArchiveMailInfo& operator=( const ArchiveMailInfo &old );
+    ArchiveMailInfo &operator=(const ArchiveMailInfo &old);
 
     enum ArchiveUnit {
         ArchiveDays = 0,
@@ -41,7 +40,7 @@ public:
         ArchiveYears
     };
 
-    KUrl realUrl(const QString &folderName, bool &dirExist) const;
+    QUrl realUrl(const QString &folderName, bool &dirExist) const;
 
     bool isValid() const;
 
@@ -51,26 +50,26 @@ public:
     void setSaveSubCollection(bool b);
     bool saveSubCollection() const;
 
-    void setUrl(const KUrl& url);
-    KUrl url() const;
+    void setUrl(const QUrl &url);
+    QUrl url() const;
 
     void readConfig(const KConfigGroup &config);
-    void writeConfig(KConfigGroup &config );
+    void writeConfig(KConfigGroup &config);
 
-    void setArchiveType( MailCommon::BackupJob::ArchiveType type );
+    void setArchiveType(MailCommon::BackupJob::ArchiveType type);
     MailCommon::BackupJob::ArchiveType archiveType() const;
 
-    void setArchiveUnit( ArchiveMailInfo::ArchiveUnit unit );
+    void setArchiveUnit(ArchiveMailInfo::ArchiveUnit unit);
     ArchiveMailInfo::ArchiveUnit archiveUnit() const;
 
-    void setArchiveAge( int age );
+    void setArchiveAge(int age);
     int archiveAge() const;
 
-    void setLastDateSaved( const QDate &date );
+    void setLastDateSaved(const QDate &date);
     QDate lastDateSaved() const;
 
     int maximumArchiveCount() const;
-    void setMaximumArchiveCount( int max );
+    void setMaximumArchiveCount(int max);
 
     QStringList listOfArchive(const QString &foldername, bool &dirExist) const;
 
@@ -86,7 +85,7 @@ private:
     MailCommon::BackupJob::ArchiveType mArchiveType;
     ArchiveUnit mArchiveUnit;
     Akonadi::Collection::Id mSaveCollectionId;
-    KUrl mPath;
+    QUrl mPath;
     int mMaximumArchiveCount;
     bool mSaveSubCollection;
     bool mIsEnabled;
