@@ -15,7 +15,6 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #include "followupreminderagent.h"
 #include "followupremindermanager.h"
 #include "followupreminderutil.h"
@@ -23,47 +22,50 @@
 #include "followupreminderinfodialog.h"
 #include "followupreminderagentsettings.h"
 #include <KWindowSystem>
-#include <KLocale>
 #include <KMime/Message>
-#include <Akonadi/Session>
-#include <Akonadi/ChangeRecorder>
-#include <Akonadi/ItemFetchScope>
-#include <akonadi/dbusconnectionpool.h>
-#include <Akonadi/CollectionFetchScope>
+
+#include <AkonadiCore/ChangeRecorder>
+#include <AkonadiCore/ItemFetchScope>
+#include <kdbusconnectionpool.h>
+
+#include <Kdelibs4ConfigMigrator>
+#include <AkonadiCore/Session>
+#include <AkonadiCore/CollectionFetchScope>
 
 #include <QPointer>
-#include <QDebug>
+#include "followupreminderagent_debug.h"
 #include <QTimer>
 
 FollowUpReminderAgent::FollowUpReminderAgent(const QString &id)
-    : Akonadi::AgentBase( id )
+    : Akonadi::AgentBase(id)
 {
-    KGlobal::locale()->insertCatalog( QLatin1String("akonadi_followupreminder_agent") );
+    Kdelibs4ConfigMigrator migrate(QStringLiteral("followupreminderagent"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_followupreminder_agentrc") << QStringLiteral("akonadi_followupreminder_agent.notifyrc"));
+    migrate.migrate();
+
     new FollowUpReminderAgentAdaptor(this);
-    Akonadi::DBusConnectionPool::threadConnection().registerObject( QLatin1String( "/FollowUpReminder" ), this, QDBusConnection::ExportAdaptors );
-    Akonadi::DBusConnectionPool::threadConnection().registerService( QLatin1String( "org.freedesktop.Akonadi.FollowUpReminder" ) );
+    KDBusConnectionPool::threadConnection().registerObject(QStringLiteral("/FollowUpReminder"), this, QDBusConnection::ExportAdaptors);
+    KDBusConnectionPool::threadConnection().registerService(QStringLiteral("org.freedesktop.Akonadi.FollowUpReminder"));
     mManager = new FollowUpReminderManager(this);
     setNeedsNetwork(true);
 
-    changeRecorder()->setMimeTypeMonitored( KMime::Message::mimeType() );
-    changeRecorder()->itemFetchScope().setCacheOnly( true );
-    changeRecorder()->itemFetchScope().setFetchModificationTime( false );
-    changeRecorder()->fetchCollection( true );
-    changeRecorder()->setChangeRecordingEnabled( false );
-    changeRecorder()->ignoreSession( Akonadi::Session::defaultSession() );
-    changeRecorder()->collectionFetchScope().setAncestorRetrieval( Akonadi::CollectionFetchScope::All );
+    changeRecorder()->setMimeTypeMonitored(KMime::Message::mimeType());
+    changeRecorder()->itemFetchScope().setCacheOnly(true);
+    changeRecorder()->itemFetchScope().setFetchModificationTime(false);
+    changeRecorder()->fetchCollection(true);
+    changeRecorder()->setChangeRecordingEnabled(false);
+    changeRecorder()->ignoreSession(Akonadi::Session::defaultSession());
+    changeRecorder()->collectionFetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
     changeRecorder()->setCollectionMonitored(Akonadi::Collection::root(), true);
 
-
     if (FollowUpReminderAgentSettings::enabled()) {
         mManager->load();
     }
 
-
     mTimer = new QTimer(this);
-    connect(mTimer, SIGNAL(timeout()), this, SLOT(reload()));
+    connect(mTimer, &QTimer::timeout, this, &FollowUpReminderAgent::reload);
     //Reload all each 24hours
-    mTimer->start(24*60*60*1000);
+    mTimer->start(24 * 60 * 60 * 1000);
 }
 
 FollowUpReminderAgent::~FollowUpReminderAgent()
@@ -72,11 +74,12 @@ FollowUpReminderAgent::~FollowUpReminderAgent()
 
 void FollowUpReminderAgent::setEnableAgent(bool enabled)
 {
-    if (FollowUpReminderAgentSettings::self()->enabled() == enabled)
+    if (FollowUpReminderAgentSettings::self()->enabled() == enabled) {
         return;
+    }
 
     FollowUpReminderAgentSettings::self()->setEnabled(enabled);
-    FollowUpReminderAgentSettings::self()->writeConfig();
+    FollowUpReminderAgentSettings::self()->save();
     if (enabled) {
         mManager->load();
         mTimer->start();
@@ -95,10 +98,10 @@ void FollowUpReminderAgent::showConfigureDialog(qlonglong windowId)
     QPointer<FollowUpReminderInfoDialog> dialog = new FollowUpReminderInfoDialog();
     dialog->load();
     if (windowId) {
-#ifndef Q_WS_WIN
-        KWindowSystem::setMainWindow( dialog, windowId );
+#ifndef Q_OS_WIN
+        KWindowSystem::setMainWindow(dialog, windowId);
 #else
-        KWindowSystem::setMainWindow( dialog, (HWND)windowId );
+        KWindowSystem::setMainWindow(dialog, (HWND)windowId);
 #endif
     }
     if (dialog->exec()) {
@@ -110,18 +113,19 @@ void FollowUpReminderAgent::showConfigureDialog(qlonglong windowId)
     delete dialog;
 }
 
-void FollowUpReminderAgent::configure( WId windowId )
+void FollowUpReminderAgent::configure(WId windowId)
 {
     showConfigureDialog((qulonglong)windowId);
 }
 
-void FollowUpReminderAgent::itemAdded( const Akonadi::Item &item, const Akonadi::Collection &collection )
+void FollowUpReminderAgent::itemAdded(const Akonadi::Item &item, const Akonadi::Collection &collection)
 {
-    if (!enabledAgent())
+    if (!enabledAgent()) {
         return;
+    }
 
-    if ( item.mimeType() != KMime::Message::mimeType() ) {
-        kDebug() << "FollowUpReminderAgent::itemAdded called for a non-message item!";
+    if (item.mimeType() != KMime::Message::mimeType()) {
+        qCDebug(FOLLOWUPREMINDERAGENT_LOG) << "FollowUpReminderAgent::itemAdded called for a non-message item!";
         return;
     }
     mManager->checkFollowUp(item, collection);
@@ -140,5 +144,5 @@ QString FollowUpReminderAgent::printDebugInfo()
     return mManager->printDebugInfo();
 }
 
-AKONADI_AGENT_MAIN( FollowUpReminderAgent )
+AKONADI_AGENT_MAIN(FollowUpReminderAgent)
 
