@@ -23,48 +23,51 @@
 #include "sendlateragentadaptor.h"
 #include "sendlateragentsettings.h"
 #include "sendlaterremovemessagejob.h"
-
+#include "sendlateragent_debug.h"
 #include <Akonadi/KMime/SpecialMailCollections>
-#include <Akonadi/AgentInstance>
-#include <Akonadi/AgentManager>
-#include <akonadi/dbusconnectionpool.h>
-#include <akonadi/changerecorder.h>
-#include <akonadi/itemfetchscope.h>
-#include <akonadi/session.h>
-#include <Akonadi/AttributeFactory>
-#include <Akonadi/CollectionFetchScope>
+#include <AgentInstance>
+#include <AgentManager>
+#include <kdbusconnectionpool.h>
+#include <changerecorder.h>
+#include <itemfetchscope.h>
+#include <AkonadiCore/session.h>
+#include <AttributeFactory>
+#include <CollectionFetchScope>
 #include <KMime/Message>
 
 #include <KWindowSystem>
-#include <KLocale>
+#include <Kdelibs4ConfigMigrator>
 
 #include <QPointer>
 
 //#define DEBUG_SENDLATERAGENT 1
 
 SendLaterAgent::SendLaterAgent(const QString &id)
-    : Akonadi::AgentBase( id ),
+    : Akonadi::AgentBase(id),
       mAgentInitialized(false)
 {
-    mManager = new SendLaterManager(this);
-    connect(mManager, SIGNAL(needUpdateConfigDialogBox()), SIGNAL(needUpdateConfigDialogBox()));
-    KGlobal::locale()->insertCatalog( QLatin1String("akonadi_sendlater_agent") );
-    new SendLaterAgentAdaptor( this );
-    Akonadi::DBusConnectionPool::threadConnection().registerObject( QLatin1String( "/SendLaterAgent" ), this, QDBusConnection::ExportAdaptors );
-    Akonadi::DBusConnectionPool::threadConnection().registerService( QLatin1String( "org.freedesktop.Akonadi.SendLaterAgent" ) );
+    Kdelibs4ConfigMigrator migrate(QStringLiteral("sendlateragent"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("akonadi_sendlater_agentrc") << QStringLiteral("akonadi_sendlater_agent.notifyrc"));
+    migrate.migrate();
 
-    changeRecorder()->setMimeTypeMonitored( KMime::Message::mimeType() );
-    changeRecorder()->itemFetchScope().setCacheOnly( true );
-    changeRecorder()->itemFetchScope().setFetchModificationTime( false );
-    changeRecorder()->setChangeRecordingEnabled( false );
-    changeRecorder()->ignoreSession( Akonadi::Session::defaultSession() );
+    mManager = new SendLaterManager(this);
+    connect(mManager, &SendLaterManager::needUpdateConfigDialogBox, this, &SendLaterAgent::needUpdateConfigDialogBox);
+    new SendLaterAgentAdaptor(this);
+    KDBusConnectionPool::threadConnection().registerObject(QStringLiteral("/SendLaterAgent"), this, QDBusConnection::ExportAdaptors);
+    KDBusConnectionPool::threadConnection().registerService(QStringLiteral("org.freedesktop.Akonadi.SendLaterAgent"));
+
+    changeRecorder()->setMimeTypeMonitored(KMime::Message::mimeType());
+    changeRecorder()->itemFetchScope().setCacheOnly(true);
+    changeRecorder()->itemFetchScope().setFetchModificationTime(false);
+    changeRecorder()->setChangeRecordingEnabled(false);
+    changeRecorder()->ignoreSession(Akonadi::Session::defaultSession());
     setNeedsNetwork(true);
 
     if (SendLaterAgentSettings::enabled()) {
 #ifdef DEBUG_SENDLATERAGENT
         QTimer::singleShot(1000, this, SLOT(slotStartAgent()));
 #else
-        QTimer::singleShot(1000*60*4, this, SLOT(slotStartAgent()));
+        QTimer::singleShot(1000 * 60 * 4, this, SLOT(slotStartAgent()));
 #endif
     }
 }
@@ -76,11 +79,12 @@ SendLaterAgent::~SendLaterAgent()
 void SendLaterAgent::slotStartAgent()
 {
     mAgentInitialized = true;
-    if (isOnline())
+    if (isOnline()) {
         mManager->load();
+    }
 }
 
-void SendLaterAgent::doSetOnline( bool online )
+void SendLaterAgent::doSetOnline(bool online)
 {
     if (mAgentInitialized) {
         if (online) {
@@ -93,18 +97,20 @@ void SendLaterAgent::doSetOnline( bool online )
 
 void SendLaterAgent::reload()
 {
-    qDebug()<<" void SendLaterAgent::reload()";
-    if (SendLaterAgentSettings::enabled())
+    qCDebug(SENDLATERAGENT_LOG) << " void SendLaterAgent::reload()";
+    if (SendLaterAgentSettings::enabled()) {
         mManager->load(true);
+    }
 }
 
 void SendLaterAgent::setEnableAgent(bool enabled)
 {
-    if (SendLaterAgentSettings::enabled() == enabled)
+    if (SendLaterAgentSettings::enabled() == enabled) {
         return;
+    }
 
     SendLaterAgentSettings::setEnabled(enabled);
-    SendLaterAgentSettings::self()->writeConfig();
+    SendLaterAgentSettings::self()->save();
     if (enabled) {
         mManager->load();
     } else {
@@ -117,7 +123,7 @@ bool SendLaterAgent::enabledAgent() const
     return SendLaterAgentSettings::enabled();
 }
 
-void SendLaterAgent::configure( WId windowId )
+void SendLaterAgent::configure(WId windowId)
 {
     showConfigureDialog((qlonglong)windowId);
 }
@@ -131,14 +137,14 @@ void SendLaterAgent::showConfigureDialog(qlonglong windowId)
 {
     QPointer<SendLaterConfigureDialog> dialog = new SendLaterConfigureDialog();
     if (windowId) {
-#ifndef Q_WS_WIN
-        KWindowSystem::setMainWindow( dialog, windowId );
+#ifndef Q_OS_WIN
+        KWindowSystem::setMainWindow(dialog, windowId);
 #else
-        KWindowSystem::setMainWindow( dialog, (HWND)windowId );
+        KWindowSystem::setMainWindow(dialog, (HWND)windowId);
 #endif
     }
-    connect(this, SIGNAL(needUpdateConfigDialogBox()), dialog, SLOT(slotNeedToReloadConfig()));
-    connect(dialog, SIGNAL(sendNow(Akonadi::Item::Id)), this, SLOT(slotSendNow(Akonadi::Item::Id)));
+    connect(this, &SendLaterAgent::needUpdateConfigDialogBox, dialog.data(), &SendLaterConfigureDialog::slotNeedToReloadConfig);
+    connect(dialog.data(), &SendLaterConfigureDialog::sendNow, this, &SendLaterAgent::slotSendNow);
     if (dialog->exec()) {
         mManager->load();
         QList<Akonadi::Item::Id> listMessage = dialog->messagesToRemove();
@@ -151,10 +157,10 @@ void SendLaterAgent::showConfigureDialog(qlonglong windowId)
     delete dialog;
 }
 
-void SendLaterAgent::itemsRemoved( const Akonadi::Item::List &items )
+void SendLaterAgent::itemsRemoved(const Akonadi::Item::List &items)
 {
-    Q_FOREACH(const Akonadi::Item &item, items) {
-       mManager->itemRemoved(item.id());
+    Q_FOREACH (const Akonadi::Item &item, items) {
+        mManager->itemRemoved(item.id());
     }
 }
 
@@ -171,5 +177,5 @@ QString SendLaterAgent::printDebugInfo()
     return mManager->printDebugInfo();
 }
 
-AKONADI_AGENT_MAIN( SendLaterAgent )
+AKONADI_AGENT_MAIN(SendLaterAgent)
 
