@@ -41,7 +41,7 @@ Command::Private::Private() : parentWidget()
 {
 }
 
-Command::Command( QObject* parent ) : QObject( parent ), d( new Private )
+Command::Command(QObject *parent) : QObject(parent), d(new Private)
 {
 
 }
@@ -51,12 +51,12 @@ Command::~Command()
     delete d;
 }
 
-QWidget* Command::parentWidget() const
+QWidget *Command::parentWidget() const
 {
     return d->parentWidget;
 }
 
-void Command::setParentWidget( QWidget* parentWidget )
+void Command::setParentWidget(QWidget *parentWidget)
 {
     d->parentWidget = parentWidget;
 }
@@ -64,7 +64,7 @@ void Command::setParentWidget( QWidget* parentWidget )
 void Command::start()
 {
     doStart();
-    emit started();
+    Q_EMIT started();
 }
 
 void Command::abort()
@@ -74,15 +74,14 @@ void Command::abort()
 
 void Command::done()
 {
-    emit finished();
+    Q_EMIT finished();
     deleteLater();
 }
 
 void Command::waitForFinished()
 {
     QEventLoop loop;
-    connect( this, SIGNAL(finished()), &loop, SLOT(quit()) );
+    connect(this, &Command::finished, &loop, &QEventLoop::quit);
     loop.exec();
 }
 
-#include "command.moc"
