@@ -26,7 +26,7 @@
 #include "ui/configurationdialog.h"
 #include "sync/feedsync.h"
 
-#include <KAction>
+#include <QAction>
 #include <KActionMenu>
 #include <KActionCollection>
 #include <KLocalizedString>
@@ -37,25 +37,24 @@ using namespace feedsync;
 
 K_PLUGIN_FACTORY(OnlineSyncPluginFactory,
                  registerPlugin<Akregator::OnlineSyncPluginIface>();
-)
-K_EXPORT_PLUGIN(OnlineSyncPluginFactory( "akregator_onlinesync_plugin" ) )
+                )
 
-
-OnlineSyncPluginIface::OnlineSyncPluginIface( QObject* parent, const QList<QVariant>& args ) : Plugin( parent ), m_impl( new OnlineSyncPlugin( parent, args ) )
+OnlineSyncPluginIface::OnlineSyncPluginIface(QObject *parent, const QList<QVariant> &args) : Plugin(parent), m_impl(new OnlineSyncPlugin(parent, args))
 {
 }
 
-OnlineSyncPluginIface::~OnlineSyncPluginIface() {
+OnlineSyncPluginIface::~OnlineSyncPluginIface()
+{
     delete m_impl;
 }
 
-OnlineSyncPlugin::OnlineSyncPlugin( QObject* parent, const QList<QVariant>& args ) : KParts::Plugin( parent ), m_syncTool( new FeedSync( this ) )
-{ 
-    Q_UNUSED( args )
-    setComponentData( OnlineSyncPluginFactory::componentData() );
+OnlineSyncPlugin::OnlineSyncPlugin(QObject *parent, const QList<QVariant> &args) : KParts::Plugin(parent), m_syncTool(new FeedSync(this))
+{
+    Q_UNUSED(args)
+    setComponentData(OnlineSyncPluginFactory::componentData());
 
-    setXMLFile( "akregator_onlinesync_plugin.rc" , /*merge=*/true );
-    KActionCollection* coll = actionCollection();
+    setXMLFile("akregator_onlinesync_plugin.rc" , /*merge=*/true);
+    KActionCollection *coll = actionCollection();
     m_feedSyncMenu = coll->add<KActionMenu>("file_onlinesync_sync");
     m_feedSyncMenu->setText(i18n("Synchronize Feeds"));
 
@@ -65,82 +64,85 @@ OnlineSyncPlugin::OnlineSyncPlugin( QObject* parent, const QList<QVariant>& args
 
 OnlineSyncPlugin::~OnlineSyncPlugin()
 {
-    kDebug();
+    qDebug();
 }
 
 void OnlineSyncPlugin::updateActions()
 {
-    kDebug();
+    qDebug();
 
     // Clear the menubar
-    Q_FOREACH( KAction* const i, m_feedSyncActions )
-        m_feedSyncMenu->removeAction( i );
-    qDeleteAll( m_feedSyncActions );
+    Q_FOREACH (QAction *const i, m_feedSyncActions) {
+        m_feedSyncMenu->removeAction(i);
+    }
+    qDeleteAll(m_feedSyncActions);
     m_feedSyncActions.clear();
 
     // Fill the menubar
-    KActionCollection* coll = actionCollection();
-    KAction* action;
+    KActionCollection *coll = actionCollection();
+    QAction *action;
     // Read configuration
     const KConfig config("akregator_feedsyncrc");
-    Q_FOREACH ( const QString& groupname, config.groupList() ) {
-        if ( groupname.startsWith( QLatin1String("FeedSyncSource_") ) ) {
-            kDebug() << groupname;
-            KConfigGroup generalGroup( &config, groupname );
+    Q_FOREACH (const QString &groupname, config.groupList()) {
+        if (groupname.startsWith(QLatin1String("FeedSyncSource_"))) {
+            qDebug() << groupname;
+            KConfigGroup generalGroup(&config, groupname);
 
             action = coll->addAction(groupname);
-            action->setProperty("ConfigGroup",groupname);
+            action->setProperty("ConfigGroup", groupname);
             action->setProperty("SyncType", m_syncTool->Get);
-            action->setIcon(KIcon("mail-receive"));
-            action->setText(i18n("Get from %1",generalGroup.readEntry( "Identifier", QString() )));
+            action->setIcon(QIcon::fromTheme("mail-receive"));
+            action->setText(i18n("Get from %1", generalGroup.readEntry("Identifier", QString())));
             m_feedSyncMenu->addAction(action);
             m_feedSyncActions.append(action);
-            connect( action, SIGNAL(triggered(bool)), m_syncTool, SLOT(sync()) );
+            connect(action, &QAction::triggered, m_syncTool, &feedsync::FeedSync::sync);
 
             action = coll->addAction(groupname);
-            action->setProperty("ConfigGroup",groupname);
+            action->setProperty("ConfigGroup", groupname);
             action->setProperty("SyncType", m_syncTool->Send);
-            action->setIcon(KIcon("mail-send"));
-            action->setText(i18n("Send to %1",generalGroup.readEntry( "Identifier", QString() )));
+            action->setIcon(QIcon::fromTheme("mail-send"));
+            action->setText(i18n("Send to %1", generalGroup.readEntry("Identifier", QString())));
             m_feedSyncMenu->addAction(action);
             m_feedSyncActions.append(action);
-            connect( action, SIGNAL(triggered(bool)), m_syncTool, SLOT(sync()) );
+            connect(action, &QAction::triggered, m_syncTool, &feedsync::FeedSync::sync);
         }
     }
 
     action = coll->addAction("feedsync_manage");
-    action->setIcon(KIcon("application-rss+xml"));
+    action->setIcon(QIcon::fromTheme("application-rss+xml"));
     action->setText(i18n("Manage..."));
     m_feedSyncMenu->addAction(action);
     m_feedSyncActions.append(action);
-    connect(action, SIGNAL(triggered(bool)), this, SLOT(slotFeedSyncManage()));
+    connect(action, &QAction::triggered, this, &OnlineSyncPlugin::slotFeedSyncManage);
 }
 
 void OnlineSyncPlugin::doSynchronize()
 {
-    kDebug();
+    qDebug();
 }
 
 void OnlineSyncPlugin::slotFeedSyncManage()
 {
-    kDebug();
-    feedsync::ConfigurationDialog* dlg = new feedsync::ConfigurationDialog();
-    dlg->setAttribute( Qt::WA_DeleteOnClose );
-    connect( dlg, SIGNAL(finished()), this, SLOT(slotFeedSyncManageDone()) );
+    qDebug();
+    feedsync::ConfigurationDialog *dlg = new feedsync::ConfigurationDialog();
+    dlg->setAttribute(Qt::WA_DeleteOnClose);
+    connect(dlg, &feedsync::ConfigurationDialog::finished, this, &OnlineSyncPlugin::slotFeedSyncManageDone);
     dlg->show();
 }
 
 void OnlineSyncPlugin::slotFeedSyncManageDone()
 {
-    kDebug();
+    qDebug();
     updateActions();
 }
 
-void OnlineSyncPluginIface::insertGuiClients( KXMLGUIClient* parent ) {
-    parent->insertChildClient( m_impl );
+void OnlineSyncPluginIface::insertGuiClients(KXMLGUIClient *parent)
+{
+    parent->insertChildClient(m_impl);
 }
 
-void OnlineSyncPluginIface::removeGuiClients( KXMLGUIClient* parent ) {
-    parent->removeChildClient( m_impl );
+void OnlineSyncPluginIface::removeGuiClients(KXMLGUIClient *parent)
+{
+    parent->removeChildClient(m_impl);
 }
 
