@@ -28,82 +28,82 @@
 #include <QRegExp>
 
 #include <kactioncollection.h>
-#include <kdebug.h>
-#include <klocale.h>
-#include <kurl.h>
+#include "akregator_debug.h"
+#include <KLocalizedString>
+#include <QUrl>
 #include <kparts/browserextension.h>
 #include <kparts/part.h>
 
 #include <libkdepim/progresswidget/progressmanager.h>
 
-namespace Akregator {
-
+namespace Akregator
+{
 
 void Frame::slotSetTitle(const QString &s)
 {
-    if (m_title != s)
-    {
+    if (m_title != s) {
         m_title = s;
-        emit signalTitleChanged(this, s);
+        Q_EMIT signalTitleChanged(this, s);
     }
 }
 
-bool Frame::isLoading() const 
+bool Frame::isLoading() const
 {
     return m_loading;
 }
 
 void Frame::slotSetCaption(const QString &s)
 {
-    if(m_progressItem) m_progressItem->setLabel(s);
-    m_caption=s;
-    emit signalCaptionChanged(this, s);
+    if (m_progressItem) {
+        m_progressItem->setLabel(s);
+    }
+    m_caption = s;
+    Q_EMIT signalCaptionChanged(this, s);
 }
 
 void Frame::slotSetStatusText(const QString &s)
 {
-    m_statusText=s;
-    m_statusText.remove(QRegExp(QLatin1String("<[^>]*>")));
-    emit signalStatusText(this, m_statusText);
+    m_statusText = s;
+    m_statusText.remove(QRegExp(QStringLiteral("<[^>]*>")));
+    Q_EMIT signalStatusText(this, m_statusText);
 }
 
 void Frame::slotSetProgress(int a)
 {
-    if(m_progressItem) {
+    if (m_progressItem) {
         m_progressItem->setProgress((int)a);
     }
-    m_progress=a;
-    emit signalLoadingProgress(this, a);
+    m_progress = a;
+    Q_EMIT signalLoadingProgress(this, a);
 }
 
 void Frame::slotSetState(State state)
 {
-    m_state=state;
+    m_state = state;
 
-    switch (m_state)
-    {
-        case Frame::Started:
-            emit signalStarted(this);
-            break;
-        case Frame::Canceled:
-            emit signalCanceled(this, QString());
-            break;
-        case Frame::Idle:
-        case Frame::Completed:
-        default:
-            emit signalCompleted(this);
+    switch (m_state) {
+    case Frame::Started:
+        Q_EMIT signalStarted(this);
+        break;
+    case Frame::Canceled:
+        Q_EMIT signalCanceled(this, QString());
+        break;
+    case Frame::Idle:
+    case Frame::Completed:
+    default:
+        Q_EMIT signalCompleted(this);
     }
 }
 
-Frame::Frame(QWidget* parent)
-   : QWidget(parent)
+Frame::Frame(QWidget *parent)
+    : QWidget(parent)
 {
     m_title = i18n("Untitled");
-    m_state=Idle;
-    m_progress=-1;
-    m_progressItem=0;
+    m_state = Idle;
+    m_progress = -1;
+    m_progressItem = 0;
     m_isRemovable = true;
-    m_loading = false; 
+    m_loading = false;
     m_id = m_idCounter++;
 }
 
@@ -126,13 +126,11 @@ bool Frame::isRemovable() const
 
 Frame::~Frame()
 {
-    if(m_progressItem)
-    {
+    if (m_progressItem) {
         m_progressItem->setComplete();
     }
 }
 
-
 Frame::State Frame::state() const
 {
     return m_state;
@@ -156,50 +154,49 @@ QString Frame::statusText() const
 void Frame::slotSetStarted()
 {
     m_loading = true;
-    if(m_progressId.isNull() || m_progressId.isEmpty()) m_progressId = KPIM::ProgressManager::getUniqueID();
+    if (m_progressId.isNull() || m_progressId.isEmpty()) {
+        m_progressId = KPIM::ProgressManager::getUniqueID();
+    }
     m_progressItem = KPIM::ProgressManager::createProgressItem(m_progressId, title(), QString(), false);
     m_progressItem->setStatus(i18n("Loading..."));
     //connect(m_progressItem, SIGNAL(progressItemCanceled(KPIM::ProgressItem*)), SLOT(slotAbortFetch()));
-    m_state=Started;
-    emit signalStarted(this);
-    emit signalIsLoadingToggled(this, m_loading);
+    m_state = Started;
+    Q_EMIT signalStarted(this);
+    Q_EMIT signalIsLoadingToggled(this, m_loading);
 }
 
 void Frame::slotStop()
 {
-    if (m_loading)
-    {
+    if (m_loading) {
         m_loading = false;
-        emit signalIsLoadingToggled(this, false);
+        Q_EMIT signalIsLoadingToggled(this, false);
     }
 }
 
 void Frame::slotSetCanceled(const QString &s)
 {
     m_loading = false;
-    if(m_progressItem) 
-    {
+    if (m_progressItem) {
         m_progressItem->setStatus(i18n("Loading canceled"));
         m_progressItem->setComplete();
         m_progressItem = 0;
     }
-    m_state=Canceled;
-    emit signalCanceled(this, s);
-    emit signalIsLoadingToggled(this, m_loading);
+    m_state = Canceled;
+    Q_EMIT signalCanceled(this, s);
+    Q_EMIT signalIsLoadingToggled(this, m_loading);
 }
 
 void Frame::slotSetCompleted()
 {
-    m_loading = false; 
-    if(m_progressItem)
-    {
+    m_loading = false;
+    if (m_progressItem) {
         m_progressItem->setStatus(i18n("Loading completed"));
         m_progressItem->setComplete();
         m_progressItem = 0;
     }
-    m_state=Completed;
-    emit signalCompleted(this);
-    emit signalIsLoadingToggled(this, m_loading);
+    m_state = Completed;
+    Q_EMIT signalCompleted(this);
+    Q_EMIT signalIsLoadingToggled(this, m_loading);
 }
 
 int Frame::progress() const
@@ -207,10 +204,10 @@ int Frame::progress() const
     return m_progress;
 }
 
-MainFrame::MainFrame(QWidget* parent, KParts::ReadOnlyPart* part, QWidget* visibleWidget) : Frame(parent), m_part(part)
+MainFrame::MainFrame(QWidget *parent, KParts::ReadOnlyPart *part, QWidget *visibleWidget) : Frame(parent), m_part(part)
 {
     setRemovable(false);
-    QGridLayout* layout = new QGridLayout(this);
+    QGridLayout *layout = new QGridLayout(this);
     layout->setMargin(0);
     layout->addWidget(visibleWidget, 0, 0);
     setLayout(layout);
@@ -220,9 +217,9 @@ MainFrame::~MainFrame()
 {
 }
 
-KUrl MainFrame::url() const
+QUrl MainFrame::url() const
 {
-    return KUrl();
+    return QUrl();
 }
 
 } // namespace Akregator
