@@ -22,13 +22,15 @@
 #include "pimcommon/storageservice/storageservicemanager.h"
 
 #include <KLocalizedString>
-#include <KStandardDirs>
+
 #include <KMessageBox>
 #include <KUrlRequester>
+#include <QUrl>
 
 #include <QVBoxLayout>
 #include <QProcess>
 #include <QPushButton>
+#include <QStandardPaths>
 
 StorageServiceConfigureWidget::StorageServiceConfigureWidget(QWidget *parent)
     : PimCommon::StorageServiceConfigureWidget(parent)
@@ -43,13 +45,13 @@ StorageServiceConfigureWidget::~StorageServiceConfigureWidget()
 
 void StorageServiceConfigureWidget::loadSettings()
 {
-    downloadFolder()->setUrl(KUrl(Settings::self()->downloadDirectory()));
+    downloadFolder()->setUrl(QUrl::fromLocalFile(Settings::self()->downloadDirectory()));
 }
 
 void StorageServiceConfigureWidget::writeSettings()
 {
     Settings::self()->setDownloadDirectory(downloadFolder()->url().path());
-    Settings::self()->writeConfig();
+    Settings::self()->save();
 }
 
 ConfigureStorageServiceWidget::ConfigureStorageServiceWidget(PimCommon::StorageServiceManager *storageManager, QWidget *parent)
@@ -58,7 +60,7 @@ ConfigureStorageServiceWidget::ConfigureStorageServiceWidget(PimCommon::StorageS
 {
     QVBoxLayout *lay = new QVBoxLayout;
     mStorageServiceConfigureWidget = new StorageServiceConfigureWidget;
-    connect(mStorageServiceConfigureWidget, SIGNAL(changed()), this, SIGNAL(changed()));
+    connect(mStorageServiceConfigureWidget, &StorageServiceConfigureWidget::changed, this, &ConfigureStorageServiceWidget::changed);
     lay->addWidget(mStorageServiceConfigureWidget);
 
     QHBoxLayout *hbox = new QHBoxLayout;
@@ -66,10 +68,10 @@ ConfigureStorageServiceWidget::ConfigureStorageServiceWidget(PimCommon::StorageS
     hbox->addWidget(mManageStorageService);
     hbox->addStretch();
     lay->addLayout(hbox);
-    if (KStandardDirs::findExe(QLatin1String("storageservicemanager")).isEmpty()) {
+    if (QStandardPaths::findExecutable(QStringLiteral("storageservicemanager")).isEmpty()) {
         mManageStorageService->setEnabled(false);
     } else {
-        connect(mManageStorageService, SIGNAL(clicked(bool)), this, SLOT(slotManageStorageService()));
+        connect(mManageStorageService, &QPushButton::clicked, this, &ConfigureStorageServiceWidget::slotManageStorageService);
     }
     setLayout(lay);
     //TODO need to implement save/load from KDialogConfig
@@ -89,10 +91,10 @@ ConfigureStorageServiceWidget::~ConfigureStorageServiceWidget()
 
 void ConfigureStorageServiceWidget::slotManageStorageService()
 {
-    if ( !QProcess::startDetached(QLatin1String("storageservicemanager") ) )
-        KMessageBox::error( this, i18n( "Could not start storage service manager; "
-                                        "please check your installation." ),
-                            i18n( "KMail Error" ) );
+    if (!QProcess::startDetached(QStringLiteral("storageservicemanager")))
+        KMessageBox::error(this, i18n("Could not start storage service manager; "
+                                      "please check your installation."),
+                           i18n("KMail Error"));
 }
 
 void ConfigureStorageServiceWidget::save()
@@ -106,4 +108,3 @@ void ConfigureStorageServiceWidget::doLoadFromGlobalSettings()
     mStorageServiceConfigureWidget->loadSettings();
 }
 
-#include "moc_configurestorageservicewidget.cpp"
