@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,20 +26,21 @@ class StorageServiceConfigureWidget : public PimCommon::StorageServiceConfigureW
 {
     Q_OBJECT
 public:
-    explicit StorageServiceConfigureWidget(QWidget *parent=0);
+    explicit StorageServiceConfigureWidget(QWidget *parent = Q_NULLPTR);
     ~StorageServiceConfigureWidget();
-    virtual void loadSettings();
-    virtual void writeSettings();
+    void loadSettings() Q_DECL_OVERRIDE;
+    void writeSettings() Q_DECL_OVERRIDE;
 };
 
-namespace PimCommon {
+namespace PimCommon
+{
 class StorageServiceManager;
 }
 class ConfigureStorageServiceWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit ConfigureStorageServiceWidget(PimCommon::StorageServiceManager *storageManager, QWidget *parent=0);
+    explicit ConfigureStorageServiceWidget(PimCommon::StorageServiceManager *storageManager, QWidget *parent = Q_NULLPTR);
     ~ConfigureStorageServiceWidget();
 
     void save();
@@ -48,7 +49,7 @@ public:
 Q_SIGNALS:
     void changed();
 
-private slots:
+private Q_SLOTS:
     void slotManageStorageService();
 
 private:
