@@ -22,21 +22,22 @@
 #ifndef CALENDARSUPPORT_INCIDENCEVIEWER_P_H
 #define CALENDARSUPPORT_INCIDENCEVIEWER_P_H
 
-#include <KTextBrowser>
+#include <QTextBrowser>
 
-namespace CalendarSupport {
-
-class TextBrowser : public KTextBrowser
+namespace CalendarSupport
 {
-  Q_OBJECT
 
-  public:
-    explicit TextBrowser( QWidget *parent = 0 );
+class TextBrowser : public QTextBrowser
+{
+    Q_OBJECT
 
-    void setSource( const QUrl &name );
+public:
+    explicit TextBrowser(QWidget *parent = Q_NULLPTR);
 
-  Q_SIGNALS:
-    void attachmentUrlClicked( const QString &uri );
+    void setSource(const QUrl &name);
+
+Q_SIGNALS:
+    void attachmentUrlClicked(const QString &uri);
 };
 
 }
