@@ -27,19 +27,22 @@
 
 #include "eventviews_export.h"
 #include "agendaitem.h"
+#include "viewcalendar.h"
 
-#include <Akonadi/Item>
+#include <Item>
 
 #include <KCalCore/Todo>
 
 #include <QFrame>
 #include <QScrollArea>
 
-namespace Akonadi {
-  class IncidenceChanger;
+namespace Akonadi
+{
+class IncidenceChanger;
 }
 
-namespace EventViews {
+namespace EventViews
+{
 
 class Agenda;
 class AgendaItem;
@@ -47,70 +50,70 @@ class AgendaView;
 
 class EVENTVIEWS_EXPORT MarcusBains : public QFrame
 {
-  Q_OBJECT
-  public:
-    explicit MarcusBains( EventView *eventView, Agenda *agenda = 0 );
-    void updateLocationRecalc( bool recalculate = false );
+    Q_OBJECT
+public:
+    explicit MarcusBains(EventView *eventView, Agenda *agenda = Q_NULLPTR);
+    void updateLocationRecalc(bool recalculate = false);
     virtual ~MarcusBains();
 
-  public Q_SLOTS:
+public Q_SLOTS:
     void updateLocation();
 
-  private:
+private:
     class Private;
     Private *const d;
 };
 
 class EVENTVIEWS_EXPORT Agenda : public QWidget
 {
-  Q_OBJECT
-  public:
-    Agenda ( AgendaView *agendaView, QScrollArea *scrollArea,
-             int columns, int rows, int rowSize, bool isInteractive );
+    Q_OBJECT
+public:
+    Agenda(AgendaView *agendaView, QScrollArea *scrollArea,
+           int columns, int rows, int rowSize, bool isInteractive);
 
-    Agenda ( AgendaView *agendaView, QScrollArea *scrollArea, int columns, bool isInteractive );
+    Agenda(AgendaView *agendaView, QScrollArea *scrollArea, int columns, bool isInteractive);
 
     virtual ~Agenda();
 
-    Akonadi::Item selectedIncidence() const;
+    KCalCore::Incidence::Ptr selectedIncidence() const;
     QDate selectedIncidenceDate() const;
-    QSize sizeHint() const;
-    QSize minimumSizeHint() const;
+    QSize sizeHint() const Q_DECL_OVERRIDE;
+    QSize minimumSizeHint() const Q_DECL_OVERRIDE;
     QSize minimumSize() const;
     int minimumHeight() const;
     // QSizePolicy sizePolicy() const;
     int contentsY() const
     {
-      return -y();
+        return -y();
     }
 
     int contentsX() const
     {
-      return x();
+        return x();
     }
 
     QScrollBar *verticalScrollBar() const;
 
     QScrollArea *scrollArea() const;
 
-    AgendaItem::List agendaItems( Akonadi::Entity::Id id ) const;
+    AgendaItem::List agendaItems(const QString &uid) const;
 
     /**
       Returns the uid of the last incidence that was selected. This
       persists across reloads and clear, so that if the same uid
       reappears, it can be reselected.
     */
-    Akonadi::Item::Id lastSelectedItemId() const;
+    QString lastSelectedItemUid() const;
 
-    bool eventFilter ( QObject *, QEvent * );
+    bool eventFilter(QObject *, QEvent *) Q_DECL_OVERRIDE;
 
-    void paintEvent( QPaintEvent * );
+    void paintEvent(QPaintEvent *) Q_DECL_OVERRIDE;
 
-    QPoint contentsToGrid ( const QPoint &pos ) const;
-    QPoint gridToContents ( const QPoint &gpos ) const;
+    QPoint contentsToGrid(const QPoint &pos) const;
+    QPoint gridToContents(const QPoint &gpos) const;
 
-    int timeToY ( const QTime &time ) const;
-    QTime gyToTime ( int y ) const;
+    int timeToY(const QTime &time) const;
+    QTime gyToTime(int y) const;
 
     QVector<int> minContentsY() const;
     QVector<int> maxContentsY() const;
@@ -118,16 +121,16 @@ class EVENTVIEWS_EXPORT Agenda : public QWidget
     int visibleContentsYMin() const;
     int visibleContentsYMax() const;
 
-    void setStartTime( const QTime &startHour );
+    void setStartTime(const QTime &startHour);
 
-    AgendaItem::QPtr insertItem ( const Akonadi::Item &incidence, const KDateTime &occurrenceDateTime, int X, int YTop,
-                                  int YBottom, int itemPos, int itemCount, bool isSelected );
+    AgendaItem::QPtr insertItem(const KCalCore::Incidence::Ptr &incidence, const KDateTime &recurrenceId, int X, int YTop,
+                                int YBottom, int itemPos, int itemCount, bool isSelected);
 
-    AgendaItem::QPtr insertAllDayItem ( const Akonadi::Item &event, const KDateTime &occurrenceDateTime, int XBegin,
-                                        int XEnd, bool isSelected );
+    AgendaItem::QPtr insertAllDayItem(const KCalCore::Incidence::Ptr &event, const KDateTime &recurrenceId, int XBegin,
+                                      int XEnd, bool isSelected);
 
-    void insertMultiItem ( const Akonadi::Item &event, const KDateTime &occurrenceDateTime, int XBegin, int XEnd,
-                           int YTop, int YBottom, bool isSelected );
+    void insertMultiItem(const KCalCore::Incidence::Ptr &event, const KDateTime &recurrenceId, int XBegin, int XEnd,
+                         int YTop, int YBottom, bool isSelected);
 
     /**
       Removes an event and all its multi-items from the agenda. This function
@@ -136,9 +139,9 @@ class EVENTVIEWS_EXPORT Agenda : public QWidget
       slot deleteItemsToDelete() (called by QTimer::singleShot ).
       @param incidence The pointer to the incidence that should be removed.
     */
-    void removeIncidence( const KCalCore::Incidence::Ptr &incidence );
+    void removeIncidence(const KCalCore::Incidence::Ptr &incidence);
 
-    void changeColumns( int columns );
+    void changeColumns(int columns);
 
     int columns() const;
     int rows() const;
@@ -153,22 +156,22 @@ class EVENTVIEWS_EXPORT Agenda : public QWidget
 
     void checkScrollBoundaries();
 
-    void setHolidayMask( QVector<bool> * );
+    void setHolidayMask(QVector<bool> *);
 
-    void setDateList( const KCalCore::DateList &selectedDates );
+    void setDateList(const KCalCore::DateList &selectedDates);
     KCalCore::DateList dateList() const;
 
-    void setCalendar( const Akonadi::ETMCalendar::Ptr &cal );
+    void setCalendar(const EventViews::MultiViewCalendar::Ptr &cal);
 
-    void setIncidenceChanger( Akonadi::IncidenceChanger *changer );
+    void setIncidenceChanger(Akonadi::IncidenceChanger *changer);
 
-  public Q_SLOTS:
+public Q_SLOTS:
     void scrollUp();
     void scrollDown();
 
-    void checkScrollBoundaries( int );
+    void checkScrollBoundaries(int);
 
-    /** Deselect selected items. This function does not emit any signals. */
+    /** Deselect selected items. This function does not Q_EMIT any signals. */
     void deselectItem();
 
     void clearSelection();
@@ -178,7 +181,7 @@ class EVENTVIEWS_EXPORT Agenda : public QWidget
       deselected. This function emits the itemSelected(bool) signal to inform
       about selection/deselection of events.
     */
-    void selectItem( AgendaItem::QPtr );
+    void selectItem(const AgendaItem::QPtr &);
 
     /**
       Selects the item associated with a given Akonadi Item id.
@@ -186,78 +189,78 @@ class EVENTVIEWS_EXPORT Agenda : public QWidget
       @param id the item id of the item that should be selected. If no such
       item exists, the selection is not changed.
     */
-    void selectItemByItemId( const Akonadi::Item::Id &id );
-    void selectItem( const Akonadi::Item &item );
+    void selectIncidenceByUid(const QString &id);
+    void selectItem(const Akonadi::Item &item);
 
-    bool removeAgendaItem( AgendaItem::QPtr item );
-    void showAgendaItem( AgendaItem::QPtr item );
+    bool removeAgendaItem(const AgendaItem::QPtr &item);
+    void showAgendaItem(const AgendaItem::QPtr &item);
 
-  Q_SIGNALS:
+Q_SIGNALS:
     void newEventSignal();
-    void newTimeSpanSignal( const QPoint &, const QPoint & );
+    void newTimeSpanSignal(const QPoint &, const QPoint &);
     void newStartSelectSignal();
 
-    void showIncidenceSignal( const Akonadi::Item & );
-    void editIncidenceSignal( const Akonadi::Item & );
-    void deleteIncidenceSignal( const Akonadi::Item & );
-    void showIncidencePopupSignal( const Akonadi::Item &, const QDate &);
+    void showIncidenceSignal(const KCalCore::Incidence::Ptr &);
+    void editIncidenceSignal(const KCalCore::Incidence::Ptr &);
+    void deleteIncidenceSignal(const KCalCore::Incidence::Ptr &);
+    void showIncidencePopupSignal(const KCalCore::Incidence::Ptr &, const QDate &);
 
     void showNewEventPopupSignal();
 
-    void incidenceSelected( const Akonadi::Item &, const QDate & );
+    void incidenceSelected(const KCalCore::Incidence::Ptr &, const QDate &);
 
-    void lowerYChanged( int );
-    void upperYChanged( int );
+    void lowerYChanged(int);
+    void upperYChanged(int);
 
-    void startDragSignal( const Akonadi::Item & );
-    void droppedIncidences( const KCalCore::Incidence::List &, const QPoint &gpos, bool allDay );
-    void droppedIncidences( const QList<KUrl> &, const QPoint &gpos, bool allDay );
+    void startDragSignal(const KCalCore::Incidence::Ptr &);
+    void droppedIncidences(const KCalCore::Incidence::List &, const QPoint &gpos, bool allDay);
+    void droppedIncidences(const QList<QUrl> &, const QPoint &gpos, bool allDay);
 
-    void enableAgendaUpdate( bool enable );
-    void zoomView( const int delta, const QPoint &pos, const Qt::Orientation );
+    void enableAgendaUpdate(bool enable);
+    void zoomView(const int delta, const QPoint &pos, const Qt::Orientation);
 
-    void mousePosSignal( const QPoint &pos );
+    void mousePosSignal(const QPoint &pos);
     void enterAgenda();
     void leaveAgenda();
 
-    void gridSpacingYChanged( double );
+    void gridSpacingYChanged(double);
 
-  private:
+private:
     enum MouseActionType {
-      NOP,
-      MOVE,
-      SELECT,
-      RESIZETOP,
-      RESIZEBOTTOM,
-      RESIZELEFT,
-      RESIZERIGHT
+        NOP,
+        MOVE,
+        SELECT,
+        RESIZETOP,
+        RESIZEBOTTOM,
+        RESIZELEFT,
+        RESIZERIGHT
     };
 
-    AgendaItem::QPtr createAgendaItem( const Akonadi::Item &item, int itemPos,
-                                       int itemCount, const KDateTime &qd, bool isSelected );
+    AgendaItem::QPtr createAgendaItem(const KCalCore::Incidence::Ptr &incidence, int itemPos,
+                                      int itemCount, const KDateTime &recurrentId, bool isSelected);
 
-  protected:
+protected:
     /**
       Draw the background grid of the agenda.
       @p cw grid width
       @p ch grid height
     */
-    void drawContents( QPainter *p, int cx, int cy, int cw, int ch );
+    void drawContents(QPainter *p, int cx, int cy, int cw, int ch);
 
-    int columnWidth( int column ) const;
-    virtual void resizeEvent ( QResizeEvent * );
+    int columnWidth(int column) const;
+    void resizeEvent(QResizeEvent *) Q_DECL_OVERRIDE;
 
     /** Handles mouse events. Called from eventFilter */
-    virtual bool eventFilter_mouse ( QObject *, QMouseEvent * );
+    virtual bool eventFilter_mouse(QObject *, QMouseEvent *);
 #ifndef QT_NO_WHEELEVENT
     /** Handles mousewheel events. Called from eventFilter */
-    virtual bool eventFilter_wheel ( QObject *, QWheelEvent * );
+    virtual bool eventFilter_wheel(QObject *, QWheelEvent *);
 #endif
     /** Handles key events. Called from eventFilter */
-    virtual bool eventFilter_key ( QObject *, QKeyEvent * );
+    virtual bool eventFilter_key(QObject *, QKeyEvent *);
 
     /** Handles drag and drop events. Called from eventFilter */
-    virtual bool eventFilter_drag( QObject *, QDropEvent * );
+    virtual bool eventFilter_drag(QObject *, QDropEvent *);
 
     /** returns RESIZELEFT if pos is near the lower edge of the action item,
       RESIZERIGHT if pos is near the higher edge, and MOVE otherwise.
@@ -268,58 +271,58 @@ class EVENTVIEWS_EXPORT Agenda : public QWidget
         @param pos The current mouse position
         @param item The affected item
     */
-    MouseActionType isInResizeArea( bool horizontal, const QPoint &pos, AgendaItem::QPtr item );
+    MouseActionType isInResizeArea(bool horizontal, const QPoint &pos, const AgendaItem::QPtr &item);
     /** Return whether the cell specified by the grid point belongs to the current select
     */
-    bool ptInSelection( const QPoint &gpos ) const;
+    bool ptInSelection(const QPoint &gpos) const;
 
     /** Start selecting time span. */
-    void startSelectAction( const QPoint &viewportPos );
+    void startSelectAction(const QPoint &viewportPos);
 
     /** Select time span. */
-    void performSelectAction( const QPoint &viewportPos );
+    void performSelectAction(const QPoint &viewportPos);
 
     /** Emd selecting time span. */
-    void endSelectAction( const QPoint &viewportPos );
+    void endSelectAction(const QPoint &viewportPos);
 
     /** Start moving/resizing agenda item */
-    void startItemAction( const QPoint &viewportPos );
+    void startItemAction(const QPoint &viewportPos);
 
     /** Move/resize agenda item */
-    void performItemAction( const QPoint &viewportPos );
+    void performItemAction(const QPoint &viewportPos);
 
     /** End moving/resizing agenda item */
     void endItemAction();
 
     /** Set cursor, when no item action is in progress */
-    void setNoActionCursor( AgendaItem::QPtr moveItem, const QPoint &viewportPos );
+    void setNoActionCursor(const AgendaItem::QPtr &moveItem, const QPoint &viewportPos);
     /** Sets the cursor according to the given action type.
         @param actionType The type of action for which the cursor should be set.
         @param acting If true, the corresponding action is running (e.g. the
         item is currently being moved by the user). If false the
         cursor should just indicate that the corresponding
         action is possible */
-    void setActionCursor( int actionType, bool acting=false );
+    void setActionCursor(int actionType, bool acting = false);
 
     /** calculate the width of the column subcells of the given item */
-    double calcSubCellWidth( AgendaItem::QPtr item );
+    double calcSubCellWidth(const AgendaItem::QPtr &item);
     /** Move and resize the given item to the correct position */
-    void placeAgendaItem( AgendaItem::QPtr item, double subCellWidth );
+    void placeAgendaItem(const AgendaItem::QPtr &item, double subCellWidth);
     /** Place agenda item in agenda and adjust other cells if necessary */
-    void placeSubCells( AgendaItem::QPtr placeItem );
+    void placeSubCells(const AgendaItem::QPtr &placeItem);
     /** Place the agenda item at the correct position (ignoring conflicting items) */
-    void adjustItemPosition( AgendaItem::QPtr item );
+    void adjustItemPosition(const AgendaItem::QPtr &item);
 
     /** Process the keyevent, including the ignored keyevents of eventwidgets.
      * Implements pgup/pgdn and cursor key navigation in the view.
      */
-    void keyPressEvent( QKeyEvent * );
+    void keyPressEvent(QKeyEvent *) Q_DECL_OVERRIDE;
 
     void calculateWorkingHours();
 
-    virtual void contentsMousePressEvent ( QMouseEvent * );
+    virtual void contentsMousePressEvent(QMouseEvent *);
 
-  protected Q_SLOTS:
+protected Q_SLOTS:
     /** delete the items that are queued for deletion */
     void deleteItemsToDelete();
     /** Resizes all the child elements after the size of the agenda
@@ -328,24 +331,24 @@ class EVENTVIEWS_EXPORT Agenda : public QWidget
         lot of time / does a lot of resizes.... see bug 80114 */
     void resizeAllContents();
 
-  private:
+private:
     void init();
     void marcus_bains();
 
-  private:
+private:
     class Private;
     Private *const d;
 };
 
 class EVENTVIEWS_EXPORT AgendaScrollArea : public QScrollArea
 {
-  public:
-    AgendaScrollArea( bool allDay, AgendaView *agendaView, bool isInteractive, QWidget *parent );
+public:
+    AgendaScrollArea(bool allDay, AgendaView *agendaView, bool isInteractive, QWidget *parent);
     ~AgendaScrollArea();
 
     Agenda *agenda() const;
 
-  private:
+private:
     Agenda *mAgenda;
 
 };
@@ -354,4 +357,3 @@ class EVENTVIEWS_EXPORT AgendaScrollArea : public QScrollArea
 
 #endif
 
-// kate: space-indent on; indent-width 2; replace-tabs on;
