@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2012-2013 Montel Laurent <montel@kde.org>
+  Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,12 +24,12 @@
 
 #include <KToolBar>
 
-#include <QDebug>
+#include "composereditorng_debug.h"
 #include <QVBoxLayout>
 #include <QWebFrame>
 
-namespace ComposerEditorNG {
-
+namespace ComposerEditorNG
+{
 
 class ComposerEditorPrivate
 {
@@ -57,16 +57,16 @@ public:
         findReplaceBar = new FindReplaceBar(view);
         vlay->addWidget(findReplaceBar);
         q->setLayout(vlay);
-        q->connect(view,SIGNAL(showFindBar()),findReplaceBar,SLOT(showAndFocus()));
-        q->connect(view,SIGNAL(openLink(QUrl)),SIGNAL(openLink(QUrl)));
-        q->connect(view->page(), SIGNAL(contentsChanged()), q, SIGNAL(textChanged()) );
+        q->connect(view, SIGNAL(showFindBar()), findReplaceBar, SLOT(showAndFocus()));
+        q->connect(view, SIGNAL(openLink(QUrl)), SIGNAL(openLink(QUrl)));
+        q->connect(view->page(), SIGNAL(contentsChanged()), q, SIGNAL(textChanged()));
     }
 
     KToolBar *createToolBar(const QList<ComposerView::ComposerViewAction> &lstActions)
     {
         KToolBar *toolbar = new KToolBar(q);
-        toolbar->setIconSize ( QSize ( 22, 22 ) );
-        toolbar->setToolButtonStyle ( Qt::ToolButtonIconOnly );
+        toolbar->setIconSize(QSize(22, 22));
+        toolbar->setToolButtonStyle(Qt::ToolButtonIconOnly);
         toolBarLayout->addWidget(toolbar);
         view->createToolBar(lstActions, toolbar);
         listToolBar.append(toolbar);
@@ -80,7 +80,6 @@ public:
         }
     }
 
-
     QList<KToolBar *> listToolBar;
     QVBoxLayout *toolBarLayout;
     FindReplaceBar *findReplaceBar;
@@ -107,7 +106,7 @@ ComposerEditor::ComposerEditor(QWidget *parent)
 ComposerEditor::~ComposerEditor()
 {
     //const QString content = d->view->page()->mainFrame()->toHtml();
-    //qDebug()<<" content :"<<content;
+    //qCDebug(COMPOSEREDITORNG_LOG)<<" content :"<<content;
     delete d;
 }
 
@@ -165,7 +164,7 @@ void ComposerEditor::redo()
     d->view->page()->triggerAction(QWebPage::Redo);
 }
 
-QAction* ComposerEditor::action(QWebPage::WebAction action)
+QAction *ComposerEditor::action(QWebPage::WebAction action)
 {
     return d->view->page()->action(action);
 }
@@ -175,7 +174,7 @@ ComposerView *ComposerEditor::view() const
     return d->view;
 }
 
-void ComposerEditor::setHtmlContent( const QString &html )
+void ComposerEditor::setHtmlContent(const QString &html)
 {
     d->view->setHtmlContent(html);
 }
@@ -217,6 +216,5 @@ QMap<QString, QString> ComposerEditor::localImages() const
     return d->view->localImages();
 }
 
-
 }
 
