@@ -31,7 +31,10 @@
 #include <QVBoxLayout>
 #include <QCheckBox>
 #include <QLabel>
-#include <QDebug>
+#include "composereditorng_debug.h"
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
 
 namespace ComposerEditorNG
 {
@@ -39,12 +42,12 @@ class ComposerTableFormatDialogPrivate
 {
 public:
     ComposerTableFormatDialogPrivate(const QWebElement &element, ComposerTableFormatDialog *qq)
-        :q(qq)
+        : q(qq)
     {
         initialize(element);
     }
 
-    void initialize(const QWebElement& element);
+    void initialize(const QWebElement &element);
 
     void applyChanges();
     void updateSettings();
@@ -68,16 +71,16 @@ void ComposerTableFormatDialogPrivate::_k_slotWebElementChanged()
 void ComposerTableFormatDialogPrivate::applyChanges()
 {
     if (!webElement.isNull()) {
-        webElement.setAttribute(QLatin1String("border"),QString::number(insertTableWidget->border()));
-        const QString width = QString::fromLatin1("%1%2").arg(insertTableWidget->length()).arg(insertTableWidget->typeOfLength() == QTextLength::PercentageLength ? QLatin1String("%") : QString());
-        webElement.setAttribute(QLatin1String("width"),width);
+        webElement.setAttribute(QStringLiteral("border"), QString::number(insertTableWidget->border()));
+        const QString width = QStringLiteral("%1%2").arg(insertTableWidget->length()).arg(insertTableWidget->typeOfLength() == QTextLength::PercentageLength ? QLatin1String("%") : QString());
+        webElement.setAttribute(QStringLiteral("width"), width);
         if (useBackgroundColor->isChecked()) {
             const QColor col = backgroundColor->color();
             if (col.isValid()) {
-                webElement.setAttribute(QLatin1String("bgcolor"),backgroundColor->color().name());
+                webElement.setAttribute(QStringLiteral("bgcolor"), backgroundColor->color().name());
             }
         } else {
-            webElement.removeAttribute(QLatin1String("bgcolor"));
+            webElement.removeAttribute(QStringLiteral("bgcolor"));
         }
         //TODO update column/row
     }
@@ -86,53 +89,60 @@ void ComposerTableFormatDialogPrivate::applyChanges()
 void ComposerTableFormatDialogPrivate::initialize(const QWebElement &element)
 {
     webElement = element;
-    q->setCaption( i18n( "Table Format" ) );
-    q->setButtons( KDialog::Ok | KDialog::Apply | KDialog::Cancel );
-    q->setButtonText( KDialog::Ok, i18n( "Edit" ) );
-    QWidget *page = new QWidget( q );
-    q->setMainWidget( page );
+    q->setWindowTitle(i18n("Table Format"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel | QDialogButtonBox::Apply);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    q->setLayout(mainLayout);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    q->connect(buttonBox, &QDialogButtonBox::accepted, q, &ComposerTableFormatDialog::accept);
+    q->connect(buttonBox, &QDialogButtonBox::rejected, q, &ComposerTableFormatDialog::reject);
+    okButton->setText(i18n("Edit"));
+    QWidget *page = new QWidget(q);
+    mainLayout->addWidget(page);
+    mainLayout->addWidget(buttonBox);
 
-    QVBoxLayout *lay = new QVBoxLayout( page );
-    insertTableWidget = new KPIMTextEdit::InsertTableWidget( q );
+    QVBoxLayout *lay = new QVBoxLayout(page);
+    insertTableWidget = new KPIMTextEdit::InsertTableWidget(q);
     lay->addWidget(insertTableWidget);
 
     KSeparator *sep = new KSeparator;
-    lay->addWidget( sep );
+    lay->addWidget(sep);
 
     QHBoxLayout *hbox = new QHBoxLayout;
-    useBackgroundColor = new QCheckBox( i18n( "Background Color:" ) );
+    useBackgroundColor = new QCheckBox(i18n("Background Color:"));
     hbox->addWidget(useBackgroundColor);
     backgroundColor = new KColorButton;
     backgroundColor->setEnabled(false);
     hbox->addWidget(backgroundColor);
 
-
     lay->addLayout(hbox);
 
     if (!webElement.isNull()) {
-        ExtendAttributesButton *button = new ExtendAttributesButton(webElement,ExtendAttributesDialog::Table,q);
+        ExtendAttributesButton *button = new ExtendAttributesButton(webElement, ExtendAttributesDialog::Table, q);
         q->connect(button, SIGNAL(webElementChanged()), q, SLOT(_k_slotWebElementChanged()));
-        lay->addWidget( button );
+        lay->addWidget(button);
     }
 
     sep = new KSeparator;
-    lay->addWidget( sep );
+    lay->addWidget(sep);
 
-    q->connect(q,SIGNAL(okClicked()),q,SLOT(_k_slotOkClicked()));
-    q->connect(q,SIGNAL(applyClicked()),q,SLOT(_k_slotApplyClicked()));
+    q->connect(q, SIGNAL(clicked()), q, SLOT(_k_slotOkClicked()));
+    q->connect(q, SIGNAL(clicked()), q, SLOT(_k_slotApplyClicked()));
 
-    q->connect(useBackgroundColor, SIGNAL(toggled(bool)), backgroundColor, SLOT(setEnabled(bool)));
+    q->connect(useBackgroundColor, &QCheckBox::toggled, backgroundColor, &KColorButton::setEnabled);
     updateSettings();
 }
 
 void ComposerTableFormatDialogPrivate::updateSettings()
 {
     if (!webElement.isNull()) {
-        if (webElement.hasAttribute(QLatin1String("border"))) {
-            insertTableWidget->setBorder(webElement.attribute(QLatin1String("border")).toInt());
+        if (webElement.hasAttribute(QStringLiteral("border"))) {
+            insertTableWidget->setBorder(webElement.attribute(QStringLiteral("border")).toInt());
         }
-        if (webElement.hasAttribute(QLatin1String("width"))) {
-            QString width = webElement.attribute(QLatin1String("width"));
+        if (webElement.hasAttribute(QStringLiteral("width"))) {
+            QString width = webElement.attribute(QStringLiteral("width"));
             if (width.endsWith(QLatin1Char('%'))) {
                 insertTableWidget->setTypeOfLength(QTextLength::PercentageLength);
                 width.chop(1);
@@ -142,17 +152,17 @@ void ComposerTableFormatDialogPrivate::updateSettings()
                 insertTableWidget->setLength(width.toInt());
             }
         }
-        if (webElement.hasAttribute(QLatin1String("bgcolor"))) {
+        if (webElement.hasAttribute(QStringLiteral("bgcolor"))) {
             useBackgroundColor->setChecked(true);
-            const QColor color = QColor(webElement.attribute(QLatin1String("bgcolor")));
+            const QColor color = QColor(webElement.attribute(QStringLiteral("bgcolor")));
             backgroundColor->setColor(color);
         } else {
             useBackgroundColor->setChecked(false);
         }
-        QWebElementCollection allRows = webElement.findAll(QLatin1String("tr"));
+        QWebElementCollection allRows = webElement.findAll(QStringLiteral("tr"));
         insertTableWidget->setRows(allRows.count());
-        QWebElementCollection allCol = webElement.findAll(QLatin1String("td"));
-        insertTableWidget->setColumns(allCol.count()/allRows.count());
+        QWebElementCollection allCol = webElement.findAll(QStringLiteral("td"));
+        insertTableWidget->setColumns(allCol.count() / allRows.count());
     }
 }
 
@@ -167,8 +177,8 @@ void ComposerTableFormatDialogPrivate::_k_slotApplyClicked()
     applyChanges();
 }
 
-ComposerTableFormatDialog::ComposerTableFormatDialog(const QWebElement& element, QWidget *parent)
-    : KDialog(parent), d(new ComposerTableFormatDialogPrivate(element, this))
+ComposerTableFormatDialog::ComposerTableFormatDialog(const QWebElement &element, QWidget *parent)
+    : QDialog(parent), d(new ComposerTableFormatDialogPrivate(element, this))
 {
 }
 
@@ -177,7 +187,6 @@ ComposerTableFormatDialog::~ComposerTableFormatDialog()
     delete d;
 }
 
-
 }
 
 #include "moc_composertableformatdialog.cpp"
