@@ -18,25 +18,27 @@
 #ifndef CONTACTCONFIGUREDIALOG_H
 #define CONTACTCONFIGUREDIALOG_H
 
-#include <KDialog>
+#include <QDialog>
 
-namespace GrantleeThemeEditor {
+namespace GrantleeThemeEditor
+{
 class ConfigureWidget;
 }
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ContactEditor;
 }
 
-
-namespace PimCommon {
-class RichTextEditorWidget;
+namespace PimCommon
+{
+class PlainTextEditorWidget;
 }
-class ContactConfigureDialog : public KDialog
+class ContactConfigureDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ContactConfigureDialog(QWidget *parent = 0);
+    explicit ContactConfigureDialog(QWidget *parent = Q_NULLPTR);
     ~ContactConfigureDialog();
 
     void readConfig();
@@ -48,7 +50,7 @@ private Q_SLOTS:
 
 private:
     GrantleeThemeEditor::ConfigureWidget *mConfigureWidget;
-    PimCommon::RichTextEditorWidget *mDefaultTemplate;
+    PimCommon::PlainTextEditorWidget *mDefaultTemplate;
     Akonadi::ContactEditor *mDefaultContact;
 };
 
