@@ -22,10 +22,10 @@
 #include "contacttemplatewidget.h"
 #include "pimcommon/texteditor/plaintexteditor/plaintexteditor.h"
 
-#include <pimcommon/widgets/splittercollapser.h>
+#include <KSplitterCollapserButton>
 
 #include <KLocalizedString>
-#include <KGlobal>
+
 #include <KSharedConfig>
 #include <KConfigGroup>
 
@@ -49,7 +49,7 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
 
         mPreview = new PreviewWidget(projectDirectory);
         mWidgetSplitter->addWidget(mPreview);
-        connect(mPreview, SIGNAL(needUpdateViewer()), this, SIGNAL(needUpdateViewer()));
+        connect(mPreview, &PreviewWidget::needUpdateViewer, this, &EditorPage::needUpdateViewer);
     } else {
         lay->addWidget(mMainSplitter);
     }
@@ -57,26 +57,24 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
     mEditor = new ContactEditorWidget;
 
     if (mType == MainPage) {
-        KConfigGroup group( KGlobal::config(), QLatin1String("Global"));
-        mEditor->setPlainText(group.readEntry("defaultTemplate",QString()));
+        KConfigGroup group(KSharedConfig::openConfig(), QStringLiteral("Global"));
+        mEditor->setPlainText(group.readEntry("defaultTemplate", QString()));
     }
     mMainSplitter->addWidget(mEditor);
     mContactTemplate = new ContactTemplateWidget(i18n("Theme Templates:"));
     connect(mContactTemplate, SIGNAL(insertTemplate(QString)), mEditor->editor(), SLOT(insertPlainText(QString)));
     mMainSplitter->addWidget(mContactTemplate);
     mMainSplitter->setCollapsible(0, false);
-    new PimCommon::SplitterCollapser(mContactTemplate, mMainSplitter);
-
+    new KSplitterCollapserButton(mContactTemplate, mMainSplitter);
 
     connect(mEditor->editor(), SIGNAL(textChanged()), this, SIGNAL(changed()));
 
-
     if (mType == MainPage) {
-        KConfigGroup group( KGlobal::config(), "EditorPage" );
+        KConfigGroup group(KSharedConfig::openConfig(), "EditorPage");
         QList<int> size;
         size << 400 << 100;
-        mMainSplitter->setSizes(group.readEntry( "mainSplitter", size));
-        mWidgetSplitter->setSizes(group.readEntry( "widgetSplitter", size));
+        mMainSplitter->setSizes(group.readEntry("mainSplitter", size));
+        mWidgetSplitter->setSizes(group.readEntry("widgetSplitter", size));
     }
     setLayout(lay);
 }
@@ -84,8 +82,8 @@ EditorPage::EditorPage(GrantleeThemeEditor::EditorPage::PageType type, const QSt
 EditorPage::~EditorPage()
 {
     if (mType == MainPage) {
-        KConfigGroup group( KGlobal::config(), "EditorPage" );
-        group.writeEntry( "mainSplitter", mMainSplitter->sizes());
+        KConfigGroup group(KSharedConfig::openConfig(), "EditorPage");
+        group.writeEntry("mainSplitter", mMainSplitter->sizes());
         group.writeEntry("widgetSplitter", mWidgetSplitter->sizes());
     }
 }
