@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,15 +26,14 @@
 #include <KLocalizedString>
 #include <KNS3/DownloadDialog>
 #include <KActionMenu>
-#include <KStandardDirs>
-#include <KDebug>
+#include <QDebug>
+#include <QAction>
+#include <QIcon>
 
 #include <QDir>
-#include <QAction>
 #include <QDirIterator>
 #include <QActionGroup>
-
-static const KCatalogLoader loader( QLatin1String("libgrantleetheme") );
+#include <QStandardPaths>
 
 using namespace GrantleeTheme;
 
@@ -49,33 +48,37 @@ public:
           actionCollection(ac),
           q(qq)
     {
-        watch = new KDirWatch( q );
+        watch = new KDirWatch(q);
         initThemesDirectories(relativePath);
-        downloadThemesAction = new KAction(i18n("Download New Themes..."), q);
-        downloadThemesAction->setIcon(KIcon(QLatin1String("get-hot-new-stuff")));
-        if (actionCollection)
-            actionCollection->addAction( QLatin1String("download_header_themes"), downloadThemesAction );
+        downloadThemesAction = new QAction(i18n("Download New Themes..."), q);
+        downloadThemesAction->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
+        if (actionCollection) {
+            actionCollection->addAction(QStringLiteral("download_header_themes"), downloadThemesAction);
+        }
         separatorAction = new QAction(q);
         separatorAction->setSeparator(true);
 
-        q->connect(downloadThemesAction, SIGNAL(triggered(bool)), q, SLOT(slotDownloadHeaderThemes()) );
-        q->connect( watch, SIGNAL(dirty(QString)), SLOT(directoryChanged()) );
-        updateThemesPath();
+        q->connect(downloadThemesAction, SIGNAL(triggered(bool)), q, SLOT(slotDownloadHeaderThemes()));
+        q->connect(watch, SIGNAL(dirty(QString)), SLOT(directoryChanged()));
+        updateThemesPath(true);
     }
 
     ~Private()
     {
-        Q_FOREACH ( KToggleAction *action, themesActionList ) {
-            if (actionGroup)
+        Q_FOREACH (KToggleAction *action, themesActionList) {
+            if (actionGroup) {
                 actionGroup->removeAction(action);
-            if (actionCollection)
-                actionCollection->removeAction( action );
+            }
+            if (actionCollection) {
+                actionCollection->removeAction(action);
+            }
             delete action;
         }
         themesActionList.clear();
         themes.clear();
-        if (downloadThemesDialog)
+        if (downloadThemesDialog) {
             delete downloadThemesDialog.data();
+        }
     }
 
     void slotDownloadHeaderThemes()
@@ -93,26 +96,28 @@ public:
         Q_EMIT q->updateThemes();
     }
 
-    void updateThemesPath()
+    void updateThemesPath(bool init = false)
     {
-        if ( !themesDirectories.isEmpty() ) {
-            Q_FOREACH (const QString &directory, themesDirectories) {
-                watch->removeDir( directory );
+        if (!init) {
+            if (!themesDirectories.isEmpty()) {
+                Q_FOREACH (const QString &directory, themesDirectories) {
+                    watch->removeDir(directory);
+                }
+            } else {
+                return;
             }
-        } else {
-            return;
         }
 
         // clear all previous theme information
         themes.clear();
 
         Q_FOREACH (const QString &directory, themesDirectories) {
-            QDirIterator dirIt( directory, QStringList(), QDir::AllDirs | QDir::NoDotAndDotDot );
+            QDirIterator dirIt(directory, QStringList(), QDir::AllDirs | QDir::NoDotAndDotDot);
             QStringList alreadyLoadedThemeName;
-            while ( dirIt.hasNext() ) {
+            while (dirIt.hasNext()) {
                 dirIt.next();
                 const QString dirName = dirIt.fileName();
-                GrantleeTheme::Theme theme = q->loadTheme( dirIt.filePath(), dirName, defaultDesktopFileName );
+                GrantleeTheme::Theme theme = q->loadTheme(dirIt.filePath(), dirName, defaultDesktopFileName);
                 if (theme.isValid()) {
                     QString themeName = theme.name();
                     if (alreadyLoadedThemeName.contains(themeName)) {
@@ -125,30 +130,31 @@ public:
                         theme.setName(themeName);
                     }
                     alreadyLoadedThemeName << themeName;
-                    themes.insert( dirName, theme );
-                    //kDebug()<<" theme.name()"<<theme.name();
+                    themes.insert(dirName, theme);
+                    //qDebug()<<" theme.name()"<<theme.name();
                 }
             }
-            watch->addDir( directory );
+            watch->addDir(directory);
         }
 
         Q_EMIT q->themesChanged();
         watch->startScan();
     }
 
-
     void updateActionList()
     {
-        if (!actionGroup || !menu)
+        if (!actionGroup || !menu) {
             return;
+        }
         QString themeActivated;
-        Q_FOREACH ( KToggleAction *action, themesActionList ) {
+        Q_FOREACH (KToggleAction *action, themesActionList) {
             if (action->isChecked()) {
                 themeActivated = action->data().toString();
             }
             actionGroup->removeAction(action);
-            if (actionCollection)
-                actionCollection->removeAction( action );
+            if (actionCollection) {
+                actionCollection->removeAction(action);
+            }
             menu->removeAction(action);
             delete action;
         }
@@ -156,13 +162,12 @@ public:
         menu->removeAction(downloadThemesAction);
         themesActionList.clear();
 
-
         bool themeActivatedFound = false;
         QMapIterator<QString, GrantleeTheme::Theme> i(themes);
         while (i.hasNext()) {
             i.next();
             GrantleeTheme::Theme theme = i.value();
-            KToggleAction *act = new KToggleAction(theme.name(),q);
+            KToggleAction *act = new KToggleAction(theme.name(), q);
             act->setToolTip(theme.description());
             act->setData(theme.dirName());
             if (theme.dirName() == themeActivated) {
@@ -189,21 +194,21 @@ public:
     void selectTheme(KToggleAction *act)
     {
         if (act) {
-            switch(applicationType) {
+            switch (applicationType) {
             case GrantleeThemeManager::Mail:
-                GrantleeSettings::self()->setGrantleeMailThemeName( act->data().toString() );
+                GrantleeSettings::self()->setGrantleeMailThemeName(act->data().toString());
                 break;
             case GrantleeThemeManager::Addressbook:
-                GrantleeSettings::self()->setGrantleeAddressBookThemeName( act->data().toString() );
+                GrantleeSettings::self()->setGrantleeAddressBookThemeName(act->data().toString());
                 break;
             }
-            GrantleeSettings::self()->writeConfig();
+            GrantleeSettings::self()->save();
         }
     }
 
     void slotThemeSelected()
     {
-        if (q->sender() ) {
+        if (q->sender()) {
             KToggleAction *act = dynamic_cast<KToggleAction *>(q->sender());
             selectTheme(act);
             Q_EMIT q->grantleeThemeSelected();
@@ -213,7 +218,7 @@ public:
     KToggleAction *actionForTheme()
     {
         QString themeName;
-        switch(applicationType) {
+        switch (applicationType) {
         case GrantleeThemeManager::Mail:
             themeName = GrantleeSettings::self()->grantleeMailThemeName();
             break;
@@ -221,11 +226,12 @@ public:
             themeName = GrantleeSettings::self()->grantleeAddressBookThemeName();
             break;
         }
-        if (themeName.isEmpty())
+        if (themeName.isEmpty()) {
             return 0;
-        Q_FOREACH(KToggleAction *act, themesActionList) {
+        }
+        Q_FOREACH (KToggleAction *act, themesActionList) {
             if (act->data().toString() == themeName) {
-                return static_cast<KToggleAction*>(act);
+                return static_cast<KToggleAction *>(act);
             }
         }
         return 0;
@@ -234,10 +240,11 @@ public:
     void initThemesDirectories(const QString &themesRelativePath)
     {
         if (!themesRelativePath.isEmpty()) {
-            themesDirectories = KGlobal::dirs()->findDirs("data", themesRelativePath);
+
+            themesDirectories = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, themesRelativePath, QStandardPaths::LocateDirectory);
             if (themesDirectories.count() < 2) {
                 //Make sure to add local directory
-                const QString localDirectory = KStandardDirs::locateLocal("data", themesRelativePath);
+                const QString localDirectory = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + themesRelativePath;
                 if (!themesDirectories.contains(localDirectory)) {
                     themesDirectories.append(localDirectory);
                 }
@@ -249,20 +256,20 @@ public:
     QString downloadConfigFileName;
     QStringList themesDirectories;
     QMap<QString, GrantleeTheme::Theme> themes;
-    QList<KToggleAction*> themesActionList;
+    QList<KToggleAction *> themesActionList;
     KDirWatch *watch;
     QActionGroup *actionGroup;
     KActionMenu *menu;
     KActionCollection *actionCollection;
     QAction *separatorAction;
 
-    KAction *downloadThemesAction;
+    QAction *downloadThemesAction;
     QWeakPointer<KNS3::DownloadDialog> downloadThemesDialog;
     GrantleeThemeManager *q;
 };
 
 GrantleeThemeManager::GrantleeThemeManager(GrantleeTheme::GrantleeThemeManager::Application applicationType, const QString &defaultDesktopFileName, KActionCollection *actionCollection, const QString &path, QObject *parent)
-    : QObject(parent), d(new Private(applicationType, defaultDesktopFileName, actionCollection, path,this))
+    : QObject(parent), d(new Private(applicationType, defaultDesktopFileName, actionCollection, path, this))
 {
 }
 
@@ -276,7 +283,7 @@ QMap<QString, GrantleeTheme::Theme> GrantleeThemeManager::themes() const
     return d->themes;
 }
 
-void GrantleeThemeManager::setActionGroup( QActionGroup *actionGroup )
+void GrantleeThemeManager::setActionGroup(QActionGroup *actionGroup)
 {
     if (d->actionGroup != actionGroup) {
         d->actionGroup = actionGroup;
@@ -326,20 +333,20 @@ QString GrantleeThemeManager::pathFromThemes(const QString &themesRelativePath,
 {
     QStringList themesDirectories;
     if (!themesRelativePath.isEmpty()) {
-        themesDirectories = KGlobal::dirs()->findDirs("data", themesRelativePath);
+        themesDirectories = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, themesRelativePath, QStandardPaths::LocateDirectory);
         if (themesDirectories.count() < 2) {
             //Make sure to add local directory
-            const QString localDirectory = KStandardDirs::locateLocal("data", themesRelativePath);
+            const QString localDirectory = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1Char('/') + themesRelativePath;
             if (!themesDirectories.contains(localDirectory)) {
                 themesDirectories.append(localDirectory);
             }
         }
         Q_FOREACH (const QString &directory, themesDirectories) {
-            QDirIterator dirIt( directory, QStringList(), QDir::AllDirs | QDir::NoDotAndDotDot );
-            while ( dirIt.hasNext() ) {
+            QDirIterator dirIt(directory, QStringList(), QDir::AllDirs | QDir::NoDotAndDotDot);
+            while (dirIt.hasNext()) {
                 dirIt.next();
                 const QString dirName = dirIt.fileName();
-                GrantleeTheme::Theme theme = loadTheme( dirIt.filePath(), dirName, defaultDesktopFileName );
+                GrantleeTheme::Theme theme = loadTheme(dirIt.filePath(), dirName, defaultDesktopFileName);
                 if (theme.isValid()) {
                     if (dirName == themeName) {
                         return theme.absolutePath();
@@ -351,21 +358,10 @@ QString GrantleeThemeManager::pathFromThemes(const QString &themesRelativePath,
     return QString();
 }
 
-GrantleeTheme::Theme GrantleeThemeManager::loadTheme(const QString &themePath, const QString &dirName, const QString &defaultDesktopFileName )
+GrantleeTheme::Theme GrantleeThemeManager::loadTheme(const QString &themePath, const QString &dirName, const QString &defaultDesktopFileName)
 {
-    const QString themeInfoFile = themePath + QDir::separator() + defaultDesktopFileName;
-    KConfig config( themeInfoFile );
-    KConfigGroup group( &config, QLatin1String( "Desktop Entry" ) );
-
-    GrantleeTheme::Theme theme;
-    theme.setDirName(dirName);
-    theme.setName( group.readEntry( "Name", QString() ) );
-    theme.setDescription( group.readEntry( "Description", QString() ) );
-    theme.setFilename( group.readEntry( "FileName" , QString() ) );
-    theme.setDisplayExtraVariables( group.readEntry( "DisplayExtraVariables", QStringList() ) );
-    theme.setAbsolutePath(themePath);
+    const GrantleeTheme::Theme theme(themePath, dirName, defaultDesktopFileName);
     return theme;
 }
 
-
 #include "moc_grantleethememanager.cpp"
