@@ -27,40 +27,46 @@
 #ifndef INCIDENCEEDITOR_ATTACHMENTEDITDIALOG_H
 #define INCIDENCEEDITOR_ATTACHMENTEDITDIALOG_H
 
-#include "incidenceeditors-ng_export.h"
+#include "incidenceeditors_ng_export.h"
 
 #include <KCalCore/Attachment>
+#include <QUrl>
+#include <QDialog>
+#include <QMimeDatabase>
+#include <QMimeType>
 
-#include <KDialog>
-#include <KMimeType>
+class QPushButton;
 
-namespace Ui {
-  class AttachmentEditDialog;
+namespace Ui
+{
+class AttachmentEditDialog;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 
 class AttachmentIconItem;
 
-class INCIDENCEEDITORS_NG_EXPORT AttachmentEditDialog : public KDialog
+class INCIDENCEEDITORS_NG_EXPORT AttachmentEditDialog : public QDialog
 {
-  Q_OBJECT
-  public:
-    AttachmentEditDialog( AttachmentIconItem *item, QWidget *parent, bool modal = true );
+    Q_OBJECT
+public:
+    AttachmentEditDialog(AttachmentIconItem *item, QWidget *parent, bool modal = true);
     virtual ~AttachmentEditDialog();
-    void accept();
+    void accept() Q_DECL_OVERRIDE;
 
-  protected slots:
-    void inlineChanged( int state );
-    void urlChanged( const KUrl &url );
-    void urlChanged( const QString & url );
+protected Q_SLOTS:
+    void inlineChanged(int state);
+    void urlChanged(const QUrl &url);
+    void urlChanged(const QString &url);
     virtual void slotApply();
 
-  private:
+private:
     KCalCore::Attachment::Ptr mAttachment;
     AttachmentIconItem *mItem;
-    KMimeType::Ptr mMimeType;
+    QMimeType mMimeType;
     Ui::AttachmentEditDialog *mUi;
+    QPushButton *mOkButton;
 };
 
 }
