@@ -21,7 +21,7 @@
 #ifndef INCIDENCEEDITOR_ATTENDEELINE_H
 #define INCIDENCEEDITOR_ATTENDEELINE_H
 
-#include "incidenceeditors-ng_export.h"
+#include "incidenceeditors_ng_export.h"
 
 #include <libkdepim/addressline/addresslineedit/addresseelineedit.h>
 #include <libkdepim/multiplyingline/multiplyingline.h>
@@ -33,38 +33,39 @@
 
 class QKeyEvent;
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 
 class AttendeeData;
 
 class INCIDENCEEDITORS_NG_EXPORT AttendeeComboBox : public QToolButton
 {
-  Q_OBJECT
-  public:
-    explicit AttendeeComboBox( QWidget *parent );
+    Q_OBJECT
+public:
+    explicit AttendeeComboBox(QWidget *parent);
 
-    void addItem( const QIcon &icon, const QString &text );
-    void addItems( const QStringList &texts );
+    void addItem(const QIcon &icon, const QString &text);
+    void addItems(const QStringList &texts);
 
     int currentIndex() const;
 
-  signals:
+Q_SIGNALS:
     void rightPressed();
     void leftPressed();
     void itemChanged();
 
-  public slots:
+public Q_SLOTS:
     /** Clears the combobox, removing all items. */
     void clear();
-    void setCurrentIndex( int index );
+    void setCurrentIndex(int index);
 
-  protected:
-    void keyPressEvent( QKeyEvent *ev );
+protected:
+    void keyPressEvent(QKeyEvent *ev) Q_DECL_OVERRIDE;
 
-  private slots:
+private Q_SLOTS:
     void slotActionTriggered();
 
-  private:
+private:
     QMenu *mMenu;
     QList<QPair<QString, QIcon> > mList;
     int mCurrentIndex;
@@ -72,32 +73,32 @@ class INCIDENCEEDITORS_NG_EXPORT AttendeeComboBox : public QToolButton
 
 class INCIDENCEEDITORS_NG_EXPORT AttendeeLineEdit : public KPIM::AddresseeLineEdit
 {
-  Q_OBJECT
-  public:
-    explicit AttendeeLineEdit( QWidget * parent );
+    Q_OBJECT
+public:
+    explicit AttendeeLineEdit(QWidget *parent);
 
-  signals:
+Q_SIGNALS:
     void deleteMe();
     void leftPressed();
     void rightPressed();
     void upPressed();
     void downPressed();
 
-  protected:
-    void keyPressEvent( QKeyEvent *ev );
+protected:
+    void keyPressEvent(QKeyEvent *ev) Q_DECL_OVERRIDE;
 };
 
 class INCIDENCEEDITORS_NG_EXPORT AttendeeLine : public KPIM::MultiplyingLine
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
     enum AttendeeActions {
-      EventActions,
-      TodoActions
+        EventActions,
+        TodoActions
     };
 
-    explicit AttendeeLine( QWidget *parent );
-    virtual ~AttendeeLine(){}
+    explicit AttendeeLine(QWidget *parent);
+    virtual ~AttendeeLine() {}
 
     virtual void activate();
     virtual bool isActive() const;
@@ -109,32 +110,32 @@ class INCIDENCEEDITORS_NG_EXPORT AttendeeLine : public KPIM::MultiplyingLine
     virtual void clearModified();
 
     virtual KPIM::MultiplyingLineData::Ptr data() const;
-    virtual void setData( const KPIM::MultiplyingLineData::Ptr &data );
+    virtual void setData(const KPIM::MultiplyingLineData::Ptr &data);
 
-    virtual void fixTabOrder( QWidget *previous );
+    virtual void fixTabOrder(QWidget *previous);
     virtual QWidget *tabOut() const;
 
     virtual void moveCompletionPopup();
-    virtual void setCompletionMode( KGlobalSettings::Completion );
+    virtual void setCompletionMode(KCompletion::CompletionMode);
 
-    virtual int setColumnWidth( int w );
+    virtual int setColumnWidth(int w);
 
     virtual void aboutToBeDeleted();
 
-    void setActions( AttendeeActions actions );
+    void setActions(AttendeeActions actions);
 
-  signals:
+Q_SIGNALS:
     void changed();
-    void changed( const KCalCore::Attendee::Ptr &oldAttendee,
-                  const KCalCore::Attendee::Ptr &newAttendee );
-    void editingFinished( KPIM::MultiplyingLine * );
+    void changed(const KCalCore::Attendee::Ptr &oldAttendee,
+                 const KCalCore::Attendee::Ptr &newAttendee);
+    void editingFinished(KPIM::MultiplyingLine *);
 
-  private slots:
-    void slotTextChanged( const QString & );
+private Q_SLOTS:
+    void slotTextChanged(const QString &);
     void slotHandleChange();
     void slotComboChanged();
 
-  private:
+private:
     void dataFromFields();
     void fieldsFromData();
 
