@@ -22,20 +22,21 @@
 #ifndef INCIDENCEEDITOR_GLOBALSETTINGS_H
 #define INCIDENCEEDITOR_GLOBALSETTINGS_H
 
-#include "incidenceeditors-ng_export.h"
+#include "incidenceeditors_ng_export.h"
 
 #include "incidenceeditor-ng/globalsettings_base.h"
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 
 class INCIDENCEEDITORS_NG_EXPORT GlobalSettings : public IncidenceEditorNG::GlobalSettingsBase
 {
-  Q_OBJECT
+    Q_OBJECT
 
-  public:
+public:
     static GlobalSettings *self();
 
-  private:
+private:
     GlobalSettings();
     virtual ~GlobalSettings();
     static GlobalSettings *mSelf;
