@@ -24,69 +24,74 @@
 #include "incidenceeditor-ng.h"
 
 #include <KLocalizedString>
-
-namespace Ui {
-  class EventOrTodoDesktop;
-  class EventOrTodoMore;
+#include <QDate>
+namespace Ui
+{
+class EventOrTodoDesktop;
+class EventOrTodoMore;
 }
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 
 class IncidenceDateTime;
 
 /// Keep this in sync with the values in mUi->mRecurrenceTypeCombo
 enum RecurrenceType {
-  RecurrenceTypeNone = 0,
-  RecurrenceTypeDaily,
-  RecurrenceTypeWeekly,
-  RecurrenceTypeMonthly,
-  RecurrenceTypeYearly,
-  RecurrenceTypeUnknown, // keep this one at the end of the ones which are also in the combobox
-  RecurrenceTypeException
+    RecurrenceTypeNone = 0,
+    RecurrenceTypeDaily,
+    RecurrenceTypeWeekly,
+    RecurrenceTypeMonthly,
+    RecurrenceTypeYearly,
+    RecurrenceTypeUnknown, // keep this one at the end of the ones which are also in the combobox
+    RecurrenceTypeException
 };
 
 class INCIDENCEEDITORS_NG_EXPORT IncidenceRecurrence : public IncidenceEditor
 {
-  Q_OBJECT
-  public:
+    Q_OBJECT
+public:
+    using IncidenceEditorNG::IncidenceEditor::save; // So we don't trigger -Woverloaded-virtual
+    using IncidenceEditorNG::IncidenceEditor::load; // So we don't trigger -Woverloaded-virtual    
+
 #ifdef KDEPIM_MOBILE_UI
-    IncidenceRecurrence( IncidenceDateTime *dateTime, Ui::EventOrTodoMore *ui );
+    IncidenceRecurrence(IncidenceDateTime *dateTime, Ui::EventOrTodoMore *ui);
 #else
-    IncidenceRecurrence( IncidenceDateTime *dateTime, Ui::EventOrTodoDesktop *ui );
+    IncidenceRecurrence(IncidenceDateTime *dateTime, Ui::EventOrTodoDesktop *ui);
 #endif
 
-    virtual void load( const KCalCore::Incidence::Ptr &incidence );
-    virtual void save( const KCalCore::Incidence::Ptr &incidence );
+    virtual void load(const KCalCore::Incidence::Ptr &incidence);
+    virtual void save(const KCalCore::Incidence::Ptr &incidence);
     virtual bool isDirty() const;
     virtual bool isValid() const;
 
     RecurrenceType currentRecurrenceType() const;
 
-  Q_SIGNALS:
-    void recurrenceChanged( IncidenceEditorNG::RecurrenceType type );
+Q_SIGNALS:
+    void recurrenceChanged(IncidenceEditorNG::RecurrenceType type);
 
-  private Q_SLOTS:
+private Q_SLOTS:
     void addException();
     void fillCombos();
     void handleDateTimeToggle();
-    void handleEndAfterOccurrencesChange( int currentValue );
-    void handleExceptionDateChange( const QDate &currentDate );
+    void handleEndAfterOccurrencesChange(int currentValue);
+    void handleExceptionDateChange(const QDate &currentDate);
     void handleFrequencyChange();
-    void handleRecurrenceTypeChange( int currentIndex );
+    void handleRecurrenceTypeChange(int currentIndex);
     void removeExceptions();
     void updateRemoveExceptionButton();
-    void updateWeekDays( const QDate &newStartDate );
-    void handleStartDateChange( const QDate & );
+    void updateWeekDays(const QDate &newStartDate);
+    void handleStartDateChange(const QDate &);
 
-  private:
+private:
 
     /**
        I needed save() to be const, so created this func.
        save() calls this now, and changes members outside.
     */
-    void writeToIncidence( const KCalCore::Incidence::Ptr &incidence ) const;
+    void writeToIncidence(const KCalCore::Incidence::Ptr &incidence) const;
 
-    KLocalizedString subsOrdinal( const KLocalizedString &text, int number ) const;
+    KLocalizedString subsOrdinal(const KLocalizedString &text, int number) const;
     /**
      * Return the day in the month/year on which the event recurs, starting at the
      * beginning/end. Both return a positive number.
@@ -102,14 +107,14 @@ class INCIDENCEEDITORS_NG_EXPORT IncidenceRecurrence : public IncidenceEditor
 
     /** DO NOT USE THIS METHOD DIRECTLY
         use subsOrdinal() instead for i18n * */
-    QString numberToString( int number ) const;
-    void selectMonthlyItem( KCalCore::Recurrence *recurrence, ushort recurenceType );
-    void selectYearlyItem( KCalCore::Recurrence *recurrence, ushort recurenceType );
+    QString numberToString(int number) const;
+    void selectMonthlyItem(KCalCore::Recurrence *recurrence, ushort recurenceType);
+    void selectYearlyItem(KCalCore::Recurrence *recurrence, ushort recurenceType);
     void setDefaults();
-    void setDuration( int duration );
-    void setExceptionDates( const KCalCore::DateList &dates );
-    void setFrequency( int freq );
-    void toggleRecurrenceWidgets( int enable );
+    void setDuration(int duration);
+    void setExceptionDates(const KCalCore::DateList &dates);
+    void setFrequency(int freq);
+    void toggleRecurrenceWidgets(int enable);
     /** Returns an array with the weekday on which the event occurs set to 1 */
     QBitArray weekday() const;
 
@@ -117,11 +122,11 @@ class INCIDENCEEDITORS_NG_EXPORT IncidenceRecurrence : public IncidenceEditor
      * Return how many times the weekday represented by @param date occurs in
      * the month of @param date.
      */
-    int weekdayCountForMonth( const QDate &date ) const;
+    int weekdayCountForMonth(const QDate &date) const;
 
     QDate currentDate() const;
 
-  private:
+private:
 #ifdef KDEPIM_MOBILE_UI
     Ui::EventOrTodoMore *mUi;
 #else
