@@ -21,53 +21,58 @@
 #ifndef INCIDENCEEDITOR_VISUALFREEBUSYWIDGET_H
 #define INCIDENCEEDITOR_VISUALFREEBUSYWIDGET_H
 
-#include "incidenceeditors-ng_export.h"
+#include "incidenceeditors_ng_export.h"
 
 #include <KDateTime>
 
 #include <QWidget>
 
-namespace KDGantt {
-  class DateTimeGrid;
-  class GraphicsView;
+namespace KDGantt
+{
+class DateTimeGrid;
+class GraphicsView;
+}
+
+namespace KPIM
+{
+class FreeBusyItemModel;
 }
 
 class KComboBox;
-
 class QTreeView;
 
-namespace IncidenceEditorNG {
+namespace IncidenceEditorNG
+{
 
-class FreeBusyItemModel;
 class FreeBusyGanttProxyModel;
 class RowController;
 
 class INCIDENCEEDITORS_NG_EXPORT VisualFreeBusyWidget : public QWidget
 {
-  Q_OBJECT
-  public:
-    explicit VisualFreeBusyWidget( FreeBusyItemModel *model, int spacing = 8, QWidget *parent = 0 );
+    Q_OBJECT
+public:
+    explicit VisualFreeBusyWidget(KPIM::FreeBusyItemModel *model, int spacing = 8, QWidget *parent = Q_NULLPTR);
     ~VisualFreeBusyWidget();
 
-  public slots:
-    void slotUpdateIncidenceStartEnd( const KDateTime &, const KDateTime & );
+public Q_SLOTS:
+    void slotUpdateIncidenceStartEnd(const KDateTime &, const KDateTime &);
 
-  signals:
-    void dateTimesChanged( const KDateTime &, const KDateTime & );
+Q_SIGNALS:
+    void dateTimesChanged(const KDateTime &, const KDateTime &);
     void manualReload();
 
-  protected slots:
-    void slotScaleChanged( int );
+protected Q_SLOTS:
+    void slotScaleChanged(int);
     void slotCenterOnStart() ;
     void slotZoomToTime();
     void slotPickDate();
     void showAttendeeStatusMenu();
-    void slotIntervalColorRectangleMoved( const KDateTime &start, const KDateTime &end );
+    void slotIntervalColorRectangleMoved(const KDateTime &start, const KDateTime &end);
 
-  private slots:
+private Q_SLOTS:
     void splitterMoved();
 
-  private:
+private:
     KDGantt::GraphicsView *mGanttGraphicsView;
     QTreeView *mLeftView;
     RowController *mRowController;
