@@ -19,26 +19,21 @@
 
 #include "categoryselectwidget.h"
 
-#include <kicon.h>
-#include <klocale.h>
-#include <kdebug.h>
-#include <kdialog.h>
-
+#include "kaddressbook_debug.h"
+#include <KLocalizedString>
 #include <qtoolbutton.h>
 #include <qlayout.h>
 #include <qstandarditemmodel.h>
 #include <qtimer.h>
 
-#include <akonadi/monitor.h>
-#include <akonadi/tagmodel.h>
+#include <AkonadiCore/monitor.h>
+#include <AkonadiCore/tagmodel.h>
 
 #include <widgets/kcheckcombobox.h>
 
 using namespace Akonadi;
 
-
-static const int FILTER_ROLE = Qt::UserRole+1;
-
+static const int FILTER_ROLE = Qt::UserRole + 1;
 
 class CategorySelectWidgetPrivate : public QObject
 {
@@ -58,7 +53,7 @@ public:
     void selectAll(Qt::CheckState state) const;
     QList<Akonadi::Tag::Id> filterTags() const;
 
-public slots:
+public Q_SLOTS:
     void slotSelectAll();
     void slotSelectNone();
 
@@ -73,18 +68,16 @@ private:
     CategorySelectWidget *q_ptr;
 };
 
-
 CategorySelectWidgetPrivate::CategorySelectWidgetPrivate(CategorySelectWidget *parent)
     : QObject(),
-      tagModel(0),
+      tagModel(Q_NULLPTR),
       rowOffset(0),
-      updateTimer(0),
-      checkCombo(0),
+      updateTimer(Q_NULLPTR),
+      checkCombo(Q_NULLPTR),
       q_ptr(parent)
 {
 }
 
-
 void CategorySelectWidgetPrivate::init()
 {
     Q_Q(CategorySelectWidget);
@@ -95,40 +88,38 @@ void CategorySelectWidgetPrivate::init()
     checkCombo = new KPIM::KCheckComboBox;
     checkCombo->setMinimumWidth(150);
     checkCombo->setSqueezeText(true);
-    connect(checkCombo, SIGNAL(checkedItemsChanged(QStringList)),
-            SLOT(slotCheckedItemsChanged()));
+    connect(checkCombo, &KPIM::KCheckComboBox::checkedItemsChanged,
+            this, &CategorySelectWidgetPrivate::slotCheckedItemsChanged);
     hbox->addWidget(checkCombo);
 
     Monitor *monitor = new Monitor(this);
     monitor->setTypeMonitored(Monitor::Tags);
     tagModel = new Akonadi::TagModel(monitor, this);
 
-    connect(tagModel, SIGNAL(rowsInserted(QModelIndex,int,int)),
-            SLOT(slotTagsInserted(QModelIndex,int,int)));
-    connect(tagModel, SIGNAL(rowsRemoved(QModelIndex,int,int)),
-            SLOT(slotTagsRemoved(QModelIndex,int,int)));
-    connect(tagModel, SIGNAL(dataChanged(QModelIndex,QModelIndex)),
-            SLOT(slotTagsChanged(QModelIndex,QModelIndex)));
+    connect(tagModel, &QAbstractItemModel::rowsInserted,
+            this, &CategorySelectWidgetPrivate::slotTagsInserted);
+    connect(tagModel, &QAbstractItemModel::rowsRemoved,
+            this, &CategorySelectWidgetPrivate::slotTagsRemoved);
+    connect(tagModel, &QAbstractItemModel::dataChanged,
+            this, &CategorySelectWidgetPrivate::slotTagsChanged);
 
     updateTimer = new QTimer(this);
     updateTimer->setSingleShot(true);
     updateTimer->setInterval(200);
-    connect(updateTimer, SIGNAL(timeout()), SLOT(slotCheckedItemsTimer()));
-
-    hbox->addSpacing(KDialog::spacingHint());
+    connect(updateTimer, &QTimer::timeout, this, &CategorySelectWidgetPrivate::slotCheckedItemsTimer);
 
     QToolButton *but = new QToolButton(q);
     but ->setAutoRaise(true);
-    but->setIcon(KIcon(QLatin1String("edit-undo")));
+    but->setIcon(QIcon::fromTheme(QStringLiteral("edit-undo")));
     but->setToolTip(i18nc("@action:button", "Reset category filter"));
-    connect(but, SIGNAL(clicked(bool)), SLOT(slotSelectAll()));
+    connect(but, &QToolButton::clicked, this, &CategorySelectWidgetPrivate::slotSelectAll);
     hbox->addWidget(but);
 
     but = new QToolButton(q);
     but->setAutoRaise(true);
-    but->setIcon(KIcon(QLatin1String("edit-clear")));
+    but->setIcon(QIcon::fromTheme(QStringLiteral("edit-clear")));
     but->setToolTip(i18nc("@action:button", "Clear category filter"));
-    connect(but, SIGNAL(clicked(bool)), SLOT(slotSelectNone()));
+    connect(but, &QToolButton::clicked, this, &CategorySelectWidgetPrivate::slotSelectNone);
     hbox->addWidget(but);
 
     QStandardItem *item = new QStandardItem(i18n("(Untagged)"));
@@ -144,26 +135,23 @@ void CategorySelectWidgetPrivate::init()
     rowOffset = itemModel()->rowCount();
 }
 
-
 QStandardItemModel *CategorySelectWidgetPrivate::itemModel() const
 {
     QStandardItemModel *m = qobject_cast<QStandardItemModel *>(checkCombo->model());
-    Q_ASSERT(m!=NULL);
+    Q_ASSERT(m != NULL);
     return m;
 }
 
-
 void CategorySelectWidgetPrivate::slotTagsRemoved(const QModelIndex &parent, int start, int end)
 {
-    itemModel()->removeRows(start+rowOffset, end+rowOffset, parent);
+    itemModel()->removeRows(start + rowOffset, end + rowOffset, parent);
 }
 
-
 void CategorySelectWidgetPrivate::slotTagsChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
 {
-    for (int row = topLeft.row(); row<=bottomRight.row(); ++row) {
-        QStandardItem *it = itemModel()->item(row+rowOffset);
-        Q_ASSERT(it!=NULL);
+    for (int row = topLeft.row(); row <= bottomRight.row(); ++row) {
+        QStandardItem *it = itemModel()->item(row + rowOffset);
+        Q_ASSERT(it != NULL);
 
         QModelIndex idx = tagModel->index(row, 0);
         it->setText(tagModel->data(idx, TagModel::NameRole).toString());
@@ -172,16 +160,15 @@ void CategorySelectWidgetPrivate::slotTagsChanged(const QModelIndex &topLeft, co
     }
 }
 
-
 void CategorySelectWidgetPrivate::slotTagsInserted(const QModelIndex &parent, int start, int end)
 {
-    for (int row = start; row<=end; ++row) {
+    for (int row = start; row <= end; ++row) {
         QModelIndex idx = tagModel->index(row, 0, parent);
 #if 0
-	kDebug() << "idx" << idx << "=" << tagModel->data(idx, Qt::DisplayRole).toString()
-            << "name" << tagModel->data(idx, TagModel::NameRole).toString()
-            << "tag" << tagModel->data(idx, TagModel::TagRole)
-            << "id" << tagModel->data(idx, TagModel::IdRole).toInt();
+        qCDebug(KADDRESSBOOK_LOG) << "idx" << idx << "=" << tagModel->data(idx, Qt::DisplayRole).toString()
+                                  << "name" << tagModel->data(idx, TagModel::NameRole).toString()
+                                  << "tag" << tagModel->data(idx, TagModel::TagRole)
+                                  << "id" << tagModel->data(idx, TagModel::IdRole).toInt();
 #endif
         QStandardItem *it = new QStandardItem(tagModel->data(idx, TagModel::NameRole).toString());
         it->setIcon(tagModel->data(idx, Qt::DecorationRole).value<QIcon>());
@@ -193,61 +180,56 @@ void CategorySelectWidgetPrivate::slotTagsInserted(const QModelIndex &parent, in
         // tags, as is required in Akonadi::TagModel.
         //
         // FIXME: not tested (no way to create hierarchial tags at present)
-        if (parent!=QModelIndex()) {
+        if (parent != QModelIndex()) {
             const Tag::Id parentId = tagModel->data(idx, TagModel::IdRole).value<Tag::Id>();
             QModelIndexList matchList = itemModel()->match(itemModel()->index(0, 0), FILTER_ROLE,
-                                                           parentId, 1,
-                                                           Qt::MatchExactly|Qt::MatchRecursive);
-            if (matchList.count()==1) {			// found the parent tag
-                QModelIndex parentIndex = matchList.first();
+                                        parentId, 1,
+                                        Qt::MatchExactly | Qt::MatchRecursive);
+            if (matchList.count() == 1) {       // found the parent tag
+                QModelIndex parentIndex = matchList.at(0);
                 itemModel()->itemFromIndex(parentIndex)->appendRow(it);
             } else {
-                kWarning() << "Cannot find parent with ID" << parentId;
-                itemModel()->insertRow(row+rowOffset, it);
+                qCWarning(KADDRESSBOOK_LOG) << "Cannot find parent with ID" << parentId;
+                itemModel()->insertRow(row + rowOffset, it);
             }
         } else {
-            itemModel()->insertRow(row+rowOffset, it);
+            itemModel()->insertRow(row + rowOffset, it);
         }
     }
 }
 
-
 void CategorySelectWidgetPrivate::selectAll(Qt::CheckState state) const
 {
-    for (int row = 0; row<itemModel()->rowCount(); ++row) {
+    for (int row = 0; row < itemModel()->rowCount(); ++row) {
         QStandardItem *it = itemModel()->item(row);
         it->setCheckState(state);
     }
 }
 
-
 void CategorySelectWidgetPrivate::slotSelectAll()
 {
     selectAll(Qt::Checked);
 }
 
-
 void CategorySelectWidgetPrivate::slotSelectNone()
 {
     selectAll(Qt::Unchecked);
 }
 
-
 void CategorySelectWidgetPrivate::slotCheckedItemsChanged()
 {
     updateTimer->start();
 }
 
-
 void CategorySelectWidgetPrivate::slotCheckedItemsTimer()
 {
     Q_Q(CategorySelectWidget);
 
     bool allOn = true;
-    for (int row = 0; row<itemModel()->rowCount(); ++row) {
+    for (int row = 0; row < itemModel()->rowCount(); ++row) {
         const QStandardItem *it = itemModel()->item(row);
         Qt::CheckState rowState = static_cast<Qt::CheckState>(it->data(Qt::CheckStateRole).toInt());
-        if (rowState!=Qt::Checked) {
+        if (rowState != Qt::Checked) {
             allOn = false;
             break;
         }
@@ -268,20 +250,21 @@ void CategorySelectWidgetPrivate::slotCheckedItemsTimer()
         checkCombo->setToolTip(QString());
     }
 
-    emit q->filterChanged(filterTags());
+    Q_EMIT q->filterChanged(filterTags());
 }
 
-
 QList<Akonadi::Tag::Id> CategorySelectWidgetPrivate::filterTags() const
 {
     QList<Tag::Id> filter;
     bool allOn = true;
-    for (int row = 0; row<itemModel()->rowCount(); ++row) {
+    for (int row = 0; row < itemModel()->rowCount(); ++row) {
         const QStandardItem *it = itemModel()->item(row);
-        Q_ASSERT(it!=NULL);
-        if (it->checkState()==Qt::Checked) {
+        Q_ASSERT(it != NULL);
+        if (it->checkState() == Qt::Checked) {
             Tag::Id id = it->data(FILTER_ROLE).toInt();
-            if (id!=0) filter.append(id);
+            if (id != 0) {
+                filter.append(id);
+            }
         } else {
             allOn = false;
         }
@@ -292,11 +275,10 @@ QList<Akonadi::Tag::Id> CategorySelectWidgetPrivate::filterTags() const
         filter.append(CategorySelectWidget::FilterAll);
     }
 
-    //kDebug() << "filter" << filter;
+    //qCDebug(KADDRESSBOOK_LOG) << "filter" << filter;
     return filter;
 }
 
-
 CategorySelectWidget::CategorySelectWidget(QWidget *parent)
     : QWidget(parent),
       d_ptr(new CategorySelectWidgetPrivate(this))
@@ -305,18 +287,15 @@ CategorySelectWidget::CategorySelectWidget(QWidget *parent)
     d->init();
 }
 
-
 CategorySelectWidget::~CategorySelectWidget()
 {
     delete d_ptr;
 }
 
-
 QList<Akonadi::Tag::Id> CategorySelectWidget::filterTags() const
 {
     Q_D(const CategorySelectWidget);
     return d->filterTags();
 }
 
-
 #include "categoryselectwidget.moc"
