@@ -21,14 +21,13 @@
 #ifndef BIRTHDAYMODEL_H
 #define BIRTHDAYMODEL_H
 
-#include <akonadi/contact/contactstreemodel.h>
+#include <Akonadi/Contact/ContactsTreeModel>
 
 #include <QSortFilterProxyModel>
 
 namespace Akonadi
 {
     class ChangeRecorder;
-    class Session;
 }
 
 /**
@@ -56,8 +55,8 @@ class BirthdayModel : public Akonadi::ContactsTreeModel
          */
         static BirthdayModel* instance();
 
-        virtual QVariant entityData(const Akonadi::Item&, int column, int role = Qt::DisplayRole) const;
-        virtual QVariant entityData(const Akonadi::Collection& collection, int column, int role = Qt::DisplayRole) const
+        QVariant entityData(const Akonadi::Item&, int column, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE;
+        QVariant entityData(const Akonadi::Collection& collection, int column, int role = Qt::DisplayRole) const Q_DECL_OVERRIDE
                                     { return Akonadi::ContactsTreeModel::entityData(collection, column, role); }
 
   private:
@@ -71,12 +70,12 @@ class BirthdaySortModel : public QSortFilterProxyModel
 {
         Q_OBJECT
     public:
-        explicit BirthdaySortModel(QObject* parent = 0);
+        explicit BirthdaySortModel(QObject* parent = Q_NULLPTR);
 
         void setPrefixSuffix(const QString& prefix, const QString& suffix);
 
     protected:
-        virtual bool filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const;
+        bool filterAcceptsRow(int sourceRow, const QModelIndex& sourceParent) const Q_DECL_OVERRIDE;
 
     private:
         QStringList mContactsWithAlarm;
