@@ -1,7 +1,7 @@
 /*
  *  calendarmigrator.cpp  -  migrates or creates KAlarm Akonadi resources
  *  Program:  kalarm
- *  Copyright © 2011-2014 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2011-2015 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -30,24 +30,29 @@
 #include <kalarmcal/compatibilityattribute.h>
 #include <kalarmcal/version.h>
 
-#include <akonadi/agentinstancecreatejob.h>
-#include <akonadi/agentmanager.h>
-#include <akonadi/collectionfetchjob.h>
-#include <akonadi/collectionfetchscope.h>
-#include <akonadi/collectionmodifyjob.h>
-#include <akonadi/entitydisplayattribute.h>
-#include <akonadi/resourcesynchronizationjob.h>
+#include <AkonadiCore/agentinstancecreatejob.h>
+#include <AkonadiCore/agentmanager.h>
+#include <AkonadiCore/collectionfetchjob.h>
+#include <AkonadiCore/collectionfetchscope.h>
+#include <AkonadiCore/collectionmodifyjob.h>
+#include <AkonadiCore/entitydisplayattribute.h>
+#include <AkonadiCore/resourcesynchronizationjob.h>
 
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kconfiggroup.h>
-#include <kstandarddirs.h>
-#include <kdebug.h>
 
 #include <QTimer>
+#include <QStandardPaths>
+#include "kalarm_debug.h"
 
 using namespace Akonadi;
 using namespace KAlarmCal;
 
+namespace
+{
+const QString KALARM_RESOURCE(QStringLiteral("akonadi_kalarm_resource"));
+const QString KALARM_DIR_RESOURCE(QStringLiteral("akonadi_kalarm_dir_resource"));
+}
 
 // Creates, or migrates from KResources, a single alarm calendar
 class CalendarCreator : public QObject
@@ -67,14 +72,14 @@ class CalendarCreator : public QObject
         QString        errorMessage() const   { return mErrorMessage; }
         void           createAgent(const QString& agentType, QObject* parent);
 
-    public slots:
+    public Q_SLOTS:
         void agentCreated(KJob*);
 
-    signals:
+    Q_SIGNALS:
         void creating(const QString& path);
         void finished(CalendarCreator*);
 
-    private slots:
+    private Q_SLOTS:
         void fetchCollection();
         void collectionFetchResult(KJob*);
         void resourceSynchronised(KJob*);
@@ -118,7 +123,7 @@ class CalendarUpdater : public QObject
         // Check whether any instance is for the given collection ID
         static bool containsCollection(Collection::Id);
 
-    public slots:
+    public Q_SLOTS:
         bool update();
 
     private:
@@ -132,7 +137,7 @@ class CalendarUpdater : public QObject
 };
 
 
-CalendarMigrator* CalendarMigrator::mInstance = 0;
+CalendarMigrator* CalendarMigrator::mInstance = Q_NULLPTR;
 bool              CalendarMigrator::mCompleted = false;
 
 CalendarMigrator::CalendarMigrator(QObject* parent)
@@ -143,8 +148,8 @@ CalendarMigrator::CalendarMigrator(QObject* parent)
 
 CalendarMigrator::~CalendarMigrator()
 {
-    kDebug();
-    mInstance = 0;
+    qCDebug(KALARM_LOG);
+    mInstance = Q_NULLPTR;
 }
 
 /******************************************************************************
@@ -178,7 +183,7 @@ void CalendarMigrator::execute()
 */
 void CalendarMigrator::migrateOrCreate()
 {
-    kDebug();
+    qCDebug(KALARM_LOG);
 
     // First, check whether any Akonadi resources already exist, and if
     // so, find their alarm types.
@@ -186,8 +191,7 @@ void CalendarMigrator::migrateOrCreate()
     foreach (const AgentInstance& agent, agents)
     {
         const QString type = agent.type().identifier();
-        if (type == QLatin1String("akonadi_kalarm_resource")
-        ||  type == QLatin1String("akonadi_kalarm_dir_resource"))
+        if (type == KALARM_RESOURCE  ||  type == KALARM_DIR_RESOURCE)
         {
             // Fetch the resource's collection to determine its alarm types
             CollectionFetchJob* job = new CollectionFetchJob(Collection::root(), CollectionFetchJob::FirstLevel);
@@ -203,7 +207,7 @@ void CalendarMigrator::migrateOrCreate()
     {
         // There are no Akonadi resources, so migrate any KResources alarm
         // calendars from pre-Akonadi versions of KAlarm.
-        const QString configFile = KStandardDirs::locateLocal("config", QLatin1String("kresources/alarms/stdrc"));
+        const QString configFile = QStandardPaths::writableLocation(QStandardPaths::ConfigLocation) + QStringLiteral("/kresources/alarms/stdrc");
         const KConfig config(configFile, KConfig::SimpleConfig);
 
         // Fetch all the KResource identifiers which are actually in use
@@ -215,15 +219,15 @@ void CalendarMigrator::migrateOrCreate()
         CalendarCreator* creator;
         foreach (const QString& id, keys)
         {
-            const KConfigGroup configGroup = config.group(QLatin1String("Resource_") + id);
+            const KConfigGroup configGroup = config.group(QStringLiteral("Resource_") + id);
             const QString resourceType = configGroup.readEntry("ResourceType", QString());
             QString agentType;
-            if (resourceType == QLatin1String("file"))
-                agentType = QLatin1String("akonadi_kalarm_resource");
-            else if (resourceType == QLatin1String("dir"))
-                agentType = QLatin1String("akonadi_kalarm_dir_resource");
-            else if (resourceType == QLatin1String("remote"))
-                agentType = QLatin1String("akonadi_kalarm_resource");
+            if (resourceType == QStringLiteral("file"))
+                agentType = KALARM_RESOURCE;
+            else if (resourceType == QStringLiteral("dir"))
+                agentType = KALARM_DIR_RESOURCE;
+            else if (resourceType == QStringLiteral("remote"))
+                agentType = KALARM_RESOURCE;
             else
                 continue;   // unknown resource type - can't convert
 
@@ -255,12 +259,12 @@ void CalendarMigrator::collectionFetchResult(KJob* j)
     CollectionFetchJob* job = static_cast<CollectionFetchJob*>(j);
     const QString id = job->fetchScope().resource();
     if (j->error())
-        kError() << "CollectionFetchJob" << id << "error: " << j->errorString();
+        qCCritical(KALARM_LOG) << "CollectionFetchJob" << id << "error: " << j->errorString();
     else
     {
         const Collection::List collections = job->collections();
         if (collections.isEmpty())
-            kError() << "No collections found for resource" << id;
+            qCCritical(KALARM_LOG) << "No collections found for resource" << id;
         else
             mExistingAlarmTypes |= CalEvent::types(collections[0].contentMimeTypes());
     }
@@ -283,31 +287,31 @@ void CalendarMigrator::collectionFetchResult(KJob* j)
 */
 void CalendarMigrator::createDefaultResources()
 {
-    kDebug();
+    qCDebug(KALARM_LOG);
     CalendarCreator* creator;
     if (!(mExistingAlarmTypes & CalEvent::ACTIVE))
     {
-        creator = new CalendarCreator(CalEvent::ACTIVE, QLatin1String("calendar.ics"), i18nc("@info/plain", "Active Alarms"));
+        creator = new CalendarCreator(CalEvent::ACTIVE, QStringLiteral("calendar.ics"), i18nc("@info", "Active Alarms"));
         connect(creator, SIGNAL(finished(CalendarCreator*)), SLOT(calendarCreated(CalendarCreator*)));
         connect(creator, SIGNAL(creating(QString)), SLOT(creatingCalendar(QString)));
         mCalendarsPending << creator;
-        creator->createAgent(QLatin1String("akonadi_kalarm_resource"), this);
+        creator->createAgent(KALARM_RESOURCE, this);
     }
     if (!(mExistingAlarmTypes & CalEvent::ARCHIVED))
     {
-        creator = new CalendarCreator(CalEvent::ARCHIVED, QLatin1String("expired.ics"), i18nc("@info/plain", "Archived Alarms"));
+        creator = new CalendarCreator(CalEvent::ARCHIVED, QStringLiteral("expired.ics"), i18nc("@info", "Archived Alarms"));
         connect(creator, SIGNAL(finished(CalendarCreator*)), SLOT(calendarCreated(CalendarCreator*)));
         connect(creator, SIGNAL(creating(QString)), SLOT(creatingCalendar(QString)));
         mCalendarsPending << creator;
-        creator->createAgent(QLatin1String("akonadi_kalarm_resource"), this);
+        creator->createAgent(KALARM_RESOURCE, this);
     }
     if (!(mExistingAlarmTypes & CalEvent::TEMPLATE))
     {
-        creator = new CalendarCreator(CalEvent::TEMPLATE, QLatin1String("template.ics"), i18nc("@info/plain", "Alarm Templates"));
+        creator = new CalendarCreator(CalEvent::TEMPLATE, QStringLiteral("template.ics"), i18nc("@info", "Alarm Templates"));
         connect(creator, SIGNAL(finished(CalendarCreator*)), SLOT(calendarCreated(CalendarCreator*)));
         connect(creator, SIGNAL(creating(QString)), SLOT(creatingCalendar(QString)));
         mCalendarsPending << creator;
-        creator->createAgent(QLatin1String("akonadi_kalarm_resource"), this);
+        creator->createAgent(KALARM_RESOURCE, this);
     }
 
     if (mCalendarsPending.isEmpty())
@@ -323,7 +327,7 @@ void CalendarMigrator::createDefaultResources()
 */
 void CalendarMigrator::creatingCalendar(const QString& path)
 {
-    emit creating(path, -1, false);
+    Q_EMIT creating(path, -1, false);
 }
 
 /******************************************************************************
@@ -336,20 +340,20 @@ void CalendarMigrator::calendarCreated(CalendarCreator* creator)
     if (i < 0)
         return;    // calendar already finished
 
-    emit creating(creator->path(), creator->collectionId(), true);
+    Q_EMIT creating(creator->path(), creator->collectionId(), true);
 
     if (!creator->errorMessage().isEmpty())
     {
         QString errmsg = creator->newCalendar()
-                       ? i18nc("@info/plain", "Failed to create default calendar <resource>%1</resource>", creator->resourceName())
-                       : i18nc("@info/plain 'Import Alarms' is the name of a menu option",
+                       ? xi18nc("@info/plain", "Failed to create default calendar <resource>%1</resource>", creator->resourceName())
+                       : xi18nc("@info/plain 'Import Alarms' is the name of a menu option",
                                "Failed to convert old configuration for calendar <resource>%1</resource>. "
                                "Please use Import Alarms to load its alarms into a new or existing calendar.", creator->resourceName());
-        const QString locn = i18nc("@info/plain File path or URL", "Location: %1", creator->path());
+        const QString locn = i18nc("@info File path or URL", "Location: %1", creator->path());
         if (creator->errorMessage().isEmpty())
-            errmsg = i18nc("@info", "<para>%1</para><para>%2</para>", errmsg, locn);
+            errmsg = xi18nc("@info", "<para>%1</para><para>%2</para>", errmsg, locn);
         else
-            errmsg = i18nc("@info", "<para>%1</para><para>%2<nl/>(%3)</para>", errmsg, locn, creator->errorMessage());
+            errmsg = xi18nc("@info", "<para>%1</para><para>%2<nl/>(%3)</para>", errmsg, locn, creator->errorMessage());
         KAMessageBox::error(MainWindow::mainMainWindow(), errmsg);
     }
     creator->deleteLater();
@@ -374,19 +378,19 @@ void CalendarMigrator::calendarCreated(CalendarCreator* creator)
 */
 void CalendarMigrator::updateToCurrentFormat(const Collection& collection, bool ignoreKeepFormat, QWidget* parent)
 {
-    kDebug() << collection.id();
+    qCDebug(KALARM_LOG) << collection.id();
     if (CalendarUpdater::containsCollection(collection.id()))
         return;   // prevent multiple simultaneous user prompts
     const AgentInstance agent = AgentManager::self()->instance(collection.resource());
     const QString id = agent.type().identifier();
     bool dirResource;
-    if (id == QLatin1String("akonadi_kalarm_resource"))
+    if (id == KALARM_RESOURCE)
         dirResource = false;
-    else if (id == QLatin1String("akonadi_kalarm_dir_resource"))
+    else if (id == KALARM_DIR_RESOURCE)
         dirResource = true;
     else
     {
-        kError() << "Invalid agent type" << id;
+        qCCritical(KALARM_LOG) << "Invalid agent type" << id;
         return;
     }
     CalendarUpdater* updater = new CalendarUpdater(collection, dirResource, ignoreKeepFormat, false, parent);
@@ -425,7 +429,7 @@ bool CalendarUpdater::containsCollection(Collection::Id id)
 
 bool CalendarUpdater::update()
 {
-    kDebug() << mCollection.id() << (mDirResource ? "directory" : "file");
+    qCDebug(KALARM_LOG) << mCollection.id() << (mDirResource ? "directory" : "file");
     bool result = true;
     if (!mDuplicate     // prevent concurrent updates
     &&  mCollection.hasAttribute<CompatibilityAttribute>())   // must know format to update
@@ -440,13 +444,13 @@ bool CalendarUpdater::update()
             if (!mIgnoreKeepFormat
             &&  mCollection.hasAttribute<CollectionAttribute>()
             &&  mCollection.attribute<CollectionAttribute>()->keepFormat())
-                kDebug() << "Not updating format (previous user choice)";
+                qCDebug(KALARM_LOG) << "Not updating format (previous user choice)";
             else
             {
                 // The user hasn't previously said not to convert it
                 const QString versionString = KAlarmCal::getVersionString(compatAttr->version());
                 const QString msg = KAlarm::conversionPrompt(mCollection.name(), versionString, false);
-                kDebug() << "Version" << versionString;
+                qCDebug(KALARM_LOG) << "Version" << versionString;
                 if (KAMessageBox::warningYesNo(qobject_cast<QWidget*>(mParent), msg) != KMessageBox::Yes)
                     result = false;   // the user chose not to update the calendar
                 else
@@ -458,7 +462,7 @@ bool CalendarUpdater::update()
                         // Refetch the collection's details because anything could
                         // have happened since the prompt was first displayed.
                         if (!AkonadiModel::instance()->refresh(mCollection))
-                            errmsg = i18nc("@info/plain", "Invalid collection");
+                            errmsg = i18nc("@info", "Invalid collection");
                     }
                     if (errmsg.isEmpty())
                     {
@@ -471,8 +475,8 @@ bool CalendarUpdater::update()
                     if (!errmsg.isEmpty())
                     {
                         KAMessageBox::error(MainWindow::mainMainWindow(),
-                                            i18nc("@info", "%1<nl/>(%2)",
-                                                  i18nc("@info/plain", "Failed to update format of calendar <resource>%1</resource>", mCollection.name()),
+                                            xi18nc("@info", "%1<nl/>(%2)",
+                                                  xi18nc("@info/plain", "Failed to update format of calendar <resource>%1</resource>", mCollection.name()),
                                             errmsg));
                     }
                 }
@@ -496,17 +500,17 @@ bool CalendarUpdater::update()
 */
 template <class Interface> bool CalendarMigrator::updateStorageFormat(const AgentInstance& agent, QString& errorMessage, QObject* parent)
 {
-    kDebug();
+    qCDebug(KALARM_LOG);
     Interface* iface = getAgentInterface<Interface>(agent, errorMessage, parent);
     if (!iface)
     {
-        kDebug() << errorMessage;
+        qCDebug(KALARM_LOG) << errorMessage;
         return false;
     }
     iface->setUpdateStorageFormat(true);
-    iface->writeConfig();
+    iface->save();
     delete iface;
-    kDebug() << "true";
+    qCDebug(KALARM_LOG) << "true";
     return true;
 }
 
@@ -517,14 +521,14 @@ template <class Interface> bool CalendarMigrator::updateStorageFormat(const Agen
 */
 template <class Interface> Interface* CalendarMigrator::getAgentInterface(const AgentInstance& agent, QString& errorMessage, QObject* parent)
 {
-    Interface* iface = new Interface(QLatin1String("org.freedesktop.Akonadi.Resource.") + agent.identifier(),
-              QLatin1String("/Settings"), QDBusConnection::sessionBus(), parent);
+    Interface* iface = new Interface(QStringLiteral("org.freedesktop.Akonadi.Resource.") + agent.identifier(),
+              QStringLiteral("/Settings"), QDBusConnection::sessionBus(), parent);
     if (!iface->isValid())
     {
         errorMessage = iface->lastError().message();
-        kDebug() << "D-Bus error accessing resource:" << errorMessage;
+        qCDebug(KALARM_LOG) << "D-Bus error accessing resource:" << errorMessage;
         delete iface;
-        return 0;
+        return Q_NULLPTR;
     }
     return iface;
 }
@@ -539,35 +543,35 @@ CalendarCreator::CalendarCreator(const QString& resourceType, const KConfigGroup
       mFinished(false)
 {
     // Read the resource configuration parameters from the config
-    const char* pathKey = 0;
-    if (resourceType == QLatin1String("file"))
+    const char* pathKey = Q_NULLPTR;
+    if (resourceType == QStringLiteral("file"))
     {
         mResourceType = LocalFile;
         pathKey = "CalendarURL";
     }
-    else if (resourceType == QLatin1String("dir"))
+    else if (resourceType == QStringLiteral("dir"))
     {
         mResourceType = LocalDir;
         pathKey = "CalendarURL";
     }
-    else if (resourceType == QLatin1String("remote"))
+    else if (resourceType == QStringLiteral("remote"))
     {
         mResourceType = RemoteFile;
         pathKey = "DownloadUrl";
     }
     else
     {
-        kError() << "Invalid resource type:" << resourceType;
+        qCCritical(KALARM_LOG) << "Invalid resource type:" << resourceType;
         return;
     }
-    mPath = config.readPathEntry(pathKey, QLatin1String(""));
+    mPath = config.readPathEntry(pathKey, QStringLiteral(""));
     switch (config.readEntry("AlarmType", (int)0))
     {
         case 1:  mAlarmType = CalEvent::ACTIVE;  break;
         case 2:  mAlarmType = CalEvent::ARCHIVED;  break;
         case 4:  mAlarmType = CalEvent::TEMPLATE;  break;
         default:
-            kError() << "Invalid alarm type for resource";
+            qCCritical(KALARM_LOG) << "Invalid alarm type for resource";
             return;
     }
     mName     = config.readEntry("ResourceName", QString());
@@ -575,7 +579,7 @@ CalendarCreator::CalendarCreator(const QString& resourceType, const KConfigGroup
     mReadOnly = config.readEntry("ResourceIsReadOnly", true);
     mEnabled  = config.readEntry("ResourceIsActive", false);
     mStandard = config.readEntry("Standard", false);
-    kDebug() << "Migrating:" << mName << ", type=" << mAlarmType << ", path=" << mPath;
+    qCDebug(KALARM_LOG) << "Migrating:" << mName << ", type=" << mAlarmType << ", path=" << mPath;
 }
 
 /******************************************************************************
@@ -593,8 +597,8 @@ CalendarCreator::CalendarCreator(CalEvent::Type alarmType, const QString& file,
       mNew(true),
       mFinished(false)
 {
-    mPath = KStandardDirs::locateLocal("appdata", file);
-    kDebug() << "New:" << mName << ", type=" << mAlarmType << ", path=" << mPath;
+    mPath = QStandardPaths::writableLocation(QStandardPaths::DataLocation) + QLatin1Char('/') + file;
+    qCDebug(KALARM_LOG) << "New:" << mName << ", type=" << mAlarmType << ", path=" << mPath;
 }
 
 /******************************************************************************
@@ -602,7 +606,7 @@ CalendarCreator::CalendarCreator(CalEvent::Type alarmType, const QString& file,
 */
 void CalendarCreator::createAgent(const QString& agentType, QObject* parent)
 {
-    emit creating(mPath);
+    Q_EMIT creating(mPath);
     AgentInstanceCreateJob* job = new AgentInstanceCreateJob(agentType, parent);
     connect(job, SIGNAL(result(KJob*)), SLOT(agentCreated(KJob*)));
     job->start();
@@ -617,13 +621,13 @@ void CalendarCreator::agentCreated(KJob* j)
     if (j->error())
     {
         mErrorMessage = j->errorString();
-        kError() << "AgentInstanceCreateJob error:" << mErrorMessage;
+        qCCritical(KALARM_LOG) << "AgentInstanceCreateJob error:" << mErrorMessage;
         finish(false);
         return;
     }
 
     // Configure the Akonadi Agent
-    kDebug() << mName;
+    qCDebug(KALARM_LOG) << mName;
     AgentInstanceCreateJob* job = static_cast<AgentInstanceCreateJob*>(j);
     mAgent = job->instance();
     mAgent.setName(mName);
@@ -640,7 +644,7 @@ void CalendarCreator::agentCreated(KJob* j)
             ok = writeRemoteFileConfig();
             break;
         default:
-            kError() << "Invalid resource type";
+            qCCritical(KALARM_LOG) << "Invalid resource type";
             break;
     }
     if (!ok)
@@ -657,16 +661,16 @@ void CalendarCreator::agentCreated(KJob* j)
 }
 
 /******************************************************************************
-* Called when a resource synchronisation job has completed.
+* Called when a resource synchronization job has completed.
 * Fetches the collection which this agent manages.
 */
 void CalendarCreator::resourceSynchronised(KJob* j)
 {
-    kDebug() << mName;
+    qCDebug(KALARM_LOG) << mName;
     if (j->error())
     {
         // Don't give up on error - we can still try to fetch the collection
-        kError() << "ResourceSynchronizationJob error: " << j->errorString();
+        qCCritical(KALARM_LOG) << "ResourceSynchronizationJob error: " << j->errorString();
     }
     mCollectionFetchRetryCount = 0;
     fetchCollection();
@@ -689,7 +693,7 @@ bool CalendarCreator::writeLocalFileConfig()
     if (!iface)
         return false;
     iface->setMonitorFile(true);
-    iface->writeConfig();   // save the Agent config changes
+    iface->save();   // save the Agent config changes
     delete iface;
     return true;
 }
@@ -700,7 +704,7 @@ bool CalendarCreator::writeLocalDirectoryConfig()
     if (!iface)
         return false;
     iface->setMonitorFiles(true);
-    iface->writeConfig();   // save the Agent config changes
+    iface->save();   // save the Agent config changes
     delete iface;
     return true;
 }
@@ -711,7 +715,7 @@ bool CalendarCreator::writeRemoteFileConfig()
     if (!iface)
         return false;
     iface->setMonitorFile(true);
-    iface->writeConfig();   // save the Agent config changes
+    iface->save();   // save the Agent config changes
     delete iface;
     return true;
 }
@@ -736,11 +740,11 @@ template <class Interface> Interface* CalendarCreator::writeBasicConfig()
 */
 void CalendarCreator::collectionFetchResult(KJob* j)
 {
-    kDebug() << mName;
+    qCDebug(KALARM_LOG) << mName;
     if (j->error())
     {
         mErrorMessage = j->errorString();
-        kError() << "CollectionFetchJob error: " << mErrorMessage;
+        qCCritical(KALARM_LOG) << "CollectionFetchJob error: " << mErrorMessage;
         finish(true);
         return;
     }
@@ -750,21 +754,21 @@ void CalendarCreator::collectionFetchResult(KJob* j)
     {
         if (++mCollectionFetchRetryCount >= 10)
         {
-            mErrorMessage = i18nc("@info/plain", "New configuration timed out");
-            kError() << "Timeout fetching collection for resource";
+            mErrorMessage = i18nc("@info", "New configuration timed out");
+            qCCritical(KALARM_LOG) << "Timeout fetching collection for resource";
             finish(true);
             return;
         }
         // Need to wait a bit longer until the resource has initialised and
         // created its collection. Retry after 200ms.
-        kDebug() << "Retrying";
+        qCDebug(KALARM_LOG) << "Retrying";
         QTimer::singleShot(200, this, SLOT(fetchCollection()));
         return;
     }
     if (collections.count() > 1)
     {
-        mErrorMessage = i18nc("@info/plain", "New configuration was corrupt");
-        kError() << "Wrong number of collections for this resource:" << collections.count();
+        mErrorMessage = i18nc("@info", "New configuration was corrupt");
+        qCCritical(KALARM_LOG) << "Wrong number of collections for this resource:" << collections.count();
         finish(true);
         return;
     }
@@ -774,7 +778,7 @@ void CalendarCreator::collectionFetchResult(KJob* j)
     mCollectionId = collection.id();
     collection.setContentMimeTypes(CalEvent::mimeTypes(mAlarmType));
     EntityDisplayAttribute* dattr = collection.attribute<EntityDisplayAttribute>(Collection::AddIfMissing);
-    dattr->setIconName(QLatin1String("kalarm"));
+    dattr->setIconName(QStringLiteral("kalarm"));
     CollectionAttribute* attr = collection.attribute<CollectionAttribute>(Entity::AddIfMissing);
     attr->setEnabled(mEnabled ? mAlarmType : CalEvent::EMPTY);
     if (mStandard)
@@ -833,12 +837,12 @@ void CalendarCreator::modifyCollectionJobDone(KJob* j)
     if (j->error())
     {
         mErrorMessage = j->errorString();
-        kError() << "CollectionFetchJob error: " << mErrorMessage;
+        qCCritical(KALARM_LOG) << "CollectionFetchJob error: " << mErrorMessage;
         finish(true);
     }
     else
     {
-        kDebug() << "Completed:" << mName;
+        qCDebug(KALARM_LOG) << "Completed:" << mName;
         finish(false);
     }
 }
@@ -854,7 +858,7 @@ void CalendarCreator::finish(bool cleanup)
         if (cleanup)
             AgentManager::self()->removeInstance(mAgent);
         mFinished = true;
-        emit finished(this);
+        Q_EMIT finished(this);
     }
 }
 
