@@ -24,11 +24,8 @@
 #include "checkbox.h"
 #include "fontcolour.h"
 
-#include <kglobal.h>
 #include <kfontchooser.h>
 #include <kfontdialog.h>
-#include <kcolordialog.h>
-#include <khbox.h>
 
 #include <QGroupBox>
 #include <QPushButton>
@@ -37,10 +34,10 @@
 #include <QHBoxLayout>
 
 
-FontColourChooser::FontColourChooser(QWidget *parent,
-          const QStringList &fontList, const QString& frameLabel, bool fg, bool defaultFont, int visibleListSize)
+FontColourChooser::FontColourChooser(QWidget* parent, const QStringList& fontList,
+           const QString& frameLabel, bool fg, bool defaultFont, int visibleListSize)
     : QWidget(parent),
-      mFgColourButton(0),
+      mFgColourButton(Q_NULLPTR),
       mReadOnly(false)
 {
     QVBoxLayout* topLayout = new QVBoxLayout(this);
@@ -63,28 +60,34 @@ FontColourChooser::FontColourChooser(QWidget *parent,
     hlayout->addLayout(colourLayout);
     if (fg)
     {
-        KHBox* box = new KHBox(page);    // to group widgets for QWhatsThis text
-        box->setMargin(0);
-        box->setSpacing(KDialog::spacingHint()/2);
+        QWidget* box = new QWidget(page);    // to group widgets for QWhatsThis text
         colourLayout->addWidget(box);
+        QHBoxLayout* boxHLayout = new QHBoxLayout(box);
+        boxHLayout->setMargin(0);
+        boxHLayout->setSpacing(KDialog::spacingHint()/2);
 
         QLabel* label = new QLabel(i18nc("@label:listbox", "Foreground color:"), box);
-        box->setStretchFactor(new QWidget(box), 0);
+        boxHLayout->addWidget(label);
+        boxHLayout->setStretchFactor(new QWidget(box), 0);
         mFgColourButton = new ColourButton(box);
-        connect(mFgColourButton, SIGNAL(changed(QColor)), SLOT(setSampleColour()));
+        boxHLayout->addWidget(mFgColourButton);
+        connect(mFgColourButton, &ColourButton::changed, this, &FontColourChooser::setSampleColour);
         label->setBuddy(mFgColourButton);
         box->setWhatsThis(i18nc("@info:whatsthis", "Select the alarm message foreground color"));
     }
 
-    KHBox* box = new KHBox(page);    // to group widgets for QWhatsThis text
-    box->setMargin(0);
-    box->setSpacing(KDialog::spacingHint()/2);
+    QWidget* box = new QWidget(page);    // to group widgets for QWhatsThis text
     colourLayout->addWidget(box);
+    QHBoxLayout* boxHLayout = new QHBoxLayout(box);
+    boxHLayout->setMargin(0);
+    boxHLayout->setSpacing(KDialog::spacingHint()/2);
 
     QLabel* label = new QLabel(i18nc("@label:listbox", "Background color:"), box);
-    box->setStretchFactor(new QWidget(box), 0);
+    boxHLayout->addWidget(label);
+    boxHLayout->setStretchFactor(new QWidget(box), 0);
     mBgColourButton = new ColourButton(box);
-    connect(mBgColourButton, SIGNAL(changed(QColor)), SLOT(setSampleColour()));
+    boxHLayout->addWidget(mBgColourButton);
+    connect(mBgColourButton, &ColourButton::changed, this, &FontColourChooser::setSampleColour);
     label->setBuddy(mBgColourButton);
     box->setWhatsThis(i18nc("@info:whatsthis", "Select the alarm message background color"));
     hlayout->addStretch();
@@ -96,13 +99,13 @@ FontColourChooser::FontColourChooser(QWidget *parent,
         topLayout->addLayout(layout);
         mDefaultFont = new CheckBox(i18nc("@option:check", "Use default font"), page);
         mDefaultFont->setMinimumSize(mDefaultFont->sizeHint());
-        connect(mDefaultFont, SIGNAL(toggled(bool)), SLOT(slotDefaultFontToggled(bool)));
+        connect(mDefaultFont, &CheckBox::toggled, this, &FontColourChooser::slotDefaultFontToggled);
         mDefaultFont->setWhatsThis(i18nc("@info:whatsthis", "Check to use the default font current at the time the alarm is displayed."));
         layout->addWidget(mDefaultFont);
         layout->addWidget(new QWidget(page));    // left adjust the widget
     }
     else
-        mDefaultFont = 0;
+        mDefaultFont = Q_NULLPTR;
 
     mFontChooser = new KFontChooser(page, KFontChooser::DisplayFrame, fontList, visibleListSize);
     mFontChooser->installEventFilter(this);   // for read-only mode
@@ -223,6 +226,6 @@ void FontColourChooser::slotDefaultFontToggled(bool on)
 {
     mFontChooser->setEnabled(!on);
 }
-#include "moc_fontcolour.cpp"
+
 
 // vim: et sw=4:
