@@ -1,7 +1,7 @@
 /*
  *  kalarm.h  -  global header file
  *  Program:  kalarm
- *  Copyright © 2001-2014 by David Jarvie <djarvie@kde.org>
+ *  Copyright © 2001-2015 by David Jarvie <djarvie@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,17 +23,13 @@
 
 #undef QT3_SUPPORT
 
-#ifdef USE_AKONADI
-#define VERSION_SUFFIX "-ak"
-#else
-#define VERSION_SUFFIX "-res"
-#endif
-#define KALARM_VERSION "2.10.11" VERSION_SUFFIX
+#define VERSION_SUFFIX "-5ak"
+#define KALARM_VERSION "2.11.0" VERSION_SUFFIX
 
 #define KALARM_NAME "KAlarm"
 #define KALARM_DBUS_SERVICE  "org.kde.kalarm"  // D-Bus service name of KAlarm application
 
-#include <kdeversion.h>
+//#include <kdeversion.h>
 
 namespace KAlarm
 {
