@@ -23,15 +23,10 @@
 
 #include "checkbox.h"
 
-#ifdef USE_AKONADI
-#include <kcalcore/duration.h>
+#include <KCalCore/Duration>
 using namespace KCalCore;
-#else
-#include <kcal/duration.h>
-using namespace KCal;
-#endif
 
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kdialog.h>
 
 #include <QStackedWidget>
@@ -52,7 +47,7 @@ LateCancelSelector::LateCancelSelector(bool allowHourMinute, QWidget* parent)
       mReadOnly(false),
       mAutoCloseShown(false)
 {
-    QString whatsThis = i18nc("@info:whatsthis",
+    QString whatsThis = xi18nc("@info:whatsthis",
                               "<para>If checked, the alarm will be canceled if it cannot be triggered within the "
                              "specified period after its scheduled time. Possible reasons for not triggering "
                              "include your being logged off, X not running, or <application>KAlarm</application> not running.</para>"
@@ -70,8 +65,8 @@ LateCancelSelector::LateCancelSelector(bool allowHourMinute, QWidget* parent)
     QHBoxLayout* hlayout = new QHBoxLayout(mCheckboxFrame);
     hlayout->setMargin(0);
     mCheckbox = new CheckBox(i18n_chk_CancelIfLate(), mCheckboxFrame);
-    connect(mCheckbox, SIGNAL(toggled(bool)), SLOT(slotToggled(bool)));
-    connect(mCheckbox, SIGNAL(toggled(bool)), SIGNAL(changed()));
+    connect(mCheckbox, &CheckBox::toggled, this, &LateCancelSelector::slotToggled);
+    connect(mCheckbox, &CheckBox::toggled, this, &LateCancelSelector::changed);
     mCheckbox->setWhatsThis(whatsThis);
     hlayout->addWidget(mCheckbox, 0, Qt::AlignLeft);
 
@@ -82,12 +77,8 @@ LateCancelSelector::LateCancelSelector(bool allowHourMinute, QWidget* parent)
     mTimeSelector = new TimeSelector(i18nc("@option:check Cancel if late by 10 minutes", "Cancel if late by"),
                                      whatsThis, i18nc("@info:whatsthis", "Enter how late will cause the alarm to be canceled"),
                                      allowHourMinute, mTimeSelectorFrame);
-    connect(mTimeSelector, SIGNAL(toggled(bool)), SLOT(slotToggled(bool)));
-#ifdef USE_AKONADI
-    connect(mTimeSelector, SIGNAL(valueChanged(KCalCore::Duration)), SIGNAL(changed()));
-#else
-    connect(mTimeSelector, SIGNAL(valueChanged(KCal::Duration)), SIGNAL(changed()));
-#endif
+    connect(mTimeSelector, &TimeSelector::toggled, this, &LateCancelSelector::slotToggled);
+    connect(mTimeSelector, &TimeSelector::valueChanged, this, &LateCancelSelector::changed);
     hlayout->addWidget(mTimeSelector, 0, Qt::AlignLeft);
 
     hlayout = new QHBoxLayout();
@@ -95,7 +86,7 @@ LateCancelSelector::LateCancelSelector(bool allowHourMinute, QWidget* parent)
     hlayout->addSpacing(3*KDialog::spacingHint());
     topLayout->addLayout(hlayout);
     mAutoClose = new CheckBox(i18n_chk_AutoCloseWin(), this);
-    connect(mAutoClose, SIGNAL(toggled(bool)), SIGNAL(changed()));
+    connect(mAutoClose, &CheckBox::toggled, this, &LateCancelSelector::changed);
     mAutoClose->setWhatsThis(i18nc("@info:whatsthis", "Automatically close the alarm window after the expiry of the late-cancellation period"));
     hlayout->addWidget(mAutoClose);
     hlayout->addStretch();
@@ -180,5 +171,5 @@ void LateCancelSelector::slotToggled(bool on)
         mStack->setCurrentWidget(mCheckboxFrame);
     mAutoClose->setEnabled(on);
 }
-#include "moc_latecancel.cpp"
+
 // vim: et sw=4:
