@@ -26,14 +26,14 @@
 CheckBox::CheckBox(QWidget* parent)
     : QCheckBox(parent),
       mFocusPolicy(focusPolicy()),
-      mFocusWidget(0),
+      mFocusWidget(Q_NULLPTR),
       mReadOnly(false)
 { }
 
 CheckBox::CheckBox(const QString& text, QWidget* parent)
     : QCheckBox(text, parent),
       mFocusPolicy(focusPolicy()),
-      mFocusWidget(0),
+      mFocusWidget(Q_NULLPTR),
       mReadOnly(false)
 { }
 
@@ -60,9 +60,9 @@ void CheckBox::setFocusWidget(QWidget* w, bool enable)
     mFocusWidget = w;
     mFocusWidgetEnable = enable;
     if (w)
-        connect(this, SIGNAL(clicked()), SLOT(slotClicked()));
+        connect(this, &CheckBox::clicked, this, &CheckBox::slotClicked);
     else
-        disconnect(this, SIGNAL(clicked()), this, SLOT(slotClicked()));
+        disconnect(this, &CheckBox::clicked, this, &CheckBox::slotClicked);
 }
 
 /******************************************************************************
@@ -135,5 +135,5 @@ void CheckBox::keyReleaseEvent(QKeyEvent* e)
     if (!mReadOnly)
         QCheckBox::keyReleaseEvent(e);
 }
-#include "moc_checkbox.cpp"
+
 // vim: et sw=4:
