@@ -21,24 +21,29 @@
 #include "kalarm.h"
 
 #include "kalarmapp.h"
+#include "kalarmmigrateapplication.h"
 
 #include <kalarmcal/version.h>
 
 #include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <klocale.h>
-#include <kdebug.h>
+#include <k4aboutdata.h>
+#include <KLocalizedString>
+#include "kalarm_debug.h"
 
 #include <stdlib.h>
 
 #define PROGRAM_NAME "kalarm"
 
 
-int main(int argc, char *argv[])
+int main(int argc, char* argv[])
 {
-    KAboutData aboutData(PROGRAM_NAME, 0, ki18n("KAlarm"), KALARM_VERSION,
+    KAlarmMigrateApplication migrate;
+    migrate.migrate();
+
+    KLocalizedString::setApplicationDomain("kalarm");
+    K4AboutData aboutData(PROGRAM_NAME, 0, ki18n("KAlarm"), KALARM_VERSION,
         ki18n("Personal alarm message, command and email scheduler for KDE"),
-        KAboutData::License_GPL,
+        K4AboutData::License_GPL,
         ki18n("Copyright 2001-2014, David Jarvie"), KLocalizedString(), "http://www.astrojar.org.uk/kalarm");
     aboutData.addAuthor(ki18n("David Jarvie"), KLocalizedString(), "djarvie@kde.org");
     aboutData.setOrganizationDomain("kde.org");
@@ -125,7 +130,7 @@ int main(int argc, char *argv[])
     }
 
     // This is the first time through
-    kDebug() << "initialising";
+    qCDebug(KALARM_LOG) << "initialising";
     KAlarmApp* app = KAlarmApp::getInstance();
     app->restoreSession();
     return app->exec();
@@ -141,7 +146,7 @@ int Version()
 {
     static int version = 0;
     if (!version)
-        version = KAlarmCal::getVersionNumber(QLatin1String(KALARM_VERSION));
+        version = KAlarmCal::getVersionNumber(QStringLiteral(KALARM_VERSION));
     return version;
 }
 
