@@ -27,16 +27,16 @@
 
 #include <kalarmcal/identities.h>
 
-#include <kpimidentities/identity.h>
-#include <kpimidentities/identitymanager.h>
-#include <kholidays/holidays.h>
+#include <KIdentityManagement/kidentitymanagement/identity.h>
+#include <KIdentityManagement/kidentitymanagement/identitymanager.h>
+#include <KHolidays/kholidays/holidays.h>
 
 #include <kglobal.h>
+#include <KSharedConfig>
 #include <kconfiggroup.h>
 #include <kmessagebox.h>
 #include <ksystemtimezone.h>
-#include <kdebug.h>
-
+#include "kalarm_debug.h"
 
 #include <time.h>
 #include <unistd.h>
@@ -51,8 +51,8 @@ static const char* GENERAL_SECTION  = "General";
 static const char* TEMP = "Temp";
 
 // Values for EmailFrom entry
-static const QString FROM_SYS_SETTINGS = QLatin1String("@SystemSettings");
-static const QString FROM_KMAIL        = QLatin1String("@KMail");
+static const QString FROM_SYS_SETTINGS(QStringLiteral("@SystemSettings"));
+static const QString FROM_KMAIL(QStringLiteral("@KMail"));
 
 // Config file entry names for notification messages
 const QLatin1String Preferences::QUIT_WARN("QuitWarn");
@@ -66,10 +66,10 @@ const bool  default_confirmAlarmDeletion = true;
 static QString translateXTermPath(const QString& cmdline, bool write);
 
 
-Preferences*   Preferences::mInstance = 0;
+Preferences*   Preferences::mInstance = Q_NULLPTR;
 bool           Preferences::mUsingDefaults = false;
 KTimeZone      Preferences::mSystemTimeZone;
-HolidayRegion* Preferences::mHolidays = 0;   // always non-null after Preferences initialisation
+HolidayRegion* Preferences::mHolidays = Q_NULLPTR;   // always non-null after Preferences initialisation
 QString        Preferences::mPreviousVersion;
 Preferences::Backend Preferences::mPreviousBackend;
 // Change tracking
@@ -93,19 +93,19 @@ Preferences* Preferences::self()
 
 Preferences::Preferences()
 {
-    QObject::connect(this, SIGNAL(base_StartOfDayChanged(QDateTime)), SLOT(startDayChange(QDateTime)));
-    QObject::connect(this, SIGNAL(base_TimeZoneChanged(QString)), SLOT(timeZoneChange(QString)));
-    QObject::connect(this, SIGNAL(base_HolidayRegionChanged(QString)), SLOT(holidaysChange(QString)));
-    QObject::connect(this, SIGNAL(base_WorkTimeChanged(QDateTime,QDateTime,int)), SLOT(workTimeChange(QDateTime,QDateTime,int)));
+    QObject::connect(this, &Preferences::base_StartOfDayChanged, this, &Preferences::startDayChange);
+    QObject::connect(this, &Preferences::base_TimeZoneChanged, this, &Preferences::timeZoneChange);
+    QObject::connect(this, &Preferences::base_HolidayRegionChanged, this, &Preferences::holidaysChange);
+    QObject::connect(this, &Preferences::base_WorkTimeChanged, this, &Preferences::workTimeChange);
 
-    readConfig();
+    load();
     // Fetch the KAlarm version and backend which wrote the previous config file
     mPreviousVersion = version();
     mPreviousBackend = backend();
     // Update the KAlarm version in the config file, but don't call
     // writeConfig() here - leave it to be written only if the config file
     // is updated with other data.
-    setVersion(QLatin1String(KALARM_VERSION));
+    setVersion(QStringLiteral(KALARM_VERSION));
 }
 
 void Preferences::setAskAutoStart(bool yes)
@@ -143,7 +143,7 @@ void Preferences::setTimeZone(const KTimeZone& tz)
 void Preferences::timeZoneChange(const QString& zone)
 {
     Q_UNUSED(zone);
-    emit mInstance->timeZoneChanged(timeZone(false));
+    Q_EMIT mInstance->timeZoneChanged(timeZone(false));
 }
 
 const HolidayRegion& Preferences::holidays()
@@ -165,7 +165,7 @@ void Preferences::setHolidayRegion(const QString& regionCode)
 void Preferences::holidaysChange(const QString& regionCode)
 {
     Q_UNUSED(regionCode);
-    emit mInstance->holidaysChanged(holidays());
+    Q_EMIT mInstance->holidaysChanged(holidays());
 }
 
 void Preferences::setStartOfDay(const QTime& t)
@@ -173,14 +173,14 @@ void Preferences::setStartOfDay(const QTime& t)
     if (t != self()->mBase_StartOfDay.time())
     {
         self()->setBase_StartOfDay(QDateTime(QDate(1900,1,1), t));
-        emit mInstance->startOfDayChanged(t);
+        Q_EMIT mInstance->startOfDayChanged(t);
     }
 }
 
 // Called when the start of day value has changed in the config file
 void Preferences::startDayChange(const QDateTime& dt)
 {
-    emit mInstance->startOfDayChanged(dt.time());
+    Q_EMIT mInstance->startOfDayChanged(dt.time());
 }
 
 QBitArray Preferences::workDays()
@@ -207,7 +207,7 @@ void Preferences::workTimeChange(const QDateTime& start, const QDateTime& end, i
     for (int i = 0;  i < 7;  ++i)
         if (days & (1 << i))
             dayBits.setBit(i);
-    emit mInstance->workTimeChanged(start.time(), end.time(), dayBits);
+    Q_EMIT mInstance->workTimeChanged(start.time(), end.time(), dayBits);
 }
 
 Preferences::MailFrom Preferences::emailFrom()
@@ -359,7 +359,7 @@ QString translateXTermPath(const QString& cmdline, bool write)
     }
     // Translate any home directory specification at the start of the
     // executable's path.
-    KConfigGroup group(KGlobal::config(), GENERAL_SECTION);
+    KConfigGroup group(KSharedConfig::openConfig(), GENERAL_SECTION);
     if (write)
     {
         group.writePathEntry(TEMP, cmd);
@@ -376,5 +376,5 @@ QString translateXTermPath(const QString& cmdline, bool write)
     else
         return cmd + params;
 }
-#include "moc_preferences.cpp"
+
 // vim: et sw=4:
