@@ -41,22 +41,17 @@
 #include <kalarmcal/kaevent.h>
 #include <kalarmcal/karecurrence.h>
 
-#ifdef USE_AKONADI
-#include <kcalcore/event.h>
+#include <KCalCore/Event>
 using namespace KCalCore;
-#else
-#include <kcal/event.h>
-using namespace KCal;
-#endif
 
 #include <kglobal.h>
-#include <klocale.h>
+#include <KLocalizedString>
 #include <kcalendarsystem.h>
 #include <kiconloader.h>
 #include <kdialog.h>
 #include <kmessagebox.h>
-#include <kdebug.h>
 #include <kdatecombobox.h>
+#include <KHBox>
 
 #include <QPushButton>
 #include <QLabel>
@@ -67,13 +62,14 @@ using namespace KCal;
 #include <QHBoxLayout>
 #include <QVBoxLayout>
 #include <QtAlgorithms>
+#include "kalarm_debug.h"
 
 
 class ListWidget : public QListWidget
 {
     public:
         explicit ListWidget(QWidget* parent) : QListWidget(parent) {}
-        virtual QSize sizeHint() const  { return minimumSizeHint(); }
+        QSize sizeHint() const Q_DECL_OVERRIDE  { return minimumSizeHint(); }
 };
 
 // Collect these widget labels together to ensure consistent wording and
@@ -89,7 +85,7 @@ QString RecurrenceEdit::i18n_combo_Yearly()         { return i18nc("@item:inlist
 
 RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     : QFrame(parent),
-      mRule(0),
+      mRule(Q_NULLPTR),
       mRuleButtonType(INVALID_RECUR),
       mDailyShown(false),
       mWeeklyShown(false),
@@ -98,7 +94,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
       mNoEmitTypeChanged(true),
       mReadOnly(readOnly)
 {
-    kDebug();
+    qCDebug(KALARM_LOG);
     QVBoxLayout* topLayout = new QVBoxLayout(this);
     topLayout->setMargin(0);
     topLayout->setSpacing(KDialog::spacingHint());
@@ -122,8 +118,8 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     vlayout->setMargin(0);
     hlayout->addLayout(vlayout);
     mRuleButtonGroup = new ButtonGroup(recurGroup);
-    connect(mRuleButtonGroup, SIGNAL(buttonSet(QAbstractButton*)), SLOT(periodClicked(QAbstractButton*)));
-    connect(mRuleButtonGroup, SIGNAL(buttonSet(QAbstractButton*)), SIGNAL(contentsChanged()));
+    connect(mRuleButtonGroup, &ButtonGroup::buttonSet, this, &RecurrenceEdit::periodClicked);
+    connect(mRuleButtonGroup, &ButtonGroup::buttonSet, this, &RecurrenceEdit::contentsChanged);
 
     mNoneButton = new RadioButton(i18n_combo_NoRecur(), recurGroup);
     mNoneButton->setFixedSize(mNoneButton->sizeHint());
@@ -135,7 +131,7 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mAtLoginButton = new RadioButton(i18n_combo_AtLogin(), recurGroup);
     mAtLoginButton->setFixedSize(mAtLoginButton->sizeHint());
     mAtLoginButton->setReadOnly(mReadOnly);
-    mAtLoginButton->setWhatsThis(i18nc("@info:whatsthis",
+    mAtLoginButton->setWhatsThis(xi18nc("@info:whatsthis",
                                       "<para>Trigger the alarm at the specified date/time and at every login until then.</para>"
                                       "<para>Note that it will also be triggered any time <application>KAlarm</application> is restarted.</para>"));
     mRuleButtonGroup->addButton(mAtLoginButton);
@@ -183,9 +179,9 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mSubRepetition->setReadOnly(mReadOnly);
     mSubRepetition->setWhatsThis(i18nc("@info:whatsthis",
                                        "Set up a repetition within the recurrence, to trigger the alarm multiple times each time the recurrence is due."));
-    connect(mSubRepetition, SIGNAL(needsInitialisation()), SIGNAL(repeatNeedsInitialisation()));
-    connect(mSubRepetition, SIGNAL(changed()), SIGNAL(frequencyChanged()));
-    connect(mSubRepetition, SIGNAL(changed()), SIGNAL(contentsChanged()));
+    connect(mSubRepetition, &RepetitionButton::needsInitialisation, this, &RecurrenceEdit::repeatNeedsInitialisation);
+    connect(mSubRepetition, &RepetitionButton::changed, this, &RecurrenceEdit::frequencyChanged);
+    connect(mSubRepetition, &RepetitionButton::changed, this, &RecurrenceEdit::contentsChanged);
     vlayout->addSpacing(KDialog::spacingHint());
     vlayout->addWidget(mSubRepetition);
 
@@ -208,16 +204,16 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mMonthlyRule  = new MonthlyRule(mReadOnly, mRuleStack);
     mYearlyRule   = new YearlyRule(mReadOnly, mRuleStack);
 
-    connect(mSubDailyRule, SIGNAL(frequencyChanged()), SIGNAL(frequencyChanged()));
-    connect(mDailyRule, SIGNAL(frequencyChanged()), SIGNAL(frequencyChanged()));
-    connect(mWeeklyRule, SIGNAL(frequencyChanged()), SIGNAL(frequencyChanged()));
-    connect(mMonthlyRule, SIGNAL(frequencyChanged()), SIGNAL(frequencyChanged()));
-    connect(mYearlyRule, SIGNAL(frequencyChanged()), SIGNAL(frequencyChanged()));
-    connect(mSubDailyRule, SIGNAL(changed()), SIGNAL(contentsChanged()));
-    connect(mDailyRule, SIGNAL(changed()), SIGNAL(contentsChanged()));
-    connect(mWeeklyRule, SIGNAL(changed()), SIGNAL(contentsChanged()));
-    connect(mMonthlyRule, SIGNAL(changed()), SIGNAL(contentsChanged()));
-    connect(mYearlyRule, SIGNAL(changed()), SIGNAL(contentsChanged()));
+    connect(mSubDailyRule, &SubDailyRule::frequencyChanged, this, &RecurrenceEdit::frequencyChanged);
+    connect(mDailyRule, &DailyRule::frequencyChanged, this, &RecurrenceEdit::frequencyChanged);
+    connect(mWeeklyRule, &WeeklyRule::frequencyChanged, this, &RecurrenceEdit::frequencyChanged);
+    connect(mMonthlyRule, &MonthlyRule::frequencyChanged, this, &RecurrenceEdit::frequencyChanged);
+    connect(mYearlyRule, &YearlyRule::frequencyChanged, this, &RecurrenceEdit::frequencyChanged);
+    connect(mSubDailyRule, &SubDailyRule::changed, this, &RecurrenceEdit::contentsChanged);
+    connect(mDailyRule, &DailyRule::changed, this, &RecurrenceEdit::contentsChanged);
+    connect(mWeeklyRule, &WeeklyRule::changed, this, &RecurrenceEdit::contentsChanged);
+    connect(mMonthlyRule, &MonthlyRule::changed, this, &RecurrenceEdit::contentsChanged);
+    connect(mYearlyRule, &YearlyRule::changed, this, &RecurrenceEdit::contentsChanged);
 
     mRuleStack->addWidget(mNoRule);
     mRuleStack->addWidget(mSubDailyRule);
@@ -233,8 +229,8 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mRangeButtonBox = new QGroupBox(i18nc("@title:group", "Recurrence End"), this);
     topLayout->addWidget(mRangeButtonBox);
     mRangeButtonGroup = new ButtonGroup(mRangeButtonBox);
-    connect(mRangeButtonGroup, SIGNAL(buttonSet(QAbstractButton*)), SLOT(rangeTypeClicked()));
-    connect(mRangeButtonGroup, SIGNAL(buttonSet(QAbstractButton*)), SIGNAL(contentsChanged()));
+    connect(mRangeButtonGroup, &ButtonGroup::buttonSet, this, &RecurrenceEdit::rangeTypeClicked);
+    connect(mRangeButtonGroup, &ButtonGroup::buttonSet, this, &RecurrenceEdit::contentsChanged);
 
     vlayout = new QVBoxLayout(mRangeButtonBox);
     vlayout->setMargin(KDialog::marginHint());
@@ -260,8 +256,8 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mRepeatCountEntry->setSelectOnStep(false);
     mRepeatCountEntry->setReadOnly(mReadOnly);
     mRepeatCountEntry->setWhatsThis(i18nc("@info:whatsthis", "Enter the total number of times to trigger the alarm"));
-    connect(mRepeatCountEntry, SIGNAL(valueChanged(int)), SLOT(repeatCountChanged(int)));
-    connect(mRepeatCountEntry, SIGNAL(valueChanged(int)), SIGNAL(contentsChanged()));
+    connect(mRepeatCountEntry, static_cast<void (SpinBox::*)(int)>(&SpinBox::valueChanged), this, &RecurrenceEdit::repeatCountChanged);
+    connect(mRepeatCountEntry, static_cast<void (SpinBox::*)(int)>(&SpinBox::valueChanged), this, &RecurrenceEdit::contentsChanged);
     mRepeatCountButton->setFocusWidget(mRepeatCountEntry);
     mRepeatCountLabel = new QLabel(i18nc("@label", "occurrence(s)"), mRangeButtonBox);
     mRepeatCountLabel->setFixedSize(mRepeatCountLabel->sizeHint());
@@ -278,28 +274,28 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
     mEndDateButton = new RadioButton(i18nc("@option:radio", "End by:"), mRangeButtonBox);
     mEndDateButton->setReadOnly(mReadOnly);
     mEndDateButton->setWhatsThis(
-          i18nc("@info:whatsthis", "<para>Repeat the alarm until the date/time specified.</para>"
+          xi18nc("@info:whatsthis", "<para>Repeat the alarm until the date/time specified.</para>"
                 "<para><note>This applies to the main recurrence only. It does not limit any sub-repetition which will occur regardless after the last main recurrence.</note></para>"));
     mRangeButtonGroup->addButton(mEndDateButton);
     mEndDateEdit = new KDateComboBox(mRangeButtonBox);
     mEndDateEdit->setOptions(mReadOnly ? KDateComboBox::Options(0) : KDateComboBox::EditDate | KDateComboBox::SelectDate | KDateComboBox::DatePicker);
-    static const QString tzText = i18nc("@info/plain", "This uses the same time zone as the start time.");
-    mEndDateEdit->setWhatsThis(i18nc("@info:whatsthis",
+    static const QString tzText = i18nc("@info", "This uses the same time zone as the start time.");
+    mEndDateEdit->setWhatsThis(xi18nc("@info:whatsthis",
           "<para>Enter the last date to repeat the alarm.</para><para>%1</para>", tzText));
-    connect(mEndDateEdit, SIGNAL(dateEdited(QDate)), SIGNAL(contentsChanged()));
+    connect(mEndDateEdit, &KDateComboBox::dateEdited, this, &RecurrenceEdit::contentsChanged);
     mEndDateButton->setFocusWidget(mEndDateEdit);
     mEndTimeEdit = new TimeEdit(mRangeButtonBox);
     mEndTimeEdit->setFixedSize(mEndTimeEdit->sizeHint());
     mEndTimeEdit->setReadOnly(mReadOnly);
-    mEndTimeEdit->setWhatsThis(i18nc("@info:whatsthis",
+    mEndTimeEdit->setWhatsThis(xi18nc("@info:whatsthis",
           "<para>Enter the last time to repeat the alarm.</para><para>%1</para><para>%2</para>", tzText, TimeSpinBox::shiftWhatsThis()));
-    connect(mEndTimeEdit, SIGNAL(valueChanged(int)), SIGNAL(contentsChanged()));
+    connect(mEndTimeEdit, &TimeEdit::valueChanged, this, &RecurrenceEdit::contentsChanged);
     mEndAnyTimeCheckBox = new CheckBox(i18nc("@option:check", "Any time"), mRangeButtonBox);
     mEndAnyTimeCheckBox->setFixedSize(mEndAnyTimeCheckBox->sizeHint());
     mEndAnyTimeCheckBox->setReadOnly(mReadOnly);
     mEndAnyTimeCheckBox->setWhatsThis(i18nc("@info:whatsthis", "Stop repeating the alarm after your first login on or after the specified end date"));
-    connect(mEndAnyTimeCheckBox, SIGNAL(toggled(bool)), SLOT(slotAnyTimeToggled(bool)));
-    connect(mEndAnyTimeCheckBox, SIGNAL(toggled(bool)), SIGNAL(contentsChanged()));
+    connect(mEndAnyTimeCheckBox, &CheckBox::toggled, this, &RecurrenceEdit::slotAnyTimeToggled);
+    connect(mEndAnyTimeCheckBox, &CheckBox::toggled, this, &RecurrenceEdit::contentsChanged);
     hlayout->addWidget(mEndDateButton);
     hlayout->addSpacing(KDialog::spacingHint());
     hlayout->addWidget(mEndDateEdit);
@@ -327,14 +323,14 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
 
     mExceptionDateList = new ListWidget(mExceptionGroup);
     mExceptionDateList->setWhatsThis(i18nc("@info:whatsthis", "The list of exceptions, i.e. dates/times excluded from the recurrence"));
-    connect(mExceptionDateList, SIGNAL(currentRowChanged(int)), SLOT(enableExceptionButtons()));
+    connect(mExceptionDateList, &QListWidget::currentRowChanged, this, &RecurrenceEdit::enableExceptionButtons);
     vlayout->addWidget(mExceptionDateList);
 
     if (mReadOnly)
     {
-        mExceptionDateEdit     = 0;
-        mChangeExceptionButton = 0;
-        mDeleteExceptionButton = 0;
+        mExceptionDateEdit     = Q_NULLPTR;
+        mChangeExceptionButton = Q_NULLPTR;
+        mDeleteExceptionButton = Q_NULLPTR;
     }
     else
     {
@@ -354,18 +350,18 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
         vlayout->addLayout(hlayout);
         QPushButton* button = new QPushButton(i18nc("@action:button", "Add"), mExceptionGroup);
         button->setWhatsThis(i18nc("@info:whatsthis", "Add the date entered above to the exceptions list"));
-        connect(button, SIGNAL(clicked()), SLOT(addException()));
+        connect(button, &QPushButton::clicked, this, &RecurrenceEdit::addException);
         hlayout->addWidget(button);
 
         mChangeExceptionButton = new QPushButton(i18nc("@action:button", "Change"), mExceptionGroup);
         mChangeExceptionButton->setWhatsThis(i18nc("@info:whatsthis",
               "Replace the currently highlighted item in the exceptions list with the date entered above"));
-        connect(mChangeExceptionButton, SIGNAL(clicked()), SLOT(changeException()));
+        connect(mChangeExceptionButton, &QPushButton::clicked, this, &RecurrenceEdit::changeException);
         hlayout->addWidget(mChangeExceptionButton);
 
         mDeleteExceptionButton = new QPushButton(i18nc("@action:button", "Delete"), mExceptionGroup);
         mDeleteExceptionButton->setWhatsThis(i18nc("@info:whatsthis", "Remove the currently highlighted item from the exceptions list"));
-        connect(mDeleteExceptionButton, SIGNAL(clicked()), SLOT(deleteException()));
+        connect(mDeleteExceptionButton, &QPushButton::clicked, this, &RecurrenceEdit::deleteException);
         hlayout->addWidget(mDeleteExceptionButton);
     }
 
@@ -373,18 +369,18 @@ RecurrenceEdit::RecurrenceEdit(bool readOnly, QWidget* parent)
 
     mExcludeHolidays = new CheckBox(i18nc("@option:check", "Exclude holidays"), mExceptionGroup);
     mExcludeHolidays->setReadOnly(mReadOnly);
-    mExcludeHolidays->setWhatsThis(i18nc("@info:whatsthis",
+    mExcludeHolidays->setWhatsThis(xi18nc("@info:whatsthis",
           "<para>Do not trigger the alarm on holidays.</para>"
           "<para>You can specify your holiday region in the Configuration dialog.</para>"));
-    connect(mExcludeHolidays, SIGNAL(toggled(bool)), SIGNAL(contentsChanged()));
+    connect(mExcludeHolidays, &CheckBox::toggled, this, &RecurrenceEdit::contentsChanged);
     vlayout->addWidget(mExcludeHolidays);
 
     mWorkTimeOnly = new CheckBox(i18nc("@option:check", "Only during working time"), mExceptionGroup);
     mWorkTimeOnly->setReadOnly(mReadOnly);
-    mWorkTimeOnly->setWhatsThis(i18nc("@info:whatsthis",
+    mWorkTimeOnly->setWhatsThis(xi18nc("@info:whatsthis",
           "<para>Only execute the alarm during working hours, on working days.</para>"
           "<para>You can specify working days and hours in the Configuration dialog.</para>"));
-    connect(mWorkTimeOnly, SIGNAL(toggled(bool)), SIGNAL(contentsChanged()));
+    connect(mWorkTimeOnly, &CheckBox::toggled, this, &RecurrenceEdit::contentsChanged);
     vlayout->addWidget(mWorkTimeOnly);
 
     topLayout->addStretch();
@@ -410,12 +406,12 @@ void RecurrenceEdit::showMoreOptions(bool more)
 QWidget* RecurrenceEdit::checkData(const KDateTime& startDateTime, QString& errorMessage) const
 {
     if (mAtLoginButton->isChecked())
-        return 0;
+        return Q_NULLPTR;
     const_cast<RecurrenceEdit*>(this)->mCurrStartDateTime = startDateTime;
     if (mEndDateButton->isChecked())
     {
         // N.B. End date/time takes the same time spec as start date/time
-        QWidget* errWidget = 0;
+        QWidget* errWidget = Q_NULLPTR;
         bool noTime = !mEndTimeEdit->isEnabled();
         QDate endDate = mEndDateEdit->date();
         if (endDate < startDateTime.date())
@@ -431,7 +427,7 @@ QWidget* RecurrenceEdit::checkData(const KDateTime& startDateTime, QString& erro
         }
     }
     if (!mRule)
-        return 0;
+        return Q_NULLPTR;
     return mRule->validate(errorMessage);
 }
 
@@ -446,12 +442,12 @@ void RecurrenceEdit::periodClicked(QAbstractButton* button)
     bool subdaily = (button == mSubDailyButton);
     if (none)
     {
-        mRule = 0;
+        mRule = Q_NULLPTR;
         mRuleButtonType = NO_RECUR;
     }
     else if (atLogin)
     {
-        mRule = 0;
+        mRule = Q_NULLPTR;
         mRuleButtonType = AT_LOGIN;
         mEndDateButton->setChecked(true);
     }
@@ -502,7 +498,7 @@ void RecurrenceEdit::periodClicked(QAbstractButton* button)
         rangeTypeClicked();
         mSubRepetition->setEnabled(!(none || atLogin));
         if (!mNoEmitTypeChanged)
-            emit typeChanged(mRuleButtonType);
+            Q_EMIT typeChanged(mRuleButtonType);
     }
 }
 
@@ -534,7 +530,7 @@ void RecurrenceEdit::showEvent(QShowEvent*)
         mRule->setFrequencyFocus();
     else
         mRuleButtonGroup->checkedButton()->setFocus();
-    emit shown();
+    Q_EMIT shown();
 }
 
 /******************************************************************************
@@ -616,8 +612,8 @@ void RecurrenceEdit::addException()
     if (insert)
     {
         mExceptionDates.insert(it, date);
-        mExceptionDateList->insertItem(index, new QListWidgetItem(KGlobal::locale()->formatDate(date)));
-        emit contentsChanged();
+        mExceptionDateList->insertItem(index, new QListWidgetItem(KLocale::global()->formatDate(date)));
+        Q_EMIT contentsChanged();
     }
     mExceptionDateList->setCurrentItem(mExceptionDateList->item(index));
     enableExceptionButtons();
@@ -641,7 +637,7 @@ void RecurrenceEdit::changeException()
         {
             mExceptionDates.removeAt(index);
             mExceptionDateList->takeItem(index);
-            emit contentsChanged();
+            Q_EMIT contentsChanged();
             addException();
         }
     }
@@ -658,7 +654,7 @@ void RecurrenceEdit::deleteException()
         int index = mExceptionDateList->row(item);
         mExceptionDates.removeAt(index);
         mExceptionDateList->takeItem(index);
-        emit contentsChanged();
+        Q_EMIT contentsChanged();
         enableExceptionButtons();
     }
 }
@@ -923,7 +919,7 @@ void RecurrenceEdit::set(const KAEvent& event)
     qSort(mExceptionDates);
     mExceptionDateList->clear();
     for (int i = 0, iend = mExceptionDates.count();  i < iend;  ++i)
-        new QListWidgetItem(KGlobal::locale()->formatDate(mExceptionDates[i]), mExceptionDateList);
+        new QListWidgetItem(KLocale::global()->formatDate(mExceptionDates[i]), mExceptionDateList);
     enableExceptionButtons();
     mExcludeHolidays->setChecked(event.holidaysExcluded());
     mWorkTimeOnly->setChecked(event.workTimeOnly());
@@ -1115,14 +1111,14 @@ Rule::Rule(const QString& freqText, const QString& freqWhatsThis, bool time, boo
     label->setFixedSize(label->sizeHint());
     if (time)
     {
-        mIntSpinBox = 0;
+        mIntSpinBox = Q_NULLPTR;
         mSpinBox = mTimeSpinBox = new TimeSpinBox(1, 5999, box);
         mTimeSpinBox->setFixedSize(mTimeSpinBox->sizeHint());
         mTimeSpinBox->setReadOnly(readOnly);
     }
     else
     {
-        mTimeSpinBox = 0;
+        mTimeSpinBox = Q_NULLPTR;
         mSpinBox = mIntSpinBox = new SpinBox(1, 999, box);
         mIntSpinBox->setFixedSize(mIntSpinBox->sizeHint());
         mIntSpinBox->setReadOnly(readOnly);
@@ -1212,7 +1208,7 @@ DayWeekRule::DayWeekRule(const QString& freqText, const QString& freqWhatsThis,
     QGridLayout* dgrid = new QGridLayout(box);
     dgrid->setMargin(0);
     dgrid->setSpacing(KDialog::spacingHint());
-    const KCalendarSystem* calendar = KGlobal::locale()->calendar();
+    const KCalendarSystem* calendar = KLocale::global()->calendar();
     for (int i = 0;  i < 7;  ++i)
     {
         int day = KAlarm::localeDayInWeek_to_weekDay(i);
@@ -1281,7 +1277,7 @@ QWidget* DayWeekRule::validate(QString& errorMessage)
 {
     for (int i = 0;  i < 7;  ++i)
         if (mDayBox[i]->isChecked())
-            return 0;
+            return Q_NULLPTR;
     errorMessage = i18nc("@info", "No day selected");
     return mDayBox[0];
 }
@@ -1365,8 +1361,8 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     mDayCombo->setReadOnly(readOnly);
     mDayCombo->setWhatsThis(i18nc("@info:whatsthis", "Select the day of the month on which to repeat the alarm"));
     mDayButton->setFocusWidget(mDayCombo);
-    connect(mDayCombo, SIGNAL(activated(int)), SLOT(slotDaySelected(int)));
-    connect(mDayCombo, SIGNAL(currentIndexChanged(int)), SIGNAL(changed()));
+    connect(mDayCombo, static_cast<void (ComboBox::*)(int)>(&ComboBox::activated), this, &MonthYearRule::slotDaySelected);
+    connect(mDayCombo, static_cast<void (ComboBox::*)(int)>(&ComboBox::currentIndexChanged), this, &MonthYearRule::changed);
 
     box->setStretchFactor(new QWidget(box), 1);    // left adjust the controls
     box->setFixedHeight(box->sizeHint().height());
@@ -1404,11 +1400,11 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     mWeekCombo->setFixedSize(mWeekCombo->sizeHint());
     mWeekCombo->setReadOnly(readOnly);
     mPosButton->setFocusWidget(mWeekCombo);
-    connect(mWeekCombo, SIGNAL(currentIndexChanged(int)), SIGNAL(changed()));
+    connect(mWeekCombo, static_cast<void (ComboBox::*)(int)>(&ComboBox::currentIndexChanged), this, &MonthYearRule::changed);
 
     mDayOfWeekCombo = new ComboBox(box);
     mDayOfWeekCombo->setEditable(false);
-    const KCalendarSystem* calendar = KGlobal::locale()->calendar();
+    const KCalendarSystem* calendar = KLocale::global()->calendar();
     for (int i = 0;  i < 7;  ++i)
     {
         int day = KAlarm::localeDayInWeek_to_weekDay(i);
@@ -1416,12 +1412,12 @@ MonthYearRule::MonthYearRule(const QString& freqText, const QString& freqWhatsTh
     }
     mDayOfWeekCombo->setReadOnly(readOnly);
     mDayOfWeekCombo->setWhatsThis(i18nc("@info:whatsthis", "Select the day of the week on which to repeat the alarm"));
-    connect(mDayOfWeekCombo, SIGNAL(currentIndexChanged(int)), SIGNAL(changed()));
+    connect(mDayOfWeekCombo, static_cast<void (ComboBox::*)(int)>(&ComboBox::currentIndexChanged), this, &MonthYearRule::changed);
 
     box->setStretchFactor(new QWidget(box), 1);    // left adjust the controls
     box->setFixedHeight(box->sizeHint().height());
-    connect(mButtonGroup, SIGNAL(buttonSet(QAbstractButton*)), SLOT(clicked(QAbstractButton*)));
-    connect(mButtonGroup, SIGNAL(buttonSet(QAbstractButton*)), SIGNAL(changed()));
+    connect(mButtonGroup, &ButtonGroup::buttonSet, this, &MonthYearRule::clicked);
+    connect(mButtonGroup, &ButtonGroup::buttonSet, this, &MonthYearRule::changed);
 }
 
 MonthYearRule::DayPosType MonthYearRule::type() const
@@ -1568,7 +1564,7 @@ YearlyRule::YearlyRule(bool readOnly, QWidget* parent)
     QGridLayout* grid = new QGridLayout(w);
     grid->setMargin(0);
     grid->setSpacing(KDialog::spacingHint());
-    const KCalendarSystem* calendar = KGlobal::locale()->calendar();
+    const KCalendarSystem* calendar = KLocale::global()->calendar();
     int year = KDateTime::currentLocalDate().year();
     for (int i = 0;  i < 12;  ++i)
     {
@@ -1598,7 +1594,7 @@ YearlyRule::YearlyRule(bool readOnly, QWidget* parent)
     mFeb29Combo->addItem(i18nc("@item:inlistbox 28th February (short form)", "28 Feb"));
     mFeb29Combo->setFixedSize(mFeb29Combo->sizeHint());
     mFeb29Combo->setReadOnly(readOnly);
-    connect(mFeb29Combo, SIGNAL(currentIndexChanged(int)), SIGNAL(changed()));
+    connect(mFeb29Combo, static_cast<void (ComboBox::*)(int)>(&ComboBox::currentIndexChanged), this, &YearlyRule::changed);
     mFeb29Label->setBuddy(mFeb29Combo);
     box->setFixedSize(box->sizeHint());
     box->setWhatsThis(i18nc("@info:whatsthis", "Select which date, if any, the February 29th alarm should trigger in non-leap years"));
@@ -1684,7 +1680,7 @@ QWidget* YearlyRule::validate(QString& errorMessage)
 {
     for (int i = 0;  i < 12;  ++i)
         if (mMonthBox[i]->isChecked()  &&  mMonthBox[i]->isEnabled())
-            return 0;
+            return Q_NULLPTR;
     errorMessage = i18nc("@info", "No month selected");
     return mMonthBox[0];
 }
@@ -1744,7 +1740,7 @@ bool YearlyRule::stateChanged() const
         ||  mSavedMonths    != months()
         ||  mSavedFeb29Type != feb29Type());
 }
-#include "moc_recurrenceedit.cpp"
-#include "moc_recurrenceedit_p.cpp"
+
+
 
 // vim: et sw=4:
