@@ -29,8 +29,8 @@
 #include <kalarmcal/kaevent.h>
 
 #include <kapplication.h>
-#include <klocale.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+#include "kalarm_debug.h"
 
 static int maxCount = 12;
 
@@ -39,17 +39,10 @@ static int maxCount = 12;
 #endif
 
 // Simplify access to Undo::Event struct
-#ifdef USE_AKONADI
 #define RESOURCE_PARAM_TYPE  const Collection&
 #define EVENT_RESOURCE collection
-#else
-#define RESOURCE_PARAM_TYPE  AlarmResource*
-#define EVENT_RESOURCE resource
-#endif
 
-#ifdef USE_AKONADI
 using namespace Akonadi;
-#endif
 
 class UndoItem
 {
@@ -64,15 +57,11 @@ class UndoItem
         virtual QString    eventID() const       { return QString(); }
         virtual QString    oldEventID() const    { return QString(); }
         virtual QString    newEventID() const    { return QString(); }
-#ifdef USE_AKONADI
         virtual Collection collection() const    { return Collection(); }
-#else
-        virtual AlarmResource* resource() const  { return 0; }
-#endif
         int                id() const            { return mId; }
         Undo::Type         type() const          { return mType; }
         void               setType(Undo::Type t) { mType = t; }
-        CalEvent::Type     calendar() const  { return mCalendar; }
+        CalEvent::Type     calendar() const      { return mCalendar; }
         virtual void       setCalendar(CalEvent::Type s) { mCalendar = s; }
         virtual UndoItem*  restore() = 0;
         virtual bool       deleteID(const QString& /*id*/)  { return false; }
@@ -101,9 +90,9 @@ class UndoMultiBase : public UndoItem
 {
     public:
         UndoMultiBase(Undo::Type t, const QString& name)
-                : UndoItem(t, name), mUndos(new Undo::List) { }
+                : UndoItem(t, name), mUndos(new Undo::List) {}
         UndoMultiBase(Undo::Type t, Undo::List* undos, const QString& name)
-                : UndoItem(t, name), mUndos(undos) { }
+                : UndoItem(t, name), mUndos(undos) {}
         ~UndoMultiBase()  { delete mUndos; }
         const Undo::List* undos() const         { return mUndos; }
     protected:
@@ -114,10 +103,10 @@ template <class T> class UndoMulti : public UndoMultiBase
 {
     public:
         UndoMulti(Undo::Type, const Undo::EventList&, const QString& name);
-        UndoMulti(Undo::Type t, Undo::List* undos, const QString& name)  : UndoMultiBase(t, undos, name) { }
-        virtual Operation operation() const     { return MULTI; }
-        virtual UndoItem* restore();
-        virtual bool      deleteID(const QString& id);
+        UndoMulti(Undo::Type t, Undo::List* undos, const QString& name)  : UndoMultiBase(t, undos, name) {}
+        Operation         operation() const Q_DECL_OVERRIDE     { return MULTI; }
+        UndoItem*         restore() Q_DECL_OVERRIDE;
+        bool              deleteID(const QString& id) Q_DECL_OVERRIDE;
         virtual UndoItem* createRedo(Undo::List*) = 0;
 };
 
@@ -127,26 +116,18 @@ class UndoAdd : public UndoItem
         UndoAdd(Undo::Type, const Undo::Event&, const QString& name = QString());
         UndoAdd(Undo::Type, const KAEvent&, RESOURCE_PARAM_TYPE, const QString& name = QString());
         UndoAdd(Undo::Type, const KAEvent&, RESOURCE_PARAM_TYPE, const QString& name, CalEvent::Type);
-        virtual Operation  operation() const     { return ADD; }
-        virtual QString    defaultActionText() const;
-        virtual QString    description() const   { return mDescription; }
-#ifdef USE_AKONADI
-        virtual Collection collection() const    { return mResource; }
-#else
-        virtual AlarmResource* resource() const  { return mResource; }
-#endif
-        virtual QString    eventID() const       { return mEventId; }
-        virtual QString    newEventID() const    { return mEventId; }
-        virtual UndoItem*  restore()             { return doRestore(); }
+        Operation          operation() const Q_DECL_OVERRIDE     { return ADD; }
+        QString            defaultActionText() const Q_DECL_OVERRIDE;
+        QString            description() const Q_DECL_OVERRIDE   { return mDescription; }
+        Collection         collection() const Q_DECL_OVERRIDE    { return mResource; }
+        QString            eventID() const Q_DECL_OVERRIDE       { return mEventId; }
+        QString            newEventID() const Q_DECL_OVERRIDE    { return mEventId; }
+        UndoItem*          restore() Q_DECL_OVERRIDE             { return doRestore(); }
     protected:
         UndoItem*          doRestore(bool setArchive = false);
         virtual UndoItem*  createRedo(const KAEvent&, RESOURCE_PARAM_TYPE);
     private:
-#ifdef USE_AKONADI
         Collection     mResource;  // collection containing the event
-#else
-        AlarmResource* mResource;  // resource calendar containing the event
-#endif
         QString        mEventId;
         QString        mDescription;
 };
@@ -157,24 +138,16 @@ class UndoEdit : public UndoItem
         UndoEdit(Undo::Type, const KAEvent& oldEvent, const QString& newEventID,
                  RESOURCE_PARAM_TYPE, const QStringList& dontShowErrors, const QString& description);
         ~UndoEdit();
-        virtual Operation  operation() const     { return EDIT; }
-        virtual QString    defaultActionText() const;
-        virtual QString    description() const   { return mDescription; }
-#ifdef USE_AKONADI
-        virtual Collection collection() const    { return mResource; }
-#else
-        virtual AlarmResource* resource() const  { return mResource; }
-#endif
-        virtual QString    eventID() const       { return mNewEventId; }
-        virtual QString    oldEventID() const    { return mOldEvent->id(); }
-        virtual QString    newEventID() const    { return mNewEventId; }
-        virtual UndoItem*  restore();
+        Operation          operation() const Q_DECL_OVERRIDE     { return EDIT; }
+        QString            defaultActionText() const Q_DECL_OVERRIDE;
+        QString            description() const Q_DECL_OVERRIDE   { return mDescription; }
+        Collection         collection() const Q_DECL_OVERRIDE    { return mResource; }
+        QString            eventID() const Q_DECL_OVERRIDE       { return mNewEventId; }
+        QString            oldEventID() const Q_DECL_OVERRIDE    { return mOldEvent->id(); }
+        QString            newEventID() const Q_DECL_OVERRIDE    { return mNewEventId; }
+        UndoItem*          restore() Q_DECL_OVERRIDE;
     private:
-#ifdef USE_AKONADI
         Collection     mResource;  // collection containing the event
-#else
-        AlarmResource* mResource;  // resource calendar containing the event
-#endif
         KAEvent*       mOldEvent;
         QString        mNewEventId;
         QString        mDescription;
@@ -187,26 +160,18 @@ class UndoDelete : public UndoItem
         UndoDelete(Undo::Type, const Undo::Event&, const QString& name = QString());
         UndoDelete(Undo::Type, const KAEvent&, RESOURCE_PARAM_TYPE, const QStringList& dontShowErrors, const QString& name = QString());
         ~UndoDelete();
-        virtual Operation  operation() const     { return DELETE; }
-        virtual QString    defaultActionText() const;
-        virtual QString    description() const   { return UndoItem::description(*mEvent); }
-#ifdef USE_AKONADI
-        virtual Collection collection() const    { return mResource; }
-#else
-        virtual AlarmResource* resource() const  { return mResource; }
-#endif
-        virtual QString    eventID() const       { return mEvent->id(); }
-        virtual QString    oldEventID() const    { return mEvent->id(); }
-        virtual UndoItem*  restore();
-        KAEvent*           event() const         { return mEvent; }
+        Operation          operation() const Q_DECL_OVERRIDE     { return DELETE; }
+        QString            defaultActionText() const Q_DECL_OVERRIDE;
+        QString            description() const Q_DECL_OVERRIDE   { return UndoItem::description(*mEvent); }
+        Collection         collection() const Q_DECL_OVERRIDE    { return mResource; }
+        QString            eventID() const Q_DECL_OVERRIDE       { return mEvent->id(); }
+        QString            oldEventID() const Q_DECL_OVERRIDE    { return mEvent->id(); }
+        UndoItem*          restore() Q_DECL_OVERRIDE;
+        KAEvent*           event() const                         { return mEvent; }
     protected:
         virtual UndoItem*  createRedo(const KAEvent&, RESOURCE_PARAM_TYPE);
     private:
-#ifdef USE_AKONADI
         Collection     mResource;  // collection containing the event
-#else
-        AlarmResource* mResource;  // resource calendar containing the event
-#endif
         KAEvent*       mEvent;
         QStringList    mDontShowErrors;
 };
@@ -215,62 +180,62 @@ class UndoReactivate : public UndoAdd
 {
     public:
         UndoReactivate(Undo::Type t, const Undo::Event& e, const QString& name = QString())
-                 : UndoAdd(t, e.event, e.EVENT_RESOURCE, name, CalEvent::ACTIVE) { }
+                 : UndoAdd(t, e.event, e.EVENT_RESOURCE, name, CalEvent::ACTIVE) {}
         UndoReactivate(Undo::Type t, const KAEvent& e, RESOURCE_PARAM_TYPE r, const QString& name = QString())
-                 : UndoAdd(t, e, r, name, CalEvent::ACTIVE) { }
-        virtual Operation operation() const     { return REACTIVATE; }
-        virtual QString   defaultActionText() const;
-        virtual UndoItem* restore();
+                 : UndoAdd(t, e, r, name, CalEvent::ACTIVE) {}
+        Operation         operation() const Q_DECL_OVERRIDE     { return REACTIVATE; }
+        QString           defaultActionText() const Q_DECL_OVERRIDE;
+        UndoItem*         restore() Q_DECL_OVERRIDE;
     protected:
-        virtual UndoItem* createRedo(const KAEvent&, RESOURCE_PARAM_TYPE);
+        UndoItem*         createRedo(const KAEvent&, RESOURCE_PARAM_TYPE) Q_DECL_OVERRIDE;
 };
 
 class UndoDeactivate : public UndoDelete
 {
     public:
         UndoDeactivate(Undo::Type t, const KAEvent& e, RESOURCE_PARAM_TYPE r, const QString& name = QString())
-                 : UndoDelete(t, e, r, QStringList(), name) { }
-        virtual Operation operation() const     { return DEACTIVATE; }
-        virtual QString   defaultActionText() const;
-        virtual UndoItem* restore();
+                 : UndoDelete(t, e, r, QStringList(), name) {}
+        Operation         operation() const Q_DECL_OVERRIDE     { return DEACTIVATE; }
+        QString           defaultActionText() const Q_DECL_OVERRIDE;
+        UndoItem*         restore() Q_DECL_OVERRIDE;
     protected:
-        virtual UndoItem* createRedo(const KAEvent&, RESOURCE_PARAM_TYPE);
+        UndoItem*         createRedo(const KAEvent&, RESOURCE_PARAM_TYPE) Q_DECL_OVERRIDE;
 };
 
 class UndoAdds : public UndoMulti<UndoAdd>
 {
     public:
         UndoAdds(Undo::Type t, const Undo::EventList& events, const QString& name = QString())
-                          : UndoMulti<UndoAdd>(t, events, name) { }   // UNDO only
+                          : UndoMulti<UndoAdd>(t, events, name) {}   // UNDO only
         UndoAdds(Undo::Type t, Undo::List* undos, const QString& name)
-                          : UndoMulti<UndoAdd>(t, undos, name) { }
-        virtual QString   defaultActionText() const;
-        virtual UndoItem* createRedo(Undo::List*);
+                          : UndoMulti<UndoAdd>(t, undos, name) {}
+        QString           defaultActionText() const Q_DECL_OVERRIDE;
+        UndoItem*         createRedo(Undo::List*) Q_DECL_OVERRIDE;
 };
 
 class UndoDeletes : public UndoMulti<UndoDelete>
 {
     public:
         UndoDeletes(Undo::Type t, const Undo::EventList& events, const QString& name = QString())
-                          : UndoMulti<UndoDelete>(t, events, name) { }   // UNDO only
+                          : UndoMulti<UndoDelete>(t, events, name) {}   // UNDO only
         UndoDeletes(Undo::Type t, Undo::List* undos, const QString& name)
-                          : UndoMulti<UndoDelete>(t, undos, name) { }
-        virtual QString   defaultActionText() const;
-        virtual UndoItem* createRedo(Undo::List*);
+                          : UndoMulti<UndoDelete>(t, undos, name) {}
+        QString           defaultActionText() const Q_DECL_OVERRIDE;
+        UndoItem*         createRedo(Undo::List*) Q_DECL_OVERRIDE;
 };
 
 class UndoReactivates : public UndoMulti<UndoReactivate>
 {
     public:
         UndoReactivates(Undo::Type t, const Undo::EventList& events, const QString& name = QString())
-                          : UndoMulti<UndoReactivate>(t, events, name) { }   // UNDO only
+                          : UndoMulti<UndoReactivate>(t, events, name) {}   // UNDO only
         UndoReactivates(Undo::Type t, Undo::List* undos, const QString& name)
-                          : UndoMulti<UndoReactivate>(t, undos, name) { }
-        virtual QString   defaultActionText() const;
-        virtual UndoItem* createRedo(Undo::List*);
+                          : UndoMulti<UndoReactivate>(t, undos, name) {}
+        QString           defaultActionText() const Q_DECL_OVERRIDE;
+        UndoItem*         createRedo(Undo::List*) Q_DECL_OVERRIDE;
 };
 
-Undo*       Undo::mInstance = 0;
+Undo*       Undo::mInstance = Q_NULLPTR;
 Undo::List  Undo::mUndoList;
 Undo::List  Undo::mRedoList;
 
@@ -379,7 +344,7 @@ void Undo::removeRedos(const QString& eventID)
     for (int i = 0;  i < mRedoList.count();  )
     {
         UndoItem* item = mRedoList[i];
-//kDebug()<<item->eventID()<<" (looking for"<<id<<")";
+//qCDebug(KALARM_LOG)<<item->eventID()<<" (looking for"<<id<<")";
         if (item->operation() == UndoItem::MULTI)
         {
             if (item->deleteID(id))
@@ -435,12 +400,12 @@ bool Undo::undo(int i, Undo::Type type, QWidget* parent, const QString& action)
             KAlarm::displayKOrgUpdateError(parent, errcode, UndoItem::mRestoreWarningKorg, UndoItem::mRestoreWarningCount);
             return true;
         }
-        case UndoItem::ERR_NOT_FOUND:  err = i18nc("@info/plain", "Alarm not found");  break;
-        case UndoItem::ERR_CREATE:     err = i18nc("@info/plain", "Error recreating alarm");  break;
-        case UndoItem::ERR_TEMPLATE:   err = i18nc("@info/plain", "Error recreating alarm template");  break;
-        case UndoItem::ERR_ARCHIVED:   err = i18nc("@info/plain", "Cannot reactivate archived alarm");  break;
-        case UndoItem::ERR_PROG:       err = i18nc("@info/plain", "Program error");  break;
-        default:                       err = i18nc("@info/plain", "Unknown error");  break;
+        case UndoItem::ERR_NOT_FOUND:  err = i18nc("@info", "Alarm not found");  break;
+        case UndoItem::ERR_CREATE:     err = i18nc("@info", "Error recreating alarm");  break;
+        case UndoItem::ERR_TEMPLATE:   err = i18nc("@info", "Error recreating alarm template");  break;
+        case UndoItem::ERR_ARCHIVED:   err = i18nc("@info", "Cannot reactivate archived alarm");  break;
+        case UndoItem::ERR_PROG:       err = i18nc("@info", "Program error");  break;
+        default:                       err = i18nc("@info", "Unknown error");  break;
     }
     KAMessageBox::sorry(parent, i18nc("@info Undo-action: message", "%1: %2", action, err));
     return false;
@@ -486,7 +451,7 @@ void Undo::remove(UndoItem* item, bool undo)
 void Undo::replace(UndoItem* old, UndoItem* New)
 {
     Type type = old->type();
-    List* list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : 0;
+    List* list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : Q_NULLPTR;
     if (!list)
         return;
     int i = list->indexOf(old);
@@ -503,7 +468,7 @@ void Undo::replace(UndoItem* old, UndoItem* New)
 */
 QString Undo::actionText(Undo::Type type)
 {
-    List* list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : 0;
+    List* list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : Q_NULLPTR;
     return (list && !list->isEmpty()) ? (*list)[0]->actionText() : QString();
 }
 
@@ -536,7 +501,7 @@ QList<int> Undo::ids(Undo::Type type)
     QList<int> ids;
     QStringList ignoreIDs;
 //int n=0;
-    List* list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : 0;
+    List* list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : Q_NULLPTR;
     if (!list)
         return ids;
     for (int i = 0, end = list->count();  i < end;  ++i)
@@ -576,9 +541,9 @@ QList<int> Undo::ids(Undo::Type type)
         }
         if (!omit)
             ids.append(item->id());
-//else kDebug()<<"Undo::ids(): omit"<<item->actionText()<<":"<<item->description();
+//else qCDebug(KALARM_LOG)<<"Undo::ids(): omit"<<item->actionText()<<":"<<item->description();
     }
-//kDebug()<<"Undo::ids():"<<n<<" ->"<<ids.count();
+//qCDebug(KALARM_LOG)<<"Undo::ids():"<<n<<" ->"<<ids.count();
     return ids;
 }
 
@@ -596,7 +561,7 @@ void Undo::emitChanged()
 */
 UndoItem* Undo::getItem(int id, Undo::Type type)
 {
-    List* list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : 0;
+    List* list = (type == UNDO) ? &mUndoList : (type == REDO) ? &mRedoList : Q_NULLPTR;
     if (list)
     {
         for (int i = 0, end = list->count();  i < end;  ++i)
@@ -605,7 +570,7 @@ UndoItem* Undo::getItem(int id, Undo::Type type)
                 return (*list)[i];
         }
     }
-    return 0;
+    return Q_NULLPTR;
 }
 
 /******************************************************************************
@@ -680,16 +645,16 @@ QString UndoItem::addDeleteActionText(CalEvent::Type calendar, bool add)
     {
         case CalEvent::ACTIVE:
             if (add)
-                return i18nc("@info/plain Action to create a new alarm", "New alarm");
+                return i18nc("@info Action to create a new alarm", "New alarm");
             else
-                return i18nc("@info/plain Action to delete an alarm", "Delete alarm");
+                return i18nc("@info Action to delete an alarm", "Delete alarm");
         case CalEvent::TEMPLATE:
             if (add)
-                return i18nc("@info/plain Action to create a new alarm template", "New template");
+                return i18nc("@info Action to create a new alarm template", "New template");
             else
-                return i18nc("@info/plain Action to delete an alarm template", "Delete template");
+                return i18nc("@info Action to delete an alarm template", "Delete template");
         case CalEvent::ARCHIVED:
-            return i18nc("@info/plain", "Delete archived alarm");
+            return i18nc("@info", "Delete archived alarm");
         default:
             break;
     }
@@ -729,7 +694,7 @@ UndoItem* UndoMulti<T>::restore()
     if (newUndos->isEmpty())
     {
         delete newUndos;
-        return 0;
+        return Q_NULLPTR;
     }
 
     // Create a redo item to delete the alarm again
@@ -811,16 +776,12 @@ UndoAdd::UndoAdd(Undo::Type type, const KAEvent& event, RESOURCE_PARAM_TYPE reso
 UndoItem* UndoAdd::doRestore(bool setArchive)
 {
     // Retrieve the current state of the alarm
-    kDebug() << mEventId;
-#ifdef USE_AKONADI
+    qCDebug(KALARM_LOG) << mEventId;
     const KAEvent* ev = AlarmCalendar::getEvent(EventId(mResource.id(), mEventId));
-#else
-    const KAEvent* ev = AlarmCalendar::getEvent(mEventId);
-#endif
     if (!ev)
     {
         mRestoreError = ERR_NOT_FOUND;    // alarm is no longer in calendar
-        return 0;
+        return Q_NULLPTR;
     }
     KAEvent event(*ev); 
 
@@ -858,11 +819,7 @@ UndoItem* UndoAdd::doRestore(bool setArchive)
             break;
         }
         case CalEvent::TEMPLATE:
-#ifdef USE_AKONADI
             if (KAlarm::deleteTemplate(event) != KAlarm::UPDATE_OK)
-#else
-            if (KAlarm::deleteTemplate(event.id()) != KAlarm::UPDATE_OK)
-#endif
                 mRestoreError = ERR_TEMPLATE;
             break;
         case CalEvent::ARCHIVED:    // redoing the deletion of an archived alarm
@@ -871,7 +828,7 @@ UndoItem* UndoAdd::doRestore(bool setArchive)
         default:
             delete undo;
             mRestoreError = ERR_PROG;
-            return 0;
+            return Q_NULLPTR;
     }
     return undo;
 }
@@ -913,7 +870,7 @@ UndoItem* UndoAdds::createRedo(Undo::List* undos)
 */
 QString UndoAdds::defaultActionText() const
 {
-    return i18nc("@info/plain", "Create multiple alarms");
+    return i18nc("@info", "Create multiple alarms");
 }
 
 
@@ -946,27 +903,19 @@ UndoEdit::~UndoEdit()
 */
 UndoItem* UndoEdit::restore()
 {
-    kDebug() << mNewEventId;
+    qCDebug(KALARM_LOG) << mNewEventId;
     // Retrieve the current state of the alarm
-#ifdef USE_AKONADI
     const KAEvent* event = AlarmCalendar::getEvent(EventId(mResource.id(), mNewEventId));
-#else
-    const KAEvent* event = AlarmCalendar::getEvent(mNewEventId);
-#endif
     if (!event)
     {
         mRestoreError = ERR_NOT_FOUND;    // alarm is no longer in calendar
-        return 0;
+        return Q_NULLPTR;
     }
     KAEvent newEvent(*event); 
 
     // Create a redo item to restore the edit
     Undo::Type t = (type() == Undo::UNDO) ? Undo::REDO : (type() == Undo::REDO) ? Undo::UNDO : Undo::NONE;
-#ifdef USE_AKONADI
     UndoItem* undo = new UndoEdit(t, newEvent, mOldEvent->id(), mResource, KAlarm::dontShowErrors(EventId(newEvent)), mDescription);
-#else
-    UndoItem* undo = new UndoEdit(t, newEvent, mOldEvent->id(), mResource, KAlarm::dontShowErrors(mNewEventId), mDescription);
-#endif
 
     switch (calendar())
     {
@@ -990,11 +939,7 @@ UndoItem* UndoEdit::restore()
                         mRestoreWarningKorg = status;
                     // fall through to default
                 default:
-#ifdef USE_AKONADI
                     KAlarm::setDontShowErrors(EventId(*mOldEvent), mDontShowErrors);
-#else
-                    KAlarm::setDontShowErrors(mOldEvent->id(), mDontShowErrors);
-#endif
                     break;
             }
             break;
@@ -1007,7 +952,7 @@ UndoItem* UndoEdit::restore()
         default:
             delete undo;
             mRestoreError = ERR_PROG;
-            return 0;
+            return Q_NULLPTR;
     }
     return undo;
 }
@@ -1020,9 +965,9 @@ QString UndoEdit::defaultActionText() const
     switch (calendar())
     {
         case CalEvent::ACTIVE:
-            return i18nc("@info/plain Action to edit an alarm", "Edit alarm");
+            return i18nc("@info Action to edit an alarm", "Edit alarm");
         case CalEvent::TEMPLATE:
-            return i18nc("@info/plain Action to edit an alarm template", "Edit template");
+            return i18nc("@info Action to edit an alarm template", "Edit template");
         default:
             break;
     }
@@ -1065,7 +1010,7 @@ UndoDelete::~UndoDelete()
 */
 UndoItem* UndoDelete::restore()
 {
-    kDebug() << mEvent->id();
+    qCDebug(KALARM_LOG) << mEvent->id();
     // Restore the original event
     switch (calendar())
     {
@@ -1074,11 +1019,7 @@ UndoItem* UndoDelete::restore()
             {
                 // It was archived when it was deleted
                 mEvent->setCategory(CalEvent::ARCHIVED);
-#ifdef USE_AKONADI
                 KAlarm::UpdateResult status = KAlarm::reactivateEvent(*mEvent, &mResource);
-#else
-                KAlarm::UpdateResult status = KAlarm::reactivateEvent(*mEvent, mResource);
-#endif
                 switch (status.status)
                 {
                     case KAlarm::UPDATE_KORG_FUNCERR:
@@ -1094,18 +1035,14 @@ UndoItem* UndoDelete::restore()
                     case KAlarm::UPDATE_FAILED:
                     case KAlarm::SAVE_FAILED:
                         mRestoreError = ERR_ARCHIVED;
-                        return 0;
+                        return Q_NULLPTR;
                     case KAlarm::UPDATE_OK:
                         break;
                 }
             }
             else
             {
-#ifdef USE_AKONADI
-                KAlarm::UpdateResult status = KAlarm::addEvent(*mEvent, &mResource, 0, true);
-#else
-                KAlarm::UpdateResult status = KAlarm::addEvent(*mEvent, mResource, 0, true);
-#endif
+                KAlarm::UpdateResult status = KAlarm::addEvent(*mEvent, &mResource, Q_NULLPTR, true);
                 switch (status.status)
                 {
                     case KAlarm::UPDATE_KORG_FUNCERR:
@@ -1121,42 +1058,30 @@ UndoItem* UndoDelete::restore()
                     case KAlarm::UPDATE_FAILED:
                     case KAlarm::SAVE_FAILED:
                         mRestoreError = ERR_CREATE;
-                        return 0;
+                        return Q_NULLPTR;
                     case KAlarm::UPDATE_OK:
                         break;
                 }
             }
-#ifdef USE_AKONADI
             KAlarm::setDontShowErrors(EventId(*mEvent), mDontShowErrors);
-#else
-            KAlarm::setDontShowErrors(mEvent->id(), mDontShowErrors);
-#endif
             break;
         case CalEvent::TEMPLATE:
-#ifdef USE_AKONADI
             if (KAlarm::addTemplate(*mEvent, &mResource) != KAlarm::UPDATE_OK)
-#else
-            if (KAlarm::addTemplate(*mEvent, mResource) != KAlarm::UPDATE_OK)
-#endif
             {
                 mRestoreError = ERR_CREATE;
-                return 0;
+                return Q_NULLPTR;
             }
             break;
         case CalEvent::ARCHIVED:
-#ifdef USE_AKONADI
             if (!KAlarm::addArchivedEvent(*mEvent, &mResource))
-#else
-            if (!KAlarm::addArchivedEvent(*mEvent, mResource))
-#endif
             {
                 mRestoreError = ERR_CREATE;
-                return 0;
+                return Q_NULLPTR;
             }
             break;
         default:
             mRestoreError = ERR_PROG;
-            return 0;
+            return Q_NULLPTR;
     }
 
     // Create a redo item to delete the alarm again
@@ -1207,16 +1132,16 @@ QString UndoDeletes::defaultActionText() const
         switch ((*mUndos)[i]->calendar())
         {
             case CalEvent::ACTIVE:
-                return i18nc("@info/plain", "Delete multiple alarms");
+                return i18nc("@info", "Delete multiple alarms");
             case CalEvent::TEMPLATE:
-                return i18nc("@info/plain", "Delete multiple templates");
+                return i18nc("@info", "Delete multiple templates");
             case CalEvent::ARCHIVED:
                 break;    // check if they are ALL archived
             default:
                 return QString();
         }
     }
-    return i18nc("@info/plain", "Delete multiple archived alarms");
+    return i18nc("@info", "Delete multiple archived alarms");
 }
 
 
@@ -1232,7 +1157,7 @@ QString UndoDeletes::defaultActionText() const
 */
 UndoItem* UndoReactivate::restore()
 {
-    kDebug();
+    qCDebug(KALARM_LOG);
     // Validate the alarm's calendar
     switch (calendar())
     {
@@ -1240,7 +1165,7 @@ UndoItem* UndoReactivate::restore()
             break;
         default:
             mRestoreError = ERR_PROG;
-            return 0;
+            return Q_NULLPTR;
     }
     return UndoAdd::doRestore(true);     // restore alarm, ensuring that it is re-archived
 }
@@ -1259,7 +1184,7 @@ UndoItem* UndoReactivate::createRedo(const KAEvent& event, RESOURCE_PARAM_TYPE r
 */
 QString UndoReactivate::defaultActionText() const
 {
-    return i18nc("@info/plain", "Reactivate alarm");
+    return i18nc("@info", "Reactivate alarm");
 }
 
 
@@ -1275,7 +1200,7 @@ QString UndoReactivate::defaultActionText() const
 */
 UndoItem* UndoDeactivate::restore()
 {
-    kDebug();
+    qCDebug(KALARM_LOG);
     // Validate the alarm's calendar
     switch (calendar())
     {
@@ -1283,7 +1208,7 @@ UndoItem* UndoDeactivate::restore()
             break;
         default:
             mRestoreError = ERR_PROG;
-            return 0;
+            return Q_NULLPTR;
     }
 
     return UndoDelete::restore();
@@ -1303,7 +1228,7 @@ UndoItem* UndoDeactivate::createRedo(const KAEvent& event, RESOURCE_PARAM_TYPE r
 */
 QString UndoDeactivate::defaultActionText() const
 {
-    return i18nc("@info/plain", "Reactivate alarm");
+    return i18nc("@info", "Reactivate alarm");
 }
 
 
@@ -1326,7 +1251,7 @@ UndoItem* UndoReactivates::createRedo(Undo::List* undos)
 */
 QString UndoReactivates::defaultActionText() const
 {
-    return i18nc("@info/plain", "Reactivate multiple alarms");
+    return i18nc("@info", "Reactivate multiple alarms");
 }
 
 
@@ -1339,11 +1264,7 @@ Undo::Event::Event(const KAEvent& e, RESOURCE_PARAM_TYPE r)
       EVENT_RESOURCE(r)
 {
     if (e.category() == CalEvent::ACTIVE)
-#ifdef USE_AKONADI
         dontShowErrors = KAlarm::dontShowErrors(EventId(e));
-#else
-        dontShowErrors = KAlarm::dontShowErrors(e.id());
-#endif
 }
 
 // vim: et sw=4:
