@@ -38,7 +38,7 @@
 
 #include <utils/formatting.h>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <gpgme++/key.h>
 
@@ -48,63 +48,74 @@ using namespace Kleo;
 using namespace Kleo::Crypto::Gui;
 using namespace GpgME;
 
-namespace {
-
-    class SignerResolveValidator : public SignerResolvePage::Validator {
-    public:
-        explicit SignerResolveValidator( SignerResolvePage* page );
-        bool isComplete() const;
-        QString explanation() const;
-        void update() const;
-        QString customWindowTitle() const { return QString(); }
-
-    private:
-        SignerResolvePage* m_page;
-        mutable QString expl;
-        mutable bool complete;
-    };
-}
-
-SignerResolveValidator::SignerResolveValidator( SignerResolvePage* page ) : SignerResolvePage::Validator(), m_page( page ), complete( true )
+namespace
 {
-    assert( m_page );
+
+class SignerResolveValidator : public SignerResolvePage::Validator
+{
+public:
+    explicit SignerResolveValidator(SignerResolvePage *page);
+    bool isComplete() const;
+    QString explanation() const;
+    void update() const;
+    QString customWindowTitle() const
+    {
+        return QString();
+    }
+
+private:
+    SignerResolvePage *m_page;
+    mutable QString expl;
+    mutable bool complete;
+};
 }
 
-void SignerResolveValidator::update() const {
+SignerResolveValidator::SignerResolveValidator(SignerResolvePage *page) : SignerResolvePage::Validator(), m_page(page), complete(true)
+{
+    assert(m_page);
+}
+
+void SignerResolveValidator::update() const
+{
     const bool haveSelected = !m_page->selectedProtocols().empty();
     const std::vector<Protocol> missing = m_page->selectedProtocolsWithoutSigningCertificate();
 
     complete = haveSelected && missing.empty();
     expl.clear();
-    if ( complete )
+    if (complete) {
         return;
-    if ( !haveSelected ) {
-        expl = i18n( "You need to select a signing certificate to proceed." );
+    }
+    if (!haveSelected) {
+        expl = i18n("You need to select a signing certificate to proceed.");
         return;
     }
 
-    assert( missing.size() <= 2 );
-    if ( missing.size() == 1 )
-        expl = i18n( "You need to select an %1 signing certificate to proceed.", Formatting::displayName( missing[0] ) );
-    else
-        expl = i18n( "You need to select %1 and %2 signing certificates to proceed.", Formatting::displayName( missing[0] ), Formatting::displayName( missing[1] ) );
+    assert(missing.size() <= 2);
+    if (missing.size() == 1) {
+        expl = i18n("You need to select an %1 signing certificate to proceed.", Formatting::displayName(missing[0]));
+    } else {
+        expl = i18n("You need to select %1 and %2 signing certificates to proceed.", Formatting::displayName(missing[0]), Formatting::displayName(missing[1]));
+    }
 }
 
-QString SignerResolveValidator::explanation() const {
+QString SignerResolveValidator::explanation() const
+{
     update();
     return expl;
 }
 
-bool SignerResolveValidator::isComplete() const {
+bool SignerResolveValidator::isComplete() const
+{
     update();
     return complete;
 }
 
-class SignEMailWizard::Private {
+class SignEMailWizard::Private
+{
     friend class ::Kleo::Crypto::Gui::SignEMailWizard;
-    SignEMailWizard * const q;
+    SignEMailWizard *const q;
 public:
-    explicit Private( SignEMailWizard * qq );
+    explicit Private(SignEMailWizard *qq);
     ~Private();
 
     void operationSelected();
@@ -112,29 +123,29 @@ public:
     bool m_quickMode;
 };
 
-SignEMailWizard::Private::Private( SignEMailWizard * qq )
-  : q( qq ), m_quickMode( false )
+SignEMailWizard::Private::Private(SignEMailWizard *qq)
+    : q(qq), m_quickMode(false)
 {
-    q->setWindowTitle( i18n("Sign Mail Message") );
+    q->setWindowTitle(i18n("Sign Mail Message"));
 
     std::vector<int> pageOrder;
-    q->setSignerResolvePageValidator( boost::shared_ptr<SignerResolveValidator>( new SignerResolveValidator( q->signerResolvePage() ) ) );
-    pageOrder.push_back( SignEncryptWizard::ResolveSignerPage );
-    pageOrder.push_back( SignEncryptWizard::ResultPage );
-    q->setPageOrder( pageOrder );
-    q->setCommitPage( SignEncryptWizard::ResolveSignerPage );
-    q->setEncryptionSelected( false );
-    q->setEncryptionUserMutable( false );
-    q->setSigningSelected( true );
-    q->setSigningUserMutable( false );
-    q->signerResolvePage()->setProtocolSelectionUserMutable( false );
-    q->setMultipleProtocolsAllowed( false );
+    q->setSignerResolvePageValidator(boost::shared_ptr<SignerResolveValidator>(new SignerResolveValidator(q->signerResolvePage())));
+    pageOrder.push_back(SignEncryptWizard::ResolveSignerPage);
+    pageOrder.push_back(SignEncryptWizard::ResultPage);
+    q->setPageOrder(pageOrder);
+    q->setCommitPage(SignEncryptWizard::ResolveSignerPage);
+    q->setEncryptionSelected(false);
+    q->setEncryptionUserMutable(false);
+    q->setSigningSelected(true);
+    q->setSigningUserMutable(false);
+    q->signerResolvePage()->setProtocolSelectionUserMutable(false);
+    q->setMultipleProtocolsAllowed(false);
 }
 
 SignEMailWizard::Private::~Private() {}
 
-SignEMailWizard::SignEMailWizard( QWidget * parent, Qt::WindowFlags f )
-  : SignEncryptWizard( parent, f ), d( new Private( this ) )
+SignEMailWizard::SignEMailWizard(QWidget *parent, Qt::WindowFlags f)
+    : SignEncryptWizard(parent, f), d(new Private(this))
 {
 }
 
@@ -143,15 +154,15 @@ bool SignEMailWizard::quickMode() const
     return d->m_quickMode;
 }
 
-void SignEMailWizard::setQuickMode( bool quick )
+void SignEMailWizard::setQuickMode(bool quick)
 {
-    if ( quick == d->m_quickMode )
+    if (quick == d->m_quickMode) {
         return;
+    }
     d->m_quickMode = quick;
-    signerResolvePage()->setAutoAdvance( quick );
-    setKeepResultPageOpenWhenDone( !quick );
+    signerResolvePage()->setAutoAdvance(quick);
+    setKeepResultPageOpenWhenDone(!quick);
 }
 
 SignEMailWizard::~SignEMailWizard() {}
 
-#include "moc_signemailwizard.cpp"
