@@ -38,74 +38,85 @@
 
 #include <KGuiItem>
 #include <KLocalizedString>
-#include <KPushButton>
 
 #include <QFormLayout>
 #include <QLabel>
+#include <QPushButton>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QVBoxLayout>
 
 using namespace Kleo;
 using namespace Kleo::Dialogs;
 
-class ExportCertificatesDialog::Private {
+class ExportCertificatesDialog::Private
+{
     friend class ::Kleo::Dialogs::ExportCertificatesDialog;
-    ExportCertificatesDialog * const q;
+    ExportCertificatesDialog *const q;
 public:
-    explicit Private( ExportCertificatesDialog * qq );
+    explicit Private(ExportCertificatesDialog *qq);
     ~Private();
     void fileNamesChanged();
 
 private:
-    FileNameRequester* pgpRequester;
-    FileNameRequester* cmsRequester;
+    FileNameRequester *pgpRequester;
+    FileNameRequester *cmsRequester;
+    QPushButton *mOkButton;
 };
 
-
-ExportCertificatesDialog::Private::Private( ExportCertificatesDialog * qq )
-  : q( qq )
+ExportCertificatesDialog::Private::Private(ExportCertificatesDialog *qq)
+    : q(qq)
 {
-    q->setButtons( KDialog::Ok | KDialog::Cancel );
-    q->setButtonGuiItem( KDialog::Ok, KGuiItem( i18n( "Export" ) ) );
-    QWidget* const main = new QWidget;
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    q->setLayout(mainLayout);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    mOkButton = buttonBox->button(QDialogButtonBox::Ok);
+    mOkButton->setDefault(true);
+    mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, q, &ExportCertificatesDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, q, &ExportCertificatesDialog::reject);
+
+    KGuiItem::assign(mOkButton, KGuiItem(i18n("Export")));
+    QWidget *const main = new QWidget;
+    mainLayout->addWidget(main);
+    mainLayout->addWidget(buttonBox);
+
     QFormLayout *layout = new QFormLayout;
     main->setLayout(layout);
 
-    QLabel* const pgpLabel = new QLabel;
-    pgpLabel->setText( i18n(" OpenPGP export file:" ) );
+    QLabel *const pgpLabel = new QLabel;
+    pgpLabel->setText(i18n(" OpenPGP export file:"));
     pgpRequester = new FileNameRequester;
-    connect( pgpRequester, SIGNAL(fileNameChanged(QString)), q, SLOT(fileNamesChanged()) );
+    connect(pgpRequester, SIGNAL(fileNameChanged(QString)), q, SLOT(fileNamesChanged()));
     layout->addRow(pgpLabel, pgpRequester);
 
-    QLabel* const cmsLabel = new QLabel;
-    cmsLabel->setText( i18n( "S/MIME export file:" ) );
+    QLabel *const cmsLabel = new QLabel;
+    cmsLabel->setText(i18n("S/MIME export file:"));
     cmsRequester = new FileNameRequester;
     layout->addRow(cmsLabel, cmsRequester);
 
-    connect( cmsRequester, SIGNAL(fileNameChanged(QString)), q, SLOT(fileNamesChanged()) );
-    q->setMainWidget( main );
+    connect(cmsRequester, SIGNAL(fileNameChanged(QString)), q, SLOT(fileNamesChanged()));
     fileNamesChanged();
 }
 
 ExportCertificatesDialog::Private::~Private() {}
 
-
-
-ExportCertificatesDialog::ExportCertificatesDialog( QWidget * parent, Qt::WindowFlags f )
-  : KDialog( parent, f ), d( new Private( this ) )
+ExportCertificatesDialog::ExportCertificatesDialog(QWidget *parent)
+    : QDialog(parent), d(new Private(this))
 {
-    
+
 }
 
 void ExportCertificatesDialog::Private::fileNamesChanged()
 {
-    q->button( KDialog::Ok )->setEnabled( !pgpRequester->fileName().isEmpty() && !cmsRequester->fileName().isEmpty() );
+    mOkButton->setEnabled(!pgpRequester->fileName().isEmpty() && !cmsRequester->fileName().isEmpty());
 }
 
 ExportCertificatesDialog::~ExportCertificatesDialog() {}
 
-
-void ExportCertificatesDialog::setOpenPgpExportFileName( const QString & fileName )
+void ExportCertificatesDialog::setOpenPgpExportFileName(const QString &fileName)
 {
-    d->pgpRequester->setFileName( fileName );
+    d->pgpRequester->setFileName(fileName);
 }
 
 QString ExportCertificatesDialog::openPgpExportFileName() const
@@ -113,9 +124,9 @@ QString ExportCertificatesDialog::openPgpExportFileName() const
     return d->pgpRequester->fileName();
 }
 
-void ExportCertificatesDialog::setCmsExportFileName( const QString & fileName )
+void ExportCertificatesDialog::setCmsExportFileName(const QString &fileName)
 {
-    d->cmsRequester->setFileName( fileName );
+    d->cmsRequester->setFileName(fileName);
 }
 
 QString ExportCertificatesDialog::cmsExportFileName() const
