@@ -30,64 +30,42 @@
     your version.
 */
 
-
 #include <config-kleopatra.h>
 
 #include "aboutdata.h"
 #include "kwatchgnupgmainwin.h"
+#include <kdelibs4configmigrator.h>
+#include <KDBusService>
 
-#include <kuniqueapplication.h>
-#include <kcmdlineargs.h>
 #include <kmessagebox.h>
-#include <klocale.h>
-#include <kglobal.h>
+#include <KLocalizedString>
 #include <kiconloader.h>
-#include <kdebug.h>
+#include "kwatchgnupg_debug.h"
+#include <QCommandLineParser>
+#include <QApplication>
 
-class KWatchGnuPGApplication : public KUniqueApplication {
-public:
-  KWatchGnuPGApplication();
-  ~KWatchGnuPGApplication();
-  virtual int newInstance();
-private:
-  KWatchGnuPGMainWindow* mMainWin;
-};
-
-KWatchGnuPGApplication::KWatchGnuPGApplication()
-  : KUniqueApplication(), mMainWin(0)
+int main(int argc, char **argv)
 {
-}
+    QApplication app(argc, argv);
+    Kdelibs4ConfigMigrator migrate(QStringLiteral("kwatchgnupg"));
+    migrate.setConfigFiles(QStringList() << QStringLiteral("kwatchgnupgrc"));
+    migrate.setUiFiles(QStringList() << QStringLiteral("kwatchgnupgui.rc"));
+    migrate.migrate();
 
-KWatchGnuPGApplication::~KWatchGnuPGApplication()
-{
-  delete mMainWin;
-}
+    KLocalizedString::setApplicationDomain("kwatchgnupg");
+    AboutData aboutData;
 
-int KWatchGnuPGApplication::newInstance()
-{
-  if( !mMainWin )
-      mMainWin = new KWatchGnuPGMainWindow;
-  mMainWin->show();
-  return KUniqueApplication::newInstance();
-}
+    KAboutData::setApplicationData(aboutData);
+    QCommandLineParser parser;
+    parser.addVersionOption();
+    parser.addHelpOption();
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 
-int main( int argc, char** argv )
-{
-  AboutData aboutData;
+    KDBusService service(KDBusService::Unique);
 
-  KCmdLineArgs::init(argc, argv, &aboutData);
-
-  KCmdLineOptions options;
-  KCmdLineArgs::addCmdLineOptions( options );
-  KWatchGnuPGApplication::addCmdLineOptions();
-
-#if 0
-  if (!KWatchGnuPGApplication::start()) {
-        kError() <<"KWatchGnuPG is already running!";
-        return 0;
-  }
-#endif
-
-  KWatchGnuPGApplication app;
-  return app.exec();
+    KWatchGnuPGMainWindow *mMainWin = new KWatchGnuPGMainWindow();
+    mMainWin->show();
+    return app.exec();
 }
