@@ -39,56 +39,59 @@
 #include <utils/pimpl_ptr.h>
 #include <boost/shared_ptr.hpp>
 
-namespace GpgME {
-    class Key;
+namespace GpgME
+{
+class Key;
 }
 
-namespace Kleo {
+namespace Kleo
+{
 
-    class AbstractKeyListModel;
-    class KeyFilter;
+class KeyFilter;
 
-    class AbstractKeyListSortFilterProxyModel : public QSortFilterProxyModel, public KeyListModelInterface {
-        Q_OBJECT
-    protected:
-        AbstractKeyListSortFilterProxyModel( const AbstractKeyListSortFilterProxyModel & );
-    public:
-        explicit AbstractKeyListSortFilterProxyModel( QObject * parent=0 );
-        ~AbstractKeyListSortFilterProxyModel();
+class AbstractKeyListSortFilterProxyModel : public QSortFilterProxyModel, public KeyListModelInterface
+{
+    Q_OBJECT
+protected:
+    AbstractKeyListSortFilterProxyModel(const AbstractKeyListSortFilterProxyModel &);
+public:
+    explicit AbstractKeyListSortFilterProxyModel(QObject *parent = Q_NULLPTR);
+    ~AbstractKeyListSortFilterProxyModel();
 
-        virtual AbstractKeyListSortFilterProxyModel * clone() const = 0;
+    virtual AbstractKeyListSortFilterProxyModel *clone() const = 0;
 
-        /* reimp */ GpgME::Key key( const QModelIndex & idx ) const;
-        /* reimp */ std::vector<GpgME::Key> keys( const QList<QModelIndex> & indexes ) const;
+    /* reimp */ GpgME::Key key(const QModelIndex &idx) const;
+    /* reimp */ std::vector<GpgME::Key> keys(const QList<QModelIndex> &indexes) const;
 
-        using QAbstractItemModel::index;
-        /* reimp */ QModelIndex index( const GpgME::Key & key ) const;
-        /* reimp */ QList<QModelIndex> indexes( const std::vector<GpgME::Key> & keys ) const;
+    using QAbstractItemModel::index;
+    /* reimp */ QModelIndex index(const GpgME::Key &key) const;
+    /* reimp */ QList<QModelIndex> indexes(const std::vector<GpgME::Key> &keys) const;
 
-    private:
-        void init();
-    };
+private:
+    void init();
+};
 
-    class KeyListSortFilterProxyModel : public AbstractKeyListSortFilterProxyModel {
-        Q_OBJECT
-    protected:
-        KeyListSortFilterProxyModel( const KeyListSortFilterProxyModel & );
-    public:
-        explicit KeyListSortFilterProxyModel( QObject * parent=0 );
-        ~KeyListSortFilterProxyModel();
+class KeyListSortFilterProxyModel : public AbstractKeyListSortFilterProxyModel
+{
+    Q_OBJECT
+protected:
+    KeyListSortFilterProxyModel(const KeyListSortFilterProxyModel &);
+public:
+    explicit KeyListSortFilterProxyModel(QObject *parent = Q_NULLPTR);
+    ~KeyListSortFilterProxyModel();
 
-        boost::shared_ptr<const KeyFilter> keyFilter() const;
-        void setKeyFilter( const boost::shared_ptr<const KeyFilter> & kf );
+    boost::shared_ptr<const KeyFilter> keyFilter() const;
+    void setKeyFilter(const boost::shared_ptr<const KeyFilter> &kf);
 
-        /* reimp */ KeyListSortFilterProxyModel * clone() const;
+    /* reimp */ KeyListSortFilterProxyModel *clone() const;
 
-    protected:
-        /* reimp */ bool filterAcceptsRow( int source_row, const QModelIndex & source_parent ) const;
+protected:
+    bool filterAcceptsRow(int source_row, const QModelIndex &source_parent) const Q_DECL_OVERRIDE;
 
-    private:
-        class Private;
-        kdtools::pimpl_ptr<Private> d;
-    };
+private:
+    class Private;
+    kdtools::pimpl_ptr<Private> d;
+};
 
 }
 
