@@ -45,23 +45,26 @@
 #include <algorithm>
 #include <iterator>
 
-namespace Kleo {
-namespace _detail {
+namespace Kleo
+{
+namespace _detail
+{
 
-    inline int mystrcmp( const char * s1, const char * s2 ) {
-        using namespace std;
-        return s1 ? s2 ? strcmp( s1, s2 ) : 1 : s2 ? -1 : 0 ;
-    }
+inline int mystrcmp(const char *s1, const char *s2)
+{
+    using namespace std;
+    return s1 ? s2 ? strcmp(s1, s2) : 1 : s2 ? -1 : 0 ;
+}
 
 #define make_comparator_str_impl( Name, expr, cmp )                     \
     template <template <typename U> class Op>                           \
     struct Name {                                                       \
         typedef bool result_type;                                       \
-                                                                        \
+        \
         bool operator()( const char * lhs, const char * rhs ) const {   \
             return Op<int>()( cmp, 0 );                                 \
         }                                                               \
-                                                                        \
+        \
         bool operator()( const std::string & lhs, const std::string & rhs ) const { \
             return operator()( lhs.c_str(), rhs.c_str() );              \
         }                                                               \
@@ -71,7 +74,7 @@ namespace _detail {
         bool operator()( const std::string & lhs, const char * rhs ) const { \
             return operator()( lhs.c_str(), rhs );                      \
         }                                                               \
-                                                                        \
+        \
         template <typename T>                                           \
         bool operator()( const T & lhs, const T & rhs ) const {         \
             return operator()( (lhs expr), (rhs expr) );                \
@@ -99,86 +102,97 @@ namespace _detail {
 #define make_comparator_str( Name, expr )                               \
     make_comparator_str_impl( Name, expr, qstricmp( lhs, rhs ) )
 
-    make_comparator_str_fast( ByFingerprint, .primaryFingerprint() );
-    make_comparator_str_fast( ByKeyID, .keyID() );
-    make_comparator_str_fast( ByShortKeyID, .shortKeyID() );
-    make_comparator_str_fast( ByChainID, .chainID() );
+make_comparator_str_fast(ByFingerprint, .primaryFingerprint());
+make_comparator_str_fast(ByKeyID, .keyID());
+make_comparator_str_fast(ByShortKeyID, .shortKeyID());
+make_comparator_str_fast(ByChainID, .chainID());
 
-    template <typename T>
-    void sort_by_fpr( T & t ) {
-        std::sort( t.begin(), t.end(), ByFingerprint<std::less>() );
-    }
+template <typename T>
+void sort_by_fpr(T &t)
+{
+    std::sort(t.begin(), t.end(), ByFingerprint<std::less>());
+}
 
-    template <typename T>
-    void remove_duplicates_by_fpr( T & t ) {
-        t.erase( std::unique( t.begin(), t.end(), ByFingerprint<std::equal_to>() ), t.end() );
-    }
+template <typename T>
+void remove_duplicates_by_fpr(T &t)
+{
+    t.erase(std::unique(t.begin(), t.end(), ByFingerprint<std::equal_to>()), t.end());
+}
 
-    template <typename T>
-    T union_by_fpr( const T & t1, const T & t2 ) {
-        T result;
-        result.reserve( t1.size() + t2.size() );
-        std::set_union( t1.begin(), t1.end(),
-                        t2.begin(), t2.end(),
-                        std::back_inserter( result ),
-                        ByFingerprint<std::less>() );
-        return result;
-    }
+template <typename T>
+T union_by_fpr(const T &t1, const T &t2)
+{
+    T result;
+    result.reserve(t1.size() + t2.size());
+    std::set_union(t1.begin(), t1.end(),
+                   t2.begin(), t2.end(),
+                   std::back_inserter(result),
+                   ByFingerprint<std::less>());
+    return result;
+}
 
-    template <typename T>
-    T union_by_fpr_dirty( const T & t1, const T & t2 ) {
-        T cleaned( t1 );
-        sort_by_fpr( cleaned );
-        remove_duplicates_by_fpr( cleaned );
-        return union_by_fpr( cleaned, t2 );
-    }
+template <typename T>
+T union_by_fpr_dirty(const T &t1, const T &t2)
+{
+    T cleaned(t1);
+    sort_by_fpr(cleaned);
+    remove_duplicates_by_fpr(cleaned);
+    return union_by_fpr(cleaned, t2);
+}
 
-    template <typename T>
-    void grep_protocol( T & t, GpgME::Protocol proto ) {
-        t.erase( std::remove_if( t.begin(), t.end(), boost::bind( &GpgME::Key::protocol, _1 ) != proto ), t.end() );
-    }
+template <typename T>
+void grep_protocol(T &t, GpgME::Protocol proto)
+{
+    t.erase(std::remove_if(t.begin(), t.end(), boost::bind(&GpgME::Key::protocol, _1) != proto), t.end());
+}
 
-    template <typename T>
-    bool any_protocol( const T & t, GpgME::Protocol proto ) {
-        return kdtools::any( t, boost::bind( &GpgME::Key::protocol, _1 ) == proto );
-    }
+template <typename T>
+bool any_protocol(const T &t, GpgME::Protocol proto)
+{
+    return kdtools::any(t, boost::bind(&GpgME::Key::protocol, _1) == proto);
+}
 
-    template <typename T>
-    bool all_protocol( const T & t, GpgME::Protocol proto ) {
-        return kdtools::all( t, boost::bind( &GpgME::Key::protocol, _1 ) == proto );
-    }
+template <typename T>
+bool all_protocol(const T &t, GpgME::Protocol proto)
+{
+    return kdtools::all(t, boost::bind(&GpgME::Key::protocol, _1) == proto);
+}
 
-    template <typename T>
-    bool none_of_protocol( const T & t, GpgME::Protocol proto ) {
-        return kdtools::none_of( t, boost::bind( &GpgME::Key::protocol, _1 ) == proto );
-    }
+template <typename T>
+bool none_of_protocol(const T &t, GpgME::Protocol proto)
+{
+    return kdtools::none_of(t, boost::bind(&GpgME::Key::protocol, _1) == proto);
+}
 
-    template <typename T>
-    void grep_secret( T & t ) {
-        t.erase( std::remove_if( t.begin(), t.end(), boost::mem_fn( &GpgME::Key::hasSecret ) ), t.end() );
-    }
+template <typename T>
+void grep_secret(T &t)
+{
+    t.erase(std::remove_if(t.begin(), t.end(), boost::mem_fn(&GpgME::Key::hasSecret)), t.end());
+}
 
-    template <typename T>
-    bool any_secret( const T & t ) {
-        return kdtools::any( t, boost::mem_fn( &GpgME::Key::hasSecret ) );
-    }
+template <typename T>
+bool any_secret(const T &t)
+{
+    return kdtools::any(t, boost::mem_fn(&GpgME::Key::hasSecret));
+}
 
-    template <typename T>
-    bool all_secret( const T & t ) {
-        return kdtools::all( t, boost::mem_fn( &GpgME::Key::hasSecret ) );
-    }
+template <typename T>
+bool all_secret(const T &t)
+{
+    return kdtools::all(t, boost::mem_fn(&GpgME::Key::hasSecret));
+}
 
-    template <typename T>
-    bool none_of_secret( const T & t ) {
-        return kdtools::none_of( t, boost::mem_fn( &GpgME::Key::hasSecret ) );
-    }
-
-
-    template <typename T>
-    void grep_can_encrypt( T & t ) {
-        t.erase( std::remove_if( t.begin(), t.end(), !boost::bind( &GpgME::Key::canEncrypt, _1 ) ), t.end() );
-    }
+template <typename T>
+bool none_of_secret(const T &t)
+{
+    return kdtools::none_of(t, boost::mem_fn(&GpgME::Key::hasSecret));
+}
 
+template <typename T>
+void grep_can_encrypt(T &t)
+{
+    t.erase(std::remove_if(t.begin(), t.end(), !boost::bind(&GpgME::Key::canEncrypt, _1)), t.end());
+}
 
 }
 }
