@@ -33,41 +33,48 @@ class QSpinBox;
 class KButtonGroup;
 class KLineEdit;
 class QModelIndex;
-namespace MessageViewer {
+namespace MessageViewer
+{
 class ConfigureWidget;
+class GravatarConfigWidget;
 }
 
-namespace MessageList {
-namespace Utils {
+namespace MessageList
+{
+namespace Utils
+{
 class AggregationComboBox;
 class ThemeComboBox;
 }
 }
 
-namespace MailCommon {
+namespace MailCommon
+{
 class Tag;
 typedef QSharedPointer<Tag> TagPtr;
 }
 
-namespace MailCommon {
+namespace MailCommon
+{
 class TagWidget;
 }
 
-class AppearancePageFontsTab : public ConfigModuleTab {
+class AppearancePageFontsTab : public ConfigModuleTab
+{
     Q_OBJECT
 public:
-    explicit AppearancePageFontsTab( QWidget * parent=0 );
+    explicit AppearancePageFontsTab(QWidget *parent = Q_NULLPTR);
     QString helpAnchor() const;
-    void save();
+    void save() Q_DECL_OVERRIDE;
 
-private slots:
-    void slotFontSelectorChanged( int );
+private Q_SLOTS:
+    void slotFontSelectorChanged(int);
 
 private:
     //virtual void doLoadFromGlobalSettings();
-    void doLoadOther();
+    void doLoadOther() Q_DECL_OVERRIDE;
     void updateFontSelector();
-    void doResetToDefaultsOther();
+    void doResetToDefaultsOther() Q_DECL_OVERRIDE;
 
 private:
     QCheckBox    *mCustomFontCheck;
@@ -78,18 +85,19 @@ private:
     QFont        mFont[12];
 };
 
-class AppearancePageColorsTab : public ConfigModuleTab {
+class AppearancePageColorsTab : public ConfigModuleTab
+{
     Q_OBJECT
 public:
-    explicit AppearancePageColorsTab( QWidget * parent=0 );
+    explicit AppearancePageColorsTab(QWidget *parent = Q_NULLPTR);
     QString helpAnchor() const;
-    void save();
+    void save() Q_DECL_OVERRIDE;
 
 private:
     //virtual void doLoadFromGlobalSettings();
-    void doLoadOther();
-    void doResetToDefaultsOther();
-    void loadColor( bool loadFromConfig );
+    void doLoadOther() Q_DECL_OVERRIDE;
+    void doResetToDefaultsOther() Q_DECL_OVERRIDE;
+    void loadColor(bool loadFromConfig);
 
 private:
     QCheckBox    *mCustomColorCheck;
@@ -98,17 +106,18 @@ private:
     QSpinBox     *mCloseToQuotaThreshold;
 };
 
-class AppearancePageLayoutTab : public ConfigModuleTab {
+class AppearancePageLayoutTab : public ConfigModuleTab
+{
     Q_OBJECT
 public:
-    explicit AppearancePageLayoutTab( QWidget * parent=0 );
+    explicit AppearancePageLayoutTab(QWidget *parent = Q_NULLPTR);
     QString helpAnchor() const;
 
-    void save();
+    void save() Q_DECL_OVERRIDE;
 
 private:
     //virtual void doLoadFromGlobalSettings();
-    void doLoadOther();
+    void doLoadOther() Q_DECL_OVERRIDE;
     //FIXME virtual void doResetToDefaultsOther();
 
 private: // data
@@ -123,20 +132,21 @@ private: // data
     QGroupBox     *mFavoriteFoldersViewGroupBox;
 };
 
-class AppearancePageHeadersTab : public ConfigModuleTab {
+class AppearancePageHeadersTab : public ConfigModuleTab
+{
     Q_OBJECT
 public:
-    explicit AppearancePageHeadersTab( QWidget * parent=0 );
+    explicit AppearancePageHeadersTab(QWidget *parent = Q_NULLPTR);
 
     QString helpAnchor() const;
 
-    void save();
+    void save() Q_DECL_OVERRIDE;
 
 private: // methods
-    void doLoadFromGlobalSettings();
-    void doLoadOther();
+    void doLoadFromGlobalSettings() Q_DECL_OVERRIDE;
+    void doLoadOther() Q_DECL_OVERRIDE;
     // virtual void doResetToDefaultsOther();
-    void setDateDisplay( int id, const QString & format );
+    void setDateDisplay(int id, const QString &format);
 
 private: // data
     QCheckBox    *mDisplayMessageToolTips;
@@ -148,42 +158,44 @@ private: // data
     KLineEdit    *mCustomDateFormatEdit;
     QString       mCustomDateWhatsThis;
 
-private slots:
-    void slotLinkClicked( const QString & link );
+private Q_SLOTS:
+    void slotLinkClicked(const QString &link);
     void slotSelectDefaultAggregation();
     void slotSelectDefaultTheme();
 };
 
-class AppearancePageReaderTab : public ConfigModuleTab {
+class AppearancePageReaderTab : public ConfigModuleTab
+{
     Q_OBJECT
 public:
-    explicit AppearancePageReaderTab( QWidget * parent=0 );
+    explicit AppearancePageReaderTab(QWidget *parent = Q_NULLPTR);
 
     QString helpAnchor() const;
 
-    void save();
+    void save() Q_DECL_OVERRIDE;
 
 private:
-    void doLoadOther();
-    void doResetToDefaultsOther();
+    void doLoadOther() Q_DECL_OVERRIDE;
+    void doResetToDefaultsOther() Q_DECL_OVERRIDE;
 
 private: // data
     QCheckBox *mCloseAfterReplyOrForwardCheck;
     MessageViewer::ConfigureWidget *mViewerSettings;
+    MessageViewer::GravatarConfigWidget *mGravatarConfigWidget;
 };
 
-
-class AppearancePageSystemTrayTab : public ConfigModuleTab {
+class AppearancePageSystemTrayTab : public ConfigModuleTab
+{
     Q_OBJECT
 public:
-    explicit AppearancePageSystemTrayTab( QWidget * parent=0 );
+    explicit AppearancePageSystemTrayTab(QWidget *parent = Q_NULLPTR);
 
     QString helpAnchor() const;
 
-    void save();
+    void save() Q_DECL_OVERRIDE;
 
 private:
-    void doLoadFromGlobalSettings();
+    void doLoadFromGlobalSettings() Q_DECL_OVERRIDE;
 
 private: // data
     QCheckBox    *mSystemTrayCheck;
@@ -191,15 +203,14 @@ private: // data
     KButtonGroup *mSystemTrayGroup;
 };
 
-
 class TagListWidgetItem : public QListWidgetItem
 {
 public:
-    explicit TagListWidgetItem( QListWidget *parent = 0);
-    explicit TagListWidgetItem( const QIcon & icon, const QString & text, QListWidget * parent = 0);
+    explicit TagListWidgetItem(QListWidget *parent = Q_NULLPTR);
+    explicit TagListWidgetItem(const QIcon &icon, const QString &text, QListWidget *parent = Q_NULLPTR);
 
     ~TagListWidgetItem();
-    void setKMailTag( const MailCommon::Tag::Ptr& tag );
+    void setKMailTag(const MailCommon::Tag::Ptr &tag);
     MailCommon::Tag::Ptr kmailTag() const;
 private:
     MailCommon::Tag::Ptr mTag;
@@ -207,22 +218,23 @@ private:
 
 /**Configuration tab in the appearance page for modifying the available set of
 +message tags*/
-class AppearancePageMessageTagTab : public ConfigModuleTab {
+class AppearancePageMessageTagTab : public ConfigModuleTab
+{
     Q_OBJECT
 public:
-    explicit AppearancePageMessageTagTab( QWidget * parent=0);
+    explicit AppearancePageMessageTagTab(QWidget *parent = Q_NULLPTR);
     ~AppearancePageMessageTagTab();
 
     QString helpAnchor() const;
 
-    void save();
+    void save() Q_DECL_OVERRIDE;
 
-public slots:
+public Q_SLOTS:
     /**Enables/disables Add button according to whether @p aText is empty.
-  Connected to signal of the line edit widget for adding tags
-  @param aText String to change add button according to
-  */
-    void slotAddLineTextChanged( const QString &aText );
+    Connected to signal of the line edit widget for adding tags
+    @param aText String to change add button according to
+    */
+    void slotAddLineTextChanged(const QString &aText);
     /**Creates a generic tag with the visible name from the line edit widget for
     adding tags. Adds it to the end of the list and selects. Empties the line
     edit widget*/
@@ -230,47 +242,47 @@ public slots:
     /**Removes the currently selected text in the list box.*/
     void slotRemoveTag();
     /**Increases the currently selected tag's priority and handles related visual
-  changes*/
+    changes*/
     void slotMoveTagUp();
     /**Decreases the currently selected tag's priority and handles related visual
-  changes*/
+    changes*/
     void slotMoveTagDown();
 
-private slots:
+private Q_SLOTS:
     /*Handles necessary processing when the selection in the edit box changes.
-  Records the unselected tag's information, and applies visual changes
-  necessary depending on the description of the new tag. Private since doesn't
-  change the selection of the edit box itself*/
+    Records the unselected tag's information, and applies visual changes
+    necessary depending on the description of the new tag. Private since doesn't
+    change the selection of the edit box itself*/
     void slotSelectionChanged();
     /*This slot is necessary so that apply button is not activated when we are
-  only applying visual changes after selecting a new tag in the list box*/
+    only applying visual changes after selecting a new tag in the list box*/
     void slotEmitChangeCheck();
     /*Transfers the tag settings from the widgets to the internal data structures.
-  Private since passing a wrong parameter modifies another tag's data*/
-    void slotRecordTagSettings( int aIndex );
+    Private since passing a wrong parameter modifies another tag's data*/
+    void slotRecordTagSettings(int aIndex);
     /*Transfers the tag settings from the internal data structures to the widgets.
-  Private since passing a wrong parameter visualizes another tag's data*/
-    void slotUpdateTagSettingWidgets( int aIndex );
+    Private since passing a wrong parameter visualizes another tag's data*/
+    void slotUpdateTagSettingWidgets(int aIndex);
     /*Transfers changes in the tag name edit box to the list box for tags. Private
-  since calling externally decouples the name in the list box from name edit box*/
-    void slotNameLineTextChanged( const QString & );
-    void slotIconNameChanged( const QString &iconName );
-    void slotRowsMoved( const QModelIndex &,
-                        int sourcestart, int sourceEnd,
-                        const QModelIndex &, int destinationRow );
+    since calling externally decouples the name in the list box from name edit box*/
+    void slotNameLineTextChanged(const QString &);
+    void slotIconNameChanged(const QString &iconName);
+    void slotRowsMoved(const QModelIndex &,
+                       int sourcestart, int sourceEnd,
+                       const QModelIndex &, int destinationRow);
     void slotTagsFetched(KJob *job);
 
     void slotDeleteTagJob(KJob *job);
 private:
-    void doLoadFromGlobalSettings();
-    void swapTagsInListBox( const int first, const int second );
+    void doLoadFromGlobalSettings() Q_DECL_OVERRIDE;
+    void swapTagsInListBox(const int first, const int second);
     void updateButtons();
 
 private: // data
 
     KLineEdit *mTagAddLineEdit;
     QPushButton *mTagAddButton, *mTagRemoveButton,
-    *mTagUpButton, *mTagDownButton;
+                *mTagUpButton, *mTagDownButton;
 
     QListWidget *mTagListBox;
 
@@ -286,12 +298,13 @@ private: // data
     int mPreviousTag;
 };
 
-class KMAIL_EXPORT AppearancePage : public ConfigModuleWithTabs {
+class KMAIL_EXPORT AppearancePage : public ConfigModuleWithTabs
+{
     Q_OBJECT
 public:
-    explicit AppearancePage( const KComponentData &instance, QWidget *parent=0 );
+    explicit AppearancePage(QWidget *parent = Q_NULLPTR);
 
-    QString helpAnchor() const;
+    QString helpAnchor() const Q_DECL_OVERRIDE;
 
     // hrmpf. moc doesn't like nested classes with slots/signals...:
     typedef AppearancePageFontsTab FontsTab;
@@ -312,6 +325,4 @@ private:
     MessageTagTab *mMessageTagTab;
 };
 
-
-
 #endif // CONFIGUREAPPEARANCEPAGE_H
