@@ -21,7 +21,7 @@
 #include "potentialphishingemailwarningtest.h"
 #include "../potentialphishingemailwarning.h"
 #include <QAction>
-#include <qtest_kde.h>
+#include <qtest.h>
 
 PotentialPhishingEmailWarningTest::PotentialPhishingEmailWarningTest(QObject *parent)
     : QObject(parent)
@@ -39,8 +39,8 @@ void PotentialPhishingEmailWarningTest::shouldHaveDefaultValue()
     PotentialPhishingEmailWarning w;
     QVERIFY(!w.isVisible());
     //Verify QVERIFY(w.isCloseButtonVisible());
-    QAction *act = qFindChild<QAction *>(&w, QLatin1String("sendnow"));
+    QAction *act = w.findChild<QAction *>(QStringLiteral("sendnow"));
     QVERIFY(act);
 }
 
-QTEST_KDEMAIN(PotentialPhishingEmailWarningTest, GUI)
+QTEST_MAIN(PotentialPhishingEmailWarningTest)
