@@ -1,4 +1,4 @@
-/*  -*- mode: C++; c-file-style: "gnu" -*-
+/*
     identitydialog.h
 
     This file is part of KMail, the KDE mail client.
@@ -32,82 +32,92 @@
 #ifndef __KMAIL_IDENTITYDIALOG_H__
 #define __KMAIL_IDENTITYDIALOG_H__
 
-#include <kdialog.h>
-
+#include <QDialog>
+#include <AkonadiCore/Item>
 class QCheckBox;
 
-namespace PimCommon {
+namespace PimCommon
+{
 class SimpleStringListEditor;
 }
 
 class KComboBox;
 class KJob;
 class KLineEdit;
-class KPushButton;
-class KTabWidget;
+class QPushButton;
+class QTabWidget;
 
-namespace Kleo {
+namespace Kleo
+{
 class EncryptionKeyRequester;
 class SigningKeyRequester;
 }
-namespace KPIMIdentities {
+namespace KIdentityManagement
+{
 class Identity;
 class SignatureConfigurator;
 }
-namespace KMail {
+namespace KMail
+{
 class XFaceConfigurator;
 }
 
-namespace MailCommon {
+namespace MailCommon
+{
 class FolderRequester;
 }
-namespace Sonnet {
+namespace Sonnet
+{
 class DictionaryComboBox;
 }
 
-namespace MailTransport {
+namespace MailTransport
+{
 class TransportComboBox;
 }
 
-namespace TemplateParser {
+namespace TemplateParser
+{
 class TemplatesConfiguration;
 }
 
-namespace PimCommon {
+namespace PimCommon
+{
 class AutoCorrectionLanguage;
 }
 
+namespace KMail
+{
 
-namespace KMail {
-
-class IdentityDialog : public KDialog {
+class IdentityDialog : public QDialog
+{
     Q_OBJECT
 public:
-    explicit IdentityDialog( QWidget * parent=0 );
+    explicit IdentityDialog(QWidget *parent = Q_NULLPTR);
     ~IdentityDialog();
 
-    void setIdentity( /*_not_ const*/ KPIMIdentities::Identity & ident );
+    void setIdentity(/*_not_ const*/ KIdentityManagement::Identity &ident);
 
-    void updateIdentity( KPIMIdentities::Identity & ident );
+    void updateIdentity(KIdentityManagement::Identity &ident);
 
-protected slots:
-    void slotAboutToShow( int );
-
-    /*! \reimp */
-    void slotButtonClicked( int button );
+protected Q_SLOTS:
+    void slotAboutToShow(int);
 
     // copy default templates to identity templates
     void slotCopyGlobal();
 
-private slots:
-    void slotDelayedButtonClicked( KJob* );
+private Q_SLOTS:
+    void slotAccepted();
+    void slotDelayedButtonClicked(KJob *);
     void slotEditVcard();
-
+    void slotRefreshDefaultDomainName();
+    void slotVCardRemoved();
+    void slotHelp();
 private:
-    bool checkFolderExists( const QString & folder, const QString & msg );
-    bool validateAddresses( const QString & addresses );
+    bool checkFolderExists(const QString &folder, const QString &msg);
+    bool validateAddresses(const QString &addresses);
     void updateVcardButton();
-    void editVcard(const QString& filename);
+    void editVcard(const QString &filename);
 
 private:
     // "general" tab:
@@ -136,18 +146,19 @@ private:
     MailTransport::TransportComboBox *mTransportCombo;
     QCheckBox                        *mAttachMyVCard;
     QString                          mVcardFilename;
-    KPushButton                      *mEditVCard;
+    QPushButton                      *mEditVCard;
     PimCommon::AutoCorrectionLanguage *mAutoCorrectionLanguage;
+    KLineEdit                        *mDefaultDomainEdit;
 
     // "templates" tab:
     TemplateParser::TemplatesConfiguration *mWidget;
     QCheckBox                    *mCustom;
-    KPushButton                  *mCopyGlobal;
+    QPushButton                  *mCopyGlobal;
     // "signature" tab:
-    KPIMIdentities::SignatureConfigurator *mSignatureConfigurator;
+    KIdentityManagement::SignatureConfigurator *mSignatureConfigurator;
     // "X-Face" tab:
     KMail::XFaceConfigurator *mXFaceConfigurator;
-    KTabWidget *mTabWidget;
+    QTabWidget *mTabWidget;
 };
 
 } // namespace KMail
