@@ -21,26 +21,24 @@
 #define SAVEASFILEJOB_H
 
 #include <QObject>
-namespace MessageComposer {
-class KMeditor;
-}
+class QTextDocument;
 class SaveAsFileJob : public QObject
 {
     Q_OBJECT
 public:
-    explicit SaveAsFileJob(QObject *parent = 0);
+    explicit SaveAsFileJob(QObject *parent = Q_NULLPTR);
     ~SaveAsFileJob();
     void start();
 
     void setHtmlMode(bool htmlMode);
 
-    void setEditor(MessageComposer::KMeditor *editor);
+    void setTextDocument(QTextDocument *textDocument);
 
     void setParentWidget(QWidget *parentWidget);
 
 private:
     bool mHtmlMode;
-    MessageComposer::KMeditor *mEditor;
+    QTextDocument *mTextDocument;
     QWidget *mParentWidget;
 };
 
