@@ -1,4 +1,4 @@
-// -*- mode: C++; c-file-style: "gnu" -*-
+//
 
 #ifndef KMCommands_h
 #define KMCommands_h
@@ -9,41 +9,44 @@
 #include "search/searchpattern.h"
 #include "messageviewer/viewer/viewer.h"
 
-#include <akonadi/kmime/messagestatus.h>
+#include <Akonadi/KMime/MessageStatus>
 #include <kio/job.h>
 #include <kmime/kmime_message.h>
 
 #include <QPointer>
 #include <QList>
-#include <akonadi/item.h>
-#include <akonadi/itemfetchscope.h>
-#include <akonadi/collection.h>
-
-namespace Akonadi {
+#include <AkonadiCore/item.h>
+#include <AkonadiCore/itemfetchscope.h>
+#include <AkonadiCore/collection.h>
+#include <QUrl>
+namespace Akonadi
+{
 class Tag;
 }
 
 using Akonadi::MessageStatus;
 
-class KProgressDialog;
+class QProgressDialog;
 class KMMainWidget;
 
 template <typename T> class QSharedPointer;
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class HeaderStyle;
 class HeaderStrategy;
 class AttachmentStrategy;
 }
 
-namespace KIO { class Job; }
-namespace KMail {
+namespace KIO
+{
+class Job;
+}
+namespace KMail
+{
 class Composer;
 }
-namespace GpgME { class Error; }
-namespace Kleo { class SpecialJob; }
-
-typedef QMap<KMime::Content*, Akonadi::Item> PartNodeMessageMap;
+typedef QMap<KMime::Content *, Akonadi::Item> PartNodeMessageMap;
 /// Small helper structure which encapsulates the KMMessage created when creating a reply, and
 
 class KMAIL_EXPORT KMCommand : public QObject
@@ -54,92 +57,106 @@ public:
     enum Result { Undefined, OK, Canceled, Failed };
 
     // Trival constructor, don't retrieve any messages
-    explicit KMCommand( QWidget *parent = 0 );
-    KMCommand( QWidget *parent, const Akonadi::Item & );
+    explicit KMCommand(QWidget *parent = Q_NULLPTR);
+    KMCommand(QWidget *parent, const Akonadi::Item &);
     // Retrieve all messages in msgList when start is called.
-    KMCommand( QWidget *parent, const QList<Akonadi::Item> &msgList );
+    KMCommand(QWidget *parent, const Akonadi::Item::List &msgList);
     // Retrieve the single message msgBase when start is called.
     virtual ~KMCommand();
 
-
     /** Returns the result of the command. Only call this method from the slot
       connected to completed().
-  */
+    */
     Result result() const;
 
-public slots:
+public Q_SLOTS:
     // Retrieve messages then calls execute
     void start();
 
-signals:
+Q_SIGNALS:
 
     /// @param result The status of the command.
-    void messagesTransfered( KMCommand::Result result );
+    void messagesTransfered(KMCommand::Result result);
 
     /// Emitted when the command has completed.
-    void completed( KMCommand *command );
+    void completed(KMCommand *command);
 
 protected:
-    virtual Akonadi::ItemFetchJob* createFetchJob( const Akonadi::Item::List &items );
+    virtual Akonadi::ItemFetchJob *createFetchJob(const Akonadi::Item::List &items);
 
     /** Allows to configure how much data should be retrieved of the messages. */
-    Akonadi::ItemFetchScope& fetchScope() { return mFetchScope; }
+    Akonadi::ItemFetchScope &fetchScope()
+    {
+        return mFetchScope;
+    }
 
     // Returns list of messages retrieved
-    const QList<Akonadi::Item> retrievedMsgs() const;
+    const Akonadi::Item::List retrievedMsgs() const;
     // Returns the single message retrieved
     Akonadi::Item retrievedMessage() const;
     // Returns the parent widget
     QWidget *parentWidget() const;
 
-    bool deletesItself() const { return mDeletesItself; }
+    bool deletesItself() const
+    {
+        return mDeletesItself;
+    }
     /** Specify whether the subclass takes care of the deletion of the object.
       By default the base class will delete the object.
       @param deletesItself true if the subclass takes care of deletion, false
                            if the base class should take care of deletion
-  */
-    void setDeletesItself( bool deletesItself )
-    { mDeletesItself = deletesItself; }
+    */
+    void setDeletesItself(bool deletesItself)
+    {
+        mDeletesItself = deletesItself;
+    }
 
-    bool emitsCompletedItself() const { return mEmitsCompletedItself; }
+    bool emitsCompletedItself() const
+    {
+        return mEmitsCompletedItself;
+    }
     /** Specify whether the subclass takes care of emitting the completed()
-      signal. By default the base class will emit this signal.
+      signal. By default the base class will Q_EMIT this signal.
       @param emitsCompletedItself true if the subclass emits the completed
                                   signal, false if the base class should emit
                                   the signal
-  */
-    void setEmitsCompletedItself( bool emitsCompletedItself )
-    { mEmitsCompletedItself = emitsCompletedItself; }
+    */
+    void setEmitsCompletedItself(bool emitsCompletedItself)
+    {
+        mEmitsCompletedItself = emitsCompletedItself;
+    }
 
     /** Use this to set the result of the command.
       @param result The result of the command.
-   */
-    void setResult( Result result )
-    { mResult = result; }
+    */
+    void setResult(Result result)
+    {
+        mResult = result;
+    }
 
 private:
     // execute should be implemented by derived classes
     virtual Result execute() = 0;
 
     /** transfers the list of (imap)-messages
-   *  this is a necessary preparation for e.g. forwarding */
+    *  this is a necessary preparation for e.g. forwarding */
     void transferSelectedMsgs();
 
-private slots:
-    void slotPostTransfer( KMCommand::Result result );
+private Q_SLOTS:
+    void slotPostTransfer(KMCommand::Result result);
     /** the msg has been transferred */
-    void slotMsgTransfered(const Akonadi::Item::List& msgs);
+    void slotMsgTransfered(const Akonadi::Item::List &msgs);
     /** the KMImapJob is finished */
     void slotJobFinished();
     /** the transfer was canceled */
     void slotTransferCancelled();
 
 protected:
-    QList<Akonadi::Item> mRetrievedMsgs;
+    Akonadi::Item::List mRetrievedMsgs;
 
 private:
     // ProgressDialog for transferring messages
-    QWeakPointer<KProgressDialog> mProgressDialog;
+    QWeakPointer<QProgressDialog> mProgressDialog;
     //Currently only one async command allowed at a time
     static int mCountJobs;
     int mCountMsgs;
@@ -148,7 +165,7 @@ private:
     bool mEmitsCompletedItself : 1;
 
     QWidget *mParent;
-    QList<Akonadi::Item> mMsgList;
+    Akonadi::Item::List mMsgList;
     Akonadi::ItemFetchScope mFetchScope;
 };
 
@@ -157,12 +174,12 @@ class KMAIL_EXPORT KMMailtoComposeCommand : public KMCommand
     Q_OBJECT
 
 public:
-    explicit KMMailtoComposeCommand( const KUrl &url, const Akonadi::Item &msg=Akonadi::Item() );
+    explicit KMMailtoComposeCommand(const QUrl &url, const Akonadi::Item &msg = Akonadi::Item());
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
-    KUrl mUrl;
+    QUrl mUrl;
     Akonadi::Item mMessage;
 };
 
@@ -171,13 +188,13 @@ class KMAIL_EXPORT KMMailtoReplyCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMMailtoReplyCommand( QWidget *parent, const KUrl &url,
-                          const Akonadi::Item &msg, const QString &selection );
+    KMMailtoReplyCommand(QWidget *parent, const QUrl &url,
+                         const Akonadi::Item &msg, const QString &selection);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
-    KUrl mUrl;
+    QUrl mUrl;
     QString mSelection;
 };
 
@@ -186,12 +203,11 @@ class KMAIL_EXPORT KMMailtoForwardCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMMailtoForwardCommand( QWidget *parent, const KUrl &url,const Akonadi::Item& msg );
+    KMMailtoForwardCommand(QWidget *parent, const QUrl &url, const Akonadi::Item &msg);
 
 private:
-    virtual Result execute();
-
-    KUrl mUrl;
+    Result execute() Q_DECL_OVERRIDE;
+    QUrl mUrl;
 };
 
 class KMAIL_EXPORT KMAddBookmarksCommand : public KMCommand
@@ -199,12 +215,12 @@ class KMAIL_EXPORT KMAddBookmarksCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMAddBookmarksCommand( const KUrl &url, QWidget *parent );
+    KMAddBookmarksCommand(const QUrl &url, QWidget *parent);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
-    KUrl mUrl;
+    QUrl mUrl;
 };
 
 class KMAIL_EXPORT KMUrlSaveCommand : public KMCommand
@@ -212,15 +228,15 @@ class KMAIL_EXPORT KMUrlSaveCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMUrlSaveCommand( const KUrl &url, QWidget *parent );
+    KMUrlSaveCommand(const QUrl &url, QWidget *parent);
 
-private slots:
-    void slotUrlSaveResult( KJob *job );
+private Q_SLOTS:
+    void slotUrlSaveResult(KJob *job);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
-    KUrl mUrl;
+    QUrl mUrl;
 };
 
 class KMAIL_EXPORT KMEditItemCommand : public KMCommand
@@ -228,12 +244,12 @@ class KMAIL_EXPORT KMEditItemCommand : public KMCommand
     Q_OBJECT
 
 public:
-    explicit KMEditItemCommand( QWidget *parent, const Akonadi::Item &msg, bool deleteFromSource = true );
+    explicit KMEditItemCommand(QWidget *parent, const Akonadi::Item &msg, bool deleteFromSource = true);
     ~KMEditItemCommand();
-private slots:
-    void slotDeleteItem( KJob *job );
+private Q_SLOTS:
+    void slotDeleteItem(KJob *job);
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
     bool mDeleteFromSource;
 };
 
@@ -242,9 +258,9 @@ class KMAIL_EXPORT KMEditMessageCommand : public KMCommand
     Q_OBJECT
 
 public:
-    explicit KMEditMessageCommand( QWidget *parent, const KMime::Message::Ptr& msg );
+    explicit KMEditMessageCommand(QWidget *parent, const KMime::Message::Ptr &msg);
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
     KMime::Message::Ptr mMessage;
 };
 
@@ -253,10 +269,10 @@ class KMAIL_EXPORT KMUseTemplateCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMUseTemplateCommand( QWidget *parent, const Akonadi::Item &msg );
+    KMUseTemplateCommand(QWidget *parent, const Akonadi::Item &msg);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 };
 
 class KMAIL_EXPORT KMSaveMsgCommand : public KMCommand
@@ -264,10 +280,10 @@ class KMAIL_EXPORT KMSaveMsgCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMSaveMsgCommand( QWidget *parent, const QList<Akonadi::Item> &msgList );
+    KMSaveMsgCommand(QWidget *parent, const Akonadi::Item::List &msgList);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
 };
 
@@ -276,20 +292,20 @@ class KMAIL_EXPORT KMOpenMsgCommand : public KMCommand
     Q_OBJECT
 
 public:
-    explicit KMOpenMsgCommand(QWidget *parent, const KUrl & url = KUrl(),
-                              const QString & encoding = QString() , KMMainWidget *main = 0);
+    explicit KMOpenMsgCommand(QWidget *parent, const QUrl &url = QUrl(),
+                              const QString &encoding = QString() , KMMainWidget *main = Q_NULLPTR);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
-private slots:
-    void slotDataArrived( KIO::Job *job, const QByteArray & data );
-    void slotResult( KJob *job );
+private Q_SLOTS:
+    void slotDataArrived(KIO::Job *job, const QByteArray &data);
+    void slotResult(KJob *job);
 
 private:
     void doesNotContainMessage();
-    static const int MAX_CHUNK_SIZE = 64*1024;
-    KUrl mUrl;
+    static const int MAX_CHUNK_SIZE = 64 * 1024;
+    QUrl mUrl;
     QString mMsgString;
     KIO::TransferJob *mJob;
     const QString mEncoding;
@@ -303,29 +319,28 @@ public:
     /** Use this to save all attachments of the given message.
       @param parent  The parent widget of the command used for message boxes.
       @param msg     The message of which the attachments should be saved.
-   */
-    KMSaveAttachmentsCommand( QWidget *parent, const Akonadi::Item &msg, MessageViewer::Viewer *viewer  );
+    */
+    KMSaveAttachmentsCommand(QWidget *parent, const Akonadi::Item &msg, MessageViewer::Viewer *viewer);
     /** Use this to save all attachments of the given messages.
       @param parent  The parent widget of the command used for message boxes.
       @param msgs    The messages of which the attachments should be saved.
-   */
-    KMSaveAttachmentsCommand( QWidget *parent, const QList<Akonadi::Item>& msgs );
+    */
+    KMSaveAttachmentsCommand(QWidget *parent, const Akonadi::Item::List &msgs);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
     MessageViewer::Viewer *mViewer;
 };
 
-
 class KMAIL_EXPORT KMReplyCommand : public KMCommand
 {
     Q_OBJECT
 public:
-    KMReplyCommand( QWidget *parent, const Akonadi::Item &msg,
-                    MessageComposer::ReplyStrategy replyStrategy,
-                    const QString &selection = QString(), bool noquote = false, const QString & templateName = QString());
+    KMReplyCommand(QWidget *parent, const Akonadi::Item &msg,
+                   MessageComposer::ReplyStrategy replyStrategy,
+                   const QString &selection = QString(), bool noquote = false, const QString &templateName = QString());
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
 private:
     QString mSelection;
@@ -339,14 +354,14 @@ class KMAIL_EXPORT KMForwardCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMForwardCommand( QWidget *parent, const QList<Akonadi::Item> &msgList,
-                      uint identity = 0, const QString& templateName = QString() );
-    KMForwardCommand( QWidget *parent, const Akonadi::Item& msg,
-                      uint identity = 0, const QString& templateName =QString());
+    KMForwardCommand(QWidget *parent, const Akonadi::Item::List &msgList,
+                     uint identity = 0, const QString &templateName = QString());
+    KMForwardCommand(QWidget *parent, const Akonadi::Item &msg,
+                     uint identity = 0, const QString &templateName = QString());
 
 private:
-    KMCommand::Result createComposer(const Akonadi::Item& item);
-    virtual Result execute();
+    KMCommand::Result createComposer(const Akonadi::Item &item);
+    Result execute() Q_DECL_OVERRIDE;
 
 private:
     uint mIdentity;
@@ -358,13 +373,13 @@ class KMAIL_EXPORT KMForwardAttachedCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMForwardAttachedCommand( QWidget *parent, const QList<Akonadi::Item> &msgList,
-                              uint identity = 0, KMail::Composer *win = 0 );
-    KMForwardAttachedCommand( QWidget *parent, const Akonadi::Item & msg,
-                              uint identity = 0, KMail::Composer *win = 0 );
+    KMForwardAttachedCommand(QWidget *parent, const Akonadi::Item::List &msgList,
+                             uint identity = 0, KMail::Composer *win = Q_NULLPTR);
+    KMForwardAttachedCommand(QWidget *parent, const Akonadi::Item &msg,
+                             uint identity = 0, KMail::Composer *win = Q_NULLPTR);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
     uint mIdentity;
     QPointer<KMail::Composer> mWin;
@@ -375,11 +390,11 @@ class KMAIL_EXPORT KMRedirectCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMRedirectCommand( QWidget *parent, const Akonadi::Item &msg );
-    KMRedirectCommand( QWidget *parent, const QList<Akonadi::Item> &msgList );
+    KMRedirectCommand(QWidget *parent, const Akonadi::Item &msg);
+    KMRedirectCommand(QWidget *parent, const Akonadi::Item::List &msgList);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 };
 
 class KMAIL_EXPORT KMPrintCommand : public KMCommand
@@ -387,20 +402,20 @@ class KMAIL_EXPORT KMPrintCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMPrintCommand( QWidget *parent, const Akonadi::Item &msg,
-                    MessageViewer::HeaderStyle *headerStyle = 0,
-                    MessageViewer::HeaderStrategy *headerStrategy = 0,
-                    MessageViewer::Viewer::DisplayFormatMessage format = MessageViewer::Viewer::UseGlobalSetting,
-                    bool htmlLoadExtOverride = false,
-                    bool useFixedFont = false,
-                    const QString & encoding = QString() );
+    KMPrintCommand(QWidget *parent, const Akonadi::Item &msg,
+                   MessageViewer::HeaderStyle *headerStyle = Q_NULLPTR,
+                   MessageViewer::HeaderStrategy *headerStrategy = Q_NULLPTR,
+                   MessageViewer::Viewer::DisplayFormatMessage format = MessageViewer::Viewer::UseGlobalSetting,
+                   bool htmlLoadExtOverride = false,
+                   bool useFixedFont = false,
+                   const QString &encoding = QString());
 
-    void setOverrideFont( const QFont& );
-    void setAttachmentStrategy( const MessageViewer::AttachmentStrategy *strategy );
-    void setPrintPreview( bool preview );
+    void setOverrideFont(const QFont &);
+    void setAttachmentStrategy(const MessageViewer::AttachmentStrategy *strategy);
+    void setPrintPreview(bool preview);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
     MessageViewer::HeaderStyle *mHeaderStyle;
     MessageViewer::HeaderStrategy *mHeaderStrategy;
@@ -419,14 +434,14 @@ class KMAIL_EXPORT KMSetStatusCommand : public KMCommand
 
 public:
     // Serial numbers
-    KMSetStatusCommand( const MessageStatus& status, const Akonadi::Item::List &items,
-                        bool invert=false );
+    KMSetStatusCommand(const MessageStatus &status, const Akonadi::Item::List &items,
+                       bool invert = false);
 
-protected slots:
-    void slotModifyItemDone( KJob * job );
+protected Q_SLOTS:
+    void slotModifyItemDone(KJob *job);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
     MessageStatus mStatus;
     bool mInvertMark;
 };
@@ -441,20 +456,19 @@ class KMAIL_EXPORT KMSetTagCommand : public KMCommand
 public:
     enum SetTagMode { AddIfNotExisting, Toggle, CleanExistingAndAddNew };
 
-    KMSetTagCommand( const Akonadi::Tag::List &tags, const QList<Akonadi::Item> &item,
-                     SetTagMode mode=AddIfNotExisting );
+    KMSetTagCommand(const Akonadi::Tag::List &tags, const Akonadi::Item::List &item,
+                    SetTagMode mode = AddIfNotExisting);
 
-protected slots:
-    void slotTagCreateDone( KJob * job );
-    void slotModifyItemDone( KJob * job );
+protected Q_SLOTS:
+    void slotModifyItemDone(KJob *job);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
     void setTags();
 
     Akonadi::Tag::List mTags;
     Akonadi::Tag::List mCreatedTags;
-    QList<Akonadi::Item> mItem;
+    Akonadi::Item::List mItem;
     SetTagMode mMode;
 };
 
@@ -469,20 +483,19 @@ public:
                           const QVector<qlonglong> &msgListId, const QString &filterId);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
     QVector<qlonglong> mMsgListId;
     QString mFilterId;
 };
 
-
 class KMAIL_EXPORT KMMetaFilterActionCommand : public QObject
 {
     Q_OBJECT
 
 public:
-    KMMetaFilterActionCommand( const QString &filterId, KMMainWidget *main );
+    KMMetaFilterActionCommand(const QString &filterId, KMMainWidget *main);
 
-public slots:
+public Q_SLOTS:
     void start();
 
 private:
@@ -490,36 +503,35 @@ private:
     KMMainWidget *mMainWidget;
 };
 
-
 class KMAIL_EXPORT KMMailingListFilterCommand : public KMCommand
 {
     Q_OBJECT
 
 public:
-    KMMailingListFilterCommand( QWidget *parent, const Akonadi::Item &msg );
+    KMMailingListFilterCommand(QWidget *parent, const Akonadi::Item &msg);
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 };
 
-
 class KMAIL_EXPORT KMCopyCommand : public KMCommand
 {
     Q_OBJECT
 
 public:
-    KMCopyCommand( const Akonadi::Collection &destFolder, const QList<Akonadi::Item> &msgList );
-    KMCopyCommand( const Akonadi::Collection& destFolder, const Akonadi::Item &msg );
+    KMCopyCommand(const Akonadi::Collection &destFolder, const Akonadi::Item::List &msgList);
+    KMCopyCommand(const Akonadi::Collection &destFolder, const Akonadi::Item &msg);
 
-protected slots:
-    void slotCopyResult( KJob * job );
+protected Q_SLOTS:
+    void slotCopyResult(KJob *job);
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 
     Akonadi::Collection mDestFolder;
 };
 
-namespace KPIM {
+namespace KPIM
+{
 class ProgressItem;
 }
 class KMAIL_EXPORT KMMoveCommand : public KMCommand
@@ -527,24 +539,33 @@ class KMAIL_EXPORT KMMoveCommand : public KMCommand
     Q_OBJECT
 
 public:
-    KMMoveCommand( const Akonadi::Collection& destFolder, const QList<Akonadi::Item> &msgList, MessageList::Core::MessageItemSetReference ref );
-    KMMoveCommand( const Akonadi::Collection& destFolder, const Akonadi::Item & msg, MessageList::Core::MessageItemSetReference ref = MessageList::Core::MessageItemSetReference() );
-    Akonadi::Collection destFolder() const { return mDestFolder; }
+    KMMoveCommand(const Akonadi::Collection &destFolder, const Akonadi::Item::List &msgList, MessageList::Core::MessageItemSetReference ref);
+    KMMoveCommand(const Akonadi::Collection &destFolder, const Akonadi::Item &msg, MessageList::Core::MessageItemSetReference ref = MessageList::Core::MessageItemSetReference());
+    Akonadi::Collection destFolder() const
+    {
+        return mDestFolder;
+    }
 
-    MessageList::Core::MessageItemSetReference refSet() const { return mRef; }
+    MessageList::Core::MessageItemSetReference refSet() const
+    {
+        return mRef;
+    }
 
-public slots:
+public Q_SLOTS:
     void slotMoveCanceled();
-    void slotMoveResult( KJob * job );
+    void slotMoveResult(KJob *job);
 protected:
-    void setDestFolder( const Akonadi::Collection& folder ) { mDestFolder = folder; }
+    void setDestFolder(const Akonadi::Collection &folder)
+    {
+        mDestFolder = folder;
+    }
 
-signals:
-    void moveDone( KMMoveCommand* );
+Q_SIGNALS:
+    void moveDone(KMMoveCommand *);
 
 private:
-    virtual Result execute();
-    void completeMove( Result result );
+    Result execute() Q_DECL_OVERRIDE;
+    void completeMove(Result result);
 
     Akonadi::Collection mDestFolder;
     KPIM::ProgressItem *mProgressItem;
@@ -556,11 +577,11 @@ class KMAIL_EXPORT KMTrashMsgCommand : public KMMoveCommand
     Q_OBJECT
 
 public:
-    KMTrashMsgCommand( const Akonadi::Collection& srcFolder, const QList<Akonadi::Item> &msgList,MessageList::Core::MessageItemSetReference ref );
-    KMTrashMsgCommand( const Akonadi::Collection& srcFolder, const Akonadi::Item& msg,MessageList::Core::MessageItemSetReference ref );
+    KMTrashMsgCommand(const Akonadi::Collection &srcFolder, const Akonadi::Item::List &msgList, MessageList::Core::MessageItemSetReference ref);
+    KMTrashMsgCommand(const Akonadi::Collection &srcFolder, const Akonadi::Item &msg, MessageList::Core::MessageItemSetReference ref);
 
 private:
-    static Akonadi::Collection findTrashFolder( const Akonadi::Collection& srcFolder );
+    static Akonadi::Collection findTrashFolder(const Akonadi::Collection &srcFolder);
 
 };
 
@@ -569,10 +590,10 @@ class KMAIL_EXPORT KMResendMessageCommand : public KMCommand
     Q_OBJECT
 
 public:
-    explicit KMResendMessageCommand( QWidget *parent, const Akonadi::Item & msg= Akonadi::Item() );
+    explicit KMResendMessageCommand(QWidget *parent, const Akonadi::Item &msg = Akonadi::Item());
 
 private:
-    virtual Result execute();
+    Result execute() Q_DECL_OVERRIDE;
 };
 
 class KMAIL_EXPORT KMShareImageCommand : public KMCommand
@@ -580,27 +601,26 @@ class KMAIL_EXPORT KMShareImageCommand : public KMCommand
     Q_OBJECT
 
 public:
-    explicit KMShareImageCommand(const KUrl &url, QWidget *parent);
+    explicit KMShareImageCommand(const QUrl &url, QWidget *parent);
 
 private:
-    virtual Result execute();
-    KUrl mUrl;
+    Result execute() Q_DECL_OVERRIDE;
+    QUrl mUrl;
 };
 
 class KMAIL_EXPORT KMFetchMessageCommand : public KMCommand
 {
     Q_OBJECT
 public:
-    explicit KMFetchMessageCommand( QWidget *parent, const Akonadi::Item &item );
+    explicit KMFetchMessageCommand(QWidget *parent, const Akonadi::Item &item);
 
     Akonadi::Item item() const;
 
 private:
-    Akonadi::ItemFetchJob *createFetchJob( const Akonadi::Item::List &items );
-    Result execute();
+    Akonadi::ItemFetchJob *createFetchJob(const Akonadi::Item::List &items) Q_DECL_OVERRIDE;
+    Result execute() Q_DECL_OVERRIDE;
 
     Akonadi::Item mItem;
 };
 
-
 #endif /*KMCommands_h*/
