@@ -24,7 +24,7 @@ class KMLaunchExternalComponent : public QObject
 {
     Q_OBJECT
 public:
-    explicit KMLaunchExternalComponent(QWidget *parentWidget, QObject *parent=0);
+    explicit KMLaunchExternalComponent(QWidget *parentWidget, QObject *parent = Q_NULLPTR);
     ~KMLaunchExternalComponent();
 
 public Q_SLOTS:
@@ -41,6 +41,7 @@ public Q_SLOTS:
     void slotFilterLogViewer();
     void slotAntiVirusWizard();
     void slotAntiSpamWizard();
+    void slotShowTip();
 private:
     QWidget *mParentWidget;
 };
