@@ -1,4 +1,4 @@
-/* -*- mode: C++; c-file-style: "gnu" -*-
+/*
   This file is part of KMail, the KDE mail client.
   Copyright (c) 1997 Markus Wuebben <markus.wuebben@kde.org>
   Copyright (C) 2013-2015 Laurent Montel <montel@kde.org>
@@ -22,23 +22,23 @@
 #define KMREADERWIN_H
 
 #include <QWidget>
-#include <kurl.h>
+#include <qurl.h>
 #include <messageviewer/viewer/viewer.h>
 #include <messageviewer/interfaces/bodypart.h>
-#include <Akonadi/Item>
-#include <KABC/Addressee>
+#include <AkonadiCore/Item>
+#include <KContacts/Addressee>
 class KActionCollection;
-class KAction;
+class QAction;
 class KToggleAction;
-class KMenu;
-namespace MessageViewer {
+class QMenu;
+namespace MessageViewer
+{
 class HeaderStrategy;
 class HeaderStyle;
 class CSSHelper;
 class AttachmentStrategy;
 }
 
-
 class KJob;
 
 /**
@@ -46,46 +46,47 @@ class KJob;
    used for reading or viewing messages.
 */
 
-class KMReaderWin: public QWidget {
+class KMReaderWin: public QWidget
+{
     Q_OBJECT
 
 public:
-    explicit KMReaderWin( QWidget *parent, QWidget *mainWindow,
-                          KActionCollection *actionCollection, Qt::WindowFlags f = 0 );
+    explicit KMReaderWin(QWidget *parent, QWidget *mainWindow,
+                         KActionCollection *actionCollection, Qt::WindowFlags f = Q_NULLPTR);
     virtual ~KMReaderWin();
 
     /** Read settings from app's config file. */
     void readConfig();
 
-    MessageViewer::HeaderStyle * headerStyle() const;
+    MessageViewer::HeaderStyle *headerStyle() const;
 
     /** Set the header style and strategy. We only want them to be set
       together. */
-    void setHeaderStyleAndStrategy( MessageViewer::HeaderStyle * style,
-                                    MessageViewer::HeaderStrategy * strategy );
+    void setHeaderStyleAndStrategy(MessageViewer::HeaderStyle *style,
+                                   MessageViewer::HeaderStrategy *strategy);
     /** Getthe message header strategy. */
-    const MessageViewer::HeaderStrategy * headerStrategy() const;
+    const MessageViewer::HeaderStrategy *headerStrategy() const;
 
     /** Get/set the message attachment strategy. */
-    const MessageViewer::AttachmentStrategy * attachmentStrategy() const;
+    const MessageViewer::AttachmentStrategy *attachmentStrategy() const;
 
-    void setAttachmentStrategy( const MessageViewer::AttachmentStrategy * strategy );
+    void setAttachmentStrategy(const MessageViewer::AttachmentStrategy *strategy);
 
     /** Get selected override character encoding.
       @return The encoding selected by the user or an empty string if auto-detection
       is selected. */
     QString overrideEncoding() const;
     /** Set the override character encoding. */
-    void setOverrideEncoding( const QString & encoding );
-    virtual void setPrinting(bool enable );
+    void setOverrideEncoding(const QString &encoding);
+    virtual void setPrinting(bool enable);
 
-    void setMessage( const Akonadi::Item& item, MessageViewer::Viewer::UpdateMode updateMode = MessageViewer::Viewer::Delayed);
+    void setMessage(const Akonadi::Item &item, MessageViewer::Viewer::UpdateMode updateMode = MessageViewer::Viewer::Delayed);
 
-    void setMessage( KMime::Message::Ptr message );
+    void setMessage(KMime::Message::Ptr message);
 
     /** Instead of settings a message to be shown sets a message part
       to be shown */
-    void setMsgPart( KMime::Content* aMsgPart );
+    void setMsgPart(KMime::Content *aMsgPart);
 
     /** Clear the reader and discard the current message. */
     void clear(bool force = false);
@@ -97,14 +98,13 @@ public:
 
     /** Override default html mail setting */
     bool htmlOverride() const;
-    void setHtmlOverride( bool override );
+    void setHtmlOverride(bool override);
     MessageViewer::Viewer::DisplayFormatMessage displayFormatMessageOverwrite() const;
     void setDisplayFormatMessageOverwrite(MessageViewer::Viewer::DisplayFormatMessage format);
 
-
     /** Override default load external references setting */
     bool htmlLoadExtOverride() const;
-    void setHtmlLoadExtOverride( bool override );
+    void setHtmlLoadExtOverride(bool override);
 
     /** Is html mail to be supported? Takes into account override */
     bool htmlMail() const;
@@ -116,7 +116,7 @@ public:
     static QString newFeaturesMD5();
 
     /** Display a generic HTML splash page instead of a message */
-    void displaySplashPage( const QString &info );
+    void displaySplashPage(const QString &info);
 
     /** Display the about page instead of a message */
     void displayAboutPage();
@@ -129,68 +129,109 @@ public:
     void displayResourceOfflinePage();
 
     bool isFixedFont() const;
-    void setUseFixedFont( bool useFixedFont );
-    MessageViewer::Viewer *viewer() { return mViewer; }
+    void setUseFixedFont(bool useFixedFont);
+    MessageViewer::Viewer *viewer()
+    {
+        return mViewer;
+    }
     KToggleAction *toggleFixFontAction() const;
-    KAction *mailToComposeAction() const { return mMailToComposeAction; }
-    KAction *mailToReplyAction() const { return mMailToReplyAction; }
-    KAction *mailToForwardAction() const { return mMailToForwardAction; }
-    KAction *addAddrBookAction() const { return mAddAddrBookAction; }
-    KAction *openAddrBookAction() const { return mOpenAddrBookAction; }
-    KAction *copyAction() const;
-    KAction *selectAllAction() const;
-    KAction *copyURLAction() const;
-    KAction *copyImageLocation() const;
-    KAction *urlOpenAction() const;
-    KAction *urlSaveAsAction() const { return mUrlSaveAsAction; }
-    KAction *addBookmarksAction() const { return mAddBookmarksAction;}
-    KAction *toggleMimePartTreeAction() const;
-    KAction *speakTextAction() const;
-    KAction* translateAction() const;
-    KAction* downloadImageToDiskAction() const;
-    KAction *viewSourceAction() const;
-    KAction *findInMessageAction() const;
-    KAction *saveAsAction() const;
-    KAction *saveMessageDisplayFormatAction() const;
-    KAction *resetMessageDisplayFormatAction() const;
-    KAction *blockImage() const;
-    KAction *openBlockableItems() const;
-    KAction *expandShortUrlAction() const;
-    KAction *createTodoAction() const;
-    KAction *createEventAction() const;
+    QAction *mailToComposeAction() const
+    {
+        return mMailToComposeAction;
+    }
+    QAction *mailToReplyAction() const
+    {
+        return mMailToReplyAction;
+    }
+    QAction *mailToForwardAction() const
+    {
+        return mMailToForwardAction;
+    }
+    QAction *addAddrBookAction() const
+    {
+        return mAddAddrBookAction;
+    }
+    QAction *openAddrBookAction() const
+    {
+        return mOpenAddrBookAction;
+    }
+    QAction *copyAction() const;
+    QAction *selectAllAction() const;
+    QAction *copyURLAction() const;
+    QAction *copyImageLocation() const;
+    QAction *urlOpenAction() const;
+    QAction *urlSaveAsAction() const
+    {
+        return mUrlSaveAsAction;
+    }
+    QAction *addBookmarksAction() const
+    {
+        return mAddBookmarksAction;
+    }
+    QAction *toggleMimePartTreeAction() const;
+    QAction *speakTextAction() const;
+    QAction *translateAction() const;
+    QAction *downloadImageToDiskAction() const;
+    QAction *viewSourceAction() const;
+    QAction *findInMessageAction() const;
+    QAction *saveAsAction() const;
+    QAction *saveMessageDisplayFormatAction() const;
+    QAction *resetMessageDisplayFormatAction() const;
+    QAction *blockImage() const;
+    QAction *openBlockableItems() const;
+    QAction *expandShortUrlAction() const;
+    QAction *createTodoAction() const;
+    QAction *createEventAction() const;
+    QAction *createNoteAction() const;
 
-    KAction *editContactAction() const { return mEditContactAction; }
+    QAction *editContactAction() const
+    {
+        return mEditContactAction;
+    }
 
-    KMenu *viewHtmlOption() const { return mViewHtmlOptions; }
-    KAction *shareImage() const { return mShareImage; }
+    QMenu *viewHtmlOption() const
+    {
+        return mViewHtmlOptions;
+    }
+    QAction *shareImage() const
+    {
+        return mShareImage;
+    }
 
-    KAction *addToExistingContactAction() const { return mAddEmailToExistingContactAction; }
+    QAction *addToExistingContactAction() const
+    {
+        return mAddEmailToExistingContactAction;
+    }
 
     Akonadi::Item message() const;
 
-    QWidget* mainWindow() { return mMainWindow; }
+    QWidget *mainWindow()
+    {
+        return mMainWindow;
+    }
 
     /** Enforce message decryption. */
-    void setDecryptMessageOverwrite( bool overwrite = true );
+    void setDecryptMessageOverwrite(bool overwrite = true);
 
-    MessageViewer::CSSHelper* cssHelper() const;
+    MessageViewer::CSSHelper *cssHelper() const;
 
     bool printSelectedText(bool preview);
 
-    void setContactItem(const Akonadi::Item& contact, const KABC::Addressee &address);
+    void setContactItem(const Akonadi::Item &contact, const KContacts::Addressee &address);
     void clearContactItem();
     bool adblockEnabled() const;
-    bool isAShortUrl(const KUrl &url) const;
+    bool isAShortUrl(const QUrl &url) const;
 
     bool mimePartTreeIsEmpty() const;
-signals:
+    KActionMenu *shareServiceUrlMenu() const;
+Q_SIGNALS:
     /** Emitted after parsing of a message to have it stored
       in unencrypted state in it's folder. */
     void replaceMsgByUnencryptedVersion();
 
-    void showStatusBarMessage( const QString &message );
+    void showStatusBarMessage(const QString &message);
 
-public slots:
+public Q_SLOTS:
     /** Force update even if message is the same */
     void clearCache();
 
@@ -207,15 +248,15 @@ public slots:
     /** Save the page to a file */
     void slotUrlSave();
     void slotAddBookmarks();
-    void slotUrlClicked( const Akonadi::Item &,  const KUrl& );
-    void slotShowReader(KMime::Content* , bool html, const QString& );
-    void slotShowMessage( KMime::Message::Ptr message, const QString& encoding );
-    void slotDeleteMessage( const Akonadi::Item& );
+    void slotUrlClicked(const Akonadi::Item &,  const QUrl &);
+    void slotShowReader(KMime::Content *, bool html, const QString &);
+    void slotShowMessage(KMime::Message::Ptr message, const QString &encoding);
+    void slotDeleteMessage(const Akonadi::Item &);
     void slotSaveImageOnDisk();
 
-    void slotPrintComposeResult( KJob *job );
+    void slotPrintComposeResult(KJob *job);
     void slotEditContact();
-    void contactStored( const Akonadi::Item &item );
+    void contactStored(const Akonadi::Item &item);
     void slotContactEditorError(const QString &error);
 
     void slotContactHtmlOptions();
@@ -223,38 +264,37 @@ public slots:
     void slotMailToAddToExistingContact();
 
 protected:
-    KUrl urlClicked() const;
-    KUrl imageUrlClicked() const;
+    QUrl urlClicked() const;
+    QUrl imageUrlClicked() const;
 
 private:
     void createActions();
     void updateHtmlActions();
 
 private:
-    KABC::Addressee mSearchedAddress;
+    KContacts::Addressee mSearchedAddress;
     Akonadi::Item mSearchedContact;
     QWidget *mMainWindow;
     KActionCollection *mActionCollection;
 
-    KAction *mMailToComposeAction;
-    KAction *mMailToReplyAction;
-    KAction *mMailToForwardAction;
-    KAction *mAddAddrBookAction;
-    KAction *mOpenAddrBookAction;
-    KAction *mUrlSaveAsAction;
-    KAction *mAddBookmarksAction;
-    KAction *mImageUrlSaveAsAction;
-    KAction *mEditContactAction;
-    KAction *mViewAsHtml;
-    KAction *mLoadExternalReference;
-    KAction *mShareImage;
-    KAction *mAddEmailToExistingContactAction;
+    QAction *mMailToComposeAction;
+    QAction *mMailToReplyAction;
+    QAction *mMailToForwardAction;
+    QAction *mAddAddrBookAction;
+    QAction *mOpenAddrBookAction;
+    QAction *mUrlSaveAsAction;
+    QAction *mAddBookmarksAction;
+    QAction *mImageUrlSaveAsAction;
+    QAction *mEditContactAction;
+    QAction *mViewAsHtml;
+    QAction *mLoadExternalReference;
+    QAction *mShareImage;
+    QAction *mAddEmailToExistingContactAction;
 
-    KMenu *mViewHtmlOptions;
+    QMenu *mViewHtmlOptions;
 
     MessageViewer::Viewer *mViewer;
 };
 
-
 #endif
 
