@@ -19,37 +19,23 @@
 #define ATTACHMENTLISTWIDGET_H
 
 #include "pimcommon/widgets/simplestringlisteditor.h"
-#include <KDialog>
+#include <QDialog>
 
-class KUrlRequester;
-namespace MailMerge {
-class SelectAttachmentDialog : public KDialog
+namespace MailMerge
 {
-    Q_OBJECT
-public:
-    explicit SelectAttachmentDialog(QWidget *parent);
-    ~SelectAttachmentDialog();
-
-    void setAttachmentPath(const QString &path);
-    QString attachmentPath() const;
-
-private:
-    KUrlRequester *mUrlRequester;
-};
-
 class AttachmentListWidget : public PimCommon::SimpleStringListEditor
 {
     Q_OBJECT
 public:
-    explicit AttachmentListWidget(QWidget * parent=0,
-                                  ButtonCode buttons=Unsorted,
-                                  const QString & addLabel=QString(),
-                                  const QString & removeLabel=QString(),
-                                  const QString & modifyLabel=QString());
+    explicit AttachmentListWidget(QWidget *parent = Q_NULLPTR,
+                                  ButtonCode buttons = Unsorted,
+                                  const QString &addLabel = QString(),
+                                  const QString &removeLabel = QString(),
+                                  const QString &modifyLabel = QString());
     ~AttachmentListWidget();
 
-    void addNewEntry();
-    QString modifyEntry(const QString &text);
+    void addNewEntry() Q_DECL_OVERRIDE;
+    QString modifyEntry(const QString &text) Q_DECL_OVERRIDE;
 };
 }
 #endif // ATTACHMENTLISTWIDGET_H
