@@ -19,9 +19,10 @@
 
 #include "searchdescriptionattribute.h"
 
-#include <QtCore/QByteArray>
+#include <QByteArray>
+#include <QDataStream>
 
-#include <Akonadi/Collection>
+#include <AkonadiCore/Collection>
 
 using namespace Akonadi;
 
@@ -30,21 +31,21 @@ SearchDescriptionAttribute::SearchDescriptionAttribute()
 {
 }
 
-
 QByteArray SearchDescriptionAttribute::type() const
 {
-    return "kmailsearchdescription";
+    static const QByteArray sType("kmailsearchdescription");
+    return sType;
 }
 
-Akonadi::Attribute* SearchDescriptionAttribute::clone() const
+Akonadi::Attribute *SearchDescriptionAttribute::clone() const
 {
-    return new SearchDescriptionAttribute( *this );
+    return new SearchDescriptionAttribute(*this);
 }
 
 QByteArray SearchDescriptionAttribute::serialized() const
 {
     QByteArray ba;
-    QDataStream s( &ba, QIODevice::WriteOnly );
+    QDataStream s(&ba, QIODevice::WriteOnly);
     s << mBaseCollection.id();
     s << mRecursive;
     s << mDescription;
@@ -52,12 +53,12 @@ QByteArray SearchDescriptionAttribute::serialized() const
     return ba;
 }
 
-void SearchDescriptionAttribute::deserialize( const QByteArray &data )
+void SearchDescriptionAttribute::deserialize(const QByteArray &data)
 {
-    QDataStream s( data );
+    QDataStream s(data);
     Akonadi::Entity::Id id;
     s >> id;
-    mBaseCollection = Akonadi::Collection( id );
+    mBaseCollection = Akonadi::Collection(id);
     s >> mRecursive;
     s >> mDescription;
     s >> mListCollection;
@@ -68,7 +69,7 @@ QByteArray SearchDescriptionAttribute::description() const
     return mDescription;
 }
 
-void SearchDescriptionAttribute::setDescription( const QByteArray& desc )
+void SearchDescriptionAttribute::setDescription(const QByteArray &desc)
 {
     mDescription = desc;
 }
@@ -78,7 +79,7 @@ Akonadi::Collection SearchDescriptionAttribute::baseCollection() const
     return mBaseCollection;
 }
 
-void SearchDescriptionAttribute::setBaseCollection( const Akonadi::Collection &col )
+void SearchDescriptionAttribute::setBaseCollection(const Akonadi::Collection &col)
 {
     mBaseCollection = col;
 }
@@ -88,12 +89,12 @@ bool SearchDescriptionAttribute::recursive() const
     return mRecursive;
 }
 
-void SearchDescriptionAttribute::setRecursive( bool r )
+void SearchDescriptionAttribute::setRecursive(bool r)
 {
     mRecursive = r;
 }
 
-void SearchDescriptionAttribute::setListCollection( const QList<Akonadi::Collection::Id> &col)
+void SearchDescriptionAttribute::setListCollection(const QList<Akonadi::Collection::Id> &col)
 {
     mListCollection = col;
 }
