@@ -22,22 +22,19 @@
 #define APPLICATION_H
 
 #include <kontactinterface/pimuniqueapplication.h>
-class KCmdLineArgs;
 class KNotesApp;
 
 class Application
-        : public KontactInterface::PimUniqueApplication
+    : public KontactInterface::PimUniqueApplication
 {
 public:
-    Application();
+    Application(int &argc, char **argv[]);
     ~Application();
 
-    virtual int newInstance();
-    KCmdLineArgs *args() const;
+    int activate(const QStringList &args) Q_DECL_OVERRIDE;
 
 private:
     KNotesApp *mMainWindow;
-    KCmdLineArgs *mCmdLineArguments;
 };
 
 #endif
