@@ -29,38 +29,41 @@
 
 class QFont;
 
-class KAction;
+class QAction;
 class KActionCollection;
 class KFontAction;
 class KFontSizeAction;
 class KToggleAction;
 class KNote;
-
+namespace PimCommon
+{
+class KActionMenuChangeCase;
+}
 class KNOTES_EXPORT KNoteEdit : public PimCommon::CustomTextEdit
 {
     Q_OBJECT
 public:
-    explicit KNoteEdit(const QString &configFile, KActionCollection *actions, QWidget *parent = 0 );
+    explicit KNoteEdit(const QString &configFile, KActionCollection *actions, QWidget *parent = Q_NULLPTR);
     ~KNoteEdit();
 
-    void setNote( KNote *_note );
+    void setNote(KNote *_note);
 
-    void setText( const QString &text );
+    void setText(const QString &text);
     QString text() const;
 
-    void setTextFont( const QFont &font );
-    void setTabStop( int tabs );
-    void setAutoIndentMode( bool newmode );
+    void setTextFont(const QFont &font);
+    void setTabStop(int tabs);
+    void setAutoIndentMode(bool newmode);
 
     void setColor(const QColor &fg, const QColor &bg);
     void setCursorPositionFromStart(int pos);
     int cursorPositionFromStart() const;
+    QMenu *mousePopupMenu() Q_DECL_OVERRIDE;
+public Q_SLOTS:
+    void setRichText(bool);
 
-public slots:
-    void setRichText( bool );
-
-    void textBold( bool );
-    void textStrikeOut( bool );
+    void textBold(bool);
+    void textStrikeOut(bool);
 
     void slotTextColor();
 
@@ -76,26 +79,24 @@ public slots:
 
     void textIncreaseIndent();
     void textDecreaseIndent();
-    void setTextFontSize( int );
+    void setTextFontSize(int);
 
     void slotTextBackgroundColor();
     void slotInsertDate();
 
 protected:
-    void keyPressEvent( QKeyEvent * );
-    void focusInEvent( QFocusEvent * );
-    void focusOutEvent( QFocusEvent * );
+    void keyPressEvent(QKeyEvent *) Q_DECL_OVERRIDE;
+    void focusInEvent(QFocusEvent *) Q_DECL_OVERRIDE;
+    void focusOutEvent(QFocusEvent *) Q_DECL_OVERRIDE;
 
-protected slots:
-    void mousePopupMenuImplementation(const QPoint& pos);
-
-private slots:
-    void slotCurrentCharFormatChanged( const QTextCharFormat & );
+private Q_SLOTS:
+    void slotCurrentCharFormatChanged(const QTextCharFormat &);
     void slotCursorPositionChanged();
     void slotUpperCase();
     void slotLowerCase();
-    void slotSentenceCase();    
+    void slotSentenceCase();
     void slotInsertCheckMark();
+    void slotReverseCase();
 private:
     void autoIndent();
 
@@ -119,14 +120,15 @@ private:
     KToggleAction *m_textSuper;
     KToggleAction *m_textSub;
 
-    KAction       *m_textIncreaseIndent;
-    KAction       *m_textDecreaseIndent;
+    QAction *m_textIncreaseIndent;
+    QAction *m_textDecreaseIndent;
 
-    KAction         *m_textColor;
+    QAction *m_textColor;
     KFontAction     *m_textFont;
     KFontSizeAction *m_textSize;
     KNote           *m_note;
     KActionCollection *m_actions;
+    PimCommon::KActionMenuChangeCase *mChangeCaseActionMenu;
     bool m_autoIndentMode;
 };
 
