@@ -29,13 +29,13 @@
 #ifndef KORG_ACTIONMANAGER_H
 #define KORG_ACTIONMANAGER_H
 
-#include "korganizer_export.h"
+#include "korganizerprivate_export.h"
 #include "korganizer/part.h"
 
-#include <Akonadi/Item>
+#include <AkonadiCore/Item>
 #include <Akonadi/Calendar/ETMCalendar>
 
-#include <KUrl>
+#include <QUrl>
 #include <KViewStateMaintainer>
 
 #include <QObject>
@@ -43,18 +43,20 @@
 class AkonadiCollectionView;
 class CalendarView;
 class KOWindowList;
-namespace KOrg {
-  class HTMLExportSettings;
+namespace KOrg
+{
+class HTMLExportSettings;
 }
 
-namespace Akonadi {
-  class ETMViewStateSaver;
+namespace Akonadi
+{
+class ETMViewStateSaver;
 }
 
-class KAction;
-class KMenuBar;
+class QAction;
+class QMenuBar;
 class KSelectAction;
-class KTemporaryFile;
+class QTemporaryFile;
 class KToggleAction;
 
 /**
@@ -65,31 +67,34 @@ class KToggleAction;
 */
 class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
 {
-  Q_OBJECT
-  public:
-    ActionManager( KXMLGUIClient *client, CalendarView *widget,
-                   QObject *parent, KOrg::MainWindow *mainWindow,
-                   bool isPart, KMenuBar *menuBar = 0 );
+    Q_OBJECT
+public:
+    ActionManager(KXMLGUIClient *client, CalendarView *widget,
+                  QObject *parent, KOrg::MainWindow *mainWindow,
+                  bool isPart, QMenuBar *menuBar = Q_NULLPTR);
     virtual ~ActionManager();
 
     /** Peform initialization that requires this* to be full constructed */
     void init();
 
-    CalendarView *view() const { return mCalendarView; }
+    CalendarView *view() const
+    {
+        return mCalendarView;
+    }
 
     /**
       Create Calendar object based on the akonadi framework and set it on the view.
     */
     void createCalendarAkonadi();
 
-  public slots:
-    bool importURL( const KUrl &url, bool merge);
+public Q_SLOTS:
+    bool importURL(const QUrl &url, bool merge);
 
     /** Save calendar file to URL of current calendar */
     bool saveURL();
 
     /** Save calendar file to URL */
-    bool saveAsURL( const KUrl &kurl );
+    bool saveAsURL(const QUrl &QUrl);
 
     /**
       Export the calendar to an HTML file. Reads up the user settings as needed.
@@ -103,24 +108,27 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
       @param autoMode if true, indicates that this export is for an autosave;
                       if false, then the export is explicitly user invoked.
     */
-    void exportHTML( KOrg::HTMLExportSettings *settings, bool autoMode = false );
-    void toggleMenubar( bool dontShowWarning = false );
+    void exportHTML(KOrg::HTMLExportSettings *settings, bool autoMode = false);
+    void toggleMenubar(bool dontShowWarning = false);
 
-  public:
+public:
     /** Get current URL */
-    KUrl url() const { return mURL; }
+    QUrl url() const
+    {
+        return mURL;
+    }
 
     /** Is there a instance with this URL? */
-    static KOrg::MainWindow *findInstance( const KUrl &url );
+    static KOrg::MainWindow *findInstance(const QUrl &url);
 
     /** Open calendar file from URL */
-    bool openURL( const QString &url );
+    bool openURL(const QString &url);
 
     /** Open calendar file from URL */
-    bool mergeURL( const QString &url );
+    bool mergeURL(const QString &url);
 
     /** Save calendar file to URL */
-    bool saveAsURL( const QString &url );
+    bool saveAsURL(const QString &url);
 
     /** Get current URL as QString */
     QString getCurrentURLasString() const;
@@ -131,113 +139,113 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
       @param force If true, all recurrences and sub-todos (if applicable) will
       be deleted without prompting for confirmation.
     */
-    virtual bool deleteIncidence( Akonadi::Item::Id id, bool force = false );
+    virtual bool deleteIncidence(Akonadi::Item::Id id, bool force = false);
 
-    bool editIncidence( Akonadi::Item::Id id );
+    bool editIncidence(Akonadi::Item::Id id);
 
     /**
       Add an incidence to the active calendar.
       @param ical A calendar in iCalendar format containing the incidence.
     */
-    bool addIncidence( const QString &ical );
+    bool addIncidence(const QString &ical);
     //bool addIncidence( const Akonadi::Item::Id &ical );
 
-    bool showIncidence( Akonadi::Item::Id id );
+    bool showIncidence(Akonadi::Item::Id id);
 
     /**
       Show an incidence in context. This means showing the todo, agenda or
       journal view (as appropriate) and scrolling it to show the incidence.
       @param uid Unique ID of the incidence to show.
     */
-    bool showIncidenceContext( Akonadi::Item::Id id );
+    bool showIncidenceContext(Akonadi::Item::Id id);
 
     /**
      * Called by KOrganizerUniqueAppHandler in the kontact plugin
      * Returns true if the command line was successfully handled
      * false otherwise.
      */
-    bool handleCommandLine();
+    bool handleCommandLine(const QStringList &args);
 
-  public slots:
-    void openEventEditor( const QString &);
-    void openEventEditor( const QString &summary,
-                          const QString &description,
-                          const QStringList &attachments );
-    void openEventEditor( const QString &summary,
-                          const QString &description,
-                          const QStringList &attachments,
-                          const QStringList &attendees );
-    void openEventEditor( const QString &summary,
-                          const QString &description,
-                          const QString &uri,
-                          const QString &file,
-                          const QStringList &attendees,
-                          const QString &attachmentMimetype );
-    void openEventEditor( const QString &summary,
-                          const QString &description,
-                          const QStringList &attachmentUris,
-                          const QStringList &attendees,
-                          const QStringList &attachmentMimetypes,
-                          bool attachmentIsInline );
-    void openTodoEditor( const QString &);
-    void openTodoEditor( const QString &summary,
+public Q_SLOTS:
+    void openEventEditor(const QString &);
+    void openEventEditor(const QString &summary,
                          const QString &description,
-                         const QStringList &attachments );
-    void openTodoEditor( const QString &summary,
+                         const QStringList &attachments);
+    void openEventEditor(const QString &summary,
                          const QString &description,
                          const QStringList &attachments,
-                         const QStringList &attendees );
-    void openTodoEditor( const QString &summary,
+                         const QStringList &attendees);
+    void openEventEditor(const QString &summary,
                          const QString &description,
                          const QString &uri,
                          const QString &file,
                          const QStringList &attendees,
-                         const QString &attachmentMimetype );
-    void openTodoEditor( const QString &summary,
+                         const QString &attachmentMimetype);
+    void openEventEditor(const QString &summary,
                          const QString &description,
                          const QStringList &attachmentUris,
                          const QStringList &attendees,
                          const QStringList &attachmentMimetypes,
-                         bool attachmentIsInline );
+                         bool attachmentIsInline);
+    void openTodoEditor(const QString &);
+    void openTodoEditor(const QString &summary,
+                        const QString &description,
+                        const QStringList &attachments);
+    void openTodoEditor(const QString &summary,
+                        const QString &description,
+                        const QStringList &attachments,
+                        const QStringList &attendees);
+    void openTodoEditor(const QString &summary,
+                        const QString &description,
+                        const QString &uri,
+                        const QString &file,
+                        const QStringList &attendees,
+                        const QString &attachmentMimetype);
+    void openTodoEditor(const QString &summary,
+                        const QString &description,
+                        const QStringList &attachmentUris,
+                        const QStringList &attendees,
+                        const QStringList &attachmentMimetypes,
+                        bool attachmentIsInline);
 
-    void openJournalEditor( const QDate &date );
-    void openJournalEditor( const QString &text, const QDate &date );
-    void openJournalEditor( const QString &text );
+    void openJournalEditor(const QDate &date);
+    void openJournalEditor(const QString &text, const QDate &date);
+    void openJournalEditor(const QString &text);
 
     void showJournalView();
     void showTodoView();
     void showEventView();
 
-    void goDate( const QDate &);
-    void goDate( const QString &);
-    void showDate( const QDate &date );
+    void goDate(const QDate &);
+    void goDate(const QString &);
+    void showDate(const QDate &date);
 
-  public:
+public:
     QString localFileName();
 
     bool queryClose();
 
-  signals:
+Q_SIGNALS:
     /**
       Emitted when the "New" action is activated.
     */
-    //void actionNewMainWindow( const KUrl &url = KUrl() );
+    //void actionNewMainWindow( const QUrl &url = QUrl() );
     void toggleMenuBar();
     /**
       When change is made to options dialog, the topwidget will catch this
-      and emit this signal which notifies all widgets which have registered
+      and Q_EMIT this signal which notifies all widgets which have registered
       for notification to update their settings.
     */
     void configChanged();
 
-  public slots:
+public Q_SLOTS:
     /**
       Options dialog made a changed to the configuration. we catch this
       and notify all widgets which need to update their configuration.
     */
     void updateConfig();
 
-    void processIncidenceSelection( const Akonadi::Item &item, const QDate &date );
+    void processIncidenceSelection(const Akonadi::Item &item, const QDate &date);
     void keyBindings();
 
     /**
@@ -252,15 +260,15 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
     void writeSettings();
 
     /* Session management */
-    void saveProperties( KConfigGroup & );
-    void readProperties( const KConfigGroup & );
+    void saveProperties(KConfigGroup &);
+    void readProperties(const KConfigGroup &);
 
     void loadParts();
 
-    void importCalendar( const KUrl &url );
+    void importCalendar(const QUrl &url);
 
-  protected slots:
-    void setItems( const QStringList &, int );
+protected Q_SLOTS:
+    void setItems(const QStringList &, int);
 
     /** called by the autoExportTimer to automatically export the calendar */
     void checkAutoExport();
@@ -275,7 +283,7 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
         after the URL is obtained from the user.
         @param url the URL to open
     */
-    void file_open( const KUrl &url );
+    void file_open(const QUrl &url);
 
     /** import a non-ics calendar from another program like ical. */
     void file_icalimport();
@@ -312,20 +320,20 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
 
     void updateUndoRedoActions();
 
-  protected:
+protected:
     /** Get URL for saving. Opens FileDialog. */
-    KUrl getSaveURL();
+    QUrl getSaveURL();
 
     /**
       Return widget used as parent for dialogs and message boxes.
     */
     QWidget *dialogParent();
 
-  private slots:
-    void handleExportJobResult( KJob * );
-    void dumpText( const QString & );  // only for debugging purposes
+private Q_SLOTS:
+    void handleExportJobResult(KJob *);
+    void dumpText(const QString &);    // only for debugging purposes
 
-    void slotDefaultResourceChanged( const Akonadi::Collection & );
+    void slotDefaultResourceChanged(const Akonadi::Collection &);
     void slotResourcesAddedRemoved();
 
     void slotNewEvent();
@@ -336,24 +344,23 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
     void slotMergeFinished(bool success, int total);
     void slotNewResourceFinished(bool);
 
-
-  private:
+private:
     class ActionStringsVisitor;
-
+    void setHelpText(QAction *act, const QString &text);
     void restoreCollectionViewSetting();
     /** Create all the actions. */
     void initActions();
-    void enableIncidenceActions( bool enable );
+    void enableIncidenceActions(bool enable);
     Akonadi::ETMCalendar::Ptr calendar() const;
 
     Akonadi::Collection selectedCollection() const;
 
     KOrg::Part::List mParts; // List of parts loaded
-    KUrl mURL;               // URL of calendar file
+    QUrl mURL;               // URL of calendar file
     QString mFile;           // Local name of calendar file
     QString mLastUrl;        // URL of last loaded calendar.
 
-    KTemporaryFile *mTempFile;
+    QTemporaryFile *mTempFile;
     QTimer *mAutoExportTimer;    // used if calendar is to be autoexported
     QTimer *mAutoArchiveTimer; // used for the auto-archiving feature
 
@@ -367,35 +374,35 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
 
     KToggleAction *mHideMenuBarAction;
 
-    KAction *mImportAction;
+    QAction *mImportAction;
 
-    KAction *mNewEventAction;
-    KAction *mNewTodoAction;
-    KAction *mNewSubtodoAction;
-    KAction *mNewJournalAction;
-    KAction *mConfigureViewAction;
+    QAction *mNewEventAction;
+    QAction *mNewTodoAction;
+    QAction *mNewSubtodoAction;
+    QAction *mNewJournalAction;
+    QAction *mConfigureViewAction;
 
-    KAction *mShowIncidenceAction;
-    KAction *mEditIncidenceAction;
-    KAction *mDeleteIncidenceAction;
+    QAction *mShowIncidenceAction;
+    QAction *mEditIncidenceAction;
+    QAction *mDeleteIncidenceAction;
 
-    KAction *mCutAction;
-    KAction *mCopyAction;
-    KAction *mDeleteAction;
-    KAction *mNextXDays;
-    KAction *mPublishEvent;
-    KAction *mForwardEvent;
+    QAction *mCutAction;
+    QAction *mCopyAction;
+    QAction *mDeleteAction;
+    QAction *mNextXDays;
+    QAction *mPublishEvent;
+    QAction *mForwardEvent;
 
-    KAction *mSendInvitation;
-    KAction *mSendCancel;
-    KAction *mSendStatusUpdate;
+    QAction *mSendInvitation;
+    QAction *mSendCancel;
+    QAction *mSendStatusUpdate;
 
-    KAction *mRequestChange;
-    KAction *mRequestUpdate;
+    QAction *mRequestChange;
+    QAction *mRequestUpdate;
 
-    KAction *mUndoAction;
-    KAction *mRedoAction;
-    KMenuBar *mMenuBar;
+    QAction *mUndoAction;
+    QAction *mRedoAction;
+    QMenuBar *mMenuBar;
 
     KSelectAction *mFilterAction;
 
@@ -409,7 +416,7 @@ class KORGANIZERPRIVATE_EXPORT ActionManager : public QObject
     AkonadiCollectionView *mCollectionView;
     KViewStateMaintainer<Akonadi::ETMViewStateSaver> *mCollectionViewStateSaver;
     KViewStateMaintainer<Akonadi::ETMViewStateSaver> *mCollectionSelectionModelStateSaver;
-    QSet<KOrg::HTMLExportSettings*> mSettingsToFree;
+    QSet<KOrg::HTMLExportSettings *> mSettingsToFree;
 };
 
 #endif
