@@ -36,33 +36,33 @@
 */
 class KOAgendaView : public KOEventView
 {
-  Q_OBJECT
-  public:
-    explicit KOAgendaView( QWidget *parent = 0, bool isSideBySide = false );
+    Q_OBJECT
+public:
+    explicit KOAgendaView(QWidget *parent = Q_NULLPTR, bool isSideBySide = false);
     virtual ~KOAgendaView();
 
     /** Returns maximum number of days supported by the koagendaview */
-    virtual int maxDatesHint() const;
+    int maxDatesHint() const Q_DECL_OVERRIDE;
 
     /** Returns number of currently shown dates. */
-    virtual int currentDateCount() const;
+    int currentDateCount() const Q_DECL_OVERRIDE;
 
     /** returns the currently selected events */
-    virtual Akonadi::Item::List selectedIncidences();
+    Akonadi::Item::List selectedIncidences() Q_DECL_OVERRIDE;
 
     /** returns the currently selected incidence's dates */
-    virtual KCalCore::DateList selectedIncidenceDates();
+    KCalCore::DateList selectedIncidenceDates() Q_DECL_OVERRIDE;
 
     /** return the default start/end date/time for new events   */
-    virtual bool eventDurationHint( QDateTime &startDt, QDateTime &endDt, bool &allDay );
+    bool eventDurationHint(QDateTime &startDt, QDateTime &endDt, bool &allDay) Q_DECL_OVERRIDE;
 
-    CalendarSupport::CalPrinter::PrintType printType() const;
+    CalendarSupport::CalPrinter::PrintType printType() const Q_DECL_OVERRIDE;
 
     /** start-datetime of selection */
-    virtual QDateTime selectionStart();
+    QDateTime selectionStart() Q_DECL_OVERRIDE;
 
     /** end-datetime of selection */
-    virtual QDateTime selectionEnd();
+    QDateTime selectionEnd() Q_DECL_OVERRIDE;
 
     /** returns true if selection is for whole day */
     bool selectedIsAllDay();
@@ -72,50 +72,50 @@ class KOAgendaView : public KOEventView
     bool selectedIsSingleCell();
 
     /* reimp from BaseView */
-    virtual void setCalendar( const Akonadi::ETMCalendar::Ptr &cal );
+    void setCalendar(const Akonadi::ETMCalendar::Ptr &cal) Q_DECL_OVERRIDE;
 
     /** reimpl */
-    virtual void setTypeAheadReceiver( QObject *o );
+    void setTypeAheadReceiver(QObject *o) Q_DECL_OVERRIDE;
 
-    void setChanges( EventViews::EventView::Changes changes );
+    void setChanges(EventViews::EventView::Changes changes) Q_DECL_OVERRIDE;
 
     /** reimpl */
-    void setDateRange( const KDateTime &start, const KDateTime &end,
-                       const QDate &preferredMonth = QDate() );
+    void setDateRange(const KDateTime &start, const KDateTime &end,
+                      const QDate &preferredMonth = QDate()) Q_DECL_OVERRIDE;
 
-  public slots:
-    virtual void updateView();
-    virtual void updateConfig();
-    virtual void showDates( const QDate &start, const QDate &end,
-                            const QDate &preferredMonth = QDate() );
-    virtual void showIncidences( const Akonadi::Item::List &incidenceList, const QDate &date );
+public Q_SLOTS:
+    void updateView() Q_DECL_OVERRIDE;
+    void updateConfig() Q_DECL_OVERRIDE;
+    void showDates(const QDate &start, const QDate &end,
+                   const QDate &preferredMonth = QDate()) Q_DECL_OVERRIDE;
+    void showIncidences(const Akonadi::Item::List &incidenceList, const QDate &date) Q_DECL_OVERRIDE;
 
-    void changeIncidenceDisplayAdded( const Akonadi::Item &incidence );
-    void changeIncidenceDisplay( const Akonadi::Item &incidence, Akonadi::IncidenceChanger::ChangeType );
+    void changeIncidenceDisplayAdded(const Akonadi::Item &incidence);
+    void changeIncidenceDisplay(const Akonadi::Item &incidence, Akonadi::IncidenceChanger::ChangeType) Q_DECL_OVERRIDE;
 
-    void clearSelection();
+    void clearSelection() Q_DECL_OVERRIDE;
 
     void readSettings();
-    void readSettings( KConfig * );
-    void writeSettings( KConfig * );
+    void readSettings(KConfig *);
+    void writeSettings(KConfig *);
 
-    void enableAgendaUpdate( bool enable );
-    void setIncidenceChanger( Akonadi::IncidenceChanger *changer );
+    void enableAgendaUpdate(bool enable);
+    void setIncidenceChanger(Akonadi::IncidenceChanger *changer) Q_DECL_OVERRIDE;
 
-    void zoomInHorizontally( const QDate &date=QDate() );
-    void zoomOutHorizontally( const QDate &date=QDate() );
+    void zoomInHorizontally(const QDate &date = QDate());
+    void zoomOutHorizontally(const QDate &date = QDate());
 
-    void zoomInVertically( );
-    void zoomOutVertically( );
+    void zoomInVertically();
+    void zoomOutVertically();
 
-    void zoomView( const int delta, const QPoint &pos,
-                   const Qt::Orientation orient = Qt::Horizontal );
+    void zoomView(const int delta, const QPoint &pos,
+                  const Qt::Orientation orient = Qt::Horizontal);
 
-  signals:
-    void zoomViewHorizontally( const QDate &, int count );
+Q_SIGNALS:
+    void zoomViewHorizontally(const QDate &, int count);
     void timeSpanSelectionChanged();
 
-  private:
+private:
     class Private;
     Private *const d;
 };
