@@ -28,8 +28,9 @@
 #include "korganizer/baseview.h"
 #include <Akonadi/Calendar/ETMCalendar>
 
-namespace EventViews {
-  class TimeSpentView;
+namespace EventViews
+{
+class TimeSpentView;
 }
 
 /**
@@ -37,35 +38,33 @@ namespace EventViews {
 */
 class KOTimeSpentView : public KOrg::BaseView
 {
-  Q_OBJECT
-  public:
-    explicit KOTimeSpentView( QWidget *parent = 0 );
+    Q_OBJECT
+public:
+    explicit KOTimeSpentView(QWidget *parent = Q_NULLPTR);
     ~KOTimeSpentView();
 
-    virtual int currentDateCount() const;
+    int currentDateCount() const Q_DECL_OVERRIDE;
 
-    virtual Akonadi::Item::List selectedIncidences()
-    {
-      return Akonadi::Item::List();
+    Akonadi::Item::List selectedIncidences() Q_DECL_OVERRIDE {
+        return Akonadi::Item::List();
     }
 
-    KCalCore::DateList selectedIncidenceDates()
-    {
-      return KCalCore::DateList();
+    KCalCore::DateList selectedIncidenceDates() Q_DECL_OVERRIDE {
+        return KCalCore::DateList();
     }
 
-    void setCalendar( const Akonadi::ETMCalendar::Ptr &cal );
+    void setCalendar(const Akonadi::ETMCalendar::Ptr &cal) Q_DECL_OVERRIDE;
 
-  public Q_SLOTS:
-    virtual void updateView();
-    virtual void showDates( const QDate &start, const QDate &end,
-                            const QDate &preferredMonth = QDate() );
-    virtual void showIncidences( const Akonadi::Item::List &incidenceList, const QDate &date );
+public Q_SLOTS:
+    void updateView() Q_DECL_OVERRIDE;
+    void showDates(const QDate &start, const QDate &end,
+                   const QDate &preferredMonth = QDate()) Q_DECL_OVERRIDE;
+    void showIncidences(const Akonadi::Item::List &incidenceList, const QDate &date) Q_DECL_OVERRIDE;
 
-    void changeIncidenceDisplay( const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType );
-    virtual KOrg::CalPrinterBase::PrintType printType() const;
+    void changeIncidenceDisplay(const Akonadi::Item &, Akonadi::IncidenceChanger::ChangeType) Q_DECL_OVERRIDE;
+    CalendarSupport::CalPrinterBase::PrintType printType() const Q_DECL_OVERRIDE;
 
-  private:
+private:
     EventViews::TimeSpentView *mView;
 };
 
