@@ -19,10 +19,11 @@
 */
 
 #include "blacklistbalooemaillist.h"
-#include <QDebug>
+#include "libkdepim_debug.h"
 #include <QPainter>
-#include <KGlobalSettings>
-#include <KPIMUtils/Email>
+#include <QEvent>
+#include <KLocalizedString>
+#include <KEmailAddress>
 using namespace KPIM;
 
 BlackListBalooEmailList::BlackListBalooEmailList(QWidget *parent)
@@ -30,9 +31,7 @@ BlackListBalooEmailList::BlackListBalooEmailList(QWidget *parent)
       mFirstResult(false)
 {
     setSelectionMode(QAbstractItemView::ExtendedSelection);
-    connect( KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()),
-             this, SLOT(slotGeneralPaletteChanged()));
-
+    setSortingEnabled(true);
 }
 
 BlackListBalooEmailList::~BlackListBalooEmailList()
@@ -40,6 +39,14 @@ BlackListBalooEmailList::~BlackListBalooEmailList()
 
 }
 
+void BlackListBalooEmailList::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::PaletteChange) {
+        generalPaletteChanged();
+    }
+    QListWidget::changeEvent(event);
+}
+
 void BlackListBalooEmailList::setEmailBlackList(const QStringList &list)
 {
     mEmailBlackList = list;
@@ -69,10 +76,10 @@ void BlackListBalooEmailList::slotEmailFound(const QStringList &list)
     mFirstResult = true;
     clear();
     QStringList emailsAdded;
-    Q_FOREACH(const QString & mail, list) {
+    Q_FOREACH (const QString &mail, list) {
         bool excludeDomain = false;
         QString email, name;
-        KPIMUtils::extractEmailAddressAndName( mail, email, name );
+        KEmailAddress::extractEmailAddressAndName(mail, email, name);
 
         Q_FOREACH (const QString &domain, mExcludeDomain) {
             if (email.endsWith(domain)) {
@@ -97,41 +104,39 @@ void BlackListBalooEmailList::slotEmailFound(const QStringList &list)
     }
 }
 
-void BlackListBalooEmailList::slotGeneralPaletteChanged()
+void BlackListBalooEmailList::generalPaletteChanged()
 {
     const QPalette palette = viewport()->palette();
     QColor color = palette.text().color();
-    color.setAlpha( 128 );
+    color.setAlpha(128);
     mTextColor = color;
 }
 
-void BlackListBalooEmailList::paintEvent( QPaintEvent *event )
+void BlackListBalooEmailList::paintEvent(QPaintEvent *event)
 {
-    if ( mFirstResult && (!model() || model()->rowCount() == 0) ) {
-        QPainter p( viewport() );
+    if (mFirstResult && (!model() || model()->rowCount() == 0)) {
+        QPainter p(viewport());
 
         QFont font = p.font();
-        font.setItalic( true );
-        p.setFont( font );
+        font.setItalic(true);
+        p.setFont(font);
 
         if (!mTextColor.isValid()) {
-            slotGeneralPaletteChanged();
+            generalPaletteChanged();
         }
-        p.setPen( mTextColor );
+        p.setPen(mTextColor);
 
-        //Add i18n
-        p.drawText( QRect( 0, 0, width(), height() ), Qt::AlignCenter, QLatin1String( "No result found" ) );
+        p.drawText(QRect(0, 0, width(), height()), Qt::AlignCenter, i18n("No result found"));
     } else {
-        QListWidget::paintEvent( event );
+        QListWidget::paintEvent(event);
     }
 }
 
-
 BlackListBalooEmailListItem::BlackListBalooEmailListItem(QListWidget *parent)
     : QListWidgetItem(parent),
       mInitializeStatus(false)
 {
-    setFlags(Qt::ItemIsEnabled|Qt::ItemIsUserCheckable|Qt::ItemIsSelectable);
+    setFlags(Qt::ItemIsEnabled | Qt::ItemIsUserCheckable | Qt::ItemIsSelectable);
 }
 
 BlackListBalooEmailListItem::~BlackListBalooEmailListItem()
