@@ -26,12 +26,13 @@
 #include <QHash>
 #include "kdepim_export.h"
 
-namespace KPIM {
+namespace KPIM
+{
 
 class KDEPIM_EXPORT BlackListBalooEmailListItem : public QListWidgetItem
 {
 public:
-    explicit BlackListBalooEmailListItem(QListWidget *parent = 0);
+    explicit BlackListBalooEmailListItem(QListWidget *parent = Q_NULLPTR);
     ~BlackListBalooEmailListItem();
 
     bool initializeStatus() const;
@@ -45,7 +46,7 @@ class KDEPIM_EXPORT BlackListBalooEmailList : public QListWidget
 {
     Q_OBJECT
 public:
-    explicit BlackListBalooEmailList(QWidget *parent = 0);
+    explicit BlackListBalooEmailList(QWidget *parent = Q_NULLPTR);
     ~BlackListBalooEmailList();
 
     void setEmailBlackList(const QStringList &list);
@@ -54,14 +55,14 @@ public:
 
     void setExcludeDomain(const QStringList &domain);
 protected:
-    void paintEvent( QPaintEvent *event );
+    void paintEvent(QPaintEvent *event) Q_DECL_OVERRIDE;
 
+    void changeEvent(QEvent *event) Q_DECL_OVERRIDE;
 public Q_SLOTS:
     void slotEmailFound(const QStringList &);
 
-private slots:
-    void slotGeneralPaletteChanged();
 private:
+    void generalPaletteChanged();
     QStringList mEmailBlackList;
     QStringList mExcludeDomain;
     QColor mTextColor;
