@@ -20,16 +20,13 @@
 
 #include "recentaddresswidget.h"
 #include "recentaddresses.h"
-#include <kpimutils/email.h>
 
 #include <KConfig>
 #include <KConfigGroup>
-#include <KDebug>
-#include <KGlobal>
-#include <KLocale>
 #include <KLineEdit>
-#include <KPushButton>
+#include <QPushButton>
 #include <KMessageBox>
+#include <KLocalizedString>
 
 #include <QCoreApplication>
 #include <QLayout>
@@ -37,53 +34,48 @@
 #include <QListWidget>
 #include <QKeyEvent>
 
-
 using namespace KPIM;
 RecentAddressWidget::RecentAddressWidget(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *layout = new QVBoxLayout( this );
-    layout->setSpacing( 0 );
-    layout->setMargin( 0 );
+    QVBoxLayout *layout = new QVBoxLayout(this);
 
     mLineEdit = new KLineEdit(this);
-    mLineEdit->setObjectName(QLatin1String("line_edit"));
+    mLineEdit->setObjectName(QStringLiteral("line_edit"));
     layout->addWidget(mLineEdit);
 
     mLineEdit->setTrapReturnKey(true);
     mLineEdit->installEventFilter(this);
 
-    connect(mLineEdit,SIGNAL(textChanged(QString)),SLOT(slotTypedSomething(QString)));
-    connect(mLineEdit,SIGNAL(returnPressed()),SLOT(slotAddItem()));
+    connect(mLineEdit, &KLineEdit::textChanged, this, &RecentAddressWidget::slotTypedSomething);
+    connect(mLineEdit, &KLineEdit::returnPressed, this, &RecentAddressWidget::slotAddItem);
 
+    QHBoxLayout *hboxLayout = new QHBoxLayout;
 
-    QHBoxLayout* hboxLayout = new QHBoxLayout;
-
-    QVBoxLayout* btnsLayout = new QVBoxLayout;
+    QVBoxLayout *btnsLayout = new QVBoxLayout;
     btnsLayout->addStretch();
-    mNewButton = new KPushButton(KIcon(QLatin1String("list-add")), i18n("&Add"), this);
-    mNewButton->setObjectName(QLatin1String("new_button"));
-    connect(mNewButton, SIGNAL(clicked()), SLOT(slotAddItem()));
-    btnsLayout->insertWidget(0 ,mNewButton);
 
-    mRemoveButton = new KPushButton(KIcon(QLatin1String("list-remove")), i18n("&Remove"), this);
-    mRemoveButton->setObjectName(QLatin1String("remove_button"));
+    mNewButton = new QPushButton(QIcon::fromTheme(QStringLiteral("list-add")), i18n("&Add"), this);
+    mNewButton->setObjectName(QStringLiteral("new_button"));
+    connect(mNewButton, &QPushButton::clicked, this, &RecentAddressWidget::slotAddItem);
+    btnsLayout->insertWidget(0 , mNewButton);
+
+    mRemoveButton = new QPushButton(QIcon::fromTheme(QStringLiteral("list-remove")), i18n("&Remove"), this);
+    mRemoveButton->setObjectName(QStringLiteral("remove_button"));
     mRemoveButton->setEnabled(false);
-    connect(mRemoveButton, SIGNAL(clicked()), SLOT(slotRemoveItem()));
+    connect(mRemoveButton, &QPushButton::clicked, this, &RecentAddressWidget::slotRemoveItem);
     btnsLayout->insertWidget(1, mRemoveButton);
 
-
     mListView = new QListWidget(this);
-    mListView->setObjectName(QLatin1String("list_view"));
+    mListView->setObjectName(QStringLiteral("list_view"));
     mListView->setSelectionMode(QAbstractItemView::ExtendedSelection);
     mListView->setSortingEnabled(true);
     hboxLayout->addWidget(mListView);
     hboxLayout->addLayout(btnsLayout);
     layout->addLayout(hboxLayout);
-    connect(mListView, SIGNAL(itemSelectionChanged()),
-            SLOT(slotSelectionChanged()));
+    connect(mListView, &QListWidget::itemSelectionChanged, this, &RecentAddressWidget::slotSelectionChanged);
     // maybe supplied lineedit has some text already
-    slotTypedSomething( mLineEdit->text() );
+    slotTypedSomething(mLineEdit->text());
 }
 
 RecentAddressWidget::~RecentAddressWidget()
@@ -91,7 +83,7 @@ RecentAddressWidget::~RecentAddressWidget()
 
 }
 
-void RecentAddressWidget::slotTypedSomething(const QString& text)
+void RecentAddressWidget::slotTypedSomething(const QString &text)
 {
     if (mListView->currentItem()) {
         if (mListView->currentItem()->text() != mLineEdit->text() && !mLineEdit->text().isEmpty()) {
@@ -99,19 +91,25 @@ void RecentAddressWidget::slotTypedSomething(const QString& text)
             // of currentItem() ... like changing it or emitting signals ...
             // but TT disagree with me on this one (it's been that way since ages ... grrr)
             bool block = mListView->signalsBlocked();
-            mListView->blockSignals( true );
+            mListView->blockSignals(true);
             QListWidgetItem *currentIndex = mListView->currentItem();
-            if ( currentIndex ) {
+            if (currentIndex) {
                 currentIndex->setText(text);
                 mDirty = true;
             }
-            mListView->blockSignals( block );
+            mListView->blockSignals(block);
         }
     }
 }
 
 void RecentAddressWidget::slotAddItem()
 {
+    if (mListView->count() > 0) {
+        const QString text = mListView->item(0)->text();
+        if (text.isEmpty()) {
+            return;
+        }
+    }
     mListView->blockSignals(true);
     mListView->insertItem(0, QString());
     mListView->blockSignals(false);
@@ -124,10 +122,11 @@ void RecentAddressWidget::slotAddItem()
 void RecentAddressWidget::slotRemoveItem()
 {
     QList<QListWidgetItem *> selectedItems = mListView->selectedItems();
-    if (selectedItems.isEmpty())
+    if (selectedItems.isEmpty()) {
         return;
-    if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18np("Do you want to remove this email?", "Do you want to remove %1 emails?", selectedItems.count()), i18n("Remove"))) {
-        Q_FOREACH(QListWidgetItem *item, selectedItems) {
+    }
+    if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18np("Do you want to remove this email address?", "Do you want to remove %1 email addresses?", selectedItems.count()), i18n("Remove"))) {
+        Q_FOREACH (QListWidgetItem *item, selectedItems) {
             delete mListView->takeItem(mListView->row(item));
         }
         mDirty = true;
@@ -145,8 +144,9 @@ void RecentAddressWidget::updateButtonState()
 
     if (numberOfElementSelected == 1) {
         const QString text = mListView->currentItem()->text();
-        if (text != mLineEdit->text())
+        if (text != mLineEdit->text()) {
             mLineEdit->setText(text);
+        }
     } else {
         mLineEdit->clear();
     }
@@ -157,40 +157,30 @@ void RecentAddressWidget::slotSelectionChanged()
     updateButtonState();
 }
 
-void RecentAddressWidget::setAddresses( const QStringList &addrs )
+void RecentAddressWidget::setAddresses(const QStringList &addrs)
 {
     mListView->clear();
-    mListView->addItems( addrs );
+    mListView->addItems(addrs);
 }
 
-QStringList RecentAddressWidget::addresses() const
+bool RecentAddressWidget::eventFilter(QObject *o, QEvent *e)
 {
-    QStringList lst;
-    const int numberOfItem(mListView->count());
-    for(int i = 0; i < numberOfItem; ++i) {
-        lst<<mListView->item(i)->text();
-    }
-    return lst;
-}
-
-bool RecentAddressWidget::eventFilter( QObject* o, QEvent* e )
-{
-    if (o == mLineEdit && e->type() == QEvent::KeyPress ) {
-        QKeyEvent* keyEvent = (QKeyEvent*)e;
+    if (o == mLineEdit && e->type() == QEvent::KeyPress) {
+        QKeyEvent *keyEvent = (QKeyEvent *)e;
         if (keyEvent->key() == Qt::Key_Down ||
                 keyEvent->key() == Qt::Key_Up) {
-            return ((QObject*)mListView)->event(e);
+            return ((QObject *)mListView)->event(e);
         }
     }
 
     return false;
 }
 
-void RecentAddressWidget::addAddresses(KConfig *config)
+void RecentAddressWidget::storeAddresses(KConfig *config)
 {
     const int numberOfItem(mListView->count());
     for (int i = 0; i < numberOfItem; ++i) {
-        KPIM::RecentAddresses::self( config )->add( mListView->item(i)->text() );
+        KPIM::RecentAddresses::self(config)->add(mListView->item(i)->text());
     }
 }
 
