@@ -27,12 +27,12 @@
 
 #include "kdepim_export.h"
 
-#include <KGlobalSettings>
-
+#include <KCompletion>
 #include <QWidget>
 #include <QSharedPointer>
 
-namespace KPIM {
+namespace KPIM
+{
 
 /**
   @short ABC representing line data
@@ -40,9 +40,9 @@ namespace KPIM {
 */
 class KDEPIM_EXPORT MultiplyingLineData
 {
-  public:
+public:
     typedef QSharedPointer<MultiplyingLineData> Ptr;
-    virtual ~MultiplyingLineData(){}
+    virtual ~MultiplyingLineData() {}
 
     /**
       Clear data, reset to defaults
@@ -65,8 +65,8 @@ class KDEPIM_EXPORT MultiplyingLine : public QWidget
 {
 
     Q_OBJECT
-  public:
-    explicit MultiplyingLine( QWidget *parent );
+public:
+    explicit MultiplyingLine(QWidget *parent);
     virtual ~MultiplyingLine() {}
 
     /**
@@ -103,7 +103,7 @@ class KDEPIM_EXPORT MultiplyingLine : public QWidget
       populated accordingly.
       @param data the data to populate this line wit
     */
-    virtual void setData( const MultiplyingLineData::Ptr &data ) = 0;
+    virtual void setData(const MultiplyingLineData::Ptr &data) = 0;
 
     /**
       Whether this line is empty or not. Usually there is a primary widget
@@ -119,7 +119,7 @@ class KDEPIM_EXPORT MultiplyingLine : public QWidget
       @param w the width to set the left most column to.
       @return the width that is actually being used.
     */
-    virtual int setColumnWidth( int w ) = 0;
+    virtual int setColumnWidth(int w) = 0;
 
     /**
       Used to set setup the correct chain of widgets to focus on
@@ -134,7 +134,7 @@ class KDEPIM_EXPORT MultiplyingLine : public QWidget
         setTabOrder( mMiddle, mRightMost);
       }
       */
-    virtual void fixTabOrder( QWidget *previous ) = 0;
+    virtual void fixTabOrder(QWidget *previous) = 0;
 
     /**
       @return The final widget in this line on which if the user presses
@@ -153,7 +153,7 @@ class KDEPIM_EXPORT MultiplyingLine : public QWidget
       Sets the type of completion to be used for KLineEdits in this line
       @param mode the completion mode
       */
-    virtual void setCompletionMode( KGlobalSettings::Completion mode ) = 0;
+    virtual void setCompletionMode(KCompletion::CompletionMode mode) = 0;
 
     /**
       If the view is resized while the completion popup is open, things might start
@@ -178,19 +178,19 @@ class KDEPIM_EXPORT MultiplyingLine : public QWidget
      */
     virtual void aboutToBeDeleted();
 
-  signals:
+Q_SIGNALS:
     /**
       Emitted when the return/enter key is pressed
     */
-    void returnPressed( KPIM::MultiplyingLine * );
+    void returnPressed(KPIM::MultiplyingLine *);
     /**
       Emitted when the down key is pressed
     */
-    void downPressed( KPIM::MultiplyingLine * );
+    void downPressed(KPIM::MultiplyingLine *);
     /**
       Emitted when the up key is pressed
     */
-    void upPressed( KPIM::MultiplyingLine * );
+    void upPressed(KPIM::MultiplyingLine *);
     /**
       Emitted when the right key is pressed
     */
@@ -198,26 +198,25 @@ class KDEPIM_EXPORT MultiplyingLine : public QWidget
     /**
       Should be emitted when the line should be deleted
       */
-    void deleteLine( KPIM::MultiplyingLine * );
+    void deleteLine(KPIM::MultiplyingLine *);
     /**
       Emitted when the completion mode changes
     */
-    void completionModeChanged( KGlobalSettings::Completion );
-  public slots:
+    void completionModeChanged(KCompletion::CompletionMode);
+public Q_SLOTS:
     void slotPropagateDeletion();
 
-  protected slots:
+protected Q_SLOTS:
     void slotReturnPressed();
     void slotFocusUp();
     void slotFocusDown();
 
-
-  protected:
+protected:
     /**
       Handles key press events on this line.
       Default behavior handles Up and Down presses.
     */
-    virtual void keyPressEvent( QKeyEvent * );
+    void keyPressEvent(QKeyEvent *) Q_DECL_OVERRIDE;
 };
 
 }
