@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+ * Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -26,28 +26,28 @@
  *  your version.
  */
 
-
 #include "selectedcollectiondialog.h"
 
-#include <KLocale>
-#include <KGlobal>
+#include <KLocalizedString>
 #include <KConfigGroup>
 
-#include <kabc/addressee.h>
+#include <kcontacts/addressee.h>
+#include <KSharedConfig>
 
-namespace KPIM {
+namespace KPIM
+{
 
 SelectedCollectionDialog::SelectedCollectionDialog(QWidget *parent)
-    : Akonadi::CollectionDialog (parent)
+    : Akonadi::CollectionDialog(parent)
 {
-    const QStringList mimeTypes( KABC::Addressee::mimeType() );
-    setMimeTypeFilter( mimeTypes );
-    setAccessRightsFilter( Akonadi::Collection::CanCreateItem );
-    setCaption( i18nc( "@title:window", "Select Address Book" ) );
+    const QStringList mimeTypes(KContacts::Addressee::mimeType());
+    setMimeTypeFilter(mimeTypes);
+    setAccessRightsFilter(Akonadi::Collection::CanCreateItem);
+    setCaption(i18nc("@title:window", "Select Address Book"));
     setDescription(
-                i18nc( "@info",
-                       "Select the address book where the contact will be saved:" ) );
-    changeCollectionDialogOptions( Akonadi::CollectionDialog::KeepTreeExpanded );
+        i18nc("@info",
+              "Select the address book where the contact will be saved:"));
+    changeCollectionDialogOptions(Akonadi::CollectionDialog::KeepTreeExpanded);
     readConfig();
 }
 
@@ -58,17 +58,17 @@ SelectedCollectionDialog::~SelectedCollectionDialog()
 
 void SelectedCollectionDialog::readConfig()
 {
-    KConfigGroup group( KGlobal::config(), "SelectedCollectionDialog" );
-    const QSize size = group.readEntry( "Size", QSize(600, 400) );
-    if ( size.isValid() ) {
-        resize( size );
+    KConfigGroup group(KSharedConfig::openConfig(), "SelectedCollectionDialog");
+    const QSize size = group.readEntry("Size", QSize(600, 400));
+    if (size.isValid()) {
+        resize(size);
     }
 }
 
 void SelectedCollectionDialog::writeConfig()
 {
-    KConfigGroup group( KGlobal::config(), "SelectedCollectionDialog" );
-    group.writeEntry( "Size", size() );
+    KConfigGroup group(KSharedConfig::openConfig(), "SelectedCollectionDialog");
+    group.writeEntry("Size", size());
     group.sync();
 }
 }
