@@ -40,52 +40,53 @@
 #include <gpgme++/encryptionresult.h>
 #include <gpgme++/key.h>
 
-namespace Kleo {
+namespace Kleo
+{
 
-  class QGpgMEEncryptJob
+class QGpgMEEncryptJob
 #ifdef Q_MOC_RUN
     : public EncryptJob
 #else
     : public _detail::ThreadedJobMixin<EncryptJob, boost::tuple<GpgME::EncryptionResult, QByteArray, QString, GpgME::Error> >
 #endif
-  {
+{
     Q_OBJECT
 #ifdef Q_MOC_RUN
-  public Q_SLOTS:
+public Q_SLOTS:
     void slotFinished();
 #endif
-  public:
-    explicit QGpgMEEncryptJob( GpgME::Context * context );
+public:
+    explicit QGpgMEEncryptJob(GpgME::Context *context);
     ~QGpgMEEncryptJob();
 
     /*! \reimp from EncryptJob */
-    GpgME::Error start( const std::vector<GpgME::Key> & recipients,
-                        const QByteArray & plainText, bool alwaysTrust );
+    GpgME::Error start(const std::vector<GpgME::Key> &recipients,
+                       const QByteArray &plainText, bool alwaysTrust);
 
     /*! \reimp from EncryptJob */
-    void start( const std::vector<GpgME::Key> & recipients,
-                const boost::shared_ptr<QIODevice> & plainText,
-                const boost::shared_ptr<QIODevice> & cipherText,
-                bool alwaysTrust );
+    void start(const std::vector<GpgME::Key> &recipients,
+               const boost::shared_ptr<QIODevice> &plainText,
+               const boost::shared_ptr<QIODevice> &cipherText,
+               bool alwaysTrust);
 
     /*! \reimp from EncryptJob */
-    GpgME::EncryptionResult exec( const std::vector<GpgME::Key> & recipients,
-                                  const QByteArray & plainText, bool alwaysTrust,
-                                  QByteArray & cipherText );
+    GpgME::EncryptionResult exec(const std::vector<GpgME::Key> &recipients,
+                                 const QByteArray &plainText, bool alwaysTrust,
+                                 QByteArray &cipherText);
 
     /*! \reimp from Job */
-    void showErrorDialog( QWidget * parent, const QString & caption ) const;
+    void showErrorDialog(QWidget *parent, const QString &caption) const;
 
     /*! \reimp from EncryptJob */
-    void setOutputIsBase64Encoded( bool on );
+    void setOutputIsBase64Encoded(bool on);
 
     /*! \reimp from ThreadedJobMixin */
-    void resultHook( const result_type & r );
+    void resultHook(const result_type &r);
 
-  private:
+private:
     bool mOutputIsBase64Encoded;
     GpgME::EncryptionResult mResult;
-  };
+};
 
 }
 
