@@ -31,36 +31,44 @@
 
 #include "libkleo/ui/keyselectiondialog.h"
 #include <gpgme++/key.h>
-#include <KApplication>
-#include <KComponentData>
-#include <kcmdlineargs.h>
-#include <kaboutdata.h>
-#include <kglobal.h>
+
+#include <KAboutData>
 #include <kiconloader.h>
-#include <kdebug.h>
+#include <QDebug>
 
 #include <vector>
+#include <QApplication>
+#include <KLocalizedString>
+#include <QCommandLineParser>
 
-int main( int argc, char ** argv ) {
-  KAboutData aboutData( "test_keyselectiondialog", 0, ki18n("KeySelectionDialog Test"), "0.1" );
-  KCmdLineArgs::init( argc, argv, &aboutData );
+int main(int argc, char **argv)
+{
+    QApplication app(argc, argv);
+    KAboutData aboutData(QLatin1String("test_keyselectiondialog"), i18n("KeySelectionDialog Test"), QStringLiteral("0.1"));
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(aboutData);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 
-  KApplication app;
-  KIconLoader::global()->addAppDir( "libkleopatra" );
-  KIconLoader::global()->addAppDir( "kdepim" );
+    KIconLoader::global()->addAppDir("libkleopatra");
+    KIconLoader::global()->addAppDir("kdepim");
 
-  Kleo::KeySelectionDialog dlg( "Kleo::KeySelectionDialog Test",
-                                "Please select a key:",
-                                std::vector<GpgME::Key>(),
-                                Kleo::KeySelectionDialog::AllKeys, true, true );
+    Kleo::KeySelectionDialog dlg("Kleo::KeySelectionDialog Test",
+                                 "Please select a key:",
+                                 std::vector<GpgME::Key>(),
+                                 Kleo::KeySelectionDialog::AllKeys, true, true);
 
-  if ( dlg.exec() == QDialog::Accepted ) {
-    kDebug(5150) <<"accepted; selected key:" << (dlg.selectedKey().userID(0).id() ? dlg.selectedKey().userID(0).id() :"<null>") <<"\nselected _keys_:";
-    for ( std::vector<GpgME::Key>::const_iterator it = dlg.selectedKeys().begin() ; it != dlg.selectedKeys().end() ; ++it )
-      kDebug(5150) << (it->userID(0).id() ? it->userID(0).id() :"<null>");
-  } else {
-    kDebug(5150) <<"rejected";
-  }
+    if (dlg.exec() == QDialog::Accepted) {
+        qDebug() << "accepted; selected key:" << (dlg.selectedKey().userID(0).id() ? dlg.selectedKey().userID(0).id() : "<null>") << "\nselected _keys_:";
+        for (std::vector<GpgME::Key>::const_iterator it = dlg.selectedKeys().begin() ; it != dlg.selectedKeys().end() ; ++it) {
+            qDebug() << (it->userID(0).id() ? it->userID(0).id() : "<null>");
+        }
+    } else {
+        qDebug() << "rejected";
+    }
 
-  return 0;
+    return 0;
 }
