@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -34,7 +34,7 @@ QString AutoCreateScriptUtil::createList(const QString &str, const QChar &separa
 {
     const QStringList list = str.trimmed().split(separator);
     const int count = list.count();
-    switch(count) {
+    switch (count) {
     case 0:
         return QString();
     case 1:
@@ -48,7 +48,7 @@ QString AutoCreateScriptUtil::createList(const QString &str, const QChar &separa
 
 QString AutoCreateScriptUtil::quoteStr(QString str)
 {
-    return str.replace(QLatin1String("\""), QLatin1String("\\\""));
+    return str.replace(QLatin1String("\""), QStringLiteral("\\\""));
 }
 
 QString AutoCreateScriptUtil::createList(const QStringList &lst, bool addSemiColon, bool protectSlash)
@@ -58,7 +58,7 @@ QString AutoCreateScriptUtil::createList(const QStringList &lst, bool addSemiCol
     bool wasFirst = true;
     Q_FOREACH (QString str, lst) {
         if (protectSlash) {
-            str = str.replace(QLatin1Char('\\'), QLatin1String("\\\\"));
+            str = str.replace(QLatin1Char('\\'), QStringLiteral("\\\\"));
         }
         result += (wasFirst ? QString() : QLatin1String(",")) + QString::fromLatin1(" \"%1\"").arg(quoteStr(str));
         wasFirst = false;
@@ -75,11 +75,11 @@ QStringList AutoCreateScriptUtil::createListFromString(QString str)
 {
     QStringList lst;
     if (str.startsWith(QLatin1Char('[')) && str.endsWith(QLatin1String("];"))) {
-        str.remove(0,1);
-        str.remove(str.length()-2, 2);
+        str.remove(0, 1);
+        str.remove(str.length() - 2, 2);
     } else if (str.startsWith(QLatin1Char('[')) && str.endsWith(QLatin1String("]"))) {
-        str.remove(0,1);
-        str.remove(str.length()-1, 1);
+        str.remove(0, 1);
+        str.remove(str.length() - 1, 1);
     } else {
         return lst;
     }
@@ -87,7 +87,7 @@ QStringList AutoCreateScriptUtil::createListFromString(QString str)
     QStringList resultLst;
     Q_FOREACH (QString s, lst) {
         s.remove(QLatin1String("\""));
-        resultLst<<s.trimmed();
+        resultLst << s.trimmed();
     }
     lst = resultLst;
     return lst;
@@ -95,12 +95,12 @@ QStringList AutoCreateScriptUtil::createListFromString(QString str)
 
 QString AutoCreateScriptUtil::createAddressList(const QString &str, bool addSemiColon)
 {
-    if (str.trimmed().startsWith(QLatin1Char('[')) && str.trimmed().endsWith(QLatin1Char(']')))
+    if (str.trimmed().startsWith(QLatin1Char('[')) && str.trimmed().endsWith(QLatin1Char(']'))) {
         return str;
+    }
     return createList(str, QLatin1Char(';'), addSemiColon);
 }
 
-
 QString AutoCreateScriptUtil::negativeString(bool isNegative)
 {
     return (isNegative ? QLatin1String("not ") : QString());
@@ -155,7 +155,7 @@ QStringList AutoCreateScriptUtil::listValue(const QDomElement &element)
 
 QString AutoCreateScriptUtil::fixListValue(QString valueStr)
 {
-    if (! (valueStr.startsWith(QLatin1Char('[')) && valueStr.endsWith(QLatin1Char(']')))) {
+    if (!(valueStr.startsWith(QLatin1Char('[')) && valueStr.endsWith(QLatin1Char(']')))) {
         valueStr = QString::fromLatin1("\"%1\"").arg(valueStr);
     }
 
