@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,12 +20,13 @@
 
 #include <QObject>
 class QDomElement;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveAction : public QObject
 {
     Q_OBJECT
 public:
-    SieveAction(const QString &name, const QString &label, QObject *parent = 0);
+    SieveAction(const QString &name, const QString &label, QObject *parent = Q_NULLPTR);
     virtual ~SieveAction();
 
     QString name() const;
@@ -36,11 +37,11 @@ public:
      */
     static SieveAction *newAction();
 
-    virtual QWidget *createParamWidget( QWidget *parent ) const;
+    virtual QWidget *createParamWidget(QWidget *parent) const;
 
-    virtual bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error );
+    virtual bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error);
 
-    virtual QString code( QWidget *) const;
+    virtual QString code(QWidget *) const;
 
     virtual QStringList needRequires(QWidget *parent) const;
 
