@@ -22,8 +22,7 @@
 
 #include <QHBoxLayout>
 #include <QDomNode>
-#include <QDebug>
-
+#include "libksieve_debug.h"
 
 using namespace KSieveUi;
 SieveActionAbstractFlags::SieveActionAbstractFlags(const QString &name, const QString &label, QObject *parent)
@@ -31,20 +30,20 @@ SieveActionAbstractFlags::SieveActionAbstractFlags(const QString &name, const QS
 {
 }
 
-QWidget *SieveActionAbstractFlags::createParamWidget( QWidget *parent ) const
+QWidget *SieveActionAbstractFlags::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QHBoxLayout *lay = new QHBoxLayout;
     lay->setMargin(0);
     w->setLayout(lay);
     SelectFlagsWidget *flagsWidget = new SelectFlagsWidget;
-    connect(flagsWidget, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
-    flagsWidget->setObjectName(QLatin1String("flagswidget"));
+    connect(flagsWidget, &SelectFlagsWidget::valueChanged, this, &SieveActionAbstractFlags::valueChanged);
+    flagsWidget->setObjectName(QStringLiteral("flagswidget"));
     lay->addWidget(flagsWidget);
     return w;
 }
 
-bool SieveActionAbstractFlags::setParamWidgetValue( const QDomElement &element, QWidget *w, QString &error )
+bool SieveActionAbstractFlags::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
 {
     QDomNode node = element.firstChild();
     while (!node.isNull()) {
@@ -52,18 +51,18 @@ bool SieveActionAbstractFlags::setParamWidgetValue( const QDomElement &element,
         if (!e.isNull()) {
             const QString tagName = e.tagName();
             if (tagName == QLatin1String("list")) {
-                SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget*>( QLatin1String("flagswidget") );
+                SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
                 flagsWidget->setFlags(AutoCreateScriptUtil::listValue(e));
             } else if (tagName == QLatin1String("str")) {
-                SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget*>( QLatin1String("flagswidget") );
-                flagsWidget->setFlags(QStringList()<<e.text());
+                SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget *>(QStringLiteral("flagswidget"));
+                flagsWidget->setFlags(QStringList() << e.text());
             } else if (tagName == QLatin1String("crlf")) {
                 //nothing
             } else if (tagName == QLatin1String("comment")) {
                 //implement in the future ?
             } else {
                 unknownTag(tagName, error);
-                qDebug()<<" SieveActionAbstractFlags::setParamWidgetValue unknown tag :"<<tagName;
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionAbstractFlags::setParamWidgetValue unknown tag :" << tagName;
             }
         }
         node = node.nextSibling();
@@ -73,7 +72,7 @@ bool SieveActionAbstractFlags::setParamWidgetValue( const QDomElement &element,
 
 QString SieveActionAbstractFlags::code(QWidget *w) const
 {
-    const SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget*>( QLatin1String("flagswidget") );
+    const SelectFlagsWidget *flagsWidget = w->findChild<SelectFlagsWidget *>(QLatin1String("flagswidget"));
     const QString flagCode = flagsWidget->code();
     const QString str = flagsCode();
     return str + QLatin1Char(' ') + (flagCode.isEmpty() ? QLatin1String(";") : flagCode);
@@ -81,10 +80,11 @@ QString SieveActionAbstractFlags::code(QWidget *w) const
 
 QStringList SieveActionAbstractFlags::needRequires(QWidget *) const
 {
-    if (SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QLatin1String("imap4flags")))
-        return QStringList() << QLatin1String("imap4flags");
-    else
-        return QStringList() << QLatin1String("imapflags");
+    if (SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("imap4flags"))) {
+        return QStringList() << QStringLiteral("imap4flags");
+    } else {
+        return QStringList() << QStringLiteral("imapflags");
+    }
 }
 
 bool SieveActionAbstractFlags::needCheckIfServerHasCapability() const
@@ -94,9 +94,10 @@ bool SieveActionAbstractFlags::needCheckIfServerHasCapability() const
 
 QString SieveActionAbstractFlags::serverNeedsCapability() const
 {
-    if (SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QLatin1String("imap4flags")))
-        return QLatin1String("imap4flags");
-    else
-        return QLatin1String("imapflags");
+    if (SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("imap4flags"))) {
+        return QStringLiteral("imap4flags");
+    } else {
+        return QStringLiteral("imapflags");
+    }
 }
 
