@@ -19,18 +19,19 @@
 #define SIEVEACTIONADDHEADER_H
 
 #include "sieveactionabstracteditheader.h"
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionAddHeader : public SieveActionAbstractEditHeader
 {
     Q_OBJECT
 public:
-    SieveActionAddHeader(QObject *parent = 0);
-    static SieveAction* newAction();
-    QString code(QWidget *w) const;
-    QWidget *createParamWidget( QWidget *parent ) const;
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error );
-    QString help() const;
-    QString href() const;
+    explicit SieveActionAddHeader(QObject *parent = Q_NULLPTR);
+    static SieveAction *newAction();
+    QString code(QWidget *w) const Q_DECL_OVERRIDE;
+    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
+    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error) Q_DECL_OVERRIDE;
+    QString help() const Q_DECL_OVERRIDE;
+    QString href() const Q_DECL_OVERRIDE;
 };
 }
 
