@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,18 +19,19 @@
 #define SIEVEACTIONDELETEHEADER_H
 
 #include "sieveactionabstracteditheader.h"
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionDeleteHeader : public SieveActionAbstractEditHeader
 {
     Q_OBJECT
 public:
-    SieveActionDeleteHeader(QObject *parent = 0);
-    static SieveAction* newAction();
-    QString code(QWidget *w) const;
-    QWidget *createParamWidget( QWidget *parent ) const;
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error );
-    QString help() const;
-    QString href() const;
+    explicit SieveActionDeleteHeader(QObject *parent = Q_NULLPTR);
+    static SieveAction *newAction();
+    QString code(QWidget *w) const Q_DECL_OVERRIDE;
+    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
+    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error) Q_DECL_OVERRIDE;
+    QString help() const Q_DECL_OVERRIDE;
+    QString href() const Q_DECL_OVERRIDE;
 };
 }
 
