@@ -21,18 +21,18 @@
 
 using namespace KSieveUi;
 SieveActionDiscard::SieveActionDiscard(QObject *parent)
-    : SieveAction(QLatin1String("discard"), i18n("Discard"), parent)
+    : SieveAction(QStringLiteral("discard"), i18n("Discard"), parent)
 {
 }
 
-SieveAction* SieveActionDiscard::newAction()
+SieveAction *SieveActionDiscard::newAction()
 {
     return new SieveActionDiscard;
 }
 
 QString SieveActionDiscard::code(QWidget *) const
 {
-    return QLatin1String("discard;");
+    return QStringLiteral("discard;");
 }
 
 QString SieveActionDiscard::help() const
