@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,16 +19,17 @@
 #define SIEVEACTIONDISCARD_H
 
 #include "sieveaction.h"
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionDiscard : public SieveAction
 {
     Q_OBJECT
 public:
-    SieveActionDiscard(QObject *parent = 0);
-    static SieveAction* newAction();
-    QString code(QWidget *) const;
-    QString help() const;
-    QString href() const;
+    explicit SieveActionDiscard(QObject *parent = Q_NULLPTR);
+    static SieveAction *newAction();
+    QString code(QWidget *) const Q_DECL_OVERRIDE;
+    QString help() const Q_DECL_OVERRIDE;
+    QString href() const Q_DECL_OVERRIDE;
 };
 }
 
