@@ -19,21 +19,22 @@
 #define SIEVEACTIONENCLOSE_H
 #include "sieveaction.h"
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveActionEnclose : public SieveAction
 {
     Q_OBJECT
 public:
-    SieveActionEnclose(QObject *parent = 0);
-    static SieveAction* newAction();
-    QString code(QWidget *) const;
-    QWidget *createParamWidget( QWidget *parent ) const;
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error );
-    QStringList needRequires(QWidget *parent) const;
-    bool needCheckIfServerHasCapability() const;
-    QString serverNeedsCapability() const;
-    QString help() const;
-    QString href() const;
+    explicit SieveActionEnclose(QObject *parent = Q_NULLPTR);
+    static SieveAction *newAction();
+    QString code(QWidget *) const Q_DECL_OVERRIDE;
+    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
+    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, QString &error) Q_DECL_OVERRIDE;
+    QStringList needRequires(QWidget *parent) const Q_DECL_OVERRIDE;
+    bool needCheckIfServerHasCapability() const Q_DECL_OVERRIDE;
+    QString serverNeedsCapability() const Q_DECL_OVERRIDE;
+    QString help() const Q_DECL_OVERRIDE;
+    QString href() const Q_DECL_OVERRIDE;
 };
 }
 
