@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,31 +15,30 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #include "sieveactionextracttext.h"
 #include "editor/sieveeditorutil.h"
 
 #include <KLocalizedString>
-#include <KLineEdit>
+#include <QLineEdit>
 
 #include <QLabel>
 #include <QSpinBox>
 #include <QDomNode>
-#include <QDebug>
+#include "libksieve_debug.h"
 #include <QGridLayout>
 
 using namespace KSieveUi;
 SieveActionExtractText::SieveActionExtractText(QObject *parent)
-    : SieveAction(QLatin1String("extracttext"), i18n("Extract Text"), parent)
+    : SieveAction(QStringLiteral("extracttext"), i18n("Extract Text"), parent)
 {
 }
 
-SieveAction* SieveActionExtractText::newAction()
+SieveAction *SieveActionExtractText::newAction()
 {
     return new SieveActionExtractText;
 }
 
-QWidget *SieveActionExtractText::createParamWidget( QWidget *parent ) const
+QWidget *SieveActionExtractText::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QGridLayout *grid = new QGridLayout;
@@ -52,16 +51,16 @@ QWidget *SieveActionExtractText::createParamWidget( QWidget *parent ) const
     QSpinBox *nbCharacters = new QSpinBox;
     nbCharacters->setMinimum(1);
     nbCharacters->setMaximum(99999);
-    nbCharacters->setObjectName(QLatin1String("numberOfCharacters"));
+    nbCharacters->setObjectName(QStringLiteral("numberOfCharacters"));
     grid->addWidget(nbCharacters, 0, 1);
-    connect(nbCharacters, SIGNAL(valueChanged(int)), this, SIGNAL(valueChanged()));
+    connect(nbCharacters, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SieveActionExtractText::valueChanged);
 
     lab = new QLabel(i18n("Stored in variable name:"));
     grid->addWidget(lab, 1, 0);
 
-    KLineEdit *variableName = new KLineEdit;
-    connect(variableName, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
-    variableName->setObjectName(QLatin1String("variablename"));
+    QLineEdit *variableName = new QLineEdit;
+    connect(variableName, &QLineEdit::textChanged, this, &SieveActionExtractText::valueChanged);
+    variableName->setObjectName(QStringLiteral("variablename"));
     grid->addWidget(variableName, 1, 1);
 
     return w;
@@ -77,10 +76,10 @@ bool SieveActionExtractText::setParamWidgetValue(const QDomElement &element, QWi
             if (tagName == QLatin1String("tag")) {
                 //TODO ?
             } else if (tagName == QLatin1String("num")) {
-                QSpinBox *numberOfCharacters = w->findChild<QSpinBox*>(QLatin1String("numberOfCharacters"));
+                QSpinBox *numberOfCharacters = w->findChild<QSpinBox *>(QLatin1String("numberOfCharacters"));
                 numberOfCharacters->setValue(e.text().toInt());
             } else if (tagName == QLatin1String("str")) {
-                KLineEdit *variableName = w->findChild<KLineEdit*>(QLatin1String("variablename"));
+                QLineEdit *variableName = w->findChild<QLineEdit *>(QLatin1String("variablename"));
                 variableName->setText(e.text());
             } else if (tagName == QLatin1String("crlf")) {
                 //nothing
@@ -88,7 +87,7 @@ bool SieveActionExtractText::setParamWidgetValue(const QDomElement &element, QWi
                 //implement in the future ?
             } else {
                 unknownTag(tagName, error);
-                qDebug()<<" SieveActionExtractText::setParamWidgetValue unknown tagName "<<tagName;
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionExtractText::setParamWidgetValue unknown tagName " << tagName;
             }
         }
         node = node.nextSibling();
@@ -98,20 +97,19 @@ bool SieveActionExtractText::setParamWidgetValue(const QDomElement &element, QWi
 
 QString SieveActionExtractText::code(QWidget *w) const
 {
-    const QSpinBox *numberOfCharacters = w->findChild<QSpinBox*>(QLatin1String("numberOfCharacters"));
+    const QSpinBox *numberOfCharacters = w->findChild<QSpinBox *>(QLatin1String("numberOfCharacters"));
     const QString numberOfCharactersStr = QString::number(numberOfCharacters->value());
 
-    const KLineEdit *variableName = w->findChild<KLineEdit*>(QLatin1String("variablename"));
+    const QLineEdit *variableName = w->findChild<QLineEdit *>(QLatin1String("variablename"));
     const QString variableNameStr = variableName->text();
 
-    const QString result = QString::fromLatin1("extracttext :first %1 \"%2\";").arg(numberOfCharactersStr).arg(variableNameStr);
+    const QString result = QStringLiteral("extracttext :first %1 \"%2\";").arg(numberOfCharactersStr).arg(variableNameStr);
     return result;
 }
 
-
 QStringList SieveActionExtractText::needRequires(QWidget *parent) const
 {
-    return QStringList() << QLatin1String("extracttext");
+    return QStringList() << QStringLiteral("extracttext");
 }
 
 bool SieveActionExtractText::needCheckIfServerHasCapability() const
@@ -121,7 +119,7 @@ bool SieveActionExtractText::needCheckIfServerHasCapability() const
 
 QString SieveActionExtractText::serverNeedsCapability() const
 {
-    return QLatin1String("extracttext");
+    return QStringLiteral("extracttext");
 }
 
 QString SieveActionExtractText::help() const
