@@ -15,20 +15,18 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #include "sieveactionnotify.h"
 #include "editor/sieveeditorutil.h"
 #include "widgets/selectimportancecombobox.h"
 #include "autocreatescripts/autocreatescriptutil_p.h"
 
 #include <KLocalizedString>
-#include <KLineEdit>
-
+#include <QLineEdit>
 
 #include <QHBoxLayout>
 #include <QLabel>
 #include <QDomNode>
-#include <QDebug>
+#include "libksieve_debug.h"
 
 using namespace KSieveUi;
 
@@ -37,12 +35,12 @@ SieveActionNotify::SieveActionNotify(QObject *parent)
 {
 }
 
-SieveAction* SieveActionNotify::newAction()
+SieveAction *SieveActionNotify::newAction()
 {
     return new SieveActionNotify;
 }
 
-QWidget *SieveActionNotify::createParamWidget( QWidget *parent ) const
+QWidget *SieveActionNotify::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QHBoxLayout *lay = new QHBoxLayout;
@@ -50,31 +48,30 @@ QWidget *SieveActionNotify::createParamWidget( QWidget *parent ) const
     w->setLayout(lay);
 
     SelectImportanceCombobox *importanceCombobox = new SelectImportanceCombobox;
-    importanceCombobox->setObjectName(QLatin1String("importancecombo"));
-    connect(importanceCombobox, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
+    importanceCombobox->setObjectName(QStringLiteral("importancecombo"));
+    connect(importanceCombobox, &SelectImportanceCombobox::valueChanged, this, &SieveActionNotify::valueChanged);
     lay->addWidget(importanceCombobox);
 
     QLabel *lab = new QLabel(i18n("message:"));
     lay->addWidget(lab);
 
-    KLineEdit *message = new KLineEdit;
-    message->setObjectName(QLatin1String("message"));
-    connect(message, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
+    QLineEdit *message = new QLineEdit;
+    message->setObjectName(QStringLiteral("message"));
+    connect(message, &QLineEdit::textChanged, this, &SieveActionNotify::valueChanged);
     lay->addWidget(message);
 
     lab = new QLabel(i18n("method:"));
     lay->addWidget(lab);
 
-    KLineEdit *method = new KLineEdit;
-    method->setObjectName(QLatin1String("method"));
+    QLineEdit *method = new QLineEdit;
+    method->setObjectName(QStringLiteral("method"));
     lay->addWidget(method);
-    connect(method, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
-
+    connect(method, &QLineEdit::textChanged, this, &SieveActionNotify::valueChanged);
 
     return w;
 }
 
-bool SieveActionNotify::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error )
+bool SieveActionNotify::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
 {
     QDomNode node = element.firstChild();
     while (!node.isNull()) {
@@ -86,29 +83,29 @@ bool SieveActionNotify::setParamWidgetValue(const QDomElement &element, QWidget
                 if (tagValue == QLatin1String("message")) {
                     const QString strValue = AutoCreateScriptUtil::strValue(node);
                     if (!strValue.isEmpty()) {
-                        KLineEdit *message = w->findChild<KLineEdit*>( QLatin1String("message") );
+                        QLineEdit *message = w->findChild<QLineEdit *>(QLatin1String("message"));
                         message->setText(AutoCreateScriptUtil::quoteStr(strValue));
                     }
                 } else if (tagValue == QLatin1String("importance")) {
                     const QString strValue = AutoCreateScriptUtil::strValue(node);
                     if (!strValue.isEmpty()) {
-                        SelectImportanceCombobox *importance = w->findChild<SelectImportanceCombobox*>( QLatin1String("importancecombo") );
+                        SelectImportanceCombobox *importance = w->findChild<SelectImportanceCombobox *>(QLatin1String("importancecombo"));
                         importance->setCode(strValue, name(), error);
                     }
                 } else {
                     unknowTagValue(tagValue, error);
-                    qDebug()<<" SieveActionNotify::setParamWidgetValue unknown tagValue"<<tagValue;
+                    qCDebug(LIBKSIEVE_LOG) << " SieveActionNotify::setParamWidgetValue unknown tagValue" << tagValue;
                 }
             } else if (tagName == QLatin1String("crlf")) {
                 //nothing
             } else if (tagName == QLatin1String("comment")) {
                 //implement in the future ?
             } else if (tagName == QLatin1String("str")) {
-                KLineEdit *method = w->findChild<KLineEdit*>( QLatin1String("method") );
+                QLineEdit *method = w->findChild<QLineEdit *>(QLatin1String("method"));
                 method->setText(AutoCreateScriptUtil::quoteStr(e.text()));
             } else {
                 unknownTag(tagName, error);
-                qDebug()<<" SieveActionNotify::setParamWidgetValue unknown tagName "<<tagName;
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionNotify::setParamWidgetValue unknown tagName " << tagName;
             }
         }
         node = node.nextSibling();
@@ -119,19 +116,19 @@ bool SieveActionNotify::setParamWidgetValue(const QDomElement &element, QWidget
 QString SieveActionNotify::code(QWidget *w) const
 {
     QString result = QLatin1String("notify");
-    const SelectImportanceCombobox *importance = w->findChild<SelectImportanceCombobox*>( QLatin1String("importancecombo") );
+    const SelectImportanceCombobox *importance = w->findChild<SelectImportanceCombobox *>(QLatin1String("importancecombo"));
     const QString importanceStr = importance->code();
     if (!importanceStr.isEmpty()) {
         result += QString::fromLatin1(" :importance \"%1\"").arg(importanceStr);
     }
 
-    const KLineEdit *message = w->findChild<KLineEdit*>( QLatin1String("message") );
+    const QLineEdit *message = w->findChild<QLineEdit *>(QLatin1String("message"));
     const QString messageStr = message->text();
     if (!messageStr.isEmpty()) {
         result += QString::fromLatin1(" :message \"%2\"").arg(messageStr);
     }
 
-    const KLineEdit *method = w->findChild<KLineEdit*>( QLatin1String("method") );
+    const QLineEdit *method = w->findChild<QLineEdit *>(QLatin1String("method"));
     const QString methodStr = method->text();
     result += QString::fromLatin1(" \"%3\";").arg(methodStr);
 
@@ -140,7 +137,7 @@ QString SieveActionNotify::code(QWidget *w) const
 
 QString SieveActionNotify::serverNeedsCapability() const
 {
-    return QLatin1String("enotify");
+    return QStringLiteral("enotify");
 }
 
 bool SieveActionNotify::needCheckIfServerHasCapability() const
@@ -156,7 +153,7 @@ QString SieveActionNotify::help() const
 QStringList SieveActionNotify::needRequires(QWidget *) const
 {
     QStringList lst;
-    lst << QLatin1String("enotify");
+    lst << QStringLiteral("enotify");
     return lst;
 }
 
