@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -23,18 +23,18 @@
 
 using namespace KSieveUi;
 SieveActionRemoveFlags::SieveActionRemoveFlags(QObject *parent)
-    : SieveActionAbstractFlags(QLatin1String("removeflag"), i18n("Remove Flags"), parent)
+    : SieveActionAbstractFlags(QStringLiteral("removeflag"), i18n("Remove Flags"), parent)
 {
 }
 
-SieveAction* SieveActionRemoveFlags::newAction()
+SieveAction *SieveActionRemoveFlags::newAction()
 {
     return new SieveActionRemoveFlags;
 }
 
 QString SieveActionRemoveFlags::flagsCode() const
 {
-    return QString::fromLatin1("removeflag");
+    return QStringLiteral("removeflag");
 }
 
 QString SieveActionRemoveFlags::help() const
