@@ -23,18 +23,18 @@
 using namespace KSieveUi;
 
 SieveActionStop::SieveActionStop(QObject *parent)
-    : SieveAction(QLatin1String("stop"), i18n("Stop"), parent)
+    : SieveAction(QStringLiteral("stop"), i18n("Stop"), parent)
 {
 }
 
-SieveAction* SieveActionStop::newAction()
+SieveAction *SieveActionStop::newAction()
 {
     return new SieveActionStop;
 }
 
 QString SieveActionStop::code(QWidget *) const
 {
-    return QLatin1String("stop;");
+    return QStringLiteral("stop;");
 }
 
 QString SieveActionStop::help() const
