@@ -15,7 +15,6 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #include "sieveactionvacation.h"
 #include "editor/sieveeditorutil.h"
 #include "autocreatescripts/sieveeditorgraphicalmodewidget.h"
@@ -23,13 +22,12 @@
 #include "widgets/multilineedit.h"
 #include "widgets/selectvacationcombobox.h"
 
-
 #include <KLocalizedString>
-#include <KLineEdit>
+#include <QLineEdit>
 
 #include <QLabel>
 #include <QSpinBox>
-#include <QDebug>
+#include "libksieve_debug.h"
 #include <QDomNode>
 #include <QGridLayout>
 
@@ -38,70 +36,67 @@ using namespace KSieveUi;
 SieveActionVacation::SieveActionVacation(QObject *parent)
     : SieveAction(QLatin1String("vacation"), i18n("Vacation"), parent)
 {
-    mHasVacationSecondsSupport = SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QLatin1String("vacation-seconds"));
+    mHasVacationSecondsSupport = SieveEditorGraphicalModeWidget::sieveCapabilities().contains(QStringLiteral("vacation-seconds"));
 }
 
-SieveAction* SieveActionVacation::newAction()
+SieveAction *SieveActionVacation::newAction()
 {
     return new SieveActionVacation;
 }
 
-QWidget *SieveActionVacation::createParamWidget( QWidget *parent ) const
+QWidget *SieveActionVacation::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QGridLayout *grid = new QGridLayout;
     grid->setMargin(0);
     w->setLayout(grid);
 
-    QLabel *lab = 0;
+    QLabel *lab = Q_NULLPTR;
     if (mHasVacationSecondsSupport) {
         SelectVacationComboBox *vacation = new SelectVacationComboBox;
-        vacation->setObjectName(QLatin1String("vacationcombobox"));
-        connect(vacation, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
-        grid->addWidget(vacation, 0 ,0);
+        vacation->setObjectName(QStringLiteral("vacationcombobox"));
+        connect(vacation, &SelectVacationComboBox::valueChanged, this, &SieveActionVacation::valueChanged);
+        grid->addWidget(vacation, 0 , 0);
     } else {
         lab = new QLabel(i18n("day:"));
-        grid->addWidget(lab, 0 ,0);
+        grid->addWidget(lab, 0 , 0);
     }
 
-
     QSpinBox *day = new QSpinBox;
     day->setMinimum(1);
     day->setMaximum(999);
-    day->setObjectName(QLatin1String("day"));
-    connect(day, SIGNAL(valueChanged(int)), this, SIGNAL(valueChanged()));
-    grid->addWidget(day, 0 ,1);
-
+    day->setObjectName(QStringLiteral("day"));
+    connect(day, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &SieveActionVacation::valueChanged);
+    grid->addWidget(day, 0 , 1);
 
     lab = new QLabel(i18n("Message subject:"));
-    grid->addWidget(lab, 1 ,0);
+    grid->addWidget(lab, 1 , 0);
 
-    KLineEdit *subject = new KLineEdit;
-    subject->setObjectName(QLatin1String("subject"));
-    connect(subject, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
-    grid->addWidget(subject, 1 ,1);
+    QLineEdit *subject = new QLineEdit;
+    subject->setObjectName(QStringLiteral("subject"));
+    connect(subject, &QLineEdit::textChanged, this, &SieveActionVacation::valueChanged);
+    grid->addWidget(subject, 1 , 1);
 
     lab = new QLabel(i18n("Additional email:"));
-    grid->addWidget(lab, 2 ,0);
-
-    KLineEdit *addresses = new KLineEdit;
-    addresses->setObjectName(QLatin1String("addresses"));
-    connect(addresses, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
-    grid->addWidget(addresses, 2 ,1);
+    grid->addWidget(lab, 2 , 0);
 
+    QLineEdit *addresses = new QLineEdit;
+    addresses->setObjectName(QStringLiteral("addresses"));
+    connect(addresses, &QLineEdit::textChanged, this, &SieveActionVacation::valueChanged);
+    grid->addWidget(addresses, 2 , 1);
 
     lab = new QLabel(i18n("Vacation reason:"));
-    grid->addWidget(lab, 3 ,0);
+    grid->addWidget(lab, 3 , 0);
 
     MultiLineEdit *text = new MultiLineEdit;
-    connect(text, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
-    text->setObjectName(QLatin1String("text"));
-    grid->addWidget(text, 3 ,1);
+    connect(text, &MultiLineEdit::valueChanged, this, &SieveActionVacation::valueChanged);
+    text->setObjectName(QStringLiteral("text"));
+    grid->addWidget(text, 3 , 1);
 
     return w;
 }
 
-bool SieveActionVacation::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error )
+bool SieveActionVacation::setParamWidgetValue(const QDomElement &element, QWidget *w, QString &error)
 {
     QDomNode node = element.firstChild();
     while (!node.isNull()) {
@@ -112,7 +107,7 @@ bool SieveActionVacation::setParamWidgetValue(const QDomElement &element, QWidge
                 const QString tagValue = e.text();
                 if (tagValue == QLatin1String("seconds")) {
                     if (mHasVacationSecondsSupport) {
-                        SelectVacationComboBox *vacationcombobox = w->findChild<SelectVacationComboBox*>(QLatin1String("vacationcombobox"));
+                        SelectVacationComboBox *vacationcombobox = w->findChild<SelectVacationComboBox *>(QLatin1String("vacationcombobox"));
                         vacationcombobox->setCode(AutoCreateScriptUtil::tagValue(tagValue), name(), error);
                     } else {
                         serverDoesNotSupportFeatures(QLatin1String("seconds"), error);
@@ -120,23 +115,23 @@ bool SieveActionVacation::setParamWidgetValue(const QDomElement &element, QWidge
                 } else if (tagValue == QLatin1String("days")) {
                     //Nothing wait num tag for it.
                 } else if (tagValue == QLatin1String("addresses")) {
-                    KLineEdit *addresses = w->findChild<KLineEdit*>( QLatin1String("addresses") );
+                    QLineEdit *addresses = w->findChild<QLineEdit *>(QLatin1String("addresses"));
                     addresses->setText(AutoCreateScriptUtil::strValue(e));
                 } else if (tagValue == QLatin1String("subject")) {
-                    KLineEdit *subject = w->findChild<KLineEdit*>( QLatin1String("subject") );
+                    QLineEdit *subject = w->findChild<QLineEdit *>(QLatin1String("subject"));
                     subject->setText(AutoCreateScriptUtil::strValue(e));
                 } else {
                     unknowTagValue(tagValue, error);
-                    qDebug()<<"SieveActionVacation::setParamWidgetValue unknown tagValue :"<<tagValue;
+                    qCDebug(LIBKSIEVE_LOG) << "SieveActionVacation::setParamWidgetValue unknown tagValue :" << tagValue;
                 }
             } else if (tagName == QLatin1String("num"))  {
-                QSpinBox *day = w->findChild<QSpinBox*>( QLatin1String("day") );
+                QSpinBox *day = w->findChild<QSpinBox *>(QLatin1String("day"));
                 day->setValue(e.text().toInt());
             } else if (tagName == QLatin1String("str")) {
-                MultiLineEdit *text = w->findChild<MultiLineEdit*>( QLatin1String("text") );
-                text->setText(e.text());
+                MultiLineEdit *text = w->findChild<MultiLineEdit *>(QLatin1String("text"));
+                text->setPlainText(e.text());
             } else if (tagName == QLatin1String("list")) {
-                KLineEdit *addresses = w->findChild<KLineEdit*>( QLatin1String("addresses") );
+                QLineEdit *addresses = w->findChild<QLineEdit *>(QLatin1String("addresses"));
                 addresses->setText(AutoCreateScriptUtil::listValueToStr(e));
             } else if (tagName == QLatin1String("crlf")) {
                 //nothing
@@ -144,7 +139,7 @@ bool SieveActionVacation::setParamWidgetValue(const QDomElement &element, QWidge
                 //implement in the future ?
             } else {
                 unknownTag(tagName, error);
-                qDebug()<<" SieveActionVacation::setParamWidgetValue unknown tagName "<<tagName;
+                qCDebug(LIBKSIEVE_LOG) << " SieveActionVacation::setParamWidgetValue unknown tagName " << tagName;
             }
         }
         node = node.nextSibling();
@@ -157,37 +152,41 @@ QString SieveActionVacation::code(QWidget *w) const
 {
     QString vacationTypeStr = QLatin1String(":days");
     if (mHasVacationSecondsSupport) {
-        const SelectVacationComboBox *vacationcombobox = w->findChild<SelectVacationComboBox*>(QLatin1String("vacationcombobox"));
+        const SelectVacationComboBox *vacationcombobox = w->findChild<SelectVacationComboBox *>(QLatin1String("vacationcombobox"));
         vacationTypeStr = vacationcombobox->code();
     }
-    const QSpinBox *day = w->findChild<QSpinBox*>( QLatin1String("day") );
+    const QSpinBox *day = w->findChild<QSpinBox *>(QLatin1String("day"));
     const QString dayStr = QString::number(day->value());
 
-    const MultiLineEdit *text = w->findChild<MultiLineEdit*>( QLatin1String("text") );
+    const MultiLineEdit *text = w->findChild<MultiLineEdit *>(QLatin1String("text"));
     const QString textStr = text->toPlainText();
 
-    const KLineEdit *subject = w->findChild<KLineEdit*>( QLatin1String("subject") );
+    const QLineEdit *subject = w->findChild<QLineEdit *>(QLatin1String("subject"));
     const QString subjectStr = subject->text();
 
-    const KLineEdit *addresses = w->findChild<KLineEdit*>( QLatin1String("addresses") );
+    const QLineEdit *addresses = w->findChild<QLineEdit *>(QLatin1String("addresses"));
     const QString addressesStr = addresses->text();
-    QString result = QString::fromLatin1("vacation");
-    if (!dayStr.isEmpty())
+    QString result = QStringLiteral("vacation");
+    if (!dayStr.isEmpty()) {
         result += QString::fromLatin1(" %1 %2").arg(vacationTypeStr).arg(dayStr);
-    if (!subjectStr.isEmpty())
+    }
+    if (!subjectStr.isEmpty()) {
         result += QString::fromLatin1(" :subject \"%1\"").arg(subjectStr);
-    if (!addressesStr.isEmpty())
+    }
+    if (!addressesStr.isEmpty()) {
         result += QString::fromLatin1(" :addresses %1").arg(AutoCreateScriptUtil::createAddressList(addressesStr, false));
-    if (!textStr.isEmpty())
+    }
+    if (!textStr.isEmpty()) {
         result += QString::fromLatin1(" text:%1").arg(AutoCreateScriptUtil::createMultiLine(textStr));
-    else
-        result += QLatin1Char(';'); //Be sure to have ";"
+    } else {
+        result += QLatin1Char(';');    //Be sure to have ";"
+    }
     return result;
 }
 
 QString SieveActionVacation::serverNeedsCapability() const
 {
-    return QLatin1String("vacation");
+    return QStringLiteral("vacation");
 }
 
 bool SieveActionVacation::needCheckIfServerHasCapability() const
@@ -199,9 +198,9 @@ QStringList SieveActionVacation::needRequires(QWidget *) const
 {
     QStringList lst;
     if (mHasVacationSecondsSupport) {
-        lst << QLatin1String("vacation-seconds");
+        lst << QStringLiteral("vacation-seconds");
     }
-    lst << QLatin1String("vacation");
+    lst << QStringLiteral("vacation");
     return lst;
 }
 
