@@ -20,24 +20,25 @@
 
 #include "sievecondition.h"
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveConditionAddress : public SieveCondition
 {
     Q_OBJECT
 public:
-    SieveConditionAddress(QObject *parent = 0);
+    explicit SieveConditionAddress(QObject *parent = Q_NULLPTR);
 
     static SieveCondition *newAction();
 
-    QWidget *createParamWidget( QWidget *parent ) const;
+    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
 
-    QString code(QWidget *w) const;
+    QString code(QWidget *w) const Q_DECL_OVERRIDE;
 
-    QStringList needRequires(QWidget *parent) const;
+    QStringList needRequires(QWidget *parent) const Q_DECL_OVERRIDE;
 
-    QString help() const;
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, bool notCondition, QString &error );
-    QString href() const;
+    QString help() const Q_DECL_OVERRIDE;
+    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, bool notCondition, QString &error) Q_DECL_OVERRIDE;
+    QString href() const Q_DECL_OVERRIDE;
 };
 }
 
