@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,12 +24,12 @@
 
 #include <QLabel>
 #include <QDomNode>
-#include <QDebug>
+#include "libksieve_debug.h"
 #include <QGridLayout>
 
 using namespace KSieveUi;
 SieveConditionConvert::SieveConditionConvert(QObject *parent)
-    : SieveCondition(QLatin1String("convert"), i18n("Convert"), parent)
+    : SieveCondition(QStringLiteral("convert"), i18n("Convert"), parent)
 {
 }
 
@@ -38,7 +38,7 @@ SieveCondition *SieveConditionConvert::newAction()
     return new SieveConditionConvert;
 }
 
-QWidget *SieveConditionConvert::createParamWidget( QWidget *parent ) const
+QWidget *SieveConditionConvert::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QGridLayout *lay = new QGridLayout;
@@ -49,40 +49,40 @@ QWidget *SieveConditionConvert::createParamWidget( QWidget *parent ) const
     lay->addWidget(lab, 0, 0);
 
     SelectMimeTypeComboBox *fromMimeType = new SelectMimeTypeComboBox;
-    fromMimeType->setObjectName(QLatin1String("from"));
-    connect(fromMimeType, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
+    fromMimeType->setObjectName(QStringLiteral("from"));
+    connect(fromMimeType, &SelectMimeTypeComboBox::valueChanged, this, &SieveConditionConvert::valueChanged);
     lay->addWidget(fromMimeType, 0, 1);
 
     lab = new QLabel(i18n("To:"));
     lay->addWidget(lab, 0, 2);
 
     SelectMimeTypeComboBox *toMimeType = new SelectMimeTypeComboBox;
-    connect(toMimeType, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
-    toMimeType->setObjectName(QLatin1String("to"));
+    connect(toMimeType, &SelectMimeTypeComboBox::valueChanged, this, &SieveConditionConvert::valueChanged);
+    toMimeType->setObjectName(QStringLiteral("to"));
     lay->addWidget(toMimeType, 0, 3);
 
     lab = new QLabel(i18n("Parameters:"));
     lay->addWidget(lab, 1, 0);
 
     SelectConvertParameterWidget *params = new SelectConvertParameterWidget;
-    connect(params, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
-    params->setObjectName(QLatin1String("params"));
+    connect(params, &SelectConvertParameterWidget::valueChanged, this, &SieveConditionConvert::valueChanged);
+    params->setObjectName(QStringLiteral("params"));
     lay->addWidget(params, 1, 1, 2, 3);
     return w;
 }
 
 QString SieveConditionConvert::code(QWidget *w) const
 {
-    QString result = QLatin1String("convert ");
-    const SelectMimeTypeComboBox *fromMimeType = w->findChild<SelectMimeTypeComboBox*>( QLatin1String("from") );
+    QString result = QStringLiteral("convert ");
+    const SelectMimeTypeComboBox *fromMimeType = w->findChild<SelectMimeTypeComboBox *>(QStringLiteral("from"));
     const QString fromMimeTypeStr = fromMimeType->code();
     result += QString::fromLatin1("%1 ").arg(fromMimeTypeStr);
 
-    const SelectMimeTypeComboBox *toMimeType = w->findChild<SelectMimeTypeComboBox*>( QLatin1String("to") );
+    const SelectMimeTypeComboBox *toMimeType = w->findChild<SelectMimeTypeComboBox *>(QLatin1String("to"));
     const QString toMimeTypeStr = toMimeType->code();
     result += QString::fromLatin1("%1 ").arg(toMimeTypeStr);
 
-    const SelectConvertParameterWidget *params = w->findChild<SelectConvertParameterWidget*>( QLatin1String("params") );
+    const SelectConvertParameterWidget *params = w->findChild<SelectConvertParameterWidget *>(QLatin1String("params"));
     const QString paramsStr = params->code();
     if (!paramsStr.isEmpty()) {
         result += QString::fromLatin1("%1").arg(paramsStr);
@@ -90,10 +90,9 @@ QString SieveConditionConvert::code(QWidget *w) const
     return result;
 }
 
-
-QStringList SieveConditionConvert::needRequires(QWidget*) const
+QStringList SieveConditionConvert::needRequires(QWidget *) const
 {
-    return QStringList() << QLatin1String("convert");
+    return QStringList() << QStringLiteral("convert");
 }
 
 bool SieveConditionConvert::needCheckIfServerHasCapability() const
@@ -103,7 +102,7 @@ bool SieveConditionConvert::needCheckIfServerHasCapability() const
 
 QString SieveConditionConvert::serverNeedsCapability() const
 {
-    return QLatin1String("convert");
+    return QStringLiteral("convert");
 }
 
 QString SieveConditionConvert::help() const
@@ -121,26 +120,26 @@ bool SieveConditionConvert::setParamWidgetValue(const QDomElement &element, QWid
             const QString tagName = e.tagName();
             if (tagName == QLatin1String("str")) {
                 if (index == 0) {
-                    SelectMimeTypeComboBox *fromMimeType = w->findChild<SelectMimeTypeComboBox*>( QLatin1String("from") );
+                    SelectMimeTypeComboBox *fromMimeType = w->findChild<SelectMimeTypeComboBox *>(QLatin1String("from"));
                     fromMimeType->setCode(e.text(), name(), error);
                 } else if (index == 1) {
-                    SelectMimeTypeComboBox *toMimeType = w->findChild<SelectMimeTypeComboBox*>( QLatin1String("to") );
+                    SelectMimeTypeComboBox *toMimeType = w->findChild<SelectMimeTypeComboBox *>(QLatin1String("to"));
                     toMimeType->setCode(e.text(), name(), error);
                 } else {
                     tooManyArgument(tagName, index, 2, error);
-                    qDebug()<<" SieveActionConvert::setParamWidgetValue too many argument :"<<index;
+                    qCDebug(LIBKSIEVE_LOG) << " SieveActionConvert::setParamWidgetValue too many argument :" << index;
                 }
                 ++index;
             } else if (tagName == QLatin1String("list")) {
-               SelectConvertParameterWidget *params = w->findChild<SelectConvertParameterWidget*>( QLatin1String("params") );
-               params->setCode(AutoCreateScriptUtil::listValue(e), error);
+                SelectConvertParameterWidget *params = w->findChild<SelectConvertParameterWidget *>(QLatin1String("params"));
+                params->setCode(AutoCreateScriptUtil::listValue(e), error);
             } else if (tagName == QLatin1String("crlf")) {
                 //nothing
             } else if (tagName == QLatin1String("comment")) {
                 //implement in the future ?
             } else {
                 unknownTag(tagName, error);
-                qDebug()<<"SieveActionConvert::setParamWidgetValue unknown tag "<<tagName;
+                qCDebug(LIBKSIEVE_LOG) << "SieveActionConvert::setParamWidgetValue unknown tag " << tagName;
             }
         }
         node = node.nextSibling();
