@@ -20,29 +20,30 @@
 
 #include "sievecondition.h"
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveConditionCurrentDate : public SieveCondition
 {
     Q_OBJECT
 public:
-    SieveConditionCurrentDate(QObject *parent = 0);
+    explicit SieveConditionCurrentDate(QObject *parent = Q_NULLPTR);
 
     static SieveCondition *newAction();
 
-    QWidget *createParamWidget( QWidget *parent ) const;
+    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
 
-    QString code(QWidget *w) const;
+    QString code(QWidget *w) const Q_DECL_OVERRIDE;
 
-    bool needCheckIfServerHasCapability() const;
+    bool needCheckIfServerHasCapability() const Q_DECL_OVERRIDE;
 
-    QString serverNeedsCapability() const;
+    QString serverNeedsCapability() const Q_DECL_OVERRIDE;
 
-    QStringList needRequires(QWidget *parent) const;
+    QStringList needRequires(QWidget *parent) const Q_DECL_OVERRIDE;
 
-    QString help() const;
+    QString help() const Q_DECL_OVERRIDE;
 
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, bool notCondition, QString &error );
-    QString href() const;
+    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, bool notCondition, QString &error) Q_DECL_OVERRIDE;
+    QString href() const Q_DECL_OVERRIDE;
 };
 }
 
