@@ -22,16 +22,16 @@
 #include "editor/sieveeditorutil.h"
 
 #include <KLocalizedString>
-#include <KLineEdit>
+#include <QLineEdit>
 
 #include <QHBoxLayout>
 #include <QLabel>
-#include <QDebug>
+#include "libksieve_debug.h"
 
 using namespace KSieveUi;
 
 SieveConditionDate::SieveConditionDate(QObject *parent)
-    : SieveCondition(QLatin1String("date"), i18n("Date"), parent)
+    : SieveCondition(QStringLiteral("date"), i18n("Date"), parent)
 {
 }
 
@@ -40,7 +40,7 @@ SieveCondition *SieveConditionDate::newAction()
     return new SieveConditionDate;
 }
 
-QWidget *SieveConditionDate::createParamWidget( QWidget *parent ) const
+QWidget *SieveConditionDate::createParamWidget(QWidget *parent) const
 {
     QWidget *w = new QWidget(parent);
     QHBoxLayout *lay = new QHBoxLayout;
@@ -48,8 +48,8 @@ QWidget *SieveConditionDate::createParamWidget( QWidget *parent ) const
     w->setLayout(lay);
 
     SelectMatchTypeComboBox *matchTypeCombo = new SelectMatchTypeComboBox;
-    matchTypeCombo->setObjectName(QLatin1String("matchtype"));
-    connect(matchTypeCombo, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
+    matchTypeCombo->setObjectName(QStringLiteral("matchtype"));
+    connect(matchTypeCombo, &SelectMatchTypeComboBox::valueChanged, this, &SieveConditionDate::valueChanged);
     lay->addWidget(matchTypeCombo);
 
     QGridLayout *grid = new QGridLayout;
@@ -58,14 +58,14 @@ QWidget *SieveConditionDate::createParamWidget( QWidget *parent ) const
     QLabel *lab = new QLabel(i18n("header:"));
     grid->addWidget(lab, 0, 0);
 
-    KLineEdit *header = new KLineEdit;
-    connect(header, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
-    header->setObjectName(QLatin1String("header"));
+    QLineEdit *header = new QLineEdit;
+    connect(header, &QLineEdit::textChanged, this, &SieveConditionDate::valueChanged);
+    header->setObjectName(QStringLiteral("header"));
     grid->addWidget(header, 0, 1);
 
     SelectDateWidget *dateWidget = new SelectDateWidget;
-    connect(dateWidget, SIGNAL(valueChanged()), this, SIGNAL(valueChanged()));
-    dateWidget->setObjectName(QLatin1String("datewidget"));
+    connect(dateWidget, &SelectDateWidget::valueChanged, this, &SieveConditionDate::valueChanged);
+    dateWidget->setObjectName(QStringLiteral("datewidget"));
     grid->addWidget(dateWidget, 1, 0, 1, 2);
 
     return w;
@@ -73,14 +73,14 @@ QWidget *SieveConditionDate::createParamWidget( QWidget *parent ) const
 
 QString SieveConditionDate::code(QWidget *w) const
 {
-    const SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox*>(QLatin1String("matchtype"));
+    const SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
     bool isNegative = false;
     const QString matchTypeStr = selectMatchCombobox->code(isNegative);
 
-    const KLineEdit *header = w->findChild<KLineEdit*>(QLatin1String("header"));
+    const QLineEdit *header = w->findChild<QLineEdit *>(QStringLiteral("header"));
     const QString headerStr = header->text();
 
-    const SelectDateWidget *dateWidget = w->findChild<SelectDateWidget*>(QLatin1String("datewidget"));
+    const SelectDateWidget *dateWidget = w->findChild<SelectDateWidget *>(QStringLiteral("datewidget"));
     const QString dateWidgetStr = dateWidget->code();
 
     return AutoCreateScriptUtil::negativeString(isNegative) + QString::fromLatin1("date %1 \"%2\" %3").arg(matchTypeStr).arg(headerStr).arg(dateWidgetStr);
@@ -93,12 +93,12 @@ bool SieveConditionDate::needCheckIfServerHasCapability() const
 
 QString SieveConditionDate::serverNeedsCapability() const
 {
-    return QLatin1String("date");
+    return QStringLiteral("date");
 }
 
 QStringList SieveConditionDate::needRequires(QWidget *) const
 {
-    return QStringList() << QLatin1String("date");
+    return QStringList() << QStringLiteral("date");
 }
 
 QString SieveConditionDate::help() const
@@ -126,11 +126,11 @@ bool SieveConditionDate::setParamWidgetValue(const QDomElement &element, QWidget
                     value = e.text();
                 } else {
                     tooManyArgument(tagName, index, 3, error);
-                    qDebug()<<" SieveConditionDate::setParamWidgetValue too many argument :"<<index;
+                    qCDebug(LIBKSIEVE_LOG) << " SieveConditionDate::setParamWidgetValue too many argument :" << index;
                 }
                 ++index;
             } else if (tagName == QLatin1String("tag")) {
-                SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox*>(QLatin1String("matchtype"));
+                SelectMatchTypeComboBox *selectMatchCombobox = w->findChild<SelectMatchTypeComboBox *>(QStringLiteral("matchtype"));
                 selectMatchCombobox->setCode(AutoCreateScriptUtil::tagValueWithCondition(e.text(), notCondition), name(), error);
             } else if (tagName == QLatin1String("crlf")) {
                 //nothing
@@ -138,14 +138,14 @@ bool SieveConditionDate::setParamWidgetValue(const QDomElement &element, QWidget
                 //implement in the future ?
             } else {
                 unknownTag(tagName, error);
-                qDebug()<<"SieveConditionDate::setParamWidgetValue unknown tag "<<tagName;
+                qCDebug(LIBKSIEVE_LOG) << "SieveConditionDate::setParamWidgetValue unknown tag " << tagName;
             }
         }
         node = node.nextSibling();
     }
-    SelectDateWidget *dateWidget = w->findChild<SelectDateWidget*>(QLatin1String("datewidget"));
+    SelectDateWidget *dateWidget = w->findChild<SelectDateWidget *>(QStringLiteral("datewidget"));
     dateWidget->setCode(type, value);
-    KLineEdit *header = w->findChild<KLineEdit*>(QLatin1String("header"));
+    QLineEdit *header = w->findChild<QLineEdit *>(QStringLiteral("header"));
     header->setText(headerStr);
     return true;
 }
@@ -155,4 +155,3 @@ QString SieveConditionDate::href() const
     return SieveEditorUtil::helpUrl(SieveEditorUtil::strToVariableName(name()));
 }
 
-
