@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,29 +20,30 @@
 
 #include "sievecondition.h"
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveConditionHasFlag : public SieveCondition
 {
     Q_OBJECT
 public:
-    SieveConditionHasFlag(QObject *parent = 0);
+    explicit SieveConditionHasFlag(QObject *parent = Q_NULLPTR);
 
     static SieveCondition *newAction();
 
-    QWidget *createParamWidget( QWidget *parent ) const;
+    QWidget *createParamWidget(QWidget *parent) const Q_DECL_OVERRIDE;
 
-    QString code(QWidget *parent) const;
+    QString code(QWidget *parent) const Q_DECL_OVERRIDE;
 
-    QStringList needRequires(QWidget *parent) const;
+    QStringList needRequires(QWidget *parent) const Q_DECL_OVERRIDE;
 
-    bool needCheckIfServerHasCapability() const;
+    bool needCheckIfServerHasCapability() const Q_DECL_OVERRIDE;
 
-    QString serverNeedsCapability() const;
+    QString serverNeedsCapability() const Q_DECL_OVERRIDE;
 
-    QString help() const;
+    QString help() const Q_DECL_OVERRIDE;
 
-    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, bool notCondition, QString &error );
-    QString href() const;
+    bool setParamWidgetValue(const QDomElement &element, QWidget *parent, bool notCondition, QString &error) Q_DECL_OVERRIDE;
+    QString href() const Q_DECL_OVERRIDE;
 private:
     bool hasVariableSupport;
 };
