@@ -20,7 +20,7 @@
 
 #include <KLocalizedString>
 #include <KComboBox>
-#include <KLineEdit>
+#include <QLineEdit>
 
 #include <QHBoxLayout>
 
@@ -44,13 +44,13 @@ void SelectBodyTypeWidget::initialize()
 
     mBodyCombobox = new KComboBox;
     lay->addWidget(mBodyCombobox);
-    mBodyCombobox->addItem(i18n("raw"), QLatin1String(":raw"));
-    mBodyCombobox->addItem(i18n("content"), QLatin1String(":content"));
-    mBodyCombobox->addItem(i18n("text"), QLatin1String(":text"));
-    connect(mBodyCombobox, SIGNAL(activated(int)), this, SLOT(slotBodyTypeChanged(int)));
+    mBodyCombobox->addItem(i18n("raw"), QStringLiteral(":raw"));
+    mBodyCombobox->addItem(i18n("content"), QStringLiteral(":content"));
+    mBodyCombobox->addItem(i18n("text"), QStringLiteral(":text"));
+    connect(mBodyCombobox, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &SelectBodyTypeWidget::slotBodyTypeChanged);
 
-    mBodyLineEdit = new KLineEdit;
-    connect(mBodyLineEdit, SIGNAL(textChanged(QString)), this, SIGNAL(valueChanged()));
+    mBodyLineEdit = new QLineEdit;
+    connect(mBodyLineEdit, &QLineEdit::textChanged, this, &SelectBodyTypeWidget::valueChanged);
     lay->addWidget(mBodyLineEdit);
     mBodyLineEdit->hide();
 }
@@ -88,5 +88,3 @@ void SelectBodyTypeWidget::setCode(const QString &type, const QString &content,
     mBodyLineEdit->setText(content);
 }
 
-
-
