@@ -18,13 +18,13 @@
 #ifndef SELECTCOMPARATORCOMBOBOX_H
 #define SELECTCOMPARATORCOMBOBOX_H
 
-#include <KComboBox>
+#include <QComboBox>
 
-class SelectComparatorComboBox : public KComboBox
+class SelectComparatorComboBox : public QComboBox
 {
     Q_OBJECT
 public:
-    explicit SelectComparatorComboBox(QWidget *parent = 0);
+    explicit SelectComparatorComboBox(QWidget *parent = Q_NULLPTR);
     ~SelectComparatorComboBox();
 
     QString code() const;
