@@ -21,25 +21,33 @@
 #include "sievescriptpage.h"
 #include "sieveincludewidget.h"
 
-#include <KHBox>
+#include <QHBoxLayout>
 #include <KMessageBox>
 #include <KLocalizedString>
-#include <KInputDialog>
-#include <KPushButton>
+#include <QInputDialog>
+#include <QPushButton>
+#include <KIconLoader>
+#include <QIcon>
 
 #include <QVBoxLayout>
 #include <QListWidget>
 #include <QPointer>
 #include <QDomElement>
-#include <QDebug>
+#include "libksieve_debug.h"
 
-static QString defaultScriptName = QLatin1String("SCRIPTNAME: ");
+namespace
+{
+inline const QString defaultScriptName()
+{
+    return QStringLiteral("SCRIPTNAME: ");
+}
+}
 
 using namespace KSieveUi;
 
-SieveScriptListItem::SieveScriptListItem( const QString &text, QListWidget *parent )
-    : QListWidgetItem( text, parent ),
-      mScriptPage(0)
+SieveScriptListItem::SieveScriptListItem(const QString &text, QListWidget *parent)
+    : QListWidgetItem(text, parent),
+      mScriptPage(Q_NULLPTR)
 {
 }
 
@@ -47,7 +55,7 @@ SieveScriptListItem::~SieveScriptListItem()
 {
 }
 
-void SieveScriptListItem::setDescription(const QString & desc)
+void SieveScriptListItem::setDescription(const QString &desc)
 {
     mDescription = desc;
 }
@@ -72,7 +80,7 @@ QString SieveScriptListItem::generatedScript(QStringList &requires) const
     QString script;
     if (!mDescription.isEmpty()) {
         script = QLatin1Char('#') + mDescription;
-        script.replace(QLatin1Char('\n'), QLatin1String("\n#"));
+        script.replace(QLatin1Char('\n'), QStringLiteral("\n#"));
         script += QLatin1Char('\n');
     }
     if (mScriptPage) {
@@ -90,72 +98,82 @@ SieveScriptListBox::SieveScriptListBox(const QString &title, QWidget *parent)
     layout->addWidget(mSieveListScript);
 
     //----------- the first row of buttons
-    KHBox *hb = new KHBox( this );
-    hb->setSpacing( 4 );
+    QWidget *hb = new QWidget(this);
+    QHBoxLayout *hbHBoxLayout = new QHBoxLayout(hb);
+    hbHBoxLayout->setMargin(0);
+    hbHBoxLayout->setSpacing(4);
 
-    mBtnTop = new KPushButton( QString(), hb );
-    mBtnTop->setIcon( KIcon( QLatin1String("go-top") ) );
-    mBtnTop->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
-    mBtnTop->setMinimumSize( mBtnTop->sizeHint() * 1.2 );
+    mBtnTop = new QPushButton(QString(), hb);
+    hbHBoxLayout->addWidget(mBtnTop);
+    mBtnTop->setIcon(QIcon::fromTheme(QStringLiteral("go-top")));
+    mBtnTop->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
+    mBtnTop->setMinimumSize(mBtnTop->sizeHint() * 1.2);
 
-    mBtnUp = new KPushButton( QString(), hb );
-    mBtnUp->setAutoRepeat( true );
-    mBtnUp->setIcon( KIcon( QLatin1String("go-up") ) );
-    mBtnUp->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
-    mBtnUp->setMinimumSize( mBtnUp->sizeHint() * 1.2 );
-    mBtnDown = new KPushButton( QString(), hb );
-    mBtnDown->setAutoRepeat( true );
-    mBtnDown->setIcon( KIcon( QLatin1String("go-down") ) );
-    mBtnDown->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
-    mBtnDown->setMinimumSize( mBtnDown->sizeHint() * 1.2 );
+    mBtnUp = new QPushButton(QString(), hb);
+    hbHBoxLayout->addWidget(mBtnUp);
+    mBtnUp->setAutoRepeat(true);
+    mBtnUp->setIcon(QIcon::fromTheme(QStringLiteral("go-up")));
+    mBtnUp->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
+    mBtnUp->setMinimumSize(mBtnUp->sizeHint() * 1.2);
+    mBtnDown = new QPushButton(QString(), hb);
+    hbHBoxLayout->addWidget(mBtnDown);
+    mBtnDown->setAutoRepeat(true);
+    mBtnDown->setIcon(QIcon::fromTheme(QStringLiteral("go-down")));
+    mBtnDown->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
+    mBtnDown->setMinimumSize(mBtnDown->sizeHint() * 1.2);
 
-    mBtnBottom = new KPushButton( QString(), hb );
-    mBtnBottom->setIcon( KIcon( QLatin1String("go-bottom") ) );
-    mBtnBottom->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
-    mBtnBottom->setMinimumSize( mBtnBottom->sizeHint() * 1.2 );
+    mBtnBottom = new QPushButton(QString(), hb);
+    hbHBoxLayout->addWidget(mBtnBottom);
+    mBtnBottom->setIcon(QIcon::fromTheme(QStringLiteral("go-bottom")));
+    mBtnBottom->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
+    mBtnBottom->setMinimumSize(mBtnBottom->sizeHint() * 1.2);
 
-    mBtnUp->setToolTip( i18nc( "Move selected filter up.", "Up" ) );
-    mBtnDown->setToolTip( i18nc( "Move selected filter down.", "Down" ) );
-    mBtnTop->setToolTip( i18nc( "Move selected filter to the top.", "Top" ) );
-    mBtnBottom->setToolTip( i18nc( "Move selected filter to the bottom.", "Bottom" ) );
+    mBtnUp->setToolTip(i18nc("Move selected filter up.", "Up"));
+    mBtnDown->setToolTip(i18nc("Move selected filter down.", "Down"));
+    mBtnTop->setToolTip(i18nc("Move selected filter to the top.", "Top"));
+    mBtnBottom->setToolTip(i18nc("Move selected filter to the bottom.", "Bottom"));
 
-    layout->addWidget( hb );
+    layout->addWidget(hb);
 
-    hb = new KHBox( this );
-    hb->setSpacing( 4 );
+    hb = new QWidget(this);
+    hbHBoxLayout = new QHBoxLayout(hb);
+    hbHBoxLayout->setMargin(0);
+    hbHBoxLayout->setSpacing(4);
 
-    mBtnNew = new KPushButton( QString(), hb );
-    mBtnNew->setIcon( KIcon( QLatin1String("document-new") ) );
-    mBtnNew->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
-    mBtnNew->setMinimumSize( mBtnNew->sizeHint() * 1.2 );
+    mBtnNew = new QPushButton(QString(), hb);
+    hbHBoxLayout->addWidget(mBtnNew);
+    mBtnNew->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
+    mBtnNew->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
+    mBtnNew->setMinimumSize(mBtnNew->sizeHint() * 1.2);
 
-    mBtnDelete = new KPushButton( QString(), hb );
-    mBtnDelete->setIcon( KIcon( QLatin1String("edit-delete") ) );
-    mBtnDelete->setIconSize( QSize( KIconLoader::SizeSmall, KIconLoader::SizeSmall ) );
-    mBtnDelete->setMinimumSize( mBtnDelete->sizeHint() * 1.2 );
+    mBtnDelete = new QPushButton(QString(), hb);
+    hbHBoxLayout->addWidget(mBtnDelete);
+    mBtnDelete->setIcon(QIcon::fromTheme(QStringLiteral("edit-delete")));
+    mBtnDelete->setIconSize(QSize(KIconLoader::SizeSmall, KIconLoader::SizeSmall));
+    mBtnDelete->setMinimumSize(mBtnDelete->sizeHint() * 1.2);
 
-    mBtnRename = new KPushButton( i18n( "Rename..." ), hb );
+    mBtnRename = new QPushButton(i18n("Rename..."), hb);
+    hbHBoxLayout->addWidget(mBtnRename);
 
-    mBtnDescription = new KPushButton( i18n( "Edit description..." ), hb );
+    mBtnDescription = new QPushButton(i18n("Edit description..."), hb);
+    hbHBoxLayout->addWidget(mBtnDescription);
 
+    layout->addWidget(hb);
+    setLayout(layout);
 
-    layout->addWidget( hb );
-    setLayout( layout );
+    connect(mBtnNew, &QPushButton::clicked, this, &SieveScriptListBox::slotNew);
+    connect(mBtnDelete, &QPushButton::clicked, this, &SieveScriptListBox::slotDelete);
+    connect(mBtnRename, &QPushButton::clicked, this, &SieveScriptListBox::slotRename);
+    connect(mBtnDescription, &QPushButton::clicked, this, &SieveScriptListBox::slotEditDescription);
 
-    connect( mBtnNew, SIGNAL(clicked()), this, SLOT(slotNew()));
-    connect( mBtnDelete, SIGNAL(clicked()), this, SLOT(slotDelete()));
-    connect( mBtnRename, SIGNAL(clicked()), this, SLOT(slotRename()));
-    connect( mBtnDescription, SIGNAL(clicked()), this, SLOT(slotEditDescription()));
+    connect(mBtnUp, &QPushButton::clicked, this, &SieveScriptListBox::slotUp);
+    connect(mBtnDown, &QPushButton::clicked, this, &SieveScriptListBox::slotDown);
+    connect(mBtnTop, &QPushButton::clicked, this, &SieveScriptListBox::slotTop);
+    connect(mBtnBottom, &QPushButton::clicked, this, &SieveScriptListBox::slotBottom);
 
-    connect( mBtnUp, SIGNAL(clicked()), this, SLOT(slotUp()) );
-    connect( mBtnDown, SIGNAL(clicked()), this, SLOT(slotDown()) );
-    connect( mBtnTop, SIGNAL(clicked()), this, SLOT(slotTop()) );
-    connect( mBtnBottom, SIGNAL(clicked()), this, SLOT(slotBottom()) );
-
-
-    connect( mSieveListScript, SIGNAL(itemSelectionChanged()), SLOT(updateButtons()));
-    connect( mSieveListScript, SIGNAL(itemActivated(QListWidgetItem*)), SLOT(slotItemActived(QListWidgetItem*)));
-    connect( mSieveListScript, SIGNAL(itemDoubleClicked(QListWidgetItem*)), SLOT(slotEditDescription()));
+    connect(mSieveListScript, &QListWidget::itemSelectionChanged, this, &SieveScriptListBox::updateButtons);
+    connect(mSieveListScript, &QListWidget::itemActivated, this, &SieveScriptListBox::slotItemActived);
+    connect(mSieveListScript, &QListWidget::itemDoubleClicked, this, &SieveScriptListBox::slotEditDescription);
     updateButtons();
 }
 
@@ -163,10 +181,10 @@ SieveScriptListBox::~SieveScriptListBox()
 {
 }
 
-void SieveScriptListBox::slotItemActived(QListWidgetItem* item)
+void SieveScriptListBox::slotItemActived(QListWidgetItem *item)
 {
     if (item) {
-        SieveScriptListItem *itemScript = static_cast<SieveScriptListItem*>(item);
+        SieveScriptListItem *itemScript = static_cast<SieveScriptListItem *>(item);
         Q_EMIT activatePage(itemScript->scriptPage());
     }
 }
@@ -174,11 +192,11 @@ void SieveScriptListBox::slotItemActived(QListWidgetItem* item)
 void SieveScriptListBox::updateButtons()
 {
     const int currentIndex = mSieveListScript->currentRow();
-    const bool theFirst = ( currentIndex == 0 );
-    const int numberOfElement( mSieveListScript->count() );
-    const bool theLast = ( currentIndex >= numberOfElement - 1 );
+    const bool theFirst = (currentIndex == 0);
+    const int numberOfElement(mSieveListScript->count());
+    const bool theLast = (currentIndex >= numberOfElement - 1);
 
-    const QList<QListWidgetItem*> lst = mSieveListScript->selectedItems();
+    const QList<QListWidgetItem *> lst = mSieveListScript->selectedItems();
     mBtnDelete->setEnabled(!lst.isEmpty());
     mBtnRename->setEnabled(lst.count() == 1);
     mBtnDescription->setEnabled(lst.count() == 1);
@@ -203,8 +221,8 @@ SieveScriptPage *SieveScriptListBox::createNewScript(const QString &newName, con
 
 void SieveScriptListBox::slotNew()
 {
-    const QString newName = KInputDialog::getText(i18n("New Script"), i18n("Add new name:"));
-    if (!newName.isEmpty()) {
+    const QString newName = QInputDialog::getText(this, i18n("New Script"), i18n("Add new name:"));
+    if (!newName.trimmed().isEmpty()) {
         createNewScript(newName);
         Q_EMIT valueChanged();
     }
@@ -215,10 +233,10 @@ void SieveScriptListBox::slotDelete()
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
         if (KMessageBox::warningYesNo(this, i18n("Do you want to delete \"%1\" script?", item->text()), i18n("Delete script")) == KMessageBox::Yes) {
-            SieveScriptListItem *itemScript = static_cast<SieveScriptListItem*>(item);
+            SieveScriptListItem *itemScript = static_cast<SieveScriptListItem *>(item);
             Q_EMIT removePage(itemScript->scriptPage());
             delete item;
-            Q_EMIT enableButtonOk(mSieveListScript->count()>0);
+            Q_EMIT enableButtonOk(mSieveListScript->count() > 0);
             updateButtons();
             Q_EMIT valueChanged();
         }
@@ -229,8 +247,8 @@ void SieveScriptListBox::slotRename()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        const QString newName = KInputDialog::getText(i18n("Rename"), i18n("Add new name:"), item->text());
-        if (!newName.isEmpty()) {
+        const QString newName = QInputDialog::getText(this, i18n("Rename"), i18n("Add new name:"), QLineEdit::Normal, item->text());
+        if (!newName.trimmed().isEmpty()) {
             item->setText(newName);
             Q_EMIT valueChanged();
         }
@@ -241,7 +259,7 @@ void SieveScriptListBox::slotEditDescription()
 {
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
-        SieveScriptListItem *sieveItem = static_cast<SieveScriptListItem*>(item);
+        SieveScriptListItem *sieveItem = static_cast<SieveScriptListItem *>(item);
         QPointer<SieveScriptDescriptionDialog> dlg = new SieveScriptDescriptionDialog(this);
         dlg->setDescription(sieveItem->description());
         if (dlg->exec()) {
@@ -258,8 +276,8 @@ void SieveScriptListBox::slotTop()
     if (item) {
         const int currentIndex = mSieveListScript->currentRow();
         if (currentIndex != 0) {
-            item = mSieveListScript->takeItem( currentIndex );
-            mSieveListScript->insertItem( 0, item );
+            item = mSieveListScript->takeItem(currentIndex);
+            mSieveListScript->insertItem(0, item);
             mSieveListScript->setCurrentItem(item);
             Q_EMIT valueChanged();
         }
@@ -271,9 +289,9 @@ void SieveScriptListBox::slotBottom()
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
         const int currentIndex = mSieveListScript->currentRow();
-        if (currentIndex != mSieveListScript->count() - 1 ) {
-            item = mSieveListScript->takeItem( currentIndex );
-            mSieveListScript->insertItem( mSieveListScript->count() , item );
+        if (currentIndex != mSieveListScript->count() - 1) {
+            item = mSieveListScript->takeItem(currentIndex);
+            mSieveListScript->insertItem(mSieveListScript->count() , item);
             mSieveListScript->setCurrentItem(item);
             Q_EMIT valueChanged();
         }
@@ -285,9 +303,9 @@ void SieveScriptListBox::slotDown()
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
         const int currentIndex = mSieveListScript->currentRow();
-        if (currentIndex < mSieveListScript->count() - 1 ) {
-            item = mSieveListScript->takeItem( currentIndex );
-            mSieveListScript->insertItem( currentIndex + 1, item );
+        if (currentIndex < mSieveListScript->count() - 1) {
+            item = mSieveListScript->takeItem(currentIndex);
+            mSieveListScript->insertItem(currentIndex + 1, item);
             mSieveListScript->setCurrentItem(item);
             Q_EMIT valueChanged();
         }
@@ -299,9 +317,9 @@ void SieveScriptListBox::slotUp()
     QListWidgetItem *item = mSieveListScript->currentItem();
     if (item) {
         const int currentIndex = mSieveListScript->currentRow();
-        if (currentIndex >= 1 ) {
-            item = mSieveListScript->takeItem( currentIndex );
-            mSieveListScript->insertItem( currentIndex - 1, item );
+        if (currentIndex >= 1) {
+            item = mSieveListScript->takeItem(currentIndex);
+            mSieveListScript->insertItem(currentIndex - 1, item);
             mSieveListScript->setCurrentItem(item);
             Q_EMIT valueChanged();
         }
@@ -313,11 +331,12 @@ QString SieveScriptListBox::generatedScript(QString &requires) const
     QString resultScript;
     QStringList lstRequires;
     const int numberOfScripts(mSieveListScript->count());
-    for (int i = 0; i< numberOfScripts; ++i) {
-        SieveScriptListItem* item = static_cast<SieveScriptListItem*>(mSieveListScript->item(i));
-        if (i != 0)
+    for (int i = 0; i < numberOfScripts; ++i) {
+        SieveScriptListItem *item = static_cast<SieveScriptListItem *>(mSieveListScript->item(i));
+        if (i != 0) {
             resultScript += QLatin1String("\n\n");
-        resultScript += QLatin1Char('#') + defaultScriptName + item->text() + QLatin1Char('\n');
+        }
+        resultScript += QLatin1Char('#') + defaultScriptName() + item->text() + QLatin1Char('\n');
         resultScript += item->generatedScript(lstRequires);
     }
 
@@ -325,7 +344,7 @@ QString SieveScriptListBox::generatedScript(QString &requires) const
     Q_FOREACH (const QString &r, lstRequires) {
         if (!endRequires.contains(r)) {
             endRequires.append(r);
-            requires += QString::fromLatin1("require \"%1\";\n").arg(r);
+            requires += QStringLiteral("require \"%1\";\n").arg(r);
         }
     }
 
@@ -346,7 +365,7 @@ void SieveScriptListBox::loadScript(const QDomDocument &doc, QString &error)
     clear();
     QDomElement docElem = doc.documentElement();
     QDomNode n = docElem.firstChild();
-    SieveScriptPage *currentPage = 0;
+    SieveScriptPage *currentPage = Q_NULLPTR;
     ParseSieveScriptTypeBlock typeBlock = TypeUnknown;
     loadBlock(n, currentPage, typeBlock, error);
 }
@@ -360,25 +379,27 @@ void SieveScriptListBox::loadBlock(QDomNode &n, SieveScriptPage *currentPage, Pa
         QDomElement e = n.toElement();
         if (!e.isNull()) {
             const QString tagName = e.tagName();
-            //qDebug()<<" tagName "<<tagName;
+            //qCDebug(LIBKSIEVE_LOG)<<" tagName "<<tagName;
             if (tagName == QLatin1String("control")) {
                 //Create a new page when before it was "onlyactions"
-                if (typeBlock == TypeBlockAction)
-                    currentPage = 0;
-                if (e.hasAttribute(QLatin1String("name"))) {
-                    const QString controlType = e.attribute(QLatin1String("name"));
-                    //qDebug()<<" controlType"<<controlType;
+                if (typeBlock == TypeBlockAction) {
+                    currentPage = Q_NULLPTR;
+                }
+                if (e.hasAttribute(QStringLiteral("name"))) {
+                    const QString controlType = e.attribute(QStringLiteral("name"));
+                    //qCDebug(LIBKSIEVE_LOG)<<" controlType"<<controlType;
                     if (controlType == QLatin1String("if")) {
                         typeBlock = TypeBlockIf;
-                        if (!currentPage || hasCreatedAIfBlock)
+                        if (!currentPage || hasCreatedAIfBlock) {
                             currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
+                        }
                         hasCreatedAIfBlock = true;
                         comment.clear();
                         currentPage->blockIfWidget()->loadScript(e, false, error);
                     } else if (controlType == QLatin1String("elsif")) {
                         typeBlock = TypeBlockElsif;
                         if (!currentPage) {
-                            qDebug() <<" script is not correct missing if block";
+                            qCDebug(LIBKSIEVE_LOG) << " script is not correct missing if block";
                             currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
                         }
                         SieveScriptBlockWidget *blockWidget = currentPage->addScriptBlock(KSieveUi::SieveWidgetPageAbstract::BlockElsIf);
@@ -389,14 +410,14 @@ void SieveScriptListBox::loadBlock(QDomNode &n, SieveScriptPage *currentPage, Pa
                         typeBlock = TypeBlockElse;
                         if (!currentPage) {
                             currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
-                            qDebug() <<" script is not correct missing if block";
+                            qCDebug(LIBKSIEVE_LOG) << " script is not correct missing if block";
                         }
                         SieveScriptBlockWidget *blockWidget = currentPage->addScriptBlock(KSieveUi::SieveWidgetPageAbstract::BlockElse);
                         if (blockWidget) {
                             blockWidget->loadScript(e, false, error);
                         }
                         //We are sure that we can't have another elsif
-                        currentPage = 0;
+                        currentPage = Q_NULLPTR;
                     } else if (controlType == QLatin1String("foreverypart")) {
                         typeBlock = TypeBlockForeachBlock;
                         if (!currentPage) {
@@ -414,21 +435,22 @@ void SieveScriptListBox::loadBlock(QDomNode &n, SieveScriptPage *currentPage, Pa
                     } else if (controlType == QLatin1String("require")) {
                         //Nothing. autogenerated
                     } else {
-                        qDebug()<<" unknown controlType :"<<controlType;
+                        qCDebug(LIBKSIEVE_LOG) << " unknown controlType :" << controlType;
                     }
                 }
             } else if (tagName == QLatin1String("comment")) {
                 QString str(e.text());
-                if (str.contains(defaultScriptName)) {
-                    scriptName = str.remove(defaultScriptName);
+                if (str.contains(defaultScriptName())) {
+                    scriptName = str.remove(defaultScriptName());
                 } else {
-                    if (!comment.isEmpty())
+                    if (!comment.isEmpty()) {
                         comment += QLatin1Char('\n');
+                    }
                     comment += e.text();
                 }
             } else if (tagName == QLatin1String("action")) {
-                if (e.hasAttribute(QLatin1String("name"))) {
-                    const QString actionName = e.attribute(QLatin1String("name"));
+                if (e.hasAttribute(QStringLiteral("name"))) {
+                    const QString actionName = e.attribute(QStringLiteral("name"));
                     if (actionName == QLatin1String("include")) {
                         if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
                             currentPage = createNewScript(scriptName.isEmpty() ? createUniqName() : scriptName, comment);
@@ -438,7 +460,7 @@ void SieveScriptListBox::loadBlock(QDomNode &n, SieveScriptPage *currentPage, Pa
                         if (currentPage->includeWidget()) {
                             currentPage->includeWidget()->loadScript(e, error);
                         } else {
-                            qDebug()<<" include not supported";
+                            qCDebug(LIBKSIEVE_LOG) << " include not supported";
                         }
                     } else if (actionName == QLatin1String("global")) {
                         if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
@@ -449,13 +471,13 @@ void SieveScriptListBox::loadBlock(QDomNode &n, SieveScriptPage *currentPage, Pa
                         if (currentPage->globalVariableWidget()) {
                             currentPage->globalVariableWidget()->loadScript(e, error);
                         } else {
-                            qDebug()<<" globalVariable not supported";
+                            qCDebug(LIBKSIEVE_LOG) << " globalVariable not supported";
                         }
                     } else if (actionName == QLatin1String("set") && (typeBlock == TypeBlockGlobal)) {
                         if (currentPage->globalVariableWidget()) {
                             currentPage->globalVariableWidget()->loadSetVariable(e, error);
                         } else {
-                            qDebug()<<" globalVariable not supported";
+                            qCDebug(LIBKSIEVE_LOG) << " globalVariable not supported";
                         }
                     } else {
                         if (!currentPage || (typeBlock == TypeBlockIf) || (typeBlock == TypeBlockElse) || (typeBlock == TypeBlockElsif)) {
@@ -464,13 +486,13 @@ void SieveScriptListBox::loadBlock(QDomNode &n, SieveScriptPage *currentPage, Pa
                         typeBlock = TypeBlockAction;
                         comment.clear();
                         currentPage->blockIfWidget()->loadScript(e, true, error);
-                        //qDebug()<<" unknown action name: "<<actionName;
+                        //qCDebug(LIBKSIEVE_LOG)<<" unknown action name: "<<actionName;
                     }
                 }
             } else if (tagName == QLatin1String("crlf")) {
                 //nothing
             } else {
-                qDebug()<<" unknown tagname"<<tagName;
+                qCDebug(LIBKSIEVE_LOG) << " unknown tagname" << tagName;
             }
         }
         n = n.nextSibling();
