@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,15 +18,16 @@
 #ifndef SIEVESCRIPTPARSINGERRORDIALOG_H
 #define SIEVESCRIPTPARSINGERRORDIALOG_H
 #include "ksieveui_export.h"
-#include <KDialog>
-namespace PimCommon {
+#include <QDialog>
+namespace PimCommon
+{
 class RichTextEditorWidget;
 }
-class KSIEVEUI_EXPORT SieveScriptParsingErrorDialog : public KDialog
+class KSIEVEUI_EXPORT SieveScriptParsingErrorDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit SieveScriptParsingErrorDialog(QWidget *parent=0);
+    explicit SieveScriptParsingErrorDialog(QWidget *parent = Q_NULLPTR);
     ~SieveScriptParsingErrorDialog();
 
     void setError(QString script, QString);
