@@ -20,27 +20,36 @@
 #include "sieve-editor.h"
 #include "sieveeditorwidget.h"
 
-#include <klocale.h>
-#include <KStandardGuiItem>
+#include <KLocalizedString>
 
 #include <QPushButton>
 #include <QKeyEvent>
-#include <QDebug>
+#include <KSharedConfig>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QVBoxLayout>
 
 using namespace KSieveUi;
 
-SieveEditor::SieveEditor( QWidget * parent )
-    : KDialog( parent )
+SieveEditor::SieveEditor(QWidget *parent)
+    : QDialog(parent)
 {
-    setCaption( i18n( "Edit Sieve Script" ) );
-    setButtons( Ok|Cancel );
-
-    setModal( false );
-    mSieveEditorWidget = new SieveEditorWidget(false);
-    connect(mSieveEditorWidget, SIGNAL(valueChanged(bool)), this, SIGNAL(valueChanged(bool)));
-    setMainWidget(mSieveEditorWidget);
-    connect(mSieveEditorWidget, SIGNAL(enableButtonOk(bool)), this, SLOT(slotEnableButtonOk(bool)));
-    connect(mSieveEditorWidget, SIGNAL(checkSyntax()), this, SIGNAL(checkSyntax()));
+    setWindowTitle(i18n("Edit Sieve Script"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mOkButton = buttonBox->button(QDialogButtonBox::Ok);
+    mOkButton->setDefault(true);
+    mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &SieveEditor::slotAccepted);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &SieveEditor::slotCanceled);
+    mSieveEditorWidget = new SieveEditorWidget(true);
+    connect(mSieveEditorWidget, &SieveEditorWidget::valueChanged, this, &SieveEditor::valueChanged);
+    mainLayout->addWidget(mSieveEditorWidget);
+    mainLayout->addWidget(buttonBox);
+    connect(mSieveEditorWidget, &SieveEditorWidget::enableButtonOk, this, &SieveEditor::slotEnableButtonOk);
+    connect(this, &SieveEditor::finished, this, &SieveEditor::cancelClicked);
+    connect(mSieveEditorWidget, &SieveEditorWidget::checkSyntax, this, &SieveEditor::checkSyntax);
     readConfig();
 }
 
@@ -49,41 +58,52 @@ SieveEditor::~SieveEditor()
     writeConfig();
 }
 
-bool SieveEditor::event(QEvent* e)
+void SieveEditor::slotAccepted()
+{
+    Q_EMIT okClicked();
+    accept();
+}
+
+void SieveEditor::slotCanceled()
+{
+    Q_EMIT cancelClicked();
+    reject();
+}
+
+bool SieveEditor::event(QEvent *e)
 {
     // Close the bar when pressing Escape.
     // Not using a QShortcut for this because it could conflict with
     // window-global actions (e.g. Emil Sedgh binds Esc to "close tab").
-    // With a shortcut override we can catch this before it gets to kactions.
+    // With a shortcut Q_DECL_OVERRIDE we can catch this before it gets to kactions.
     const bool shortCutOverride = (e->type() == QEvent::ShortcutOverride);
-    if (shortCutOverride || e->type() == QEvent::KeyPress ) {
-        QKeyEvent* kev = static_cast<QKeyEvent* >(e);
+    if (shortCutOverride || e->type() == QEvent::KeyPress) {
+        QKeyEvent *kev = static_cast<QKeyEvent * >(e);
         if (kev->key() == Qt::Key_Escape) {
             e->ignore();
             return true;
         }
     }
-    return KDialog::event(e);
+    return QDialog::event(e);
 }
 
-
 void SieveEditor::slotEnableButtonOk(bool b)
 {
-    enableButtonOk(b);
+    mOkButton->setEnabled(b);
 }
 
 void SieveEditor::writeConfig()
 {
-    KConfigGroup group( KGlobal::config(), "SieveEditor" );
-    group.writeEntry( "Size", size() );
+    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditor");
+    group.writeEntry("Size", size());
 }
 
 void SieveEditor::readConfig()
 {
-    KConfigGroup group( KGlobal::config(), "SieveEditor" );
-    const QSize sizeDialog = group.readEntry( "Size", QSize(800,600) );
-    if ( sizeDialog.isValid() ) {
-        resize( sizeDialog );
+    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditor");
+    const QSize sizeDialog = group.readEntry("Size", QSize(800, 600));
+    if (sizeDialog.isValid()) {
+        resize(sizeDialog);
     }
 }
 
@@ -97,27 +117,27 @@ QString SieveEditor::originalScript() const
     return mSieveEditorWidget->originalScript();
 }
 
-void SieveEditor::setScript( const QString &script )
+void SieveEditor::setScript(const QString &script)
 {
     mSieveEditorWidget->setScript(script);
 }
 
-void SieveEditor::setDebugScript( const QString &debug )
+void SieveEditor::setDebugScript(const QString &debug)
 {
     mSieveEditorWidget->setDebugScript(debug);
 }
 
-void SieveEditor::setScriptName( const QString &name )
+void SieveEditor::setScriptName(const QString &name)
 {
     mSieveEditorWidget->setScriptName(name);
-}  
+}
 
 void SieveEditor::resultDone()
 {
     mSieveEditorWidget->resultDone();
 }
 
-void SieveEditor::setSieveCapabilities( const QStringList &capabilities )
+void SieveEditor::setSieveCapabilities(const QStringList &capabilities)
 {
     mSieveEditorWidget->setSieveCapabilities(capabilities);
 }
