@@ -16,13 +16,12 @@
  * Boston, MA 02110-1301, USA.
  */
 
-
 #include "sieveeditorabstractwidget.h"
 #include "pimcommon/util/pimutil.h"
 
 #include <KLocalizedString>
 #include <KMessageBox>
-#include <KFileDialog>
+#include <QFileDialog>
 
 #include <QTextStream>
 #include <QPointer>
@@ -42,8 +41,9 @@ SieveEditorAbstractWidget::~SieveEditorAbstractWidget()
 
 void SieveEditorAbstractWidget::saveAs(const QString &defaultName)
 {
-    const QString filter = i18n( "*.siv|sieve files (*.siv)\n*|all files (*)" );
-    PimCommon::Util::saveTextAs(currentscript(), filter, this, defaultName, i18n("Save Script"));
+    const QString filter = i18n("Sieve Files (*.siv);;All Files (*)");
+    PimCommon::Util::saveTextAs(currentscript(), filter, this, defaultName,
+                                i18nc("@title:window", "Save Script"));
 }
 
 QString SieveEditorAbstractWidget::currentscript()
@@ -51,55 +51,54 @@ QString SieveEditorAbstractWidget::currentscript()
     return QString();
 }
 
-void SieveEditorAbstractWidget::setImportScript( const QString & )
+void SieveEditorAbstractWidget::setImportScript(const QString &)
 {
 
 }
 
 void SieveEditorAbstractWidget::slotImport()
 {
-    if ( !currentscript().isEmpty() ) {
-        if ( KMessageBox::warningYesNo(this, i18n( "You will overwrite script. Do you want to continue?" ), i18n( "Import Script" ) ) == KMessageBox::No )
+    if (!currentscript().isEmpty()) {
+        if (KMessageBox::warningYesNo(this, i18n("You will overwrite script. Do you want to continue?"), i18n("Import Script")) == KMessageBox::No) {
             return;
+        }
     }
-    KUrl url;
-    const QString filter = i18n( "*.siv|sieve files (*.siv)\n*|all files (*)" );
-    QPointer<KFileDialog> fdlg( new KFileDialog( url, filter, this) );
-    fdlg->setCaption(i18n("Import Script Sieve"));
-    fdlg->setMode( KFile::File );
-    fdlg->setOperationMode( KFileDialog::Opening );
-    if ( fdlg->exec() == QDialog::Accepted && fdlg ) {
-        const QString fileName = fdlg->selectedFile();
-        if ( !loadFromFile( fileName ) ) {
-            KMessageBox::error( this,
-                                i18n( "Could not load the file %1:\n"
-                                      "\"%2\" is the detailed error description.",
-                                      fileName,
-                                      QString::fromLocal8Bit( strerror( errno ) ) ),
-                                i18n( "Sieve Editor Error" ) );
+    const QString filter = i18n("*.siv;;sieve files (*.siv);;all files (*)");
+    QPointer<QFileDialog> fdlg(new QFileDialog(this, i18n("Import Script Sieve"), QString(), filter));
+    fdlg->setFileMode(QFileDialog::ExistingFile);
+    if (fdlg->exec() == QDialog::Accepted && fdlg) {
+        const QStringList fileNames = fdlg->selectedFiles();
+        if (!loadFromFile(fileNames.at(0))) {
+            KMessageBox::error(this,
+                               i18n("Could not load the file %1:\n"
+                                    "\"%2\" is the detailed error description.",
+                                    fileNames.at(0),
+                                    QString::fromLocal8Bit(strerror(errno))),
+                               i18n("Sieve Editor Error"));
         }
     }
     delete fdlg;
 }
 
-bool SieveEditorAbstractWidget::loadFromFile( const QString &filename )
+bool SieveEditorAbstractWidget::loadFromFile(const QString &filename)
 {
-    QFile file( filename );
-    if (!file.open(QIODevice::ReadOnly | QIODevice::Text))
+    QFile file(filename);
+    if (!file.open(QIODevice::ReadOnly | QIODevice::Text)) {
         return false;
+    }
 
     QTextStream in(&file);
     QString line = in.readLine();
     QString scriptText;
     while (!line.isNull()) {
-        if ( scriptText.isEmpty() )
+        if (scriptText.isEmpty()) {
             scriptText = line;
-        else
-            scriptText += QLatin1Char( '\n' ) + line;
+        } else {
+            scriptText += QLatin1Char('\n') + line;
+        }
         line = in.readLine();
     }
-    setImportScript( scriptText );
+    setImportScript(scriptText);
     return true;
 }
 
-
