@@ -23,48 +23,61 @@
 
 #include "pimcommon/texteditor/plaintexteditor/plaintexteditor.h"
 
-class QCompleter;
-class QMenu;
-namespace PimCommon {
-class SieveSyntaxHighlighter;
-}
+#include "pimcommon/sievehighlighter/sievesyntaxhighlighterrules.h"
 
-namespace KSieveUi {
+class QMenu;
+namespace KPIMTextEdit
+{
+class TextEditorCompleter;
+}
+namespace PimCommon
+{
+class SieveSyntaxHighlighterRules;
+
+}
+namespace KSieveUi
+{
 
 class SieveLineNumberArea;
-
-
 class KSIEVEUI_EXPORT SieveTextEdit : public PimCommon::PlainTextEditor
 {
     Q_OBJECT
 
 public:
-    explicit SieveTextEdit( QWidget *parent = 0 );
+    explicit SieveTextEdit(QWidget *parent = Q_NULLPTR);
     ~SieveTextEdit();
 
     void lineNumberAreaPaintEvent(QPaintEvent *event);
     int lineNumberAreaWidth() const;
 
-    void setSieveCapabilities( const QStringList &capabilities );
+    void setSieveCapabilities(const QStringList &capabilities);
 
     void setShowHelpMenu(bool b);
 
+    void uncomment();
+    void comment();
+    void upperCase();
+    void lowerCase();
+    void sentenceCase();
+    void reverseCase();
 private Q_SLOTS:
-    void slotInsertCompletion( const QString& );
     void slotUpdateLineNumberAreaWidth(int newBlockCount);
     void slotUpdateLineNumberArea(const QRect &, int);
     void slotHelp();
 
 protected:
-    QString wordUnderCursor() const;
     void initCompleter();
-    void keyPressEvent(QKeyEvent* e);
-    void resizeEvent(QResizeEvent *event);    
-    void addExtraMenuEntry(QMenu *menu, const QPoint &pos);    
-    bool event(QEvent *ev);
+    void keyPressEvent(QKeyEvent *e) Q_DECL_OVERRIDE;
+    void resizeEvent(QResizeEvent *event) Q_DECL_OVERRIDE;
+    void addExtraMenuEntry(QMenu *menu, const QPoint &pos) Q_DECL_OVERRIDE;
+    bool event(QEvent *ev) Q_DECL_OVERRIDE;
+    Sonnet::SpellCheckDecorator *createSpellCheckDecorator() Q_DECL_OVERRIDE;
 
+    void updateHighLighter() Q_DECL_OVERRIDE;
+    void clearDecorator() Q_DECL_OVERRIDE;
+    void createHighlighter() Q_DECL_OVERRIDE;
 Q_SIGNALS:
-    void openHelp(const QString &variableName, const QString &url);
+    void openHelp(const QString &url);
 
 private:
     bool openVariableHelp();
@@ -73,9 +86,9 @@ private:
     void setCompleterList(const QStringList &list);
     QString selectedWord(const QPoint &pos = QPoint()) const;
 
-    QCompleter *m_completer;
+    PimCommon::SieveSyntaxHighlighterRules mSieveHighliterRules;
     SieveLineNumberArea *m_sieveLineNumberArea;
-    PimCommon::SieveSyntaxHighlighter *m_syntaxHighlighter;
+    KPIMTextEdit::TextEditorCompleter *mTextEditorCompleter;
     bool mShowHelpMenu;
 };
 
