@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,17 +17,19 @@
 #ifndef PARSINGRESULTDIALOG_H
 #define PARSINGRESULTDIALOG_H
 #include "ksieveui_export.h"
-#include <KDialog>
+#include <QDialog>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class PlainTextEditorWidget;
 }
-namespace KSieveUi {
-class KSIEVEUI_EXPORT ParsingResultDialog : public KDialog
+namespace KSieveUi
+{
+class KSIEVEUI_EXPORT ParsingResultDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit ParsingResultDialog(QWidget *parent=0);
+    explicit ParsingResultDialog(QWidget *parent = Q_NULLPTR);
     ~ParsingResultDialog();
 
     void setResultParsing(const QString &result);
