@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,34 +18,21 @@
 #ifndef XMLPRINTINGSYNTAXHIGHLIGHTER_H
 #define XMLPRINTINGSYNTAXHIGHLIGHTER_H
 
+#include <KPIMTextEdit/SyntaxHighlighterBase>
 #include <QList>
 #include <QRegExp>
-#include <QSyntaxHighlighter>
 
 class QTextDocument;
 
-class XMLPrintingSyntaxHighLighter : public QSyntaxHighlighter
+class XMLPrintingSyntaxHighLighter : public KPIMTextEdit::SyntaxHighlighterBase
 {
     Q_OBJECT
 public:
-    explicit XMLPrintingSyntaxHighLighter( QTextDocument *doc );
+    explicit XMLPrintingSyntaxHighLighter(QTextDocument *doc);
     ~XMLPrintingSyntaxHighLighter();
 
-    void highlightBlock(const QString &text);
 private:
-    void init();
-
-    struct Rule {
-        QRegExp pattern;
-        QTextCharFormat format;
-
-        Rule( const QRegExp &r, const QTextCharFormat &f )
-            : pattern(r), format(f) {}
-    };
-
-    QList<Rule> m_rules;
-
+    void init() Q_DECL_OVERRIDE;
 };
 
-
 #endif // XMLPRINTINGSYNTAXHIGHLIGHTER_H
