@@ -20,24 +20,26 @@
 
 #include "pimcommon/templatewidgets/templatelistwidget.h"
 
-namespace PimCommon {
+namespace PimCommon
+{
 class TemplateManager;
 }
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveTemplateListWidget : public PimCommon::TemplateListWidget
 {
     Q_OBJECT
 public:
-    explicit SieveTemplateListWidget(const QString &configName, QWidget *parent = 0);
+    explicit SieveTemplateListWidget(const QString &configName, QWidget *parent = Q_NULLPTR);
     ~SieveTemplateListWidget();
 
-    QVector<PimCommon::defaultTemplate> defaultTemplates();
-    bool addNewTemplate(QString &templateName, QString &templateScript);
-    bool modifyTemplate(QString &templateName, QString &templateScript, bool defaultTemplate);
+    QVector<PimCommon::defaultTemplate> defaultTemplates() Q_DECL_OVERRIDE;
+    bool addNewTemplate(QString &templateName, QString &templateScript) Q_DECL_OVERRIDE;
+    bool modifyTemplate(QString &templateName, QString &templateScript, bool defaultTemplate) Q_DECL_OVERRIDE;
     void setSieveCapabilities(const QStringList &capabilities);
 protected:
-    QMimeData *mimeData( const QList<QListWidgetItem *> items ) const;
+    QMimeData *mimeData(const QList<QListWidgetItem *> items) const;
 private:
     QStringList mCapabilities;
     PimCommon::TemplateManager *mTemplateManager;
@@ -47,7 +49,7 @@ class SieveTemplateWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveTemplateWidget(const QString &title, QWidget *parent = 0);
+    explicit SieveTemplateWidget(const QString &title, QWidget *parent = Q_NULLPTR);
     ~SieveTemplateWidget();
 
     void setSieveCapabilities(const QStringList &capabilities);
