@@ -19,16 +19,17 @@
 
 #include <ksieveui/debug/sievedebugdialog.h>
 
-#include <kcomponentdata.h>
 #include <QApplication>
 
-int main( int argc, char** argv )
+int main(int argc, char **argv)
 {
-  QApplication app( argc, argv );
-  app.setQuitOnLastWindowClosed( false );
-  KComponentData kcd( "sievemanager" );
-  KSieveUi::SieveDebugDialog *dlg = new KSieveUi::SieveDebugDialog;
-  dlg->exec();
-  delete dlg;
-  return 0;
+    QApplication app(argc, argv);
+    app.setQuitOnLastWindowClosed(false);
+    QApplication::setApplicationName(QStringLiteral("sievedebugdialog"));
+    QApplication::setApplicationVersion(QStringLiteral("1.0"));
+
+    KSieveUi::SieveDebugDialog *dlg = new KSieveUi::SieveDebugDialog;
+    dlg->exec();
+    delete dlg;
+    return 0;
 }
