@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -23,9 +23,9 @@
 
 #include <QPointer>
 
-
 class QWidget;
-namespace KSieveUi {
+namespace KSieveUi
+{
 class MultiImapVacationManager;
 class MultiImapVacationDialog;
 class KSIEVEUI_EXPORT VacationManager : public QObject
@@ -41,10 +41,10 @@ public Q_SLOTS:
     void slotEditVacation(const QString &serverName);
 
 Q_SIGNALS:
-    void updateVacationScriptStatus(bool, const QString&);
+    void updateVacationScriptStatus(bool, const QString &);
     void editVacation();
 
-private slots:
+private Q_SLOTS:
     void slotDialogCanceled();
     void slotDialogOk();
 
