@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,18 +15,18 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #ifndef VACATIONWARNINGWIDGET_H
 #define VACATIONWARNINGWIDGET_H
 
 #include <KMessageWidget>
 
-namespace KSieveUi {
+namespace KSieveUi
+{
 class VacationWarningWidget : public KMessageWidget
 {
     Q_OBJECT
 public:
-    explicit VacationWarningWidget(QWidget *parent=0);
+    explicit VacationWarningWidget(QWidget *parent = Q_NULLPTR);
     ~VacationWarningWidget();
 };
 }
