@@ -15,7 +15,6 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #ifndef FILTERACTIONADDHEADERTEST_H
 #define FILTERACTIONADDHEADERTEST_H
 
@@ -25,7 +24,7 @@ class FilterActionAddHeaderTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit FilterActionAddHeaderTest(QObject *parent = 0);
+    explicit FilterActionAddHeaderTest(QObject *parent = Q_NULLPTR);
     ~FilterActionAddHeaderTest();
 private Q_SLOTS:
     void shouldCreateWidget();
