@@ -17,13 +17,13 @@
 
 #include "filteractionaddtoaddressbooktest.h"
 #include "../filteractions/filteractionaddtoaddressbook.h"
-#include <qtest_kde.h>
+#include <qtest.h>
 #include <QWidget>
 #include <QLabel>
 #include <klineedit.h>
 #include <widgets/minimumcombobox.h>
 #include <widgets/tagwidgets.h>
-#include <akonadi/collectioncombobox.h>
+#include <AkonadiWidgets/CollectionComboBox>
 
 FilterActionAddToAddressBookTest::FilterActionAddToAddressBookTest(QObject *parent)
     : QObject(parent)
@@ -41,19 +41,19 @@ void FilterActionAddToAddressBookTest::shouldHaveDefaultValue()
     MailCommon::FilterActionAddToAddressBook filter;
     QWidget *w = filter.createParamWidget(0);
 
-    PimCommon::MinimumComboBox *headerCombo = w->findChild<PimCommon::MinimumComboBox *>(QLatin1String("HeaderComboBox"));
+    PimCommon::MinimumComboBox *headerCombo = w->findChild<PimCommon::MinimumComboBox *>(QStringLiteral("HeaderComboBox"));
     QVERIFY(headerCombo);
 
-    QLabel *label = w->findChild<QLabel *>(QLatin1String("label_with_category"));
+    QLabel *label = w->findChild<QLabel *>(QStringLiteral("label_with_category"));
     QVERIFY(label);
 
-    KPIM::TagWidget *categoryEdit = w->findChild<KPIM::TagWidget *>( QLatin1String("CategoryEdit") );
+    KPIM::TagWidget *categoryEdit = w->findChild<KPIM::TagWidget *>(QStringLiteral("CategoryEdit"));
     QVERIFY(categoryEdit);
 
-    label = w->findChild<QLabel *>(QLatin1String("label_in_addressbook"));
+    label = w->findChild<QLabel *>(QStringLiteral("label_in_addressbook"));
     QVERIFY(label);
 
-    Akonadi::CollectionComboBox *collectionComboBox = w->findChild<Akonadi::CollectionComboBox *>(QLatin1String("AddressBookComboBox") );
+    Akonadi::CollectionComboBox *collectionComboBox = w->findChild<Akonadi::CollectionComboBox *>(QStringLiteral("AddressBookComboBox"));
     QVERIFY(collectionComboBox);
 }
 
@@ -63,13 +63,14 @@ void FilterActionAddToAddressBookTest::shouldReportErrorWhenArgumentIsEmpty()
     KMime::Message::Ptr msgPtr = KMime::Message::Ptr(new KMime::Message());
     Akonadi::Item item;
     item.setPayload<KMime::Message::Ptr>(msgPtr);
-    MailCommon::ItemContext context(item, true);
+    MailCommon::ItemContext context(item, false);
 
     filter.argsFromString("");
     QVERIFY(filter.isEmpty());
     QCOMPARE(filter.process(context, false), MailCommon::FilterAction::ErrorButGoOn);
     QCOMPARE(context.needsPayloadStore(), false);
-
+    QCOMPARE(context.needsFlagStore(), false);
+    QCOMPARE(context.needsFullPayload(), false);
 }
 
 void FilterActionAddToAddressBookTest::shouldReportErrorWhenCollectionIsInvalid()
@@ -78,12 +79,14 @@ void FilterActionAddToAddressBookTest::shouldReportErrorWhenCollectionIsInvalid(
     KMime::Message::Ptr msgPtr = KMime::Message::Ptr(new KMime::Message());
     Akonadi::Item item;
     item.setPayload<KMime::Message::Ptr>(msgPtr);
-    MailCommon::ItemContext context(item, true);
+    MailCommon::ItemContext context(item, false);
 
     filter.argsFromString("foo\t-1\tddd");
     QVERIFY(filter.isEmpty());
     QCOMPARE(filter.process(context, false), MailCommon::FilterAction::ErrorButGoOn);
     QCOMPARE(context.needsPayloadStore(), false);
+    QCOMPARE(context.needsFlagStore(), false);
+    QCOMPARE(context.needsFullPayload(), false);
 }
 
 void FilterActionAddToAddressBookTest::shouldRequiresPart()
@@ -92,4 +95,4 @@ void FilterActionAddToAddressBookTest::shouldRequiresPart()
     QCOMPARE(filter.requiredPart(), MailCommon::SearchRule::Envelope);
 }
 
-QTEST_KDEMAIN(FilterActionAddToAddressBookTest, GUI)
+QTEST_MAIN(FilterActionAddToAddressBookTest)
