@@ -17,7 +17,7 @@
 
 #include "filteractionbeeptest.h"
 #include "../filteractions/filteractionbeep.h"
-#include <qtest_kde.h>
+#include <qtest.h>
 #include <QWidget>
 FilterActionBeepTest::FilterActionBeepTest(QObject *parent)
     : QObject(parent)
@@ -34,7 +34,7 @@ void FilterActionBeepTest::shouldHaveDefaultValue()
 {
     MailCommon::FilterActionBeep w;
     QWidget *widget = w.createParamWidget(0);
-    QCOMPARE(widget->objectName(), QLatin1String("empty_widget"));
+    QCOMPARE(widget->objectName(), QStringLiteral("empty_widget"));
 }
 
 void FilterActionBeepTest::shouldSieveCode()
@@ -62,4 +62,4 @@ void FilterActionBeepTest::shouldSieveRequres()
 
 }
 
-QTEST_KDEMAIN(FilterActionBeepTest, GUI)
+QTEST_MAIN(FilterActionBeepTest)
