@@ -22,7 +22,8 @@
 
 #include "filteractionwithfolder.h"
 
-namespace MailCommon {
+namespace MailCommon
+{
 
 //=============================================================================
 // FilterActionMove - move into folder
@@ -32,12 +33,12 @@ class FilterActionMove: public FilterActionWithFolder
 {
     Q_OBJECT
 public:
-    explicit FilterActionMove( QObject *parent = 0 );
-    ReturnCode process( ItemContext &context, bool applyOnOutbound ) const;
-    SearchRule::RequiredPart requiredPart() const;
-    static FilterAction* newAction();
-    QString sieveCode() const;
-    QStringList sieveRequires() const;
+    explicit FilterActionMove(QObject *parent = Q_NULLPTR);
+    ReturnCode process(ItemContext &context, bool applyOnOutbound) const Q_DECL_OVERRIDE;
+    SearchRule::RequiredPart requiredPart() const Q_DECL_OVERRIDE;
+    static FilterAction *newAction();
+    QString sieveCode() const Q_DECL_OVERRIDE;
+    QStringList sieveRequires() const Q_DECL_OVERRIDE;
 
     QString informationAboutNotValidAction() const;
 };
