@@ -23,16 +23,16 @@
 
 #include <phonon/mediaobject.h>
 
-#include <KDE/KLocale>
+#include <KLocalizedString>
 
-#include <QtCore/QFile>
+#include <QFile>
 #include <QPointer>
 
 using namespace MailCommon;
 
-FilterActionPlaySound::FilterActionPlaySound( )
-    : FilterActionWithTest( QLatin1String("play sound"), i18n( "Play Sound" ) )
-    , mPlayer( 0 )
+FilterActionPlaySound::FilterActionPlaySound()
+    : FilterActionWithTest(QStringLiteral("play sound"), i18n("Play Sound"))
+    , mPlayer(0)
 {
 }
 
@@ -41,28 +41,27 @@ FilterActionPlaySound::~FilterActionPlaySound()
     delete mPlayer;
 }
 
-FilterAction* FilterActionPlaySound::newAction()
+FilterAction *FilterActionPlaySound::newAction()
 {
     return new FilterActionPlaySound();
 }
 
-
 bool FilterActionPlaySound::isEmpty() const
 {
     return (mParameter.isEmpty());
 }
 
-FilterAction::ReturnCode FilterActionPlaySound::process(ItemContext& , bool) const
+FilterAction::ReturnCode FilterActionPlaySound::process(ItemContext &, bool) const
 {
-    if ( mParameter.isEmpty() )
+    if (isEmpty()) {
         return ErrorButGoOn;
+    }
+    if (!mPlayer) {
+        mPlayer = Phonon::createPlayer(Phonon::NotificationCategory);
+    }
 
-    if ( !mPlayer )
-        mPlayer = Phonon::createPlayer( Phonon::NotificationCategory );
-
-    mPlayer->setCurrentSource( mParameter );
+    mPlayer->setCurrentSource(mParameter);
     mPlayer->play();
-
     return GoOn;
 }
 
@@ -71,14 +70,13 @@ SearchRule::RequiredPart FilterActionPlaySound::requiredPart() const
     return SearchRule::Envelope;
 }
 
-
-bool FilterActionPlaySound::argsFromStringInteractive( const QString &argsStr, const QString &filterName )
+bool FilterActionPlaySound::argsFromStringInteractive(const QString &argsStr, const QString &filterName)
 {
     bool needUpdate = false;
-    argsFromString( argsStr );
-    if (!QFile(mParameter).exists()){
-        QPointer<FilterActionMissingSoundUrlDialog> dlg = new FilterActionMissingSoundUrlDialog( filterName, argsStr );
-        if ( dlg->exec() ) {
+    argsFromString(argsStr);
+    if (!QFile(mParameter).exists()) {
+        QPointer<FilterActionMissingSoundUrlDialog> dlg = new FilterActionMissingSoundUrlDialog(filterName, argsStr);
+        if (dlg->exec()) {
             mParameter = dlg->soundUrl();
             needUpdate = true;
         }
@@ -89,6 +87,5 @@ bool FilterActionPlaySound::argsFromStringInteractive( const QString &argsStr, c
 
 QString FilterActionPlaySound::informationAboutNotValidAction() const
 {
-    //KF5 add i18n
-    return QString::fromLatin1("Sound file was not defined.");
+    return i18n("Sound file was not defined.");
 }
