@@ -20,13 +20,14 @@
 #ifndef MAILCOMMON_ITEMCONTEXT_H
 #define MAILCOMMON_ITEMCONTEXT_H
 
-#include "../mailcommon_export.h"
+#include "mailcommon_export.h"
 #include "../search/searchpattern.h"
 
-#include <Akonadi/Collection>
-#include <Akonadi/Item>
+#include <Collection>
+#include <Item>
 
-namespace MailCommon {
+namespace MailCommon
+{
 
 /**
  * @short A helper class for the filtering process
@@ -43,7 +44,7 @@ public:
      * Creates an item context for the given @p item.
      * @p requestedPart the part requested for the item (Envelope, Header or CompleteMessage)
      */
-    ItemContext( const Akonadi::Item &item, bool needsFullPayload );
+    ItemContext(const Akonadi::Item &item, bool needsFullPayload);
 
     /**
      * Returns the item of the context.
@@ -53,7 +54,7 @@ public:
     /**
      * Sets the target collection the item should be moved to.
      */
-    void setMoveTargetCollection( const Akonadi::Collection &collection );
+    void setMoveTargetCollection(const Akonadi::Collection &collection);
 
     /**
      * Returns the target collection the item should be moved to, or an invalid
@@ -89,12 +90,18 @@ public:
     bool deleteItem() const;
 
 private:
+    enum ItemContextAction {
+        None = 0,
+        PlayloadStore = 1,
+        FlagStore = 2,
+        DeleteItem = 4,
+        FullPayload = 8
+    };
+    Q_DECLARE_FLAGS(ItemContextActions, ItemContextAction)
+
     Akonadi::Item mItem;
     Akonadi::Collection mMoveTargetCollection;
-    bool mNeedsPayloadStore;
-    bool mNeedsFlagStore;
-    bool mDeleteItem;
-    bool mNeedsFullPayload;
+    ItemContextActions mItemContextAction;
 };
 
 }
