@@ -17,10 +17,10 @@
 
 // This filter was created by looking at libdbx  &liboe
 
-#include <klocale.h>
-#include <kfiledialog.h>
-#include <ktemporaryfile.h>
-#include <kdebug.h>
+#include <KLocalizedString>
+#include <QTemporaryFile>
+#include "mailimporter_debug.h"
+#include <QFileDialog>
 
 #include "filter_oe.h"
 
@@ -36,15 +36,15 @@
 using namespace MailImporter;
 
 FilterOE::FilterOE() :
-    Filter( i18n("Import Outlook Express Emails"),
-            i18n("Laurence Anderson <br>( Filter enhanced by Danny Kukawka )</p>"),
-            i18n("<p><b>Outlook Express 4/5/6 import filter</b></p>"
-                 "<p>You will need to locate the folder where the mailbox has been "
-                 "stored by searching for .dbx or .mbx files under "
-                 "<ul><li><i>C:\\Windows\\Application Data</i> in Windows 9x</li>"
-                 "<li><i>Documents and Settings</i> in Windows 2000 or later</li></ul></p>"
-                 "<p><b>Note:</b> Since it is possible to recreate the folder structure, the folders from "
-                 "Outlook Express 5 and 6 will be stored under: \"OE-Import\" in your local folder.</p>" ))
+    Filter(i18n("Import Outlook Express Emails"),
+           i18n("Laurence Anderson <br>( Filter enhanced by Danny Kukawka )</p>"),
+           i18n("<p><b>Outlook Express 4/5/6 import filter</b></p>"
+                "<p>You will need to locate the folder where the mailbox has been "
+                "stored by searching for .dbx or .mbx files under "
+                "<ul><li><i>C:\\Windows\\Application Data</i> in Windows 9x</li>"
+                "<li><i>Documents and Settings</i> in Windows 2000 or later</li></ul></p>"
+                "<p><b>Note:</b> Since it is possible to recreate the folder structure, the folders from "
+                "Outlook Express 5 and 6 will be stored under: \"OE-Import\" in your local folder.</p>"))
 {
 }
 
@@ -55,7 +55,7 @@ FilterOE::~FilterOE()
 void FilterOE::import()
 {
     // Select directory containing plain text emails
-    const QString maildir = KFileDialog::getExistingDirectory(QDir::homePath(),filterInfo()->parent());
+    const QString maildir = QFileDialog::getExistingDirectory(filterInfo()->parent(), QString(), QDir::homePath());
     importMails(maildir);
 }
 
@@ -67,7 +67,7 @@ void FilterOE::importMails(const QString  &maildir)
         return;
     }
 
-    QDir dir (mailDir());
+    QDir dir(mailDir());
     QStringList files = dir.entryList(QStringList(QLatin1String("*.[dDmM][bB][xX]")), QDir::Files, QDir::Name);
     if (files.isEmpty()) {
         filterInfo()->alert(i18n("No Outlook Express mailboxes found in directory %1.", mailDir()));
@@ -83,12 +83,14 @@ void FilterOE::importMails(const QString  &maildir)
     filterInfo()->setOverall(0);
 
     /** search the folderfile to recreate folder struct */
-    for ( QStringList::Iterator mailFile = files.begin(); mailFile != files.end(); ++mailFile ) {
-        if(*mailFile == QLatin1String( "Folders.dbx" )) {
+
+    for (QStringList::Iterator mailFile = files.begin(); mailFile != files.end(); ++mailFile) {
+        if (*mailFile == QLatin1String("Folders.dbx")) {
             filterInfo()->addInfoLogEntry(i18n("Import folder structure..."));
             importMailBox(dir.filePath(*mailFile));
-            if(!folderStructure.isEmpty())
+            if (!folderStructure.isEmpty()) {
                 parsedFolder = true;
+            }
             // remove file from QStringList::files, no longer needed
             files.erase(mailFile);
             currentIsFolderFile = false;
@@ -96,11 +98,12 @@ void FilterOE::importMails(const QString  &maildir)
         }
     }
 
-    int n=0;
-    QStringList::ConstIterator end( files.constEnd() );
-    for ( QStringList::ConstIterator mailFile = files.constBegin(); mailFile != end; ++mailFile ) {
-        if ( filterInfo()->shouldTerminate() )
+    int n = 0;
+    QStringList::ConstIterator end(files.constEnd());
+    for (QStringList::ConstIterator mailFile = files.constBegin(); mailFile != end; ++mailFile) {
+        if (filterInfo()->shouldTerminate()) {
             break;
+        }
         importMailBox(dir.filePath(*mailFile));
         filterInfo()->setOverall(100 * ++n  / files.count());
     }
@@ -108,21 +111,22 @@ void FilterOE::importMails(const QString  &maildir)
     filterInfo()->setOverall(100);
     filterInfo()->setCurrent(100);
     filterInfo()->addInfoLogEntry(i18n("Finished importing Outlook Express emails"));
-    if (filterInfo()->shouldTerminate())
-        filterInfo()->addInfoLogEntry( i18n("Finished import, canceled by user."));
+    if (filterInfo()->shouldTerminate()) {
+        filterInfo()->addInfoLogEntry(i18n("Finished import, canceled by user."));
+    }
 
-    kDebug() <<"total emails in current file:" << totalEmails;
-    kDebug() <<"0x84 Mails:" << count0x84;
-    kDebug() <<"0x04 Mails:" << count0x04;
+    qCDebug(MAILIMPORTER_LOG) << "total emails in current file:" << totalEmails;
+    qCDebug(MAILIMPORTER_LOG) << "0x84 Mails:" << count0x84;
+    qCDebug(MAILIMPORTER_LOG) << "0x04 Mails:" << count0x04;
 }
 
-void FilterOE::importMailBox( const QString &fileName)
+void FilterOE::importMailBox(const QString &fileName)
 {
     QFile mailfile(fileName);
     QFileInfo mailfileinfo(fileName);
     QString _nameOfFile = fileName;
-    _nameOfFile.remove( mailDir() );
-    _nameOfFile.remove( QLatin1Char('/') );
+    _nameOfFile.remove(mailDir());
+    _nameOfFile.remove(QLatin1Char('/'));
     filterInfo()->setFrom(mailfileinfo.fileName());
 
     if (!mailfile.open(QIODevice::ReadOnly)) {
@@ -137,7 +141,7 @@ void FilterOE::importMailBox( const QString &fileName)
     mailbox >> sig_block1 >> sig_block2;
     if (sig_block1 == OE4_SIG_1 && sig_block2 == OE4_SIG_2) {
         folderName = QLatin1String("OE-Import/") + mailfileinfo.completeBaseName();
-        filterInfo()->addInfoLogEntry(i18n("Importing OE4 Mailbox %1", QLatin1String("../") + _nameOfFile));
+        filterInfo()->addInfoLogEntry(i18n("Importing OE4 Mailbox %1", QStringLiteral("../") + _nameOfFile));
         filterInfo()->setTo(folderName);
         mbxImport(mailbox);
         return;
@@ -147,17 +151,19 @@ void FilterOE::importMailBox( const QString &fileName)
         if (sig_block1 == OE5_SIG_1 && sig_block3 == OE5_SIG_3 && sig_block4 == OE5_SIG_4) {
             if (sig_block2 == OE5_EMAIL_SIG_2) {
                 folderName = QLatin1String("OE-Import/") + mailfileinfo.completeBaseName();
-                if(parsedFolder) {
+                if (parsedFolder) {
                     const QString _tmpFolder = getFolderName(_nameOfFile);
-                    if(!_tmpFolder.isEmpty()) folderName = QLatin1String("OE-Import/") + _tmpFolder;
+                    if (!_tmpFolder.isEmpty()) {
+                        folderName = QLatin1String("OE-Import/") + _tmpFolder;
+                    }
                 }
-                filterInfo()->addInfoLogEntry(i18n("Importing OE5+ Mailbox %1", QLatin1String("../") + _nameOfFile));
+                filterInfo()->addInfoLogEntry(i18n("Importing OE5+ Mailbox %1", QStringLiteral("../") + _nameOfFile));
                 filterInfo()->setTo(folderName);
                 dbxImport(mailbox);
                 return;
             } else if (sig_block2 == OE5_FOLDER_SIG_2) {
-                if(!parsedFolder) {
-                    filterInfo()->addInfoLogEntry(i18n("Importing OE5+ Folder file %1", QLatin1String("../") + _nameOfFile));
+                if (!parsedFolder) {
+                    filterInfo()->addInfoLogEntry(i18n("Importing OE5+ Folder file %1", QStringLiteral("../") + _nameOfFile));
                     currentIsFolderFile = true;
                     dbxImport(mailbox);
                     currentIsFolderFile = false;
@@ -171,56 +177,59 @@ void FilterOE::importMailBox( const QString &fileName)
 
 /* ------------------- MBX support ------------------- */
 
-void FilterOE::mbxImport( QDataStream &ds)
+void FilterOE::mbxImport(QDataStream &ds)
 {
     quint32 msgCount, lastMsgNum, fileSize;
 
     // Read the header
     ds >> msgCount >> lastMsgNum >> fileSize;
-    ds.device()->seek( ds.device()->pos() + 64 ); // Skip 0's
-    kDebug() <<"This mailbox has" << msgCount <<" messages";
-    if (msgCount == 0)
-        return; // Don't import empty mailbox
+    ds.device()->seek(ds.device()->pos() + 64);   // Skip 0's
+    qCDebug(MAILIMPORTER_LOG) << "This mailbox has" << msgCount << " messages";
+    if (msgCount == 0) {
+        return;    // Don't import empty mailbox
+    }
 
     quint32 msgMagic;
     ds >> msgMagic; // Read first magic
 
     while (!ds.atEnd()) {
+
         quint32 msgNumber, msgSize, msgTextSize;
-        KTemporaryFile tmp;
+        QTemporaryFile tmp;
         tmp.open();
-        QDataStream ds(&tmp);
-        ds.setByteOrder(QDataStream::LittleEndian);
+        QDataStream dataStream(&tmp);
+        dataStream.setByteOrder(QDataStream::LittleEndian);
 
         // Read the messages
         ds >> msgNumber >> msgSize >> msgTextSize; // All seem to be lies...?
-
         do {
             ds >> msgMagic;
-            if (msgMagic != MBX_MAILMAGIC)
-                ds << msgMagic;
-            else
+            if (msgMagic != MBX_MAILMAGIC) {
+                dataStream << msgMagic;
+            } else {
                 break;
-        } while ( !ds.atEnd() );
-
+            }
+        } while (!ds.atEnd());
         tmp.flush();
         /* comment by Danny Kukawka:
-     * addMessage() == old function, need more time and check for duplicates
-     * addMessage_fastImport == new function, faster and no check for duplicates
-     */
-        if(filterInfo()->removeDupMessage())
-            addMessage( folderName, tmp.fileName() );
-        else
-            addMessage_fastImport( folderName, tmp.fileName() );
+        * addMessage() == old function, need more time and check for duplicates
+        * addMessage_fastImport == new function, faster and no check for duplicates
+        */
+        if (filterInfo()->removeDupMessage()) {
+            addMessage(folderName, tmp.fileName());
+        } else {
+            addMessage_fastImport(folderName, tmp.fileName());
+        }
 
-        if(filterInfo()->shouldTerminate())
+        if (filterInfo()->shouldTerminate()) {
             return;
+        }
     }
 }
 
 /* ------------------- DBX support ------------------- */
 
-void FilterOE::dbxImport( QDataStream &ds)
+void FilterOE::dbxImport(QDataStream &ds)
 {
     // Get item count  &offset of index
     quint32 itemCount, indexPtr;
@@ -228,10 +237,11 @@ void FilterOE::dbxImport( QDataStream &ds)
     ds >> itemCount;
     ds.device()->seek(0xe4);
     ds >> indexPtr;
-    kDebug() <<"Item count is" << itemCount <<", Index at" << indexPtr;
+    qCDebug(MAILIMPORTER_LOG) << "Item count is" << itemCount << ", Index at" << indexPtr;
 
-    if (itemCount == 0)
-        return; // Empty file
+    if (itemCount == 0) {
+        return;    // Empty file
+    }
     totalEmails = itemCount;
     currentEmail = 0;
     // Parse the indexes
@@ -239,36 +249,39 @@ void FilterOE::dbxImport( QDataStream &ds)
     dbxReadIndex(ds, indexPtr);
 }
 
-void FilterOE::dbxReadIndex( QDataStream &ds, int filePos)
+void FilterOE::dbxReadIndex(QDataStream &ds, int filePos)
 {
 
-    if(filterInfo()->shouldTerminate()) return;
+    if (filterInfo()->shouldTerminate()) {
+        return;
+    }
     quint32 self, unknown, nextIndexPtr, parent, indexCount;
     quint8 unknown2, ptrCount;
     quint16 unknown3;
     int wasAt = ds.device()->pos();
     ds.device()->seek(filePos);
 
-
-    kDebug() <<"Reading index of file" << folderName;
+    qCDebug(MAILIMPORTER_LOG) << "Reading index of file" << folderName;
     ds >> self >> unknown >> nextIndexPtr >> parent >> unknown2 >> ptrCount >> unknown3 >> indexCount; // _dbx_tableindexstruct
 
-    kDebug() <<"This index has" << (int) ptrCount <<" data pointers";
-    for (int count = 0; count < ptrCount; count++) {
-        if(filterInfo()->shouldTerminate()) return;
+    qCDebug(MAILIMPORTER_LOG) << "This index has" << (int) ptrCount << " data pointers";
+    for (int count = 0; count < ptrCount; ++count) {
+        if (filterInfo()->shouldTerminate()) {
+            return;
+        }
         quint32 dataIndexPtr, anotherIndexPtr, anotherIndexCount; // _dbx_indexstruct
         ds >> dataIndexPtr >> anotherIndexPtr >> anotherIndexCount;
 
         if (anotherIndexCount > 0) {
-            kDebug() <<"Recursing to another table @" << anotherIndexPtr;
+            qCDebug(MAILIMPORTER_LOG) << "Recursing to another table @" << anotherIndexPtr;
             dbxReadIndex(ds, anotherIndexPtr);
         }
-        kDebug() <<"Data index @" << dataIndexPtr;
-        dbxReadDataBlock( ds, dataIndexPtr);
+        qCDebug(MAILIMPORTER_LOG) << "Data index @" << dataIndexPtr;
+        dbxReadDataBlock(ds, dataIndexPtr);
     }
 
     if (indexCount > 0) { // deal with nextTablePtr
-        kDebug() <<"Recuring to next table @" << nextIndexPtr;
+        qCDebug(MAILIMPORTER_LOG) << "Recuring to next table @" << nextIndexPtr;
         dbxReadIndex(ds, nextIndexPtr);
     }
 
@@ -287,10 +300,12 @@ void FilterOE::dbxReadDataBlock(QDataStream &ds, int filePos)
     ds.device()->seek(filePos);
 
     ds >> curOffset >> blockSize >> unknown >> count >> unknown2; // _dbx_email_headerstruct
-    kDebug() <<"Data block has" << (int) count <<" elements";
+    qCDebug(MAILIMPORTER_LOG) << "Data block has" << (int) count << " elements";
 
     for (int c = 0; c < count; c++) {
-        if(filterInfo()->shouldTerminate()) return;
+        if (filterInfo()->shouldTerminate()) {
+            return;
+        }
         quint8 type;  // _dbx_email_pointerstruct
         quint32 value; // Actually 24 bit
 
@@ -298,42 +313,41 @@ void FilterOE::dbxReadDataBlock(QDataStream &ds, int filePos)
         value &= 0xffffff;
         ds.device()->seek(ds.device()->pos() - 1); // We only wanted 3 bytes
 
-        if(!currentIsFolderFile) {
+        if (!currentIsFolderFile) {
             if (type == 0x84) { // It's an email!
-                kDebug() <<"**** Offset of emaildata (0x84)" << value <<" ****";
-                dbxReadEmail( ds, value);
+                qCDebug(MAILIMPORTER_LOG) << "**** Offset of emaildata (0x84)" << value << " ****";
+                dbxReadEmail(ds, value);
                 ++count0x84;
-            } else if( type == 0x04) {
+            } else if (type == 0x04) {
                 int currentFilePos = ds.device()->pos();
-                ds.device()->seek(filePos + 12 + value + (count*4) );
+                ds.device()->seek(filePos + 12 + value + (count * 4));
                 quint32 newOFF;
                 ds >> newOFF;
-                kDebug() <<"**** Offset of emaildata (0x04)" <<  newOFF;
+                qCDebug(MAILIMPORTER_LOG) << "**** Offset of emaildata (0x04)" <<  newOFF;
                 ds.device()->seek(currentFilePos);
                 dbxReadEmail(ds, newOFF);
                 ++count0x04;
             }
-        }
-        else {
+        } else {
             // this is a folderfile
-            if(type == 0x02) {
-                // kDebug() <<"**** FOLDER: descriptive name ****";
-                folderEntry[0] = parseFolderString(ds, filePos + 12 + value + (count*4) );
+            if (type == 0x02) {
+                // qCDebug(MAILIMPORTER_LOG) <<"**** FOLDER: descriptive name ****";
+                folderEntry[0] = parseFolderString(ds, filePos + 12 + value + (count * 4));
             } else if (type == 0x03) {
-                // kDebug() <<"**** FOLDER: filename ****";
-                folderEntry[1] = parseFolderString(ds, filePos + 12 + value + (count*4) );
+                // qCDebug(MAILIMPORTER_LOG) <<"**** FOLDER: filename ****";
+                folderEntry[1] = parseFolderString(ds, filePos + 12 + value + (count * 4));
 
             } else if (type == 0x80) {
-                // kDebug() <<"**** FOLDER: current ID ****";
+                // qCDebug(MAILIMPORTER_LOG) <<"**** FOLDER: current ID ****";
                 folderEntry[2] = QString::number(value);
 
             } else if (type == 0x81) {
-                // kDebug() <<"**** FOLDER: parent ID ****";
+                // qCDebug(MAILIMPORTER_LOG) <<"**** FOLDER: parent ID ****";
                 folderEntry[3] =  QString::number(value);
             }
         }
     }
-    if(currentIsFolderFile) {
+    if (currentIsFolderFile) {
         folderStructure.append(FolderStructure(folderEntry));
     }
     ds.device()->seek(wasAt); // Restore file position to same as when function called
@@ -341,24 +355,26 @@ void FilterOE::dbxReadDataBlock(QDataStream &ds, int filePos)
 
 void FilterOE::dbxReadEmail(QDataStream &ds, int filePos)
 {
-    if(filterInfo()->shouldTerminate()) return;
-    quint32 self, nextAddressOffset, nextAddress=0;
+    if (filterInfo()->shouldTerminate()) {
+        return;
+    }
+    quint32 self, nextAddressOffset, nextAddress = 0;
     quint16 blockSize;
     quint8 intCount, unknown;
-    KTemporaryFile tmp;
+    QTemporaryFile tmp;
     tmp.open();
     bool _break = false;
     int wasAt = ds.device()->pos();
     ds.device()->seek(filePos);
-    QDataStream tempDs (&tmp);
+    QDataStream tempDs(&tmp);
 
     do {
         ds >> self >> nextAddressOffset >> blockSize >> intCount >> unknown >> nextAddress; // _dbx_block_hdrstruct
-        QByteArray blockBuffer(blockSize,'\0');
+        QByteArray blockBuffer(blockSize, '\0');
         ds.readRawData(blockBuffer.data(), blockSize);
         tempDs.writeRawData(blockBuffer.data(), blockSize);
         // to detect incomplete mails or corrupted archives. See Bug #86119
-        if(ds.atEnd()) {
+        if (ds.atEnd()) {
             _break = true;
             break;
         }
@@ -366,21 +382,22 @@ void FilterOE::dbxReadEmail(QDataStream &ds, int filePos)
     } while (nextAddress != 0);
     tmp.flush();
 
-    if(!_break) {
-        if(filterInfo()->removeDupMessage())
-            addMessage( folderName, tmp.fileName() );
-        else
-            addMessage_fastImport( folderName, tmp.fileName() );
+    if (!_break) {
+        if (filterInfo()->removeDupMessage()) {
+            addMessage(folderName, tmp.fileName());
+        } else {
+            addMessage_fastImport(folderName, tmp.fileName());
+        }
 
         currentEmail++;
-        int currentPercentage = (int) ( ( (float) currentEmail / totalEmails ) * 100 );
+        int currentPercentage = (int)(((float) currentEmail / totalEmails) * 100);
         filterInfo()->setCurrent(currentPercentage);
         ds.device()->seek(wasAt);
     }
 }
 
 /* ------------------- FolderFile support ------------------- */
-QString FilterOE::parseFolderString( QDataStream &ds, int filePos )
+QString FilterOE::parseFolderString(QDataStream &ds, int filePos)
 {
     char tmp;
     QString returnString;
@@ -388,12 +405,13 @@ QString FilterOE::parseFolderString( QDataStream &ds, int filePos )
     ds.device()->seek(filePos);
 
     // read while != 0x00
-    while( !ds.device()->atEnd() ) {
+    while (!ds.device()->atEnd()) {
         ds.device()->getChar(&tmp);
-        if( tmp != 0x00) {
+        if (tmp != 0x00) {
             returnString += QLatin1Char(tmp);
+        } else {
+            break;
         }
-        else break;
     }
     ds.device()->seek(wasAt);
     return returnString;
@@ -409,34 +427,35 @@ QString FilterOE::getFolderName(const QString &filename)
     // at start have maybe not a file named like the folder !!!
     QString search = filename.toLower();
 
-    while (!found)
-    {
-        for ( FolderStructureIterator it = folderStructure.begin(); it != folderStructure.end(); ++it) {
+    while (!found) {
+        for (FolderStructureIterator it = folderStructure.begin(); it != folderStructure.end(); ++it) {
             FolderStructure tmp = *it;
-            if(foundFilename == false) {
+            if (foundFilename == false) {
                 QString _tmpFileName = tmp[1];
                 _tmpFileName = _tmpFileName.toLower();
-                if(_tmpFileName == search) {
-                    folder.prepend( tmp[0] + QString::fromLatin1("/") );
+                if (_tmpFileName == search) {
+                    folder.prepend(tmp[0] + QString::fromLatin1("/"));
                     search = tmp[3];
                     foundFilename = true;
                 }
             } else {
                 QString _currentID = tmp[2];
                 QString _parentID = tmp[3];
-                if(_currentID == search) {
-                    if(_parentID.isEmpty()) { // this is the root of the folder
+                if (_currentID == search) {
+                    if (_parentID.isEmpty()) { // this is the root of the folder
                         found = true;
                         break;
                     } else {
-                        folder.prepend( tmp[0] + QString::fromLatin1("/") );
+                        folder.prepend(tmp[0] + QString::fromLatin1("/"));
                         search = tmp[3];
                     }
                 }
             }
         }
         // need to break the while loop maybe in some cases
-        if((foundFilename == false) && (folder.isEmpty())) return folder;
+        if ((foundFilename == false) && (folder.isEmpty())) {
+            return folder;
+        }
     }
     return folder;
 }
