@@ -20,39 +20,41 @@
 
 #include <mailcommon/interfaces/mailinterfaces.h>
 
-namespace Akonadi {
+namespace Akonadi
+{
 class EntityTreeModel;
 class EntityMimeTypeFilterModel;
 }
 
-namespace MailCommon {
+namespace MailCommon
+{
 class FolderCollectionMonitor;
 }
 
 class MBoxImporterKernel : public QObject, public MailCommon::IKernel, public MailCommon::ISettings
 {
 public:
-    explicit MBoxImporterKernel( QObject *parent = 0 );
+    explicit MBoxImporterKernel(QObject *parent = Q_NULLPTR);
 
-    KPIMIdentities::IdentityManager *identityManager();
-    MessageComposer::MessageSender *msgSender();
+    KIdentityManagement::IdentityManager *identityManager() Q_DECL_OVERRIDE;
+    MessageComposer::MessageSender *msgSender() Q_DECL_OVERRIDE;
 
-    Akonadi::EntityMimeTypeFilterModel *collectionModel() const;
-    KSharedConfig::Ptr config();
-    void syncConfig();
-    MailCommon::JobScheduler* jobScheduler() const;
-    Akonadi::ChangeRecorder *folderCollectionMonitor() const;
-    void updateSystemTray();
+    Akonadi::EntityMimeTypeFilterModel *collectionModel() const Q_DECL_OVERRIDE;
+    KSharedConfig::Ptr config() Q_DECL_OVERRIDE;
+    void syncConfig() Q_DECL_OVERRIDE;
+    MailCommon::JobScheduler *jobScheduler() const Q_DECL_OVERRIDE;
+    Akonadi::ChangeRecorder *folderCollectionMonitor() const Q_DECL_OVERRIDE;
+    void updateSystemTray() Q_DECL_OVERRIDE;
+
+    qreal closeToQuotaThreshold() Q_DECL_OVERRIDE;
+    bool excludeImportantMailFromExpiry() Q_DECL_OVERRIDE;
+    QStringList customTemplates() Q_DECL_OVERRIDE;
+    Akonadi::Entity::Id lastSelectedFolder() Q_DECL_OVERRIDE;
+    void setLastSelectedFolder(const Akonadi::Entity::Id &col) Q_DECL_OVERRIDE;
+    bool showPopupAfterDnD() Q_DECL_OVERRIDE;
 
-    qreal closeToQuotaThreshold();
-    bool excludeImportantMailFromExpiry();
-    QStringList customTemplates();
-    Akonadi::Entity::Id lastSelectedFolder();
-    void setLastSelectedFolder(const Akonadi::Entity::Id& col);
-    bool showPopupAfterDnD();
-    
 private:
-    KPIMIdentities::IdentityManager *mIdentityManager;
+    KIdentityManagement::IdentityManager *mIdentityManager;
     MailCommon::FolderCollectionMonitor *mFolderCollectionMonitor;
     Akonadi::EntityTreeModel *mEntityTreeModel;
     Akonadi::EntityMimeTypeFilterModel *mCollectionModel;
