@@ -17,9 +17,6 @@
 #include "imagescaling.h"
 #include "settings/messagecomposersettings.h"
 
-#include <QBuffer>
-#include <QImage>
-
 using namespace MessageComposer;
 
 ImageScaling::ImageScaling()
@@ -30,7 +27,7 @@ ImageScaling::~ImageScaling()
 {
 }
 
-bool ImageScaling::loadImageFromData(const QByteArray& data)
+bool ImageScaling::loadImageFromData(const QByteArray &data)
 {
     if (!mImage.loadFromData(data)) {
         return false;
@@ -40,8 +37,9 @@ bool ImageScaling::loadImageFromData(const QByteArray& data)
 
 bool ImageScaling::resizeImage()
 {
-    if (mImage.isNull())
+    if (mImage.isNull()) {
         return false;
+    }
     const int width = mImage.width();
     const int height = mImage.height();
     int newWidth = -1;
@@ -56,7 +54,7 @@ bool ImageScaling::resizeImage()
         if (maximumHeight == -1) {
             maximumHeight = MessageComposer::MessageComposerSettings::self()->customMaximumHeight();
         }
-        if ( width > maximumWidth ) {
+        if (width > maximumWidth) {
             newWidth = maximumWidth;
         } else {
             newWidth = width;
@@ -70,7 +68,6 @@ bool ImageScaling::resizeImage()
         newHeight = height;
         newWidth = width;
     }
-
     if (MessageComposer::MessageComposerSettings::self()->enlargeImageToMinimum()) {
 
         int minimumWidth = MessageComposer::MessageComposerSettings::self()->minimumWidth();
@@ -91,8 +88,20 @@ bool ImageScaling::resizeImage()
     }
     if ((newHeight != height) || (newWidth != width)) {
         mBuffer.open(QIODevice::WriteOnly);
-        mImage = mImage.scaled(newWidth,newHeight, MessageComposer::MessageComposerSettings::self()->keepImageRatio() ? Qt::KeepAspectRatio : Qt::IgnoreAspectRatio);
-        const bool result = mImage.save(&mBuffer,MessageComposer::MessageComposerSettings::self()->writeFormat().toLocal8Bit());
+        mImage = mImage.scaled(newWidth, newHeight, MessageComposer::MessageComposerSettings::self()->keepImageRatio() ? Qt::KeepAspectRatio : Qt::IgnoreAspectRatio);
+
+        QByteArray format;
+        if (mMimeType == "image/jpeg") {
+            format = "JPG";
+        } else if (mMimeType == "image/png") {
+            format = "PNG";
+        } else {
+            format = MessageComposer::MessageComposerSettings::self()->writeFormat().toLocal8Bit();
+            if (format.isEmpty()) {
+                format = "PNG";
+            }
+        }
+        const bool result = mImage.save(&mBuffer, format);
         mBuffer.close();
         return result;
     } else {
@@ -104,18 +113,68 @@ bool ImageScaling::resizeImage()
 
 QByteArray ImageScaling::mimetype() const
 {
-    //Add more mimetype if a day we add more saving format.
-    const QString type = MessageComposer::MessageComposerSettings::self()->writeFormat();
-    if (type == QLatin1String("JPG")) {
-        return "image/jpeg";
-    } else if (type == QLatin1String("PNG")) {
-        return "image/png";
+    if (mMimeType.isEmpty()) {
+        return QByteArray();
+    }
+    if ((mMimeType == "image/jpeg") || (mMimeType == "image/png")) {
+        return mMimeType;
+    } else {
+        //Add more mimetype if a day we add more saving format.
+        const QString type = MessageComposer::MessageComposerSettings::self()->writeFormat();
+        if (type == QLatin1String("JPG")) {
+            return "image/jpeg";
+        } else if (type == QLatin1String("PNG")) {
+            return "image/png";
+        } else {
+            return "image/png";
+        }
     }
     return QByteArray();
 }
 
+void ImageScaling::setMimetype(const QByteArray &mimetype)
+{
+    mMimeType = mimetype;
+}
+
+void ImageScaling::setName(const QString &name)
+{
+    mName = name;
+}
+
 QByteArray ImageScaling::imageArray() const
 {
     return mBuffer.data();
 }
 
+QString ImageScaling::generateNewName()
+{
+    if (mName.isEmpty()) {
+        return QString();
+    }
+
+    // Don't rename it.
+    if ((mMimeType == "image/jpeg") || (mMimeType == "image/png")) {
+        return mName;
+    }
+    QString type = MessageComposer::MessageComposerSettings::self()->writeFormat();
+    if (type.isEmpty()) {
+        type = QStringLiteral("PNG");
+    }
+    if (mName.endsWith(QStringLiteral(".png"))) {
+        if (type != QLatin1String("PNG")) {
+            mName.replace(QStringLiteral(".png"), QStringLiteral(".jpg"));
+        }
+    } else if (mName.endsWith(QStringLiteral(".jpg"))) {
+        if (type != QLatin1String("JPG")) {
+            mName.replace(QStringLiteral(".jpg"), QStringLiteral(".png"));
+        }
+    } else {
+        if (type == QLatin1String("PNG")) {
+            mName += QLatin1String(".png");
+        } else {
+            mName += QLatin1String(".jpg");
+        }
+    }
+    return mName;
+}
