@@ -17,12 +17,14 @@
 #ifndef IMAGESCALING_H
 #define IMAGESCALING_H
 
+#include "messagecomposer_export.h"
 #include <QByteArray>
 #include <QImage>
 #include <QBuffer>
 
-namespace MessageComposer {
-class ImageScaling
+namespace MessageComposer
+{
+class MESSAGECOMPOSER_EXPORT ImageScaling
 {
 public:
     ImageScaling();
@@ -33,7 +35,7 @@ public:
      * @param data
      * @return true if we can load image.
      */
-    bool loadImageFromData(const QByteArray& data);
+    bool loadImageFromData(const QByteArray &data);
 
     /**
      * @brief resizeImage
@@ -52,10 +54,16 @@ public:
      * @return new image mimetype after saving.
      */
     QByteArray mimetype() const;
+    void setMimetype(const QByteArray &mimetype);
 
+    void setName(const QString &name);
+
+    QString generateNewName();
 private:
     QImage mImage;
     QBuffer mBuffer;
+    QString mName;
+    QByteArray mMimeType;
 };
 }
 
