@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,8 +19,10 @@
 #define AUTORESIZEIMAGEUTIL_H
 #include <messagecore/attachment/attachmentpart.h>
 
-namespace MessageComposer {
-namespace Utils {
+namespace MessageComposer
+{
+namespace Utils
+{
 bool containsImage(const MessageCore::AttachmentPart::List &parts);
 bool resizeImage(MessageCore::AttachmentPart::Ptr part);
 void changeFileName(MessageCore::AttachmentPart::Ptr part);
