@@ -29,7 +29,7 @@
 using namespace MessageComposer;
 
 ImageScalingWidget::ImageScalingWidget(QWidget *parent)
-    :QWidget(parent),
+    : QWidget(parent),
       ui(new Ui::ImageScalingWidget),
       mWasChanged(false)
 {
@@ -40,54 +40,54 @@ ImageScalingWidget::ImageScalingWidget(QWidget *parent)
     initComboBox(ui->CBMinimumHeight);
 
     initWriteImageFormat();
-    connect(ui->enabledAutoResize,SIGNAL(clicked()),SIGNAL(changed()));
-    connect(ui->KeepImageRatio,SIGNAL(clicked()),SIGNAL(changed()));
-    connect(ui->AskBeforeResizing,SIGNAL(clicked()),SIGNAL(changed()));
-    connect(ui->EnlargeImageToMinimum,SIGNAL(clicked()),SIGNAL(changed()));
-    connect(ui->ReduceImageToMaximum,SIGNAL(clicked()),SIGNAL(changed()));
-    connect(ui->customMaximumWidth,SIGNAL(valueChanged(int)),SIGNAL(changed()));
-    connect(ui->customMaximumHeight,SIGNAL(valueChanged(int)),SIGNAL(changed()));
-    connect(ui->customMinimumWidth,SIGNAL(valueChanged(int)),SIGNAL(changed()));
-    connect(ui->customMinimumHeight,SIGNAL(valueChanged(int)),SIGNAL(changed()));
-    connect(ui->skipImageSizeLower,SIGNAL(clicked()),SIGNAL(changed()));
-    connect(ui->imageSize,SIGNAL(valueChanged(int)),SIGNAL(changed()));
-    connect(ui->pattern,SIGNAL(textChanged(QString)),SIGNAL(changed()));
-    connect(ui->CBMaximumWidth,SIGNAL(currentIndexChanged(int)),SLOT(slotComboboxChanged(int)));
-    connect(ui->CBMaximumHeight,SIGNAL(currentIndexChanged(int)),SLOT(slotComboboxChanged(int)));
-    connect(ui->CBMinimumWidth,SIGNAL(currentIndexChanged(int)),SLOT(slotComboboxChanged(int)));
-    connect(ui->CBMinimumHeight,SIGNAL(currentIndexChanged(int)),SLOT(slotComboboxChanged(int)));
-    connect(ui->WriteToImageFormat,SIGNAL(activated(int)),SIGNAL(changed()));
-    connect(ui->renameResizedImage,SIGNAL(clicked()),SIGNAL(changed()));
-    connect(ui->renameResizedImage,SIGNAL(clicked(bool)),ui->renameResizedImagePattern,SLOT(setEnabled(bool)));
-    connect(ui->renameResizedImagePattern,SIGNAL(textChanged(QString)),SIGNAL(changed()));
+    connect(ui->enabledAutoResize, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
+    connect(ui->KeepImageRatio, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
+    connect(ui->AskBeforeResizing, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
+    connect(ui->EnlargeImageToMinimum, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
+    connect(ui->ReduceImageToMaximum, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
+    connect(ui->customMaximumWidth, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
+    connect(ui->customMaximumHeight, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
+    connect(ui->customMinimumWidth, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
+    connect(ui->customMinimumHeight, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
+    connect(ui->skipImageSizeLower, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
+    connect(ui->imageSize, static_cast<void (QSpinBox::*)(int)>(&QSpinBox::valueChanged), this, &ImageScalingWidget::changed);
+    connect(ui->pattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
+    connect(ui->CBMaximumWidth, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
+    connect(ui->CBMaximumHeight, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
+    connect(ui->CBMinimumWidth, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
+    connect(ui->CBMinimumHeight, static_cast<void (KComboBox::*)(int)>(&KComboBox::currentIndexChanged), this, &ImageScalingWidget::slotComboboxChanged);
+    connect(ui->WriteToImageFormat, static_cast<void (KComboBox::*)(int)>(&KComboBox::activated), this, &ImageScalingWidget::changed);
+    connect(ui->renameResizedImage, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
+    connect(ui->renameResizedImage, &QCheckBox::clicked, ui->renameResizedImagePattern, &KLineEdit::setEnabled);
+    connect(ui->renameResizedImagePattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
 
-    connect(ui->resizeEmailsPattern,SIGNAL(textChanged(QString)),SIGNAL(changed()));
-    connect(ui->doNotResizePattern,SIGNAL(textChanged(QString)),SIGNAL(changed()));
-    connect(ui->resizeImageWithFormatsType,SIGNAL(textChanged(QString)),SIGNAL(changed()));
-    connect(ui->resizeImageWithFormats,SIGNAL(clicked(bool)),SIGNAL(changed()));
-    connect(ui->resizeImageWithFormats,SIGNAL(clicked(bool)),ui->resizeImageWithFormatsType,SLOT(setEnabled(bool)));
+    connect(ui->resizeEmailsPattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
+    connect(ui->doNotResizePattern, &KLineEdit::textChanged, this, &ImageScalingWidget::changed);
+    connect(ui->resizeImageWithFormatsType, &MessageComposer::ImageScalingSelectFormat::textChanged, this, &ImageScalingWidget::changed);
+    connect(ui->resizeImageWithFormats, &QCheckBox::clicked, this, &ImageScalingWidget::changed);
+    connect(ui->resizeImageWithFormats, &QCheckBox::clicked, ui->resizeImageWithFormatsType, &MessageComposer::ImageScalingSelectFormat::setEnabled);
     ui->resizeImageWithFormatsType->setEnabled(false);
 
     ui->pattern->setEnabled(false);
     mSourceFilenameFilterGroup = new QButtonGroup(ui->filterSourceGroupBox);
-    connect( mSourceFilenameFilterGroup, SIGNAL(buttonClicked(int)), this, SLOT(slotSourceFilterClicked(int)) );
-    mSourceFilenameFilterGroup->addButton( ui->notFilterFilename, MessageComposer::MessageComposerSettings::EnumFilterSourceType::NoFilter );
-    mSourceFilenameFilterGroup->addButton( ui->includeFilesWithPattern, MessageComposer::MessageComposerSettings::EnumFilterSourceType::IncludeFilesWithPattern );
-    mSourceFilenameFilterGroup->addButton( ui->excludeFilesWithPattern, MessageComposer::MessageComposerSettings::EnumFilterSourceType::ExcludeFilesWithPattern );
+    connect(mSourceFilenameFilterGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotSourceFilterClicked);
+    mSourceFilenameFilterGroup->addButton(ui->notFilterFilename, MessageComposer::MessageComposerSettings::EnumFilterSourceType::NoFilter);
+    mSourceFilenameFilterGroup->addButton(ui->includeFilesWithPattern, MessageComposer::MessageComposerSettings::EnumFilterSourceType::IncludeFilesWithPattern);
+    mSourceFilenameFilterGroup->addButton(ui->excludeFilesWithPattern, MessageComposer::MessageComposerSettings::EnumFilterSourceType::ExcludeFilesWithPattern);
 
     mRecipientFilterGroup = new QButtonGroup(ui->tab_4);
-    connect( mRecipientFilterGroup, SIGNAL(buttonClicked(int)), this, SLOT(slotRecipientFilterClicked(int)) );
+    connect(mRecipientFilterGroup, static_cast<void (QButtonGroup::*)(int)>(&QButtonGroup::buttonClicked), this, &ImageScalingWidget::slotRecipientFilterClicked);
     ui->doNotResizePattern->setEnabled(false);
     ui->resizeEmailsPattern->setEnabled(false);
-    mRecipientFilterGroup->addButton(ui->doNotFilterRecipients,MessageComposer::MessageComposerSettings::EnumFilterRecipientType::NoFilter );
-    mRecipientFilterGroup->addButton(ui->resizeEachEmails,MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeEachEmailsContainsPattern );
-    mRecipientFilterGroup->addButton(ui->resizeOneEmails,MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeOneEmailContainsPattern );
-    mRecipientFilterGroup->addButton(ui->doNotResizeEachEmails,MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeEachEmailsContainsPattern );
-    mRecipientFilterGroup->addButton(ui->doNotResizeOneEmails,MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeOneEmailContainsPattern );
+    mRecipientFilterGroup->addButton(ui->doNotFilterRecipients, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::NoFilter);
+    mRecipientFilterGroup->addButton(ui->resizeEachEmails, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeEachEmailsContainsPattern);
+    mRecipientFilterGroup->addButton(ui->resizeOneEmails, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeOneEmailContainsPattern);
+    mRecipientFilterGroup->addButton(ui->doNotResizeEachEmails, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeEachEmailsContainsPattern);
+    mRecipientFilterGroup->addButton(ui->doNotResizeOneEmails, MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeOneEmailContainsPattern);
 
-    ui->help->setText( i18n( "<a href=\"whatsthis\">How does this work?</a>" ) );
+    ui->help->setText(i18n("<a href=\"whatsthis\">How does this work?</a>"));
+    connect(ui->help, &QLabel::linkActivated, this, &ImageScalingWidget::slotHelpLinkClicked);
     ui->help->setContextMenuPolicy(Qt::NoContextMenu);
-    connect( ui->help, SIGNAL(linkActivated(QString)),SLOT(slotHelpLinkClicked(QString)) );
 }
 
 ImageScalingWidget::~ImageScalingWidget()
@@ -95,22 +95,22 @@ ImageScalingWidget::~ImageScalingWidget()
     delete ui;
 }
 
-void ImageScalingWidget::slotHelpLinkClicked(const QString&)
+void ImageScalingWidget::slotHelpLinkClicked(const QString &)
 {
     const QString help =
-            i18n( "<qt>"
-                  "<p>Here you can define image filename. "
-                  "You can use:</p>"
-                  "<ul>"
-                  "<li>%t set current time</li>"
-                  "<li>%d set current date</li>"
-                  "<li>%n original filename</li>"
-                  "<li>%e original extension</li>"
-                  "<li>%x new extension</li>"
-                  "</ul>"
-                  "</qt>" );
+        i18n("<qt>"
+             "<p>Here you can define image filename. "
+             "You can use:</p>"
+             "<ul>"
+             "<li>%t set current time</li>"
+             "<li>%d set current date</li>"
+             "<li>%n original filename</li>"
+             "<li>%e original extension</li>"
+             "<li>%x new extension</li>"
+             "</ul>"
+             "</qt>");
 
-    QWhatsThis::showText( QCursor::pos(), help );
+    QWhatsThis::showText(QCursor::pos(), help);
 }
 
 void ImageScalingWidget::slotSourceFilterClicked(int button)
@@ -121,25 +121,25 @@ void ImageScalingWidget::slotSourceFilterClicked(int button)
 
 void ImageScalingWidget::slotRecipientFilterClicked(int button)
 {
-    ui->resizeEmailsPattern->setEnabled( (button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeEachEmailsContainsPattern) ||
-                                         (button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeOneEmailContainsPattern) );
+    ui->resizeEmailsPattern->setEnabled((button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeEachEmailsContainsPattern) ||
+                                        (button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::ResizeOneEmailContainsPattern));
     ui->doNotResizePattern->setEnabled((button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeEachEmailsContainsPattern) ||
-                                       (button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeOneEmailContainsPattern) );
+                                       (button == MessageComposer::MessageComposerSettings::EnumFilterRecipientType::DontResizeOneEmailContainsPattern));
     Q_EMIT changed();
 }
 
 void ImageScalingWidget::slotComboboxChanged(int index)
 {
-    KComboBox* combo = qobject_cast< KComboBox* >( sender() );
+    KComboBox *combo = qobject_cast< KComboBox * >(sender());
     if (combo) {
         const bool isCustom = combo->itemData(index) == -1;
-        if(combo == ui->CBMaximumWidth) {
+        if (combo == ui->CBMaximumWidth) {
             ui->customMaximumWidth->setEnabled(isCustom);
-        } else if(combo == ui->CBMaximumHeight) {
+        } else if (combo == ui->CBMaximumHeight) {
             ui->customMaximumHeight->setEnabled(isCustom);
-        } else if(combo == ui->CBMinimumWidth) {
+        } else if (combo == ui->CBMinimumWidth) {
             ui->customMinimumWidth->setEnabled(isCustom);
-        } else if(combo == ui->CBMinimumHeight) {
+        } else if (combo == ui->CBMinimumHeight) {
             ui->customMinimumHeight->setEnabled(isCustom);
         }
         Q_EMIT changed();
@@ -149,8 +149,8 @@ void ImageScalingWidget::slotComboboxChanged(int index)
 void ImageScalingWidget::initComboBox(KComboBox *combo)
 {
     QList<int> size;
-    size <<240 <<320 <<512 <<640 <<800 <<1024 <<1600 <<2048;
-    Q_FOREACH(int val, size) {
+    size << 240 << 320 << 512 << 640 << 800 << 1024 << 1600 << 2048;
+    Q_FOREACH (int val, size) {
         combo->addItem(QString::number(val), val);
     }
     combo->addItem(i18n("Custom"), -1);
@@ -165,8 +165,8 @@ void ImageScalingWidget::initWriteImageFormat()
     }
     */
     //known by several mailer.
-    ui->WriteToImageFormat->addItem(QString::fromLatin1("JPG"));
-    ui->WriteToImageFormat->addItem(QString::fromLatin1("PNG"));
+    ui->WriteToImageFormat->addItem(QStringLiteral("JPG"));
+    ui->WriteToImageFormat->addItem(QStringLiteral("PNG"));
 }
 
 void ImageScalingWidget::updateSettings()
@@ -201,7 +201,7 @@ void ImageScalingWidget::updateSettings()
     ui->customMinimumHeight->setEnabled(ui->CBMinimumHeight->itemData(index) == -1);
 
     index = ui->WriteToImageFormat->findData(MessageComposer::MessageComposerSettings::self()->writeFormat());
-    if(index == -1) {
+    if (index == -1) {
         ui->WriteToImageFormat->setCurrentIndex(0);
     } else {
         ui->WriteToImageFormat->setCurrentIndex(index);
@@ -220,7 +220,6 @@ void ImageScalingWidget::updateSettings()
     ui->resizeImageWithFormatsType->setFormat(MessageComposer::MessageComposerSettings::self()->resizeImagesWithFormatsType());
     ui->resizeImageWithFormatsType->setEnabled(ui->resizeImageWithFormats->isChecked());
 
-
     updateFilterSourceTypeSettings();
     updateEmailsFilterTypeSettings();
 }
@@ -233,7 +232,7 @@ void ImageScalingWidget::loadConfig()
 
 void ImageScalingWidget::updateFilterSourceTypeSettings()
 {
-    switch(MessageComposer::MessageComposerSettings::self()->filterSourceType()) {
+    switch (MessageComposer::MessageComposerSettings::self()->filterSourceType()) {
     case MessageComposer::MessageComposerSettings::EnumFilterSourceType::NoFilter:
         ui->notFilterFilename->setChecked(true);
         ui->pattern->setEnabled(false);
@@ -254,7 +253,7 @@ void ImageScalingWidget::updateEmailsFilterTypeSettings()
     ui->doNotResizePattern->setEnabled(false);
     ui->resizeEmailsPattern->setEnabled(false);
 
-    switch(MessageComposer::MessageComposerSettings::self()->filterRecipientType()) {
+    switch (MessageComposer::MessageComposerSettings::self()->filterRecipientType()) {
     case MessageComposer::MessageComposerSettings::EnumFilterRecipientType::NoFilter:
         ui->doNotFilterRecipients->setChecked(true);
         break;
@@ -280,8 +279,8 @@ void ImageScalingWidget::updateEmailsFilterTypeSettings()
 void ImageScalingWidget::writeConfig()
 {
     if (ui->EnlargeImageToMinimum->isChecked() && ui->ReduceImageToMaximum->isChecked()) {
-        if ((ui->customMinimumWidth->value()>=ui->customMaximumWidth->value()) ||
-                (ui->customMinimumHeight->value()>=ui->customMaximumHeight->value())) {
+        if ((ui->customMinimumWidth->value() >= ui->customMaximumWidth->value()) ||
+                (ui->customMinimumHeight->value() >= ui->customMaximumHeight->value())) {
             KMessageBox::error(this, i18n("Please verify minimum and maximum values."), i18n("Error in minimum Maximum value"));
             return;
         }
@@ -325,8 +324,8 @@ void ImageScalingWidget::writeConfig()
 
 void ImageScalingWidget::resetToDefault()
 {
-    const bool bUseDefaults = MessageComposer::MessageComposerSettings::self()->useDefaults( true );
+    const bool bUseDefaults = MessageComposer::MessageComposerSettings::self()->useDefaults(true);
     updateSettings();
-    MessageComposer::MessageComposerSettings::self()->useDefaults( bUseDefaults );
+    MessageComposer::MessageComposerSettings::self()->useDefaults(bUseDefaults);
 }
 
