@@ -22,38 +22,37 @@
 #include "composer/composer.h"
 #include "jobbase_p.h"
 
-#include <KDebug>
+#include "messagecomposer_debug.h"
 
 using namespace MessageComposer;
 
-JobBase::JobBase( QObject *parent )
-  : KCompositeJob( parent )
-  , d_ptr( new JobBasePrivate( this ) )
+JobBase::JobBase(QObject *parent)
+    : KCompositeJob(parent)
+    , d_ptr(new JobBasePrivate(this))
 {
 }
 
-JobBase::JobBase( JobBasePrivate &dd, QObject *parent )
-  : KCompositeJob( parent )
-  , d_ptr( &dd )
+JobBase::JobBase(JobBasePrivate &dd, QObject *parent)
+    : KCompositeJob(parent)
+    , d_ptr(&dd)
 {
 }
 
 JobBase::~JobBase()
 {
-  delete d_ptr;
+    delete d_ptr;
 }
 
 GlobalPart *JobBase::globalPart()
 {
-  for( QObject *obj = this; obj != 0; obj = obj->parent() ) {
-    Composer *composer = qobject_cast<Composer*>( obj );
-    if( composer ) {
-      return composer->globalPart();
+    for (QObject *obj = this; obj != Q_NULLPTR; obj = obj->parent()) {
+        Composer *composer = qobject_cast<Composer *>(obj);
+        if (composer) {
+            return composer->globalPart();
+        }
     }
-  }
 
-  kFatal() << "Job is not part of a Composer.";
-  return 0;
+    qCCritical(MESSAGECOMPOSER_LOG) << "Job is not part of a Composer.";
+    return Q_NULLPTR;
 }
 
-#include "jobbase.moc"
