@@ -21,7 +21,6 @@
 #ifndef MESSAGECOMPOSER_SIGNJOB_H
 #define MESSAGECOMPOSER_SIGNJOB_H
 
-
 #include "contentjobbase.h"
 #include "part/infopart.h"
 #include "messagecomposer_export.h"
@@ -30,17 +29,14 @@
 #include <gpgme++/key.h>
 #include <vector>
 
-namespace KMime {
+namespace KMime
+{
 class Content;
 
 }
 
-namespace GpgME {
-class Error;
-}
-
-
-namespace MessageComposer {
+namespace MessageComposer
+{
 
 class SignJobPrivate;
 
@@ -53,21 +49,20 @@ class MESSAGECOMPOSER_EXPORT SignJob : public ContentJobBase
     Q_OBJECT
 
 public:
-    explicit SignJob( QObject *parent = 0 );
+    explicit SignJob(QObject *parent = Q_NULLPTR);
     virtual ~SignJob();
 
-    void setContent( KMime::Content* content );
-    void setCryptoMessageFormat( Kleo::CryptoMessageFormat format);
-    void setSigningKeys( std::vector<GpgME::Key>& signers );
+    void setContent(KMime::Content *content);
+    void setCryptoMessageFormat(Kleo::CryptoMessageFormat format);
+    void setSigningKeys(std::vector<GpgME::Key> &signers);
 
-    KMime::Content* origContent();
+    KMime::Content *origContent();
 
 protected Q_SLOTS:
-    //virtual void doStart();
-    virtual void process();
+    void process() Q_DECL_OVERRIDE;
 
 private:
-    Q_DECLARE_PRIVATE( SignJob )
+    Q_DECLARE_PRIVATE(SignJob)
 };
 
 }
