@@ -24,9 +24,10 @@
 
 #include "attachmentpart.h"
 
-#include <KDE/KJob>
+#include <KJob>
 
-namespace MessageCore {
+namespace MessageCore
+{
 
 /**
  * @short A base class for jobs to load attachments from different sources.
@@ -43,7 +44,7 @@ public:
      *
      * @param parent The parent object.
      */
-    explicit AttachmentLoadJob( QObject *parent = 0 );
+    explicit AttachmentLoadJob(QObject *parent = Q_NULLPTR);
 
     /**
      * Destroys the attachment load job.
@@ -53,7 +54,7 @@ public:
     /**
      * Starts the attachment load job.
      */
-    virtual void start();
+    void start() Q_DECL_OVERRIDE;
 
     /**
      * Returns the loaded attachment.
@@ -64,7 +65,7 @@ protected:
     /**
      * Subclasses use this method to set the loaded @p part.
      */
-    void setAttachmentPart( const AttachmentPart::Ptr &part );
+    void setAttachmentPart(const AttachmentPart::Ptr &part);
 
 protected Q_SLOTS:
     virtual void doStart() = 0;
