@@ -25,9 +25,10 @@
 
 #include "messagecore_export.h"
 
-#include <akonadi/attribute.h>
+#include <attribute.h>
 
-namespace MessageCore {
+namespace MessageCore
+{
 
 /**
  * @short An Attribute that keeps track of the MDN state of a mail message.
@@ -45,8 +46,7 @@ public:
     /**
      * Describes the "MDN sent" state.
      */
-    enum MDNSentState
-    {
+    enum MDNSentState {
         MDNStateUnknown, ///< The state is unknown.
         MDNNone,         ///< No MDN has been set.
         MDNIgnore,       ///< Ignore sending a MDN.
@@ -63,54 +63,56 @@ public:
      *
      * @param state The state the attribute will have.
      */
-    explicit MDNStateAttribute( const MDNSentState &state = MDNStateUnknown );
+    explicit MDNStateAttribute(const MDNSentState &state = MDNStateUnknown);
 
     /**
      * Creates a new MDN state attribute.
      *
      * @param state The string representation of the state the attribute will have.
      */
-    explicit MDNStateAttribute( const QByteArray &state );
-    
+    explicit MDNStateAttribute(const QByteArray &state);
+
     /**
      * Destroys the MDN state attribute.
      */
     ~MDNStateAttribute();
-    
+
     /**
      * Reimplemented from Attribute
      */
-    QByteArray type() const;
-    
+    QByteArray type() const Q_DECL_OVERRIDE;
+
     /**
      * Reimplemented from Attribute
      */
-    MDNStateAttribute* clone() const;
-    
+    MDNStateAttribute *clone() const Q_DECL_OVERRIDE;
+
     /**
      * Reimplemented from Attribute
      */
-    QByteArray serialized() const;
-    
+    QByteArray serialized() const Q_DECL_OVERRIDE;
+
     /**
      * Reimplemented from Attribute
      */
-    void deserialize( const QByteArray &data );
+    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
 
     /**
      * Sets the MDN @p state.
      */
-    void setMDNState( const MDNSentState &state );
+    void setMDNState(const MDNSentState &state);
 
     /**
      * Returns the MDN state.
      */
     MDNStateAttribute::MDNSentState mdnState() const;
-    
+
+    bool operator==(const MDNStateAttribute &other) const;
+
 private:
     //@cond PRIVATE
     class Private;
-    Private* const d;
+    Private *const d;
     //@endcond
 };
 
