@@ -20,13 +20,15 @@
 
 #include <KMessageWidget>
 #include "messagelist_export.h"
-namespace MessageList {
-namespace Core {
+namespace MessageList
+{
+namespace Core
+{
 class MESSAGELIST_EXPORT QuickSearchWarning : public KMessageWidget
 {
     Q_OBJECT
 public:
-    explicit QuickSearchWarning(QWidget *parent = 0);
+    explicit QuickSearchWarning(QWidget *parent = Q_NULLPTR);
     ~QuickSearchWarning();
     void setSearchText(const QString &text);
 };
