@@ -21,7 +21,7 @@
 #ifndef __MESSAGELIST_UTILS_CONFIGURETHEMESDIALOG_H__
 #define __MESSAGELIST_UTILS_CONFIGURETHEMESDIALOG_H__
 
-#include <KDialog>
+#include <QDialog>
 
 #include <QListWidget>
 
@@ -42,18 +42,21 @@ class Manager;
 namespace Utils
 {
 
-class MESSAGELIST_EXPORT ConfigureThemesDialog : public KDialog
+class MESSAGELIST_EXPORT ConfigureThemesDialog : public QDialog
 {
     Q_OBJECT
 
 public:
-    explicit ConfigureThemesDialog( QWidget *parent = 0 );
+    explicit ConfigureThemesDialog(QWidget *parent = Q_NULLPTR);
     ~ConfigureThemesDialog();
 
-    void selectTheme( const QString &themeId );
+    void selectTheme(const QString &themeId);
+
+Q_SIGNALS:
+    void okClicked();
 
 private:
-    Q_PRIVATE_SLOT(d, void themeListItemClicked(QListWidgetItem*))
+    Q_PRIVATE_SLOT(d, void themeListItemClicked(QListWidgetItem *))
     Q_PRIVATE_SLOT(d, void newThemeButtonClicked())
     Q_PRIVATE_SLOT(d, void cloneThemeButtonClicked())
     Q_PRIVATE_SLOT(d, void deleteThemeButtonClicked())
@@ -62,9 +65,8 @@ private:
     Q_PRIVATE_SLOT(d, void importThemeButtonClicked())
     Q_PRIVATE_SLOT(d, void exportThemeButtonClicked())
 
-
     class Private;
-    Private * const d;
+    Private *const d;
 };
 
 } // namespace Utils
