@@ -21,7 +21,7 @@
 
 #include <messagelist/messagelist_export.h>
 #include <KComboBox>
-#include <akonadi/collection.h>
+#include <collection.h>
 namespace MessageList
 {
 
@@ -43,30 +43,29 @@ class ThemeComboBoxPrivate;
  */
 class MESSAGELIST_EXPORT ThemeComboBox : public KComboBox
 {
-  Q_OBJECT
+    Q_OBJECT
 
 public:
-  explicit ThemeComboBox( QWidget * parent);
-  ~ThemeComboBox();
+    explicit ThemeComboBox(QWidget *parent);
+    ~ThemeComboBox();
 
-  QString currentTheme() const;
+    QString currentTheme() const;
 
-  void writeDefaultConfig() const;
+    void writeDefaultConfig() const;
 
-  void writeStorageModelConfig( MessageList::Core::StorageModel *storageModel, bool isPrivateSetting ) const;
-  void writeStorageModelConfig( const Akonadi::Collection &col, bool isPrivateSetting ) const;
-  void writeStorageModelConfig( const QString &id, bool isPrivateSetting )const;
+    void writeStorageModelConfig(MessageList::Core::StorageModel *storageModel, bool isPrivateSetting) const;
+    void writeStorageModelConfig(const Akonadi::Collection &col, bool isPrivateSetting) const;
+    void writeStorageModelConfig(const QString &id, bool isPrivateSetting)const;
 
-
-  void readStorageModelConfig( const Akonadi::Collection& col, bool &isPrivateSetting );
-  void readStorageModelConfig( MessageList::Core::StorageModel *storageModel, bool &isPrivateSetting );
+    void readStorageModelConfig(const Akonadi::Collection &col, bool &isPrivateSetting);
+    void readStorageModelConfig(MessageList::Core::StorageModel *storageModel, bool &isPrivateSetting);
 
 public Q_SLOTS:
-  void selectDefault();
+    void selectDefault();
 
 private:
-  Q_PRIVATE_SLOT(d, void slotLoadThemes())
-  ThemeComboBoxPrivate * const d;
+    Q_PRIVATE_SLOT(d, void slotLoadThemes())
+    ThemeComboBoxPrivate *const d;
 };
 
 } // namespace Utils
