@@ -20,7 +20,7 @@
 #define __MESSAGELIST_UTILS_THEMECONFIGBUTTON_H__
 
 #include <messagelist/messagelist_export.h>
-#include <KPushButton>
+#include <QPushButton>
 
 namespace MessageList
 {
@@ -32,32 +32,32 @@ class ThemeComboBox;
 class ThemeConfigButtonPrivate;
 
 /**
- * A specialized KPushButton that displays the theme
+ * A specialized QPushButton that displays the theme
  * configure dialog when pressed.
  */
-class MESSAGELIST_EXPORT ThemeConfigButton : public KPushButton
+class MESSAGELIST_EXPORT ThemeConfigButton : public QPushButton
 {
     Q_OBJECT
 
 public:
     /** Constructor.
-   * @param parent The parent widget for the button.
-   * @param themeComboBox Optional ThemeComboBox to be kept in sync
-   * with changes made by the configure dialog.
-   */
-    explicit ThemeConfigButton( QWidget * parent, const ThemeComboBox * themeComboBox = 0 );
+    * @param parent The parent widget for the button.
+    * @param themeComboBox Optional ThemeComboBox to be kept in sync
+    * with changes made by the configure dialog.
+    */
+    explicit ThemeConfigButton(QWidget *parent, const ThemeComboBox *themeComboBox = Q_NULLPTR);
     ~ThemeConfigButton();
 
-signals:
+Q_SIGNALS:
     /**
-   * A signal emitted when configure dialog has been successfully completed.
-   */
+    * A signal emitted when configure dialog has been successfully completed.
+    */
     void configureDialogCompleted();
 
 private:
     Q_PRIVATE_SLOT(d, void slotConfigureThemes())
 
-    ThemeConfigButtonPrivate * const d;
+    ThemeConfigButtonPrivate *const d;
 };
 
 } // namespace Utils
