@@ -17,27 +17,25 @@
 
 #include "messagevieweraccessiblewidgetfactory.h"
 
-#include <QtCore/qplugin.h>
 #include "accessiblemailwebview.h"
 
-Q_EXPORT_PLUGIN(MessageViewerAccessibleWidgetFactory)
-
-QAccessibleInterface *MessageViewerAccessibleWidgetFactory::create( const QString &key, QObject *object )
+QAccessibleInterface *MessageViewerAccessibleWidgetFactory::create(const QString &key, QObject *object)
 {
-    if ( key == QLatin1String( "MessageViewer::MailWebView" ) ) {
-        return new AccessibleMailWebView( reinterpret_cast< MessageViewer::MailWebView* >( object ) );
+    Q_UNUSED(key)
+    if (MessageViewer::MailWebView *view = qobject_cast<MessageViewer::MailWebView *>(object)) {
+        return new AccessibleMailWebView(view);
     }
     return 0;
 }
 
-MessageViewerAccessibleWidgetFactory::MessageViewerAccessibleWidgetFactory( QObject *parent ):
-    QAccessiblePlugin( parent )
+MessageViewerAccessibleWidgetFactory::MessageViewerAccessibleWidgetFactory(QObject *parent):
+    QAccessiblePlugin(parent)
 {
 }
 
 QStringList MessageViewerAccessibleWidgetFactory::keys() const
 {
     QStringList l;
-    l.append( QLatin1String( "MessageViewer::MailWebView" ) );
+    l.append(QLatin1String("MessageViewer::MailWebView"));
     return l;
 }
