@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,22 +19,23 @@
 #define WEBPAGE_H
 
 #include <KWebPage>
-#include <KUrl>
+#include <QUrl>
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class WebPage : public KWebPage
 {
     Q_OBJECT
 public:
-    explicit WebPage(QWidget *parent = 0);
+    explicit WebPage(QWidget *parent = Q_NULLPTR);
     ~WebPage();
-    KUrl loadingUrl() const;
+    QUrl loadingUrl() const;
 
 protected:
     bool acceptNavigationRequest(QWebFrame *frame, const QNetworkRequest &request, NavigationType type);
 
 private:
-    KUrl mLoadingUrl;
+    QUrl mLoadingUrl;
 };
 }
 
