@@ -15,13 +15,12 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #ifndef MESSAGEHEADERFILTER_H
 #define MESSAGEHEADERFILTER_H
 
+#include <QObject>
 #include <grantlee/filter.h>
 
-
 class MessageHeaderEmailShowLink : public Grantlee::Filter
 {
 public:
@@ -38,5 +37,12 @@ public:
     bool isSafe() const;
 };
 
+class MessageHeaderEmailExpandable : public Grantlee::Filter
+{
+public:
+    QVariant doFilter(const QVariant &input, const QVariant &argument = QVariant(), bool autoescape = false) const;
+
+    bool isSafe() const;
+};
 
 #endif // MESSAGEHEADERFILTER_H
