@@ -22,19 +22,21 @@
 
 #include <QWidget>
 
-namespace PimCommon {
+namespace PimCommon
+{
 class SimpleStringListEditor;
 }
 
 class QRadioButton;
 class QButtonGroup;
-namespace MessageViewer {
+namespace MessageViewer
+{
 
 class MESSAGEVIEWER_EXPORT CustomHeaderSettingWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit CustomHeaderSettingWidget(QWidget *parent = 0);
+    explicit CustomHeaderSettingWidget(QWidget *parent = Q_NULLPTR);
     ~CustomHeaderSettingWidget();
 
     void readConfig();
