@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,25 +19,30 @@
 #define FANCYHEADERSTYLE_H
 
 #include "header/headerstyle.h"
-namespace MessageViewer {
+namespace MessageViewer
+{
 
-
-class FancyHeaderStyle : public HeaderStyle {
+class FancyHeaderStyle : public HeaderStyle
+{
     friend class HeaderStyle;
 protected:
     FancyHeaderStyle() : HeaderStyle() {}
     virtual ~FancyHeaderStyle() {}
 
 public:
-    const char * name() const { return "fancy"; }
+    const char *name() const Q_DECL_OVERRIDE
+    {
+        return "fancy";
+    }
 
-    QString format( KMime::Message *message ) const;
+    QString format(KMime::Message *message) const Q_DECL_OVERRIDE;
 
-    bool hasAttachmentQuickList() const {
+    bool hasAttachmentQuickList() const Q_DECL_OVERRIDE
+    {
         return true;
     }
 private:
-    static QString imgToDataUrl( const QImage & image );
+    static QString imgToDataUrl(const QImage &image);
 };
 
 }
