@@ -21,24 +21,30 @@
 #include "header/headerstyle.h"
 #include "messageviewer_export.h"
 
-namespace MessageViewer {
+namespace MessageViewer
+{
 class GrantleeHeaderFormatter;
-class MESSAGEVIEWER_EXPORT GrantleeHeaderTestStyle : public HeaderStyle {
+class MESSAGEVIEWER_EXPORT GrantleeHeaderTestStyle : public HeaderStyle
+{
     friend class GrantleeHeaderStyle;
 public:
     GrantleeHeaderTestStyle();
     ~GrantleeHeaderTestStyle();
 
 public:
-    const char * name() const { return "grantleetest"; }
+    const char *name() const Q_DECL_OVERRIDE
+    {
+        return "grantleetest";
+    }
 
-    QString format(KMime::Message *message) const;
+    QString format(KMime::Message *message) const Q_DECL_OVERRIDE;
 
     void setAbsolutePath(const QString &);
     void setMainFilename(const QString &);
     void setExtraDisplayHeaders(const QStringList &);
 
-    bool hasAttachmentQuickList() const {
+    bool hasAttachmentQuickList() const Q_DECL_OVERRIDE
+    {
         return true;
     }
 
