@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,9 +18,9 @@
 #ifndef SCAMATTRIBUTE_H
 #define SCAMATTRIBUTE_H
 
-
-#include <akonadi/attribute.h>
-namespace MessageViewer {
+#include <AkonadiCore/attribute.h>
+namespace MessageViewer
+{
 class ScamAttributePrivate;
 
 class ScamAttribute : public Akonadi::Attribute
@@ -30,17 +30,19 @@ public:
     ~ScamAttribute();
 
     /* reimpl */
-    ScamAttribute *clone() const;
-    QByteArray type() const;
-    QByteArray serialized() const;
-    void deserialize( const QByteArray &data );
+    ScamAttribute *clone() const Q_DECL_OVERRIDE;
+    QByteArray type() const Q_DECL_OVERRIDE;
+    QByteArray serialized() const Q_DECL_OVERRIDE;
+    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
 
     bool isAScam() const;
     void setIsAScam(bool b);
 
+    bool operator==(const ScamAttribute &other) const;
+
 private:
     friend class ScamAttributePrivate;
-    ScamAttributePrivate * const d;
+    ScamAttributePrivate *const d;
 };
 }
 
