@@ -21,15 +21,17 @@
 #include <QObject>
 #include "noteshared_export.h"
 
-namespace Akonadi {
+namespace Akonadi
+{
 class ChangeRecorder;
 }
-namespace NoteShared {
+namespace NoteShared
+{
 class NOTESHARED_EXPORT NotesChangeRecorder : public QObject
 {
     Q_OBJECT
 public:
-    explicit NotesChangeRecorder(QObject *parent = 0);
+    explicit NotesChangeRecorder(QObject *parent = Q_NULLPTR);
 
     Akonadi::ChangeRecorder *changeRecorder() const;
 
