@@ -19,30 +19,31 @@
 #define NOTE_ALARM_ATTRIBUTE_H
 
 #include "noteshared_export.h"
-#include <Akonadi/Attribute>
+#include <AkonadiCore/Attribute>
 
-#include <KDateTime>
-namespace NoteShared {
+#include <QDateTime>
+namespace NoteShared
+{
 class NOTESHARED_EXPORT NoteAlarmAttribute : public Akonadi::Attribute
 {
 public:
     NoteAlarmAttribute();
     ~NoteAlarmAttribute();
 
-    QByteArray type() const;
+    QByteArray type() const Q_DECL_OVERRIDE;
 
-    NoteAlarmAttribute* clone() const;
+    NoteAlarmAttribute *clone() const Q_DECL_OVERRIDE;
 
-    QByteArray serialized() const;
+    QByteArray serialized() const Q_DECL_OVERRIDE;
 
-    void deserialize( const QByteArray &data );
+    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
 
-    void setDateTime(const KDateTime &dateTime);
-    KDateTime dateTime() const;
+    void setDateTime(const QDateTime &dateTime);
+    QDateTime dateTime() const;
 
-    bool operator ==( const NoteAlarmAttribute &other) const;
+    bool operator ==(const NoteAlarmAttribute &other) const;
 private:
-    KDateTime mDateTime;
+    QDateTime mDateTime;
 };
 }
 
