@@ -18,10 +18,11 @@
 #ifndef SHOWFOLDERNOTESATTRIBUTE_H
 #define SHOWFOLDERNOTESATTRIBUTE_H
 
-#include <akonadi/attribute.h>
+#include <AkonadiCore/attribute.h>
 #include "noteshared_export.h"
 
-namespace NoteShared {
+namespace NoteShared
+{
 class NOTESHARED_EXPORT ShowFolderNotesAttribute : public Akonadi::Attribute
 {
 public:
@@ -29,10 +30,10 @@ public:
     ~ShowFolderNotesAttribute();
 
     /* reimpl */
-    ShowFolderNotesAttribute *clone() const;
-    QByteArray type() const;
-    QByteArray serialized() const;
-    void deserialize( const QByteArray &data );
+    ShowFolderNotesAttribute *clone() const Q_DECL_OVERRIDE;
+    QByteArray type() const Q_DECL_OVERRIDE;
+    QByteArray serialized() const Q_DECL_OVERRIDE;
+    void deserialize(const QByteArray &data) Q_DECL_OVERRIDE;
 };
 }
 
