@@ -15,41 +15,39 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #ifndef NOTENETWORKCONFIG_H
 #define NOTENETWORKCONFIG_H
 #include "noteshared_export.h"
 #include <KCModule>
-class KLineEdit;
+class QLineEdit;
 class QCheckBox;
-class KComponentData;
-class KIntNumInput;
-namespace NoteShared {
+class QSpinBox;
+namespace NoteShared
+{
 
 class NOTESHARED_EXPORT NoteNetworkConfigWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit NoteNetworkConfigWidget( QWidget *parent = 0);
+    explicit NoteNetworkConfigWidget(QWidget *parent = Q_NULLPTR);
     ~NoteNetworkConfigWidget();
 
     void save();
     void load();
 private:
     QCheckBox *mTmpChkB;
-    KLineEdit *kcfg_SenderID;
-    KIntNumInput *kcfg_Port;
+    QLineEdit *kcfg_SenderID;
+    QSpinBox *kcfg_Port;
 };
 
-
 class NOTESHARED_EXPORT NoteNetworkConfig : public KCModule
 {
     Q_OBJECT
 public:
-    NoteNetworkConfig( const KComponentData &inst, QWidget *parent );
+    NoteNetworkConfig(QWidget *parent);
     /** Reimplemented from KCModule. */
-    virtual void load();
-    virtual void save();
+    void load() Q_DECL_OVERRIDE;
+    void save() Q_DECL_OVERRIDE;
 };
 }
 
