@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -17,17 +17,27 @@
 
 #include "pimcommon/autocorrection/widgets/richtexteditwithautocorrection.h"
 
-#include <kdebug.h>
-#include <kapplication.h>
-#include <KCmdLineArgs>
+#include "pimcommon_debug.h"
+
 #include <KLocalizedString>
+#include <QApplication>
+#include <KAboutData>
+#include <QCommandLineParser>
+#include <QStandardPaths>
 
-int main (int argc, char **argv)
+int main(int argc, char **argv)
 {
-    KCmdLineArgs::init(argc, argv, "richtexteditwithautocorrection_gui", 0, ki18n("richtexteditwithautocorrectionTest_Gui"),
-                       "1.0", ki18n("Test for richtexteditwithautocorrection"));
-
-    KApplication app;
+    QApplication app(argc, argv);
+    QStandardPaths::setTestModeEnabled(true);
+    KAboutData aboutData(QStringLiteral("richtexteditwithautocorrection_gui"), i18n("richtexteditwithautocorrectionTest_Gui"), QStringLiteral("1.0"));
+    aboutData.setShortDescription(i18n("Test for richtexteditwithautocorrection"));
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(aboutData);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 
     PimCommon::RichTextEditWithAutoCorrection *w = new PimCommon::RichTextEditWithAutoCorrection;
 
