@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -20,12 +20,11 @@
 
 #include <QObject>
 
-
 class BalooDebugWidgetTest : public QObject
 {
     Q_OBJECT
 public:
-    explicit BalooDebugWidgetTest(QObject *parent = 0);
+    explicit BalooDebugWidgetTest(QObject *parent = Q_NULLPTR);
     ~BalooDebugWidgetTest();
 private Q_SLOTS:
     void shouldHaveDefaultValue();
@@ -34,7 +33,5 @@ private Q_SLOTS:
     void shouldChangeSearchType();
 };
 
-
-
 #endif // BALOODEBUGWIDGETTEST_H
 
