@@ -19,27 +19,34 @@
 #include "baloodebugwidget.h"
 #include "pimcommon/util/pimutil.h"
 
-
+#include <KLocalizedString>
 #include <QVBoxLayout>
 #include <KSharedConfig>
-
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
 
 using namespace PimCommon;
 
 BalooDebugDialog::BalooDebugDialog(QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
 {
-    setButtons(User1|Close);
-    //Don't translate it.
-    setButtonText(User1, QLatin1String("Save As..."));
-    connect(this, SIGNAL(user1Clicked()), this, SLOT(slotSaveAs()));
-
     //Don't translate it's just a dialog to debug
-    setCaption(QLatin1String("Debug baloo"));
+    setWindowTitle(QStringLiteral("Debug baloo"));
 
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    QPushButton *user1Button = new QPushButton;
+    buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
+    //Don't translate it.
+    user1Button->setText(QStringLiteral("Save As..."));
+    connect(user1Button, &QPushButton::clicked, this, &BalooDebugDialog::slotSaveAs);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &BalooDebugDialog::reject);
     mBalooDebugWidget = new BalooDebugWidget(this);
-    mBalooDebugWidget->setObjectName(QLatin1String("baloodebugwidget"));
-    setMainWidget(mBalooDebugWidget);
+    mBalooDebugWidget->setObjectName(QStringLiteral("baloodebugwidget"));
+    mainLayout->addWidget(mBalooDebugWidget);
+    mainLayout->addWidget(buttonBox);
     readConfig();
 }
 
@@ -50,20 +57,19 @@ BalooDebugDialog::~BalooDebugDialog()
 
 void BalooDebugDialog::readConfig()
 {
-    KConfigGroup group( KGlobal::config(), "BalooDebugDialog" );
-    const QSize sizeDialog = group.readEntry( "Size", QSize(800,600) );
-    if ( sizeDialog.isValid() ) {
-        resize( sizeDialog );
+    KConfigGroup group(KSharedConfig::openConfig(), "BalooDebugDialog");
+    const QSize sizeDialog = group.readEntry("Size", QSize(800, 600));
+    if (sizeDialog.isValid()) {
+        resize(sizeDialog);
     }
 }
 
 void BalooDebugDialog::writeConfig()
 {
-    KConfigGroup group( KGlobal::config(), "BalooDebugDialog" );
-    group.writeEntry( "Size", size() );
+    KConfigGroup group(KSharedConfig::openConfig(), "BalooDebugDialog");
+    group.writeEntry("Size", size());
 }
 
-
 void BalooDebugDialog::setAkonadiId(Akonadi::Item::Id akonadiId)
 {
     mBalooDebugWidget->setAkonadiId(akonadiId);
@@ -81,8 +87,7 @@ void BalooDebugDialog::doSearch()
 
 void BalooDebugDialog::slotSaveAs()
 {
-    const QString filter = QLatin1String( "*.txt|all files (*)" );
+    const QString filter = i18n("Text Files (*.txt);;All Files (*)");
     PimCommon::Util::saveTextAs(mBalooDebugWidget->plainText(), filter, this);
 }
 
-
