@@ -15,19 +15,19 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #ifndef BALOODEBUGSEARCHJOB_H
 #define BALOODEBUGSEARCHJOB_H
 
 #include <QObject>
 #include <QStringList>
 class QProcess;
-namespace PimCommon {
+namespace PimCommon
+{
 class BalooDebugSearchJob : public QObject
 {
     Q_OBJECT
 public:
-    explicit BalooDebugSearchJob(QObject *parent=0);
+    explicit BalooDebugSearchJob(QObject *parent = Q_NULLPTR);
     ~BalooDebugSearchJob();
 
     void start();
@@ -40,7 +40,7 @@ Q_SIGNALS:
     void error(const QString &errorString);
     void result(const QString &text);
 
-private slots:
+private Q_SLOTS:
     void slotReadStandard();
     void slotReadError();
 
@@ -52,6 +52,5 @@ private:
 };
 }
 
-
 #endif // BALOODEBUGSEARCHJOB_H
 
