@@ -23,13 +23,15 @@
 class QLabel;
 class QLineEdit;
 class QPushButton;
-namespace PimCommon {
+class QCheckBox;
+namespace PimCommon
+{
 class GravatarResolvUrlJob;
 class PIMCOMMON_EXPORT GravatarDownloadPixmapWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit GravatarDownloadPixmapWidget(QWidget *parent = 0);
+    explicit GravatarDownloadPixmapWidget(QWidget *parent = Q_NULLPTR);
     ~GravatarDownloadPixmapWidget();
 
     QPixmap gravatarPixmap() const;
@@ -44,6 +46,9 @@ private:
     QLabel *mResultLabel;
     QLineEdit *mLineEdit;
     QPushButton *mGetPixmapButton;
+    QCheckBox *mUseLibravatar;
+    QCheckBox *mFallbackGravatar;
+    QCheckBox *mUseHttps;
 };
 }
 
