@@ -15,11 +15,10 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #include "shorturlenginestest.h"
 #include "pimcommon/shorturl/shorturlutils.h"
 #include "pimcommon/shorturl/abstractshorturl.h"
-#include <qtest_kde.h>
+#include <qtest.h>
 #include <QSignalSpy>
 
 Q_DECLARE_METATYPE(PimCommon::ShortUrlUtils::EngineType)
@@ -37,8 +36,8 @@ ShortUrlEnginesTest::~ShortUrlEnginesTest()
 
 void ShortUrlEnginesTest::shouldCreateEngine()
 {
-    for (int i=0; i <PimCommon::ShortUrlUtils::EndListEngine; ++i) {
-        PimCommon::AbstractShortUrl *abstrShortUrl = PimCommon::ShortUrlUtils::loadEngine(static_cast<PimCommon::ShortUrlUtils::EngineType>(i), 0);
+    for (int i = 0; i < PimCommon::ShortUrlUtils::EndListEngine; ++i) {
+        PimCommon::AbstractShortUrl *abstrShortUrl = PimCommon::ShortUrlUtils::loadEngine(static_cast<PimCommon::ShortUrlUtils::EngineType>(i), Q_NULLPTR);
         QVERIFY(abstrShortUrl);
         delete abstrShortUrl;
     }
@@ -50,25 +49,26 @@ void ShortUrlEnginesTest::shouldTestEngines_data()
     QTest::addColumn<QString>("longurl");
     QTest::addColumn<QString>("shorturl");
 
-    QTest::newRow("google url") << PimCommon::ShortUrlUtils::Google << QString::fromLatin1("http://www.kde.org") << QString::fromLatin1("http://goo.gl/sMKw");
-    QTest::newRow("tiny url") << PimCommon::ShortUrlUtils::Tinyurl << QString::fromLatin1("http://www.kde.org") << QString::fromLatin1("http://tinyurl.com/l6l0");
+    //QTest::newRow("google url") << PimCommon::ShortUrlUtils::Google << QStringLiteral("http://www.kde.org") << QStringLiteral("http://goo.gl/sMKw");
+    QTest::newRow("tiny url") << PimCommon::ShortUrlUtils::Tinyurl << QStringLiteral("http://www.kde.org") << QStringLiteral("http://tinyurl.com/l6l0");
     //WE can't test migreme...
-    //QTest::newRow("migreme url") << PimCommon::ShortUrlUtils::MigreMe << QString::fromLatin1("http://www.kde.org") << QString::fromLatin1("http://migre.me/nwh5a");
-    QTest::newRow("triopAB url") << PimCommon::ShortUrlUtils::TriopAB << QString::fromLatin1("http://www.kde.org") << QString::fromLatin1("http://to.ly/51UP");
+    //QTest::newRow("migreme url") << PimCommon::ShortUrlUtils::MigreMe << QStringLiteral("http://www.kde.org") << QStringLiteral("http://migre.me/nwh5a");
+    QTest::newRow("triopAB url") << PimCommon::ShortUrlUtils::TriopAB << QStringLiteral("http://www.kde.org") << QStringLiteral("http://to.ly/51UP");
+    //FIX ME QTest::newRow("ur1 url") << PimCommon::ShortUrlUtils::Ur1Ca << QStringLiteral("http://www.kde.org") << QStringLiteral("http://to.ly/51UP");
 }
 
 void ShortUrlEnginesTest::shouldTestEngines()
 {
-    QFETCH( PimCommon::ShortUrlUtils::EngineType, engine );
-    QFETCH( QString, longurl );
-    QFETCH( QString, shorturl );
-    PimCommon::AbstractShortUrl *abstrShortUrl = PimCommon::ShortUrlUtils::loadEngine(engine, 0);
-    abstrShortUrl->shortUrl(longurl);
+    QFETCH(PimCommon::ShortUrlUtils::EngineType, engine);
+    QFETCH(QString, longurl);
+    QFETCH(QString, shorturl);
+    PimCommon::AbstractShortUrl *abstrShortUrl = PimCommon::ShortUrlUtils::loadEngine(engine, Q_NULLPTR);
     QSignalSpy spy(abstrShortUrl, SIGNAL(shortUrlDone(QString)));
+    abstrShortUrl->shortUrl(longurl);
     abstrShortUrl->start();
-    QVERIFY(QTest::kWaitForSignal(abstrShortUrl, SIGNAL(shortUrlDone(QString)), 10000));
+    QVERIFY(spy.wait(10000));
     QCOMPARE(spy.at(0).count(), 1);
     QCOMPARE(spy.at(0).at(0).toString(), shorturl);
 }
 
-QTEST_KDEMAIN(ShortUrlEnginesTest, NoGUI)
+QTEST_MAIN(ShortUrlEnginesTest)
