@@ -19,9 +19,8 @@
 
 #include <QNetworkRequest>
 #include <QUrl>
-#include <QDebug>
-#include <qjson/parser.h>
-
+#include "pimcommon_debug.h"
+#include <QJsonDocument>
 
 using namespace PimCommon;
 GoogleShortUrl::GoogleShortUrl(QObject *parent)
@@ -38,17 +37,17 @@ GoogleShortUrl::~GoogleShortUrl()
 void GoogleShortUrl::start()
 {
     QNetworkRequest request(QUrl(QLatin1String("https://www.googleapis.com/urlshortener/v1/url")));
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/json"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/json"));
 
-    const QString data = QString::fromLatin1("{\"longUrl\": \"%1/\"}").arg(mOriginalUrl);
+    const QString data = QStringLiteral("{\"longUrl\": \"%1/\"}").arg(mOriginalUrl);
 
     QNetworkReply *reply = mNetworkAccessManager->post(request, data.toUtf8());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotErrorFound(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &GoogleShortUrl::slotErrorFound);
 }
 
 QString GoogleShortUrl::shortUrlName() const
 {
-    return QLatin1String("Google");
+    return QStringLiteral("Google");
 }
 
 void GoogleShortUrl::slotSslErrors(QNetworkReply *reply, const QList<QSslError> &error)
@@ -59,20 +58,21 @@ void GoogleShortUrl::slotSslErrors(QNetworkReply *reply, const QList<QSslError>
 void GoogleShortUrl::slotShortUrlFinished(QNetworkReply *reply)
 {
     if (!mErrorFound) {
+        const QByteArray data = reply->readAll();
+        qCDebug(PIMCOMMON_LOG) << "void GoogleShortUrl::slotShortUrlFinished(QNetworkReply *reply) " <<  data;
+        QJsonParseError error;
+        reply->deleteLater();
+        const QJsonDocument json = QJsonDocument::fromJson(data, &error);
+        if (error.error != QJsonParseError::NoError || json.isNull()) {
+            qCDebug(PIMCOMMON_LOG) << " Error during parsing" << error.errorString();
+            Q_EMIT shortUrlFailed(error.errorString());
+            return;
+        }
+        const QMap<QString, QVariant> map = json.toVariant().toMap();
 
-        const QString jsonData = QString::fromUtf8(reply->readAll());
-
-        QJson::Parser parser;
-        bool ok;
-        const QMap<QString, QVariant> map = parser.parse(jsonData.toUtf8(), &ok).toMap();
-        if (ok) {
-            if (map.contains(QLatin1String("id")) && map.contains(QLatin1String("kind"))) {
-                Q_EMIT shortUrlDone(map.value(QLatin1String("id")).toString());
-            }
-        } else {
-            qDebug()<<" Error during parsing";
+        if (map.contains(QStringLiteral("id")) && map.contains(QStringLiteral("kind"))) {
+            Q_EMIT shortUrlDone(map.value(QStringLiteral("id")).toString());
         }
     }
-    reply->deleteLater();
 }
 
