@@ -20,20 +20,21 @@
 
 #include "shorturl/abstractshorturl.h"
 
-namespace PimCommon {
+namespace PimCommon
+{
 class GoogleShortUrl : public PimCommon::AbstractShortUrl
 {
     Q_OBJECT
 public:
-    explicit GoogleShortUrl(QObject *parent = 0);
+    explicit GoogleShortUrl(QObject *parent = Q_NULLPTR);
     ~GoogleShortUrl();
 
-    void start();
-    QString shortUrlName() const;
+    void start() Q_DECL_OVERRIDE;
+    QString shortUrlName() const Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
-    void slotShortUrlFinished(QNetworkReply*reply);
-    void slotSslErrors(QNetworkReply *, const QList<QSslError> &error);    
+    void slotShortUrlFinished(QNetworkReply *reply) Q_DECL_OVERRIDE;
+    void slotSslErrors(QNetworkReply *, const QList<QSslError> &error);
 };
 }
 
