@@ -15,12 +15,10 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #include "migremeshorturl.h"
 
 #include <QNetworkRequest>
 
-
 using namespace PimCommon;
 
 MigremeShortUrl::MigremeShortUrl(QObject *parent)
@@ -34,26 +32,24 @@ MigremeShortUrl::~MigremeShortUrl()
 
 QString MigremeShortUrl::shortUrlName() const
 {
-    return QLatin1String("migre.me");
+    return QStringLiteral("migre.me");
 }
 
 void MigremeShortUrl::start()
 {
-    const QString requestUrl = QString::fromLatin1("http://migre.me/api.txt?url=%1").arg(mOriginalUrl);
+    const QString requestUrl = QStringLiteral("http://migre.me/api.txt?url=%1").arg(mOriginalUrl);
     QNetworkReply *reply = mNetworkAccessManager->get(QNetworkRequest(requestUrl));
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotErrorFound(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &MigremeShortUrl::slotErrorFound);
 }
 
 void MigremeShortUrl::slotShortUrlFinished(QNetworkReply *reply)
 {
-    reply->deleteLater();
-    if (mErrorFound)
-        return;
-
-    const QString data = QString::fromUtf8(reply->readAll());
-    if (!data.isEmpty()) {
-        Q_EMIT shortUrlDone(data);
+    if (!mErrorFound) {
+        const QString data = QString::fromUtf8(reply->readAll());
+        if (!data.isEmpty()) {
+            Q_EMIT shortUrlDone(data);
+        }
     }
+    reply->deleteLater();
 }
 
-
