@@ -15,25 +15,25 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #ifndef MIGREMESHORTURL_H
 #define MIGREMESHORTURL_H
 #include "abstractshorturl.h"
 
-namespace PimCommon {
+namespace PimCommon
+{
 class MigremeShortUrl : public PimCommon::AbstractShortUrl
 {
     Q_OBJECT
 public:
-    explicit MigremeShortUrl(QObject *parent = 0);
+    explicit MigremeShortUrl(QObject *parent = Q_NULLPTR);
     ~MigremeShortUrl();
 
-    void start();
+    void start() Q_DECL_OVERRIDE;
 
-    QString shortUrlName() const;
+    QString shortUrlName() const Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
-    void slotShortUrlFinished(QNetworkReply*reply);
+    void slotShortUrlFinished(QNetworkReply *reply) Q_DECL_OVERRIDE;
 };
 }
 
