@@ -15,12 +15,10 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #include "tinyurlshorturl.h"
 
 #include <QNetworkRequest>
 
-
 using namespace PimCommon;
 
 TinyurlShortUrl::TinyurlShortUrl(QObject *parent)
@@ -34,25 +32,24 @@ TinyurlShortUrl::~TinyurlShortUrl()
 
 QString TinyurlShortUrl::shortUrlName() const
 {
-    return QLatin1String("TinyURL.com");
+    return QStringLiteral("TinyURL.com");
 }
 
 void TinyurlShortUrl::start()
 {
-    const QString requestUrl = QString::fromLatin1("http://tinyurl.com/api-create.php?url=%1").arg(mOriginalUrl);
+    const QString requestUrl = QStringLiteral("http://tinyurl.com/api-create.php?url=%1").arg(mOriginalUrl);
     QNetworkReply *reply = mNetworkAccessManager->get(QNetworkRequest(requestUrl));
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotErrorFound(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &TinyurlShortUrl::slotErrorFound);
 }
 
 void TinyurlShortUrl::slotShortUrlFinished(QNetworkReply *reply)
 {
-    reply->deleteLater();
-    if (mErrorFound)
-        return;
-
-    const QString data = QString::fromUtf8(reply->readAll());
-    if (!data.isEmpty()) {
-        Q_EMIT shortUrlDone(data);
+    if (!mErrorFound) {
+        const QString data = QString::fromUtf8(reply->readAll());
+        if (!data.isEmpty()) {
+            Q_EMIT shortUrlDone(data);
+        }
     }
+    reply->deleteLater();
 }
 
