@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,25 +15,25 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #ifndef TINYURLSHORTURL_H
 #define TINYURLSHORTURL_H
 #include "abstractshorturl.h"
 
-namespace PimCommon {
+namespace PimCommon
+{
 class TinyurlShortUrl : public PimCommon::AbstractShortUrl
 {
     Q_OBJECT
 public:
-    explicit TinyurlShortUrl(QObject *parent = 0);
+    explicit TinyurlShortUrl(QObject *parent = Q_NULLPTR);
     ~TinyurlShortUrl();
 
-    void start();
+    void start() Q_DECL_OVERRIDE;
 
-    QString shortUrlName() const;
+    QString shortUrlName() const Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
-    void slotShortUrlFinished(QNetworkReply*reply);
+    void slotShortUrlFinished(QNetworkReply *reply) Q_DECL_OVERRIDE;
 };
 }
 
