@@ -15,29 +15,28 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #ifndef TRIOPABSHORTURL_H
 #define TRIOPABSHORTURL_H
 
 #include "abstractshorturl.h"
 
-namespace PimCommon {
+namespace PimCommon
+{
 class TriopabShortUrl : public PimCommon::AbstractShortUrl
 {
     Q_OBJECT
 public:
-    explicit TriopabShortUrl(QObject *parent = 0);
+    explicit TriopabShortUrl(QObject *parent = Q_NULLPTR);
     ~TriopabShortUrl();
 
-    void start();
+    void start() Q_DECL_OVERRIDE;
 
-    QString shortUrlName() const;
+    QString shortUrlName() const Q_DECL_OVERRIDE;
 
 private Q_SLOTS:
-    void slotShortUrlFinished(QNetworkReply*reply);
+    void slotShortUrlFinished(QNetworkReply *reply) Q_DECL_OVERRIDE;
 
 };
 }
 
-
 #endif // TRIOPABSHORTURL_H
