@@ -21,20 +21,21 @@
 #include "pimcommon/shorturl/engine/tinyurlshorturl.h"
 #include "pimcommon/shorturl/engine/migremeshorturl.h"
 #include "pimcommon/shorturl/engine/triopabshorturl.h"
+#include "pimcommon/shorturl/engine/ur1cashorturl.h"
+#include "pimcommon/shorturl/engine/isgdshorturl.h"
 
 #include <KConfigGroup>
 #include <KSharedConfig>
-#include <KGlobal>
 #include <KLocalizedString>
 
-#include <QDebug>
+#include "pimcommon_debug.h"
 
 PimCommon::AbstractShortUrl *PimCommon::ShortUrlUtils::loadEngine(QObject *parent)
 {
     PimCommon::ShortUrlUtils::EngineType type = static_cast<PimCommon::ShortUrlUtils::EngineType>(readEngineSettings());
     PimCommon::AbstractShortUrl *engine = PimCommon::ShortUrlUtils::loadEngine(type, parent);
     if (!engine) {
-        qDebug()<<" Engine type undefined "<<type;
+        qCDebug(PIMCOMMON_LOG) << " Engine type undefined " << type;
         engine = new PimCommon::TinyurlShortUrl(parent);
     }
     return engine;
@@ -42,7 +43,7 @@ PimCommon::AbstractShortUrl *PimCommon::ShortUrlUtils::loadEngine(QObject *paren
 
 PimCommon::AbstractShortUrl *PimCommon::ShortUrlUtils::loadEngine(PimCommon::ShortUrlUtils::EngineType type, QObject *parent)
 {
-    PimCommon::AbstractShortUrl *engine = 0;
+    PimCommon::AbstractShortUrl *engine = Q_NULLPTR;
     switch (type) {
     case Google:
         engine = new PimCommon::GoogleShortUrl(parent);
@@ -56,6 +57,12 @@ PimCommon::AbstractShortUrl *PimCommon::ShortUrlUtils::loadEngine(PimCommon::Sho
     case TriopAB:
         engine = new PimCommon::TriopabShortUrl(parent);
         break;
+    case Ur1Ca:
+        engine = new PimCommon::Ur1CaShortUrl(parent);
+        break;
+    case IsGd:
+        engine = new PimCommon::IsGdShortUrl(parent);
+        break;
     case EndListEngine:
     default:
         break;
@@ -79,16 +86,22 @@ QString PimCommon::ShortUrlUtils::stringFromEngineType(EngineType type)
     case TriopAB:
         name = i18n("TriopAB");
         break;
+    case Ur1Ca:
+        name = i18n("Ur1Ca");
+        break;
+    case IsGd:
+        name = i18n("IsGd");
+        break;
     case EndListEngine:
     default:
-        qDebug()<<" not supported engine type "<<type;
+        qCDebug(PIMCOMMON_LOG) << " not supported engine type " << type;
     }
     return name;
 }
 
 int PimCommon::ShortUrlUtils::readEngineSettings()
 {
-    KConfigGroup grp( KGlobal::config(), "ShortUrl" );
+    KConfigGroup grp(KSharedConfig::openConfig(), "ShortUrl");
     int engineType = grp.readEntry("Engine", static_cast<int>(PimCommon::ShortUrlUtils::Tinyurl));
     //Google engine is dead for the moment.
     if (engineType == PimCommon::ShortUrlUtils::Google) {
@@ -99,6 +112,6 @@ int PimCommon::ShortUrlUtils::readEngineSettings()
 
 void PimCommon::ShortUrlUtils::writeEngineSettings(int value)
 {
-    KConfigGroup grp( KGlobal::config(), "ShortUrl" );
+    KConfigGroup grp(KSharedConfig::openConfig(), "ShortUrl");
     grp.writeEntry("Engine", value);
 }
