@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,24 +19,30 @@
 #define SHORTURLUTILS_H
 
 #include <QObject>
+#include "pimcommon_export.h"
 
-namespace PimCommon {
+namespace PimCommon
+{
 class AbstractShortUrl;
 namespace ShortUrlUtils
 {
-    enum EngineType {
-        Google = 0,
-        Tinyurl = 1,
-        MigreMe = 2,
-        TriopAB = 3,
-        //TODO add more engine.
-        EndListEngine
-    };
-    QString stringFromEngineType(EngineType type);
-    AbstractShortUrl *loadEngine(QObject *parent);
+enum EngineType {
+    Google = 0,
+    Tinyurl = 1,
+    MigreMe = 2,
+    TriopAB = 3,
+    Ur1Ca = 4,
+    IsGd = 5,
 
-    int readEngineSettings();
-    void writeEngineSettings(int value);
+    //TODO add more engine.
+    EndListEngine
+};
+QString stringFromEngineType(EngineType type);
+AbstractShortUrl *loadEngine(QObject *parent);
+PIMCOMMON_EXPORT PimCommon::AbstractShortUrl *loadEngine(PimCommon::ShortUrlUtils::EngineType type, QObject *parent);
+
+int readEngineSettings();
+void writeEngineSettings(int value);
 }
 }
 
