@@ -20,33 +20,32 @@
 #include "pimcommon/storageservice/storageservicejobconfig.h"
 #include "storageservice/authdialog/storageauthviewdialog.h"
 
-#include <qjson/parser.h>
+#include <QJsonDocument>
 
 #include <KLocalizedString>
 
-#include <QDebug>
+#include "pimcommon_debug.h"
 #include <QFile>
 
-
 using namespace PimCommon;
 
 BoxJob::BoxJob(QObject *parent)
     : PimCommon::StorageServiceAbstractJob(parent)
 {
-    connect(mNetworkAccessManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(slotSendDataFinished(QNetworkReply*)));
+    connect(mNetworkAccessManager, &QNetworkAccessManager::finished, this, &BoxJob::slotSendDataFinished);
 
     mRedirectUri = PimCommon::StorageServiceJobConfig::self()->oauth2RedirectUrl();
     mClientId = PimCommon::StorageServiceJobConfig::self()->boxClientId();
     mClientSecret = PimCommon::StorageServiceJobConfig::self()->boxClientSecret();
     mRedirectUri = PimCommon::StorageServiceJobConfig::self()->oauth2RedirectUrl();
 
-    mServiceUrl = QLatin1String("https://app.box.com");
-    mApiUrl = QLatin1String("https://api.box.com");
-    mAuthorizePath = QLatin1String("/api/oauth2/authorize/");
-    mPathToken = QLatin1String("/api/oauth2/token/");
-    mFolderInfoPath = QLatin1String("/2.0/folders/");
-    mFileInfoPath = QLatin1String("/2.0/files/");
-    mCurrentAccountInfoPath = QLatin1String("/2.0/users/me");
+    mServiceUrl = QStringLiteral("https://app.box.com");
+    mApiUrl = QStringLiteral("https://api.box.com");
+    mAuthorizePath = QStringLiteral("/api/oauth2/authorize/");
+    mPathToken = QStringLiteral("/api/oauth2/token/");
+    mFolderInfoPath = QStringLiteral("/2.0/folders/");
+    mFileInfoPath = QStringLiteral("/2.0/files/");
+    mCurrentAccountInfoPath = QStringLiteral("/2.0/users/me");
 }
 
 BoxJob::~BoxJob()
@@ -64,25 +63,26 @@ void BoxJob::initializeToken(const QString &refreshToken, const QString &token)
 void BoxJob::createServiceFolder()
 {
     mActionType = PimCommon::StorageServiceAbstract::CreateServiceFolderAction;
-    mError = false;    
-    createFolderJob(PimCommon::StorageServiceJobConfig::self()->defaultUploadFolder(), QLatin1String("0"));
+    mError = false;
+    createFolderJob(PimCommon::StorageServiceJobConfig::self()->defaultUploadFolder(), QStringLiteral("0"));
 }
 
 void BoxJob::requestTokenAccess()
 {
     mError = false;
     mActionType = PimCommon::StorageServiceAbstract::RequestTokenAction;
-    QUrl url(mServiceUrl + mAuthorizePath );
-    url.addQueryItem(QLatin1String("response_type"), QLatin1String("code"));
-    url.addQueryItem(QLatin1String("client_id"), mClientId);
-    url.addQueryItem(QLatin1String("redirect_uri"), mRedirectUri);
-    if (!mScope.isEmpty())
-        url.addQueryItem(QLatin1String("scope"),mScope);
+    QUrl url(mServiceUrl + mAuthorizePath);
+    url.addQueryItem(QStringLiteral("response_type"), QStringLiteral("code"));
+    url.addQueryItem(QStringLiteral("client_id"), mClientId);
+    url.addQueryItem(QStringLiteral("redirect_uri"), mRedirectUri);
+    if (!mScope.isEmpty()) {
+        url.addQueryItem(QStringLiteral("scope"), mScope);
+    }
     mAuthUrl = url;
-    //qDebug()<<" url"<<url;
+    //qCDebug(PIMCOMMON_LOG)<<" url"<<url;
     delete mAuthDialog;
     mAuthDialog = new PimCommon::StorageAuthViewDialog;
-    connect(mAuthDialog, SIGNAL(urlChanged(QUrl)), this, SLOT(slotRedirect(QUrl)));
+    connect(mAuthDialog.data(), &PimCommon::StorageAuthViewDialog::urlChanged, this, &BoxJob::slotRedirect);
     mAuthDialog->setUrl(url);
     if (mAuthDialog->exec()) {
         delete mAuthDialog;
@@ -96,7 +96,7 @@ void BoxJob::requestTokenAccess()
 void BoxJob::slotRedirect(const QUrl &url)
 {
     if (url != mAuthUrl) {
-        //qDebug()<<" Redirect !"<<url;
+        //qCDebug(PIMCOMMON_LOG)<<" Redirect !"<<url;
         mAuthDialog->accept();
         parseRedirectUrl(url);
     }
@@ -105,7 +105,7 @@ void BoxJob::slotRedirect(const QUrl &url)
 void BoxJob::parseRedirectUrl(const QUrl &url)
 {
     const QList<QPair<QString, QString> > listQuery = url.queryItems();
-    //qDebug()<< "listQuery "<<listQuery;
+    //qCDebug(PIMCOMMON_LOG)<< "listQuery "<<listQuery;
 
     QString authorizeCode;
     QString errorStr;
@@ -135,36 +135,39 @@ void BoxJob::getTokenAccess(const QString &authorizeCode)
     mActionType = PimCommon::StorageServiceAbstract::AccessTokenAction;
     mError = false;
     QNetworkRequest request(QUrl(mServiceUrl + mPathToken));
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
     QUrl postData;
-    postData.addQueryItem(QLatin1String("code"), authorizeCode);
-    postData.addQueryItem(QLatin1String("redirect_uri"), mRedirectUri);
-    postData.addQueryItem(QLatin1String("grant_type"), QLatin1String("authorization_code"));
-    postData.addQueryItem(QLatin1String("client_id"), mClientId);
-    postData.addQueryItem(QLatin1String("client_secret"), mClientSecret);
+    postData.addQueryItem(QStringLiteral("code"), authorizeCode);
+    postData.addQueryItem(QStringLiteral("redirect_uri"), mRedirectUri);
+    postData.addQueryItem(QStringLiteral("grant_type"), QStringLiteral("authorization_code"));
+    postData.addQueryItem(QStringLiteral("client_id"), mClientId);
+    postData.addQueryItem(QStringLiteral("client_secret"), mClientSecret);
     QNetworkReply *reply = mNetworkAccessManager->post(request, postData.encodedQuery());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
-
 void BoxJob::slotSendDataFinished(QNetworkReply *reply)
 {
     const QString data = QString::fromUtf8(reply->readAll());
     reply->deleteLater();
     if (mError) {
-        qDebug()<<" error type "<<data;
-        QJson::Parser parser;
-        bool ok;
-
-        QMap<QString, QVariant> error = parser.parse(data.toUtf8(), &ok).toMap();
-        qDebug()<<" error "<<error;
-        if (error.contains(QLatin1String("message")) || error.contains(QLatin1String("error_description"))) {
+        QJsonParseError parsingError;
+        const QJsonDocument jsonDoc = QJsonDocument::fromJson(data.toUtf8(), &parsingError);
+        if (parsingError.error != QJsonParseError::NoError || jsonDoc.isNull()) {
+            errorMessage(mActionType, i18n("Unknown Error \"%1\"", data));
+            deleteLater();
+            return;
+        }
+        const QMap<QString, QVariant> error = jsonDoc.toVariant().toMap();
+        qCDebug(PIMCOMMON_LOG) << " error " << error;
+        if (error.contains(QStringLiteral("message")) || error.contains(QStringLiteral("error_description"))) {
             QString errorStr;
-            if (error.contains(QLatin1String("message")))
-                errorStr = error.value(QLatin1String("message")).toString();
-            else
-                errorStr = error.value(QLatin1String("error_description")).toString();
-            switch(mActionType) {
+            if (error.contains(QStringLiteral("message"))) {
+                errorStr = error.value(QStringLiteral("message")).toString();
+            } else {
+                errorStr = error.value(QStringLiteral("error_description")).toString();
+            }
+            switch (mActionType) {
             case PimCommon::StorageServiceAbstract::NoneAction:
                 deleteLater();
                 break;
@@ -213,8 +216,8 @@ void BoxJob::slotSendDataFinished(QNetworkReply *reply)
         }
         return;
     }
-    //qDebug()<<" data: "<<data;
-    switch(mActionType) {
+    //qCDebug(PIMCOMMON_LOG)<<" data: "<<data;
+    switch (mActionType) {
     case PimCommon::StorageServiceAbstract::NoneAction:
         deleteLater();
         break;
@@ -272,20 +275,23 @@ void BoxJob::slotSendDataFinished(QNetworkReply *reply)
     }
 }
 
-
 void BoxJob::parseAccountInfo(const QString &data)
 {
-    QJson::Parser parser;
-    bool ok;
-
-    const QMap<QString, QVariant> info = parser.parse(data.toUtf8(), &ok).toMap();
-    //qDebug()<<" info"<<info;
-    PimCommon::AccountInfo accountInfo;
-    if (info.contains(QLatin1String("space_used"))) {
-        accountInfo.shared = info.value(QLatin1String("space_used")).toLongLong();
+    //qCDebug(PIMCOMMON_LOG)<<" info"<<info;
+    QJsonParseError parsingError;
+    const QJsonDocument jsonDoc = QJsonDocument::fromJson(data.toUtf8(), &parsingError);
+    if (parsingError.error != QJsonParseError::NoError || jsonDoc.isNull()) {
+        qCDebug(PIMCOMMON_LOG) << "parseAccountInfo parse error " << data;
+        return;
     }
-    if (info.contains(QLatin1String("space_amount"))) {
-        accountInfo.quota = info.value(QLatin1String("space_amount")).toLongLong();
+    const QMap<QString, QVariant> info = jsonDoc.toVariant().toMap();
+
+    PimCommon::AccountInfo accountInfo;
+    if (info.contains(QStringLiteral("space_used"))) {
+        accountInfo.shared = info.value(QStringLiteral("space_used")).toLongLong();
+    }
+    if (info.contains(QStringLiteral("space_amount"))) {
+        accountInfo.quota = info.value(QStringLiteral("space_amount")).toLongLong();
     }
     Q_EMIT accountInfoDone(accountInfo);
     deleteLater();
@@ -295,19 +301,18 @@ void BoxJob::refreshToken()
 {
     mActionType = PimCommon::StorageServiceAbstract::AccessTokenAction;
     QNetworkRequest request(QUrl(QLatin1String("https://www.box.com/api/oauth2/token")));
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
     QUrl postData;
-    postData.addQueryItem(QLatin1String("refresh_token"), mRefreshToken);
-    postData.addQueryItem(QLatin1String("grant_type"), QLatin1String("refresh_token"));
-    postData.addQueryItem(QLatin1String("client_id"), mClientId);
-    postData.addQueryItem(QLatin1String("client_secret"), mClientSecret);
-    //qDebug()<<"refreshToken postData: "<<postData;
+    postData.addQueryItem(QStringLiteral("refresh_token"), mRefreshToken);
+    postData.addQueryItem(QStringLiteral("grant_type"), QStringLiteral("refresh_token"));
+    postData.addQueryItem(QStringLiteral("client_id"), mClientId);
+    postData.addQueryItem(QStringLiteral("client_secret"), mClientSecret);
+    //qCDebug(PIMCOMMON_LOG)<<"refreshToken postData: "<<postData;
 
     QNetworkReply *reply = mNetworkAccessManager->post(request, postData.encodedQuery());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
-
 void BoxJob::deleteFile(const QString &filename)
 {
     mActionType = PimCommon::StorageServiceAbstract::DeleteFileAction;
@@ -315,10 +320,10 @@ void BoxJob::deleteFile(const QString &filename)
     QUrl url;
     url.setUrl(mApiUrl + mFileInfoPath + filename);
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     QNetworkReply *reply = mNetworkAccessManager->deleteResource(request);
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::deleteFolder(const QString &foldername)
@@ -327,12 +332,12 @@ void BoxJob::deleteFolder(const QString &foldername)
     mError = false;
     QUrl url;
     url.setUrl(mApiUrl + mFolderInfoPath + foldername);
-    url.addQueryItem(QLatin1String("recursive"), QLatin1String("true"));
+    url.addQueryItem(QStringLiteral("recursive"), QStringLiteral("true"));
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     QNetworkReply *reply = mNetworkAccessManager->deleteResource(request);
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::renameFolder(const QString &source, const QString &destination)
@@ -342,12 +347,12 @@ void BoxJob::renameFolder(const QString &source, const QString &destination)
     QUrl url;
     url.setUrl(mApiUrl + mFolderInfoPath + source);
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
-    const QString data = QString::fromLatin1("{\"name\":\"%1\"}").arg(destination);
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
+    const QString data = QStringLiteral("{\"name\":\"%1\"}").arg(destination);
 
     QNetworkReply *reply = mNetworkAccessManager->put(request, data.toLatin1());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::renameFile(const QString &oldName, const QString &newName)
@@ -358,12 +363,12 @@ void BoxJob::renameFile(const QString &oldName, const QString &newName)
     QUrl url;
     url.setUrl(mApiUrl + mFileInfoPath + oldName);
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     const QString data = QString::fromLatin1("{\"name\":\"%1\"}").arg(newName);
 
     QNetworkReply *reply = mNetworkAccessManager->put(request, data.toLatin1());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::moveFolder(const QString &source, const QString &destination)
@@ -372,13 +377,13 @@ void BoxJob::moveFolder(const QString &source, const QString &destination)
     mError = false;
     QUrl url;
     url.setUrl(mApiUrl + mFolderInfoPath + source);
-    qDebug()<<" url "<<url;
+    qCDebug(PIMCOMMON_LOG) << " url " << url;
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     const QString data = QString::fromLatin1("{\"parent\": {\"id\" : \"%1\"} }").arg(destination);
     QNetworkReply *reply = mNetworkAccessManager->put(request, data.toLatin1());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::moveFile(const QString &source, const QString &destination)
@@ -387,14 +392,14 @@ void BoxJob::moveFile(const QString &source, const QString &destination)
     mError = false;
     QUrl url;
     url.setUrl(mApiUrl + mFileInfoPath + source);
-    //qDebug()<<" url "<<url;
+    //qCDebug(PIMCOMMON_LOG)<<" url "<<url;
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     const QString data = QString::fromLatin1("{\"parent\": {\"id\" : \"%1\"} }").arg(destination);
 
     QNetworkReply *reply = mNetworkAccessManager->put(request, data.toLatin1());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::copyFile(const QString &source, const QString &destination)
@@ -404,12 +409,12 @@ void BoxJob::copyFile(const QString &source, const QString &destination)
     QUrl url;
     url.setUrl(mApiUrl + mFileInfoPath + QString::fromLatin1("%1/copy").arg(source));
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     const QString data = QString::fromLatin1("{\"parent\": {\"id\": \"%1\"}}").arg(destination);
 
     QNetworkReply *reply = mNetworkAccessManager->post(request, data.toLatin1());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::copyFolder(const QString &source, const QString &destination)
@@ -419,12 +424,12 @@ void BoxJob::copyFolder(const QString &source, const QString &destination)
     QUrl url;
     url.setUrl(mApiUrl + mFolderInfoPath + QString::fromLatin1("%1/copy").arg(source));
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     const QString data = QString::fromLatin1("{\"parent\": {\"id\": \"%1\"}}").arg(destination);
 
     QNetworkReply *reply = mNetworkAccessManager->post(request, data.toLatin1());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 QNetworkReply *BoxJob::uploadFile(const QString &filename, const QString &uploadAsName, const QString &destination)
@@ -438,19 +443,19 @@ QNetworkReply *BoxJob::uploadFile(const QString &filename, const QString &upload
             //TODO upload multipart
             url.setUrl(QLatin1String("https://upload.box.com/api/2.0/files/content"));
             QNetworkRequest request(url);
-            request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-            request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+            request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+            request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
             QUrl postData;
-            postData.addQueryItem(QLatin1String("parent_id"), destination);
-            postData.addQueryItem(QLatin1String("filename"), uploadAsName);
+            postData.addQueryItem(QStringLiteral("parent_id"), destination);
+            postData.addQueryItem(QStringLiteral("filename"), uploadAsName);
             QNetworkReply *reply = mNetworkAccessManager->post(request, postData.encodedQuery());
             file->setParent(reply);
-            connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+            connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
             return reply;
         }
     }
     delete file;
-    return 0;
+    return Q_NULLPTR;
 }
 
 void BoxJob::listFolder(const QString &folder)
@@ -460,10 +465,10 @@ void BoxJob::listFolder(const QString &folder)
     QUrl url;
     url.setUrl(mApiUrl + mFolderInfoPath + (folder.isEmpty() ? QLatin1String("0") : folder) + QLatin1String("/items?fields=name,created_at,size,modified_at,id"));
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     QNetworkReply *reply = mNetworkAccessManager->get(request);
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::accountInfo()
@@ -473,10 +478,10 @@ void BoxJob::accountInfo()
     QUrl url;
     url.setUrl(mApiUrl + mCurrentAccountInfoPath);
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     QNetworkReply *reply = mNetworkAccessManager->get(request);
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::createFolderJob(const QString &foldername, const QString &destination)
@@ -484,11 +489,11 @@ void BoxJob::createFolderJob(const QString &foldername, const QString &destinati
     QUrl url;
     url.setUrl(mApiUrl + mFolderInfoPath);
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
     const QString data = QString::fromLatin1("{\"name\":\"%1\", \"parent\": {\"id\": \"%2\"}}").arg(foldername).arg((destination.isEmpty() ? QLatin1String("0") : destination));
     QNetworkReply *reply = mNetworkAccessManager->post(request, data.toLatin1());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::createFolder(const QString &foldername, const QString &destination)
@@ -498,7 +503,6 @@ void BoxJob::createFolder(const QString &foldername, const QString &destination)
     createFolderJob(foldername, destination);
 }
 
-
 void BoxJob::shareLink(const QString &root, const QString &fileId)
 {
     Q_UNUSED(root);
@@ -507,13 +511,13 @@ void BoxJob::shareLink(const QString &root, const QString &fileId)
     QUrl url;
     url.setUrl(mApiUrl + mFileInfoPath + fileId);
     QNetworkRequest request(url);
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-    request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+    request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
 
     const QByteArray data("{\"shared_link\": {\"access\": \"open\"}}");
 
-    QNetworkReply *reply = mNetworkAccessManager->put(request,data);
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    QNetworkReply *reply = mNetworkAccessManager->put(request, data);
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
 }
 
 void BoxJob::parseDeleteFolder(const QString &data)
@@ -523,7 +527,7 @@ void BoxJob::parseDeleteFolder(const QString &data)
     bool ok;
 
     const QMap<QString, QVariant> info = parser.parse(data.toUtf8(), &ok).toMap();
-    qDebug()<<" info"<<info;
+    qCDebug(PIMCOMMON_LOG)<<" info"<<info;
     */
     Q_EMIT deleteFolderDone(QString());
 }
@@ -535,7 +539,7 @@ void BoxJob::parseDeleteFile(const QString &data)
     bool ok;
 
     const QMap<QString, QVariant> info = parser.parse(data.toUtf8(), &ok).toMap();
-    qDebug()<<" info"<<info;
+    qCDebug(PIMCOMMON_LOG)<<" info"<<info;
     */
     Q_EMIT deleteFileDone(QString());
 }
@@ -547,7 +551,7 @@ void BoxJob::parseCreateServiceFolder(const QString &data)
     bool ok;
 
     const QMap<QString, QVariant> info = parser.parse(data.toUtf8(), &ok).toMap();
-    qDebug()<<" info"<<info;
+    qCDebug(PIMCOMMON_LOG) << " info" << info;
 #endif
     Q_EMIT actionFailed(QLatin1String("Not Implemented"));
     deleteLater();
@@ -618,28 +622,34 @@ void BoxJob::parseMoveFile(const QString &data)
 
 QString BoxJob::parseNameInfo(const QString &data)
 {
-    QJson::Parser parser;
-    bool ok;
-
     QString filename;
-    const QMap<QString, QVariant> info = parser.parse(data.toUtf8(), &ok).toMap();
-    if (info.contains(QLatin1String("name"))) {
-        filename = info.value(QLatin1String("name")).toString();
+    QJsonParseError parsingError;
+    const QJsonDocument jsonDoc = QJsonDocument::fromJson(data.toUtf8(), &parsingError);
+    if (parsingError.error != QJsonParseError::NoError || jsonDoc.isNull()) {
+        return filename;
+    }
+    const QMap<QString, QVariant> info = jsonDoc.toVariant().toMap();
+
+    if (info.contains(QStringLiteral("name"))) {
+        filename = info.value(QStringLiteral("name")).toString();
     }
     return filename;
 }
 
 void BoxJob::parseShareLink(const QString &data)
 {
-    QJson::Parser parser;
-    bool ok;
-
     QString url;
-    const QMap<QString, QVariant> info = parser.parse(data.toUtf8(), &ok).toMap();
-    if (info.contains(QLatin1String("shared_link"))) {
-        const QVariantMap map = info.value(QLatin1String("shared_link")).toMap();
-        if (map.contains(QLatin1String("url"))) {
-            url = map.value(QLatin1String("url")).toString();
+    QJsonParseError parsingError;
+    const QJsonDocument jsonDoc = QJsonDocument::fromJson(data.toUtf8(), &parsingError);
+    if (parsingError.error != QJsonParseError::NoError || jsonDoc.isNull()) {
+        qCDebug(PIMCOMMON_LOG) << "parseShareLink error " << data;
+        return;
+    }
+    const QMap<QString, QVariant> info = jsonDoc.toVariant().toMap();
+    if (info.contains(QStringLiteral("shared_link"))) {
+        const QVariantMap map = info.value(QStringLiteral("shared_link")).toMap();
+        if (map.contains(QStringLiteral("url"))) {
+            url = map.value(QStringLiteral("url")).toString();
         }
     }
     Q_EMIT shareLinkDone(url);
@@ -648,11 +658,11 @@ void BoxJob::parseShareLink(const QString &data)
 
 void BoxJob::parseDownloadFile(const QString &data)
 {
-    qDebug()<<" Data "<<data;
+    qCDebug(PIMCOMMON_LOG) << " Data " << data;
     Q_EMIT downLoadFileDone(QString());
 }
 
-QNetworkReply * BoxJob::downloadFile(const QString &name, const QString &fileId, const QString &destination)
+QNetworkReply *BoxJob::downloadFile(const QString &name, const QString &fileId, const QString &destination)
 {
     mActionType = PimCommon::StorageServiceAbstract::DownLoadFileAction;
     mError = false;
@@ -661,45 +671,49 @@ QNetworkReply * BoxJob::downloadFile(const QString &name, const QString &fileId,
     mError = false;
     const QString defaultDestination = (destination.isEmpty() ? PimCommon::StorageServiceJobConfig::self()->defaultUploadFolder() : destination);
     delete mDownloadFile;
-    mDownloadFile = new QFile(defaultDestination+ QLatin1Char('/') + name);
+    mDownloadFile = new QFile(defaultDestination + QLatin1Char('/') + name);
     if (mDownloadFile->open(QIODevice::WriteOnly)) {
         QUrl url;
-        qDebug()<<" fileId "<<fileId<<" name "<<name;
+        qCDebug(PIMCOMMON_LOG) << " fileId " << fileId << " name " << name;
         url.setUrl(mApiUrl + mFileInfoPath + fileId + QLatin1String("/content"));
-        qDebug()<<"url!"<<url;
+        qCDebug(PIMCOMMON_LOG) << "url!" << url;
         QNetworkRequest request(url);
-        request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
-        request.setRawHeader("Authorization", "Bearer "+ mToken.toLatin1());
+        request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
+        request.setRawHeader("Authorization", "Bearer " + mToken.toLatin1());
         QNetworkReply *reply = mNetworkAccessManager->get(request);
         mDownloadFile->setParent(reply);
-        connect(reply, SIGNAL(readyRead()), this, SLOT(slotDownloadReadyRead()));
-        connect(reply, SIGNAL(downloadProgress(qint64,qint64)), SLOT(slotuploadDownloadFileProgress(qint64,qint64)));
-        connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+        connect(reply, &QNetworkReply::readyRead, this, &BoxJob::slotDownloadReadyRead);
+        connect(reply, &QNetworkReply::downloadProgress, this, &BoxJob::slotuploadDownloadFileProgress);
+        connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &BoxJob::slotError);
         return reply;
     } else {
         delete mDownloadFile;
     }
-    return 0;
+    return Q_NULLPTR;
 }
 
 void BoxJob::parseAccessToken(const QString &data)
 {
-    QJson::Parser parser;
-    bool ok;
-
-    const QMap<QString, QVariant> info = parser.parse(data.toUtf8(), &ok).toMap();
-    //qDebug()<<" info"<<info;
-    if (info.contains(QLatin1String("refresh_token"))) {
-        mRefreshToken = info.value(QLatin1String("refresh_token")).toString();
+    QJsonParseError parsingError;
+    const QJsonDocument jsonDoc = QJsonDocument::fromJson(data.toUtf8(), &parsingError);
+    if (parsingError.error != QJsonParseError::NoError || jsonDoc.isNull()) {
+        qCDebug(PIMCOMMON_LOG) << "parseAccessToken error " << data;
+        return;
     }
-    if (info.contains(QLatin1String("access_token"))) {
-        mToken = info.value(QLatin1String("access_token")).toString();
+    const QMap<QString, QVariant> info = jsonDoc.toVariant().toMap();
+
+    //qCDebug(PIMCOMMON_LOG)<<" info"<<info;
+    if (info.contains(QStringLiteral("refresh_token"))) {
+        mRefreshToken = info.value(QStringLiteral("refresh_token")).toString();
+    }
+    if (info.contains(QStringLiteral("access_token"))) {
+        mToken = info.value(QStringLiteral("access_token")).toString();
     }
     qint64 expireInTime = 0;
-    if (info.contains(QLatin1String("expires_in"))) {
-        expireInTime = info.value(QLatin1String("expires_in")).toLongLong();
+    if (info.contains(QStringLiteral("expires_in"))) {
+        expireInTime = info.value(QStringLiteral("expires_in")).toLongLong();
     }
-    //qDebug()<<" parseAccessToken";
+    //qCDebug(PIMCOMMON_LOG)<<" parseAccessToken";
     Q_EMIT authorizationDone(mRefreshToken, mToken, expireInTime);
     deleteLater();
 }
