@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -22,18 +22,20 @@
 
 #include <KLocalizedString>
 #include <KSharedConfig>
-
 #include <QGridLayout>
 #include <QLabel>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
+#include <QVBoxLayout>
 
 using namespace PimCommon;
 
 StorageServicePropertiesDialog::StorageServicePropertiesDialog(const QMap<QString, QString> &information, QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
 {
-    setCaption(i18n("Properties"));
+    setWindowTitle(i18nc("@title:window", "Properties"));
 
-    setButtons( Close );
     createInformationWidget(information);
     readConfig();
 }
@@ -45,6 +47,11 @@ StorageServicePropertiesDialog::~StorageServicePropertiesDialog()
 
 void StorageServicePropertiesDialog::createInformationWidget(const QMap<QString, QString> &information)
 {
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &StorageServicePropertiesDialog::reject);
+
     QWidget *parent = new QWidget;
     QGridLayout *grid = new QGridLayout;
     parent->setLayout(grid);
@@ -69,22 +76,24 @@ void StorageServicePropertiesDialog::createInformationWidget(const QMap<QString,
 
         ++row;
     }
-    setMainWidget(parent);
+    mainLayout->addWidget(parent);
+    mainLayout->addWidget(buttonBox);
+
 }
 
 void StorageServicePropertiesDialog::readConfig()
 {
-    KConfigGroup group( KGlobal::config(), "StorageServicePropertiesDialog" );
-    const QSize size = group.readEntry( "Size", QSize(300, 200) );
-    if ( size.isValid() ) {
-        resize( size );
+    KConfigGroup group(KSharedConfig::openConfig(), "StorageServicePropertiesDialog");
+    const QSize size = group.readEntry("Size", QSize(300, 200));
+    if (size.isValid()) {
+        resize(size);
     }
 }
 
 void StorageServicePropertiesDialog::writeConfig()
 {
-    KSharedConfig::Ptr config = KGlobal::config();
+    KSharedConfig::Ptr config = KSharedConfig::openConfig();
 
-    KConfigGroup group = config->group( QLatin1String("StorageServicePropertiesDialog") );
-    group.writeEntry( "Size", size() );
+    KConfigGroup group = config->group(QStringLiteral("StorageServicePropertiesDialog"));
+    group.writeEntry("Size", size());
 }
