@@ -24,16 +24,17 @@
 
 class QFile;
 class QNetworkAccessManager;
-namespace PimCommon {
+namespace PimCommon
+{
 class AccountInfo;
 class StorageServiceAbstractJob : public QObject
 {
     Q_OBJECT
 public:
-    explicit StorageServiceAbstractJob(QObject *parent = 0);
+    explicit StorageServiceAbstractJob(QObject *parent = Q_NULLPTR);
     ~StorageServiceAbstractJob();
 
-    virtual QNetworkReply *uploadFile(const QString &filename, const QString &uploadAsName, const QString &destination=QString()) = 0;
+    virtual QNetworkReply *uploadFile(const QString &filename, const QString &uploadAsName, const QString &destination = QString()) = 0;
     virtual QNetworkReply *downloadFile(const QString &name, const QString &fileId, const QString &destination) = 0;
 
     virtual void requestTokenAccess() = 0;
@@ -72,7 +73,6 @@ Q_SIGNALS:
     void copyFileDone(const QString &folder);
     void copyFolderDone(const QString &folder);
 
-
 protected:
     void errorMessage(PimCommon::StorageServiceAbstract::ActionType type, const QString &errorStr);
 
@@ -86,7 +86,7 @@ protected Q_SLOTS:
     void slotDownloadReadyRead();
     void slotuploadDownloadFileProgress(qint64 done, qint64 total);
 
-private slots:
+public Q_SLOTS:
     void slotSslErrors(QNetworkReply *reply, const QList<QSslError> &error);
     void slotError(QNetworkReply::NetworkError);
 
