@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,6 +18,7 @@
 #include "storageservicemanager.h"
 #include "storageserviceprogressmanager.h"
 #include "storagemanageradaptor.h"
+#include "pimcommon_debug.h"
 
 #include "settings/pimcommonsettings.h"
 #include "storageservice/utils/storageserviceutils.h"
@@ -35,23 +36,21 @@
 #include "gdrive/gdrivestorageservice.h"
 #endif
 #include <KLocalizedString>
-#include <KFileDialog>
-#include <KInputDialog>
 #include <KActionMenu>
 #include <KMessageBox>
 
-#include <QMenu>
 #include <QDBusConnection>
+#include <QFileDialog>
 
 using namespace PimCommon;
 
 static QString newDBusObjectName()
 {
     static int s_count = 0;
-    QString name( QLatin1String("/STORAGESERVICE_ServiceManager") );
-    if ( s_count++ ) {
+    QString name(QStringLiteral("/STORAGESERVICE_ServiceManager"));
+    if (s_count++) {
         name += QLatin1Char('_');
-        name += QString::number( s_count );
+        name += QString::number(s_count);
     }
     return name;
 }
@@ -59,14 +58,14 @@ static QString newDBusObjectName()
 StorageServiceManager::StorageServiceManager(QObject *parent)
     : QObject(parent)
 {
-    new StorageManagerAdaptor( this );
+    new StorageManagerAdaptor(this);
     QDBusConnection dbus = QDBusConnection::sessionBus();
     const QString dbusPath = newDBusObjectName();
-    setProperty( "uniqueDBusPath", dbusPath );
-    const QString dbusInterface = QLatin1String("org.kde.pim.StorageManager");
-    dbus.registerObject( dbusPath, this );
-    dbus.connect( QString(), QString(), dbusInterface, QLatin1String("configChanged"), this,
-                  SLOT(slotConfigChanged(QString)) );
+    setProperty("uniqueDBusPath", dbusPath);
+    const QString dbusInterface = QStringLiteral("org.kde.pim.StorageManager");
+    dbus.registerObject(dbusPath, this);
+    dbus.connect(QString(), QString(), dbusInterface, QStringLiteral("configChanged"), this,
+                 SLOT(slotConfigChanged(QString)));
 
     readConfig();
 }
@@ -76,25 +75,25 @@ StorageServiceManager::~StorageServiceManager()
     qDeleteAll(mListService);
 }
 
-
 void StorageServiceManager::removeService(const QString &serviceName)
 {
-    if (mListService.contains(serviceName))
+    if (mListService.contains(serviceName)) {
         mListService.remove(serviceName);
+    }
 }
 
 QString StorageServiceManager::ourIdentifier() const
 {
-    const QString identifier = QString::fromLatin1( "%1/%2" ).
-                                    arg( QDBusConnection::sessionBus().baseService() ).
-                                    arg( property( "uniqueDBusPath" ).toString() );
+    const QString identifier = QStringLiteral("%1/%2").
+                               arg(QDBusConnection::sessionBus().baseService()).
+                               arg(property("uniqueDBusPath").toString());
     return identifier;
 }
 
 void StorageServiceManager::slotConfigChanged(const QString &id)
 {
-    qDebug()<<" void StorageServiceManager::slotConfigChanged(const QString &id)"<<id;
-    if ( id != ourIdentifier() ) {
+    qCDebug(PIMCOMMON_LOG) << " void StorageServiceManager::slotConfigChanged(const QString &id)" << id;
+    if (id != ourIdentifier()) {
         readConfig();
         Q_EMIT servicesChanged();
     }
@@ -111,7 +110,7 @@ void StorageServiceManager::setListService(const QMap<QString, StorageServiceAbs
     writeConfig();
 
     // DBus signal for other IdentityManager instances
-    emit configChanged( ourIdentifier() );
+    Q_EMIT configChanged(ourIdentifier());
 }
 
 void StorageServiceManager::setDefaultUploadFolder(const QString &folder)
@@ -161,10 +160,11 @@ KActionMenu *StorageServiceManager::menuWithCapability(PimCommon::StorageService
             if (PimCommon::StorageServiceUtils::hasExactCapabilities(i.value()->capabilities(), lstCapability)) {
                 QAction *act = new QAction(/*serviceToI18n(*/i.key(), menuService);
                 act->setData(i.key());
-                const KIcon icon = i.value()->icon();
-                if (!icon.isNull())
+                const QIcon icon = i.value()->icon();
+                if (!icon.isNull()) {
                     act->setIcon(icon);
-                switch(mainCapability) {
+                }
+                switch (mainCapability) {
                 case PimCommon::StorageServiceAbstract::NoCapability:
                 case PimCommon::StorageServiceAbstract::CreateFolderCapability:
                 case PimCommon::StorageServiceAbstract::ListFolderCapability:
@@ -174,31 +174,31 @@ KActionMenu *StorageServiceManager::menuWithCapability(PimCommon::StorageService
                 case PimCommon::StorageServiceAbstract::MoveFileCapability:
                 case PimCommon::StorageServiceAbstract::CopyFileCapability:
                 case PimCommon::StorageServiceAbstract::CopyFolderCapability:
-                    qDebug()<<" not implemented ";
+                    qCDebug(PIMCOMMON_LOG) << " not implemented ";
                     break;
                 case PimCommon::StorageServiceAbstract::DeleteFolderCapability:
                     menuService->setText(i18n("Delete Folder..."));
-                    connect(act, SIGNAL(triggered()), this, SLOT(slotDeleteFolder()));
+                    connect(act, &QAction::triggered, this, &StorageServiceManager::slotDeleteFolder);
                     break;
                 case PimCommon::StorageServiceAbstract::DownloadFileCapability:
                     menuService->setText(i18n("Download File..."));
-                    connect(act, SIGNAL(triggered()), this, SLOT(slotDownloadFile()));
+                    connect(act, &QAction::triggered, this, &StorageServiceManager::slotDownloadFile);
                     break;
                 case PimCommon::StorageServiceAbstract::UploadFileCapability:
                     menuService->setText(i18n("Upload File..."));
-                    connect(act, SIGNAL(triggered()), this, SLOT(slotShareFile()));
+                    connect(act, &QAction::triggered, this, &StorageServiceManager::slotShareFile);
                     break;
                 case PimCommon::StorageServiceAbstract::ShareLinkCapability:
                     menuService->setText(i18n("Share File..."));
-                    connect(act, SIGNAL(triggered()), this, SLOT(slotShareFile()));
+                    connect(act, &QAction::triggered, this, &StorageServiceManager::slotShareFile);
                     break;
                 case PimCommon::StorageServiceAbstract::DeleteFileCapability:
                     menuService->setText(i18n("Delete File..."));
-                    connect(act, SIGNAL(triggered()), this, SLOT(slotDeleteFile()));
+                    connect(act, &QAction::triggered, this, &StorageServiceManager::slotDeleteFile);
                     break;
                 case PimCommon::StorageServiceAbstract::AccountInfoCapability:
                     menuService->setText(i18n("Account Info..."));
-                    connect(act, SIGNAL(triggered()), this, SLOT(slotAccountInfo()));
+                    connect(act, &QAction::triggered, this, &StorageServiceManager::slotAccountInfo);
                     break;
                 }
                 menuService->addAction(act);
@@ -208,18 +208,17 @@ KActionMenu *StorageServiceManager::menuWithCapability(PimCommon::StorageService
     return menuService;
 }
 
-
 void StorageServiceManager::slotShareFile()
 {
-    QAction *act = qobject_cast< QAction* >( sender() );
-    if ( act ) {
+    QAction *act = qobject_cast< QAction * >(sender());
+    if (act) {
         const QString type = act->data().toString();
         if (mListService.contains(type)) {
             StorageServiceAbstract *service = mListService.value(type);
             if (service->hasUploadOrDownloadInProgress()) {
-                KMessageBox::information(0, i18n("There is still an upload in progress."));
+                KMessageBox::information(Q_NULLPTR, i18n("There is still an upload in progress."));
             } else {
-                const QString fileName = KFileDialog::getOpenFileName( QString(), QString(), 0, i18n("File to upload") );
+                const QString fileName = QFileDialog::getOpenFileName(Q_NULLPTR, i18n("File to upload"));
                 if (!fileName.isEmpty()) {
                     QFileInfo info(fileName);
                     const QRegExp disallowedSymbols = service->disallowedSymbols();
@@ -241,10 +240,10 @@ void StorageServiceManager::slotShareFile()
                     }
 
                     defaultConnect(service);
-                    connect(service,SIGNAL(uploadDownloadFileProgress(QString,qint64,qint64)), this, SIGNAL(uploadDownloadFileProgress(QString,qint64,qint64)), Qt::UniqueConnection);
-                    connect(service,SIGNAL(uploadFileDone(QString,QString)), this, SIGNAL(uploadFileDone(QString,QString)), Qt::UniqueConnection);
-                    connect(service,SIGNAL(uploadFileFailed(QString,QString)), this, SIGNAL(uploadFileFailed(QString,QString)), Qt::UniqueConnection);
-                    connect(service,SIGNAL(shareLinkDone(QString,QString)), this, SIGNAL(shareLinkDone(QString,QString)), Qt::UniqueConnection);
+                    connect(service, &StorageServiceAbstract::uploadDownloadFileProgress, this, &StorageServiceManager::uploadDownloadFileProgress, Qt::UniqueConnection);
+                    connect(service, &StorageServiceAbstract::uploadFileDone, this, &StorageServiceManager::uploadFileDone, Qt::UniqueConnection);
+                    connect(service, &StorageServiceAbstract::uploadFileFailed, this, &StorageServiceManager::uploadFileFailed, Qt::UniqueConnection);
+                    connect(service, &StorageServiceAbstract::shareLinkDone, this, &StorageServiceManager::shareLinkDone, Qt::UniqueConnection);
                     Q_EMIT uploadFileStart(service);
                     PimCommon::StorageServiceProgressManager::self()->addProgress(service, StorageServiceProgressManager::Upload);
                     service->uploadFile(fileName, newName, QString());
@@ -256,12 +255,12 @@ void StorageServiceManager::slotShareFile()
 
 void StorageServiceManager::slotDownloadFile()
 {
-    QAction *act = qobject_cast< QAction* >( sender() );
-    if ( act ) {
+    QAction *act = qobject_cast< QAction * >(sender());
+    if (act) {
         const QString type = act->data().toString();
         if (mListService.contains(type)) {
             StorageServiceAbstract *service = mListService.value(type);
-            QPointer<PimCommon::StorageServiceDownloadDialog> dlg = new PimCommon::StorageServiceDownloadDialog(service, 0);
+            QPointer<PimCommon::StorageServiceDownloadDialog> dlg = new PimCommon::StorageServiceDownloadDialog(service, Q_NULLPTR);
             dlg->setDefaultDownloadPath(mDefaultUploadFolder);
             dlg->exec();
             delete dlg;
@@ -271,21 +270,21 @@ void StorageServiceManager::slotDownloadFile()
 
 void StorageServiceManager::defaultConnect(StorageServiceAbstract *service)
 {
-    connect(service,SIGNAL(actionFailed(QString,QString)), this, SIGNAL(actionFailed(QString,QString)), Qt::UniqueConnection);
-    connect(service,SIGNAL(authenticationDone(QString)), this, SIGNAL(authenticationDone(QString)), Qt::UniqueConnection);
-    connect(service,SIGNAL(authenticationFailed(QString,QString)), this, SIGNAL(authenticationFailed(QString,QString)), Qt::UniqueConnection);
+    connect(service, &StorageServiceAbstract::actionFailed, this, &StorageServiceManager::actionFailed, Qt::UniqueConnection);
+    connect(service, &StorageServiceAbstract::authenticationDone, this, &StorageServiceManager::authenticationDone, Qt::UniqueConnection);
+    connect(service, &StorageServiceAbstract::authenticationFailed, this, &StorageServiceManager::authenticationFailed, Qt::UniqueConnection);
 }
 
 void StorageServiceManager::slotDeleteFile()
 {
-    QAction *act = qobject_cast< QAction* >( sender() );
-    if ( act ) {
+    QAction *act = qobject_cast< QAction * >(sender());
+    if (act) {
         const QString type = act->data().toString();
         if (mListService.contains(type)) {
             StorageServiceAbstract *service = mListService.value(type);
-            QPointer<StorageServiceDeleteDialog> dlg = new StorageServiceDeleteDialog(StorageServiceDeleteDialog::DeleteFiles,service);
+            QPointer<StorageServiceDeleteDialog> dlg = new StorageServiceDeleteDialog(StorageServiceDeleteDialog::DeleteFiles, service);
             defaultConnect(service);
-            connect(dlg,SIGNAL(deleteFileDone(QString,QString)), this, SIGNAL(deleteFileDone(QString,QString)));
+            connect(dlg.data(), &StorageServiceDeleteDialog::deleteFileDone, this, &StorageServiceManager::deleteFileDone);
             dlg->exec();
             delete dlg;
         }
@@ -294,14 +293,14 @@ void StorageServiceManager::slotDeleteFile()
 
 void StorageServiceManager::slotDeleteFolder()
 {
-    QAction *act = qobject_cast< QAction* >( sender() );
-    if ( act ) {
+    QAction *act = qobject_cast< QAction * >(sender());
+    if (act) {
         const QString type = act->data().toString();
         if (mListService.contains(type)) {
             StorageServiceAbstract *service = mListService.value(type);
             QPointer<StorageServiceDeleteDialog> dlg = new StorageServiceDeleteDialog(StorageServiceDeleteDialog::DeleteFolders, service);
             defaultConnect(service);
-            connect(dlg,SIGNAL(deleteFolderDone(QString,QString)), this, SIGNAL(deleteFolderDone(QString,QString)));
+            connect(dlg.data(), &StorageServiceDeleteDialog::deleteFolderDone, this, &StorageServiceManager::deleteFolderDone);
             dlg->exec();
             delete dlg;
         }
@@ -310,13 +309,13 @@ void StorageServiceManager::slotDeleteFolder()
 
 void StorageServiceManager::slotAccountInfo()
 {
-    QAction *act = qobject_cast< QAction* >( sender() );
-    if ( act ) {
+    QAction *act = qobject_cast< QAction * >(sender());
+    if (act) {
         const QString type = act->data().toString();
         if (mListService.contains(type)) {
             StorageServiceAbstract *service = mListService.value(type);
             defaultConnect(service);
-            connect(service,SIGNAL(accountInfoDone(QString,PimCommon::AccountInfo)), this, SIGNAL(accountInfoDone(QString,PimCommon::AccountInfo)), Qt::UniqueConnection);
+            connect(service, &StorageServiceAbstract::accountInfoDone, this, &StorageServiceManager::accountInfoDone, Qt::UniqueConnection);
             service->accountInfo();
         }
     }
@@ -326,11 +325,11 @@ void StorageServiceManager::readConfig()
 {
     mListService.clear();
     KConfig conf(kconfigName());
-    KConfigGroup grp(&conf, QLatin1String("General"));
+    KConfigGroup grp(&conf, QStringLiteral("General"));
 
     const QStringList services = grp.readEntry("Services", QStringList());
-    Q_FOREACH(const QString &service, services) {
-        PimCommon::StorageServiceAbstract *storageService = 0;
+    Q_FOREACH (const QString &service, services) {
+        PimCommon::StorageServiceAbstract *storageService = Q_NULLPTR;
         if (service == serviceName(DropBox)) {
             if (!mListService.contains(serviceName(DropBox))) {
                 storageService = new DropBoxStorageService();
@@ -367,14 +366,14 @@ void StorageServiceManager::readConfig()
 void StorageServiceManager::writeConfig()
 {
     KConfig conf(kconfigName());
-    KConfigGroup grp(&conf, QLatin1String("General"));
+    KConfigGroup grp(&conf, QStringLiteral("General"));
     grp.writeEntry("Services", mListService.keys());
     conf.sync();
 }
 
 QString StorageServiceManager::description(ServiceType type)
 {
-    switch(type) {
+    switch (type) {
     case DropBox:
         return PimCommon::DropBoxStorageService::description();
     case Hubic:
@@ -398,7 +397,7 @@ QString StorageServiceManager::description(ServiceType type)
 
 QUrl StorageServiceManager::serviceUrl(ServiceType type)
 {
-    switch(type) {
+    switch (type) {
     case DropBox:
         return PimCommon::DropBoxStorageService::serviceUrl();
     case Hubic:
@@ -420,10 +419,9 @@ QUrl StorageServiceManager::serviceUrl(ServiceType type)
     return QString();
 }
 
-
 QString StorageServiceManager::serviceName(ServiceType type)
 {
-    switch(type) {
+    switch (type) {
     case DropBox:
         return PimCommon::DropBoxStorageService::serviceName();
     case Hubic:
@@ -447,7 +445,7 @@ QString StorageServiceManager::serviceName(ServiceType type)
 
 QString StorageServiceManager::serviceToI18n(ServiceType type)
 {
-    switch(type) {
+    switch (type) {
     case DropBox:
         return PimCommon::DropBoxStorageService::name();
     case Hubic:
@@ -471,7 +469,7 @@ QString StorageServiceManager::serviceToI18n(ServiceType type)
 
 QString StorageServiceManager::icon(ServiceType type)
 {
-    switch(type) {
+    switch (type) {
     case DropBox:
         return PimCommon::DropBoxStorageService::iconName();
     case Hubic:
@@ -495,7 +493,7 @@ QString StorageServiceManager::icon(ServiceType type)
 
 StorageServiceAbstract::Capabilities StorageServiceManager::capabilities(ServiceType type)
 {
-    switch(type) {
+    switch (type) {
     case DropBox:
         return PimCommon::DropBoxStorageService::serviceCapabilities();
     case Hubic:
@@ -519,7 +517,6 @@ StorageServiceAbstract::Capabilities StorageServiceManager::capabilities(Service
 
 QString StorageServiceManager::kconfigName()
 {
-    return QLatin1String("storageservicerc");
+    return QStringLiteral("storageservicerc");
 }
 
-#include "moc_storageservicemanager.cpp"
