@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -15,7 +15,6 @@
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */
 
-
 #include "servicetestwidget.h"
 #include "pimcommon/storageservice/storageserviceabstract.h"
 #include "pimcommon/storageservice/tests/testsettingsjob.h"
@@ -23,7 +22,6 @@
 #include "pimcommon/storageservice/dialog/storageservicedownloaddialog.h"
 
 #include <KLocalizedString>
-#include <KFileDialog>
 
 #include <QVBoxLayout>
 #include <QToolBar>
@@ -32,13 +30,13 @@
 #include <QAction>
 #include <QPointer>
 #include <QDir>
-
+#include <QFileDialog>
 
 ServiceTestWidget::ServiceTestWidget(QWidget *parent)
     : QWidget(parent),
-      mStorageService(0)
+      mStorageService(Q_NULLPTR)
 {
-    PimCommon::TestSettingsJob *settingsJob = new PimCommon::TestSettingsJob(this);
+    PimCommon::TestSettingsJob *settingsJob = new PimCommon::TestSettingsJob;
     PimCommon::StorageServiceJobConfig *configJob = PimCommon::StorageServiceJobConfig::self();
     configJob->registerConfigIf(settingsJob);
 
@@ -47,15 +45,15 @@ ServiceTestWidget::ServiceTestWidget(QWidget *parent)
     QVBoxLayout *lay = new QVBoxLayout;
     QToolBar *bar = new QToolBar;
     lay->addWidget(bar);
-    mAuthenticationAction = bar->addAction(QLatin1String("Authentication..."), this, SLOT(slotAuthentication()));
-    mListFolderAction = bar->addAction(QLatin1String("List Folder..."), this, SLOT(slotListFolder()));
-    mCreateFolderAction = bar->addAction(QLatin1String("Create Folder..."), this, SLOT(slotCreateFolder()));
-    mAccountInfoAction = bar->addAction(QLatin1String("Account info..."), this, SLOT(slotAccountInfo()));
-    mUploadFileAction = bar->addAction(QLatin1String("Upload File..."), this, SLOT(slotUploadFile()));
-    mCreateServiceFolderAction = bar->addAction(QLatin1String("Create Service Folder..."), this, SLOT(slotCreateServiceFolder()));
-    mDeleteFileAction = bar->addAction(QLatin1String("Delete File..."), this, SLOT(slotDeleteFile()));
-    mDeleteFolderAction = bar->addAction(QLatin1String("Delete Folder..."), this, SLOT(slotDeleteFolder()));
-    mDownloadFileAction = bar->addAction(QLatin1String("Download File..."), this, SLOT(slotDownloadFile()));
+    mAuthenticationAction = bar->addAction(QStringLiteral("Authentication..."), this, SLOT(slotAuthentication()));
+    mListFolderAction = bar->addAction(QStringLiteral("List Folder..."), this, SLOT(slotListFolder()));
+    mCreateFolderAction = bar->addAction(QStringLiteral("Create Folder..."), this, SLOT(slotCreateFolder()));
+    mAccountInfoAction = bar->addAction(QStringLiteral("Account info..."), this, SLOT(slotAccountInfo()));
+    mUploadFileAction = bar->addAction(QStringLiteral("Upload File..."), this, SLOT(slotUploadFile()));
+    mCreateServiceFolderAction = bar->addAction(QStringLiteral("Create Service Folder..."), this, SLOT(slotCreateServiceFolder()));
+    mDeleteFileAction = bar->addAction(QStringLiteral("Delete File..."), this, SLOT(slotDeleteFile()));
+    mDeleteFolderAction = bar->addAction(QStringLiteral("Delete Folder..."), this, SLOT(slotDeleteFolder()));
+    mDownloadFileAction = bar->addAction(QStringLiteral("Download File..."), this, SLOT(slotDownloadFile()));
     lay->addWidget(mEdit);
     setLayout(lay);
 }
@@ -67,7 +65,7 @@ ServiceTestWidget::~ServiceTestWidget()
 
 void ServiceTestWidget::slotDeleteFile()
 {
-    const QString filename = QInputDialog::getText(this,i18n("Filename"), i18n("Filename:"));
+    const QString filename = QInputDialog::getText(this, i18n("Filename"), i18n("Filename:"));
     if (!filename.isEmpty()) {
         mStorageService->deleteFile(filename);
     }
@@ -75,7 +73,7 @@ void ServiceTestWidget::slotDeleteFile()
 
 void ServiceTestWidget::slotDeleteFolder()
 {
-    const QString folder = QInputDialog::getText(this,i18n("Folder Name"), i18n("Folder:"));
+    const QString folder = QInputDialog::getText(this, i18n("Folder Name"), i18n("Folder:"));
     if (!folder.isEmpty()) {
         mStorageService->deleteFolder(folder);
     }
@@ -95,18 +93,18 @@ void ServiceTestWidget::slotAuthentication()
 
 void ServiceTestWidget::connectStorageService()
 {
-    connect(mStorageService, SIGNAL(actionFailed(QString,QString)), this, SLOT(slotActionFailed(QString,QString)));
-    connect(mStorageService, SIGNAL(uploadDownloadFileProgress(QString,qint64,qint64)), this, SLOT(slotuploadDownloadFileProgress(QString,qint64,qint64)));
-    connect(mStorageService, SIGNAL(shareLinkDone(QString,QString)), this, SLOT(slotShareLinkDone(QString,QString)));
-    connect(mStorageService, SIGNAL(authenticationDone(QString)), this, SLOT(slotAuthenticationDone(QString)));
-    connect(mStorageService, SIGNAL(authenticationFailed(QString,QString)), this, SLOT(slotAuthenticationFailed(QString,QString)));
-    connect(mStorageService, SIGNAL(createFolderDone(QString,QString)), this, SLOT(slotCreateFolderDone(QString,QString)));
-    connect(mStorageService, SIGNAL(uploadFileDone(QString,QString)), this, SLOT(slotUploadFileDone(QString,QString)));
-    connect(mStorageService, SIGNAL(listFolderDone(QString,QVariant)), this, SLOT(slotListFolderDone(QString,QVariant)));
-    connect(mStorageService, SIGNAL(accountInfoDone(QString,PimCommon::AccountInfo)), this, SLOT(slotAccountInfoDone(QString,PimCommon::AccountInfo)));
-    connect(mStorageService, SIGNAL(deleteFileDone(QString,QString)), this, SLOT(slotDeleteFileDone(QString,QString)));
-    connect(mStorageService, SIGNAL(deleteFolderDone(QString,QString)), this, SLOT(slotDeleteFolderDone(QString,QString)));
-    connect(mStorageService, SIGNAL(downLoadFileDone(QString,QString)), this, SLOT(slotDownloadFileDone(QString,QString)));
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::actionFailed, this, &ServiceTestWidget::slotActionFailed);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::uploadDownloadFileProgress, this, &ServiceTestWidget::slotuploadDownloadFileProgress);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::shareLinkDone, this, &ServiceTestWidget::slotShareLinkDone);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::authenticationDone, this, &ServiceTestWidget::slotAuthenticationDone);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::authenticationFailed, this, &ServiceTestWidget::slotAuthenticationFailed);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::createFolderDone, this, &ServiceTestWidget::slotCreateFolderDone);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::uploadFileDone, this, &ServiceTestWidget::slotUploadFileDone);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::listFolderDone, this, &ServiceTestWidget::slotListFolderDone);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::accountInfoDone, this, &ServiceTestWidget::slotAccountInfoDone);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::deleteFileDone, this, &ServiceTestWidget::slotDeleteFileDone);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::deleteFolderDone, this, &ServiceTestWidget::slotDeleteFolderDone);
+    connect(mStorageService, &PimCommon::StorageServiceAbstract::downLoadFileDone, this, &ServiceTestWidget::slotDownloadFileDone);
 }
 
 void ServiceTestWidget::slotDeleteFolderDone(const QString &serviceName, const QString &foldername)
@@ -124,7 +122,7 @@ void ServiceTestWidget::slotActionFailed(const QString &serviceName, const QStri
     mEdit->insertPlainText(serviceName + QString::fromLatin1(" return an error: %1\n").arg(error));
 }
 
-void ServiceTestWidget::slotuploadDownloadFileProgress(const QString &serviceName, qint64 done ,qint64 total)
+void ServiceTestWidget::slotuploadDownloadFileProgress(const QString &serviceName, qint64 done , qint64 total)
 {
     mEdit->insertPlainText(serviceName + QString::fromLatin1(" upload in progress: send:%1 total:%2\n").arg(done).arg(total));
 }
@@ -141,7 +139,7 @@ void ServiceTestWidget::slotAuthenticationFailed(const QString &serviceName, con
 
 void ServiceTestWidget::slotAuthenticationDone(const QString &serviceName)
 {
-    mEdit->insertPlainText(serviceName + QLatin1String(" Authentication done\n"));
+    mEdit->insertPlainText(serviceName + QStringLiteral(" Authentication done\n"));
 }
 
 void ServiceTestWidget::slotCreateFolderDone(const QString &serviceName, const QString &folderName)
@@ -177,7 +175,7 @@ void ServiceTestWidget::slotAccountInfo()
 
 void ServiceTestWidget::slotCreateFolder()
 {
-    const QString folder = QInputDialog::getText(this,i18n("Folder Name"), i18n("Folder:"));
+    const QString folder = QInputDialog::getText(this, i18n("Folder Name"), i18n("Folder:"));
     if (!folder.isEmpty()) {
         mStorageService->createFolder(folder, QString());
     }
@@ -190,7 +188,7 @@ void ServiceTestWidget::slotListFolder()
 
 void ServiceTestWidget::slotUploadFile()
 {
-    const QString filename = KFileDialog::getOpenFileName();
+    const QString filename = QFileDialog::getOpenFileName(this);
     if (!filename.isEmpty()) {
         mStorageService->uploadFile(filename, QString(), QString()); //TODO
     }
