@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -19,11 +19,12 @@
 #include "pimcommon/storageservice/webdav/webdavstorageservice.h"
 #include <QWidget>
 
-#include <kdebug.h>
-#include <kapplication.h>
-#include <KCmdLineArgs>
-#include <KLocalizedString>
+#include "pimcommon_debug.h"
 
+#include <KLocalizedString>
+#include <QApplication>
+#include <KAboutData>
+#include <QCommandLineParser>
 
 WebDavTestWidget::WebDavTestWidget(QWidget *parent)
     : ServiceTestWidget(parent)
@@ -31,13 +32,19 @@ WebDavTestWidget::WebDavTestWidget(QWidget *parent)
     setStorageService(new PimCommon::WebDavStorageService(this));
 }
 
-
-int main (int argc, char **argv)
+int main(int argc, char **argv)
 {
-    KCmdLineArgs::init(argc, argv, "webdav_gui", 0, ki18n("webdav_Gui"),
-                       "1.0", ki18n("Test for webdav"));
-
-    KApplication app;
+    KAboutData aboutData(QStringLiteral("webdav_gui"), i18n("webdav_Gui"), QStringLiteral("1.0"));
+    aboutData.setShortDescription(i18n("Test for webdav"));
+    QApplication app(argc, argv);
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(aboutData);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    //PORTING SCRIPT: adapt aboutdata variable if necessary
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 
     WebDavTestWidget *w = new WebDavTestWidget;
     w->show();
