@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -18,11 +18,14 @@
 #include "yousendit_gui.h"
 #include "pimcommon/storageservice/yousendit/yousenditstorageservice.h"
 #include <QWidget>
+#include <QStandardPaths>
+
+#include "pimcommon_debug.h"
 
-#include <kdebug.h>
-#include <kapplication.h>
-#include <KCmdLineArgs>
 #include <KLocalizedString>
+#include <QApplication>
+#include <KAboutData>
+#include <QCommandLineParser>
 
 YouSendItTestWidget::YouSendItTestWidget(QWidget *parent)
     : ServiceTestWidget(parent)
@@ -30,12 +33,19 @@ YouSendItTestWidget::YouSendItTestWidget(QWidget *parent)
     setStorageService(new PimCommon::YouSendItStorageService(this));
 }
 
-int main (int argc, char **argv)
+int main(int argc, char **argv)
 {
-    KCmdLineArgs::init(argc, argv, "yousendit_gui", 0, ki18n("yousendit_Gui"),
-                       "1.0", ki18n("Test for short yousendit"));
-
-    KApplication app;
+    QApplication app(argc, argv);
+    QStandardPaths::setTestModeEnabled(true);
+    KAboutData aboutData(QStringLiteral("yousendit_gui"), i18n("yousendit_Gui"), QStringLiteral("1.0"));
+    aboutData.setShortDescription(i18n("Test for short yousendit"));
+    QCommandLineParser parser;
+    KAboutData::setApplicationData(aboutData);
+    parser.addVersionOption();
+    parser.addHelpOption();
+    aboutData.setupCommandLine(&parser);
+    parser.process(app);
+    aboutData.processCommandLine(&parser);
 
     YouSendItTestWidget *w = new YouSendItTestWidget;
     w->show();
