@@ -16,8 +16,8 @@
 */
 
 #include "templateeditdialog.h"
-#include "pimcommon/texteditor/richtexteditor/richtexteditorwidget.h"
-#include "pimcommon/texteditor/richtexteditor/richtexteditor.h"
+#include "pimcommon/texteditor/plaintexteditor/plaintexteditorwidget.h"
+#include "pimcommon/texteditor/plaintexteditor/plaintexteditor.h"
 
 #include <KLocalizedString>
 #include <KLineEdit>
@@ -25,21 +25,36 @@
 #include <QVBoxLayout>
 #include <QHBoxLayout>
 #include <QLabel>
-
+#include <KSharedConfig>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
 
 using namespace PimCommon;
 
 TemplateEditDialog::TemplateEditDialog(QWidget *parent, bool defaultTemplate)
-    : KDialog(parent)
+    : QDialog(parent), mOkButton(Q_NULLPTR)
 {
-    setCaption( defaultTemplate ? i18n("Default template") : i18n("Template") );
+    setWindowTitle(defaultTemplate ? i18n("Default template") : i18n("Template"));
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    QDialogButtonBox *buttonBox = Q_NULLPTR;
     if (defaultTemplate) {
-        setButtons( Close );
+        buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
+        connect(buttonBox, &QDialogButtonBox::rejected, this, &TemplateEditDialog::reject);
     } else {
-        setButtons( Ok |Cancel );
+        buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+        mOkButton = buttonBox->button(QDialogButtonBox::Ok);
+        mOkButton->setDefault(true);
+        mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+        connect(buttonBox, &QDialogButtonBox::accepted, this, &TemplateEditDialog::accept);
+        connect(buttonBox, &QDialogButtonBox::rejected, this, &TemplateEditDialog::reject);
+        mOkButton->setFocus();
     }
-    setButtonFocus(Ok);
     QWidget *w = new QWidget;
+    mainLayout->addWidget(w);
+    mainLayout->addWidget(buttonBox);
+
     QVBoxLayout *vbox = new QVBoxLayout;
 
     QHBoxLayout *hbox = new QHBoxLayout;
@@ -54,17 +69,17 @@ TemplateEditDialog::TemplateEditDialog(QWidget *parent, bool defaultTemplate)
 
     vbox->addLayout(hbox);
 
-    mTextEdit = new PimCommon::RichTextEditorWidget;
-    mTextEdit->setAcceptRichText(false);
+    mTextEdit = new PimCommon::PlainTextEditorWidget;
     mTextEdit->setReadOnly(defaultTemplate);
     vbox->addWidget(mTextEdit);
 
     w->setLayout(vbox);
-    setMainWidget(w);
     if (!defaultTemplate) {
-        enableButtonOk(false);
-        connect(mTemplateNameEdit, SIGNAL(textChanged(QString)),SLOT(slotTemplateChanged()));
-        connect(mTextEdit->editor(), SIGNAL(textChanged()),SLOT(slotTemplateChanged()));
+        if (mOkButton) {
+            mOkButton->setEnabled(false);
+        }
+        connect(mTemplateNameEdit, &QLineEdit::textChanged, this, &TemplateEditDialog::slotTemplateChanged);
+        connect(mTextEdit->editor(), &QPlainTextEdit::textChanged, this, &TemplateEditDialog::slotTemplateChanged);
         mTemplateNameEdit->setFocus();
     }
     readConfig();
@@ -75,26 +90,24 @@ TemplateEditDialog::~TemplateEditDialog()
     writeConfig();
 }
 
-
 void TemplateEditDialog::writeConfig()
 {
-    KConfigGroup group( KGlobal::config(), "TemplateEditDialog" );
-    group.writeEntry( "Size", size() );
+    KConfigGroup group(KSharedConfig::openConfig(), "TemplateEditDialog");
+    group.writeEntry("Size", size());
 }
 
 void TemplateEditDialog::readConfig()
 {
-    KConfigGroup group( KGlobal::config(), "TemplateEditDialog" );
-    const QSize sizeDialog = group.readEntry( "Size", QSize(600,400) );
-    if ( sizeDialog.isValid() ) {
-        resize( sizeDialog );
+    KConfigGroup group(KSharedConfig::openConfig(), "TemplateEditDialog");
+    const QSize sizeDialog = group.readEntry("Size", QSize(600, 400));
+    if (sizeDialog.isValid()) {
+        resize(sizeDialog);
     }
 }
 
-
 void TemplateEditDialog::slotTemplateChanged()
 {
-    enableButtonOk(!mTemplateNameEdit->text().trimmed().isEmpty() && !mTextEdit->editor()->toPlainText().trimmed().isEmpty());
+    mOkButton->setEnabled(!mTemplateNameEdit->text().trimmed().isEmpty() && !mTextEdit->editor()->toPlainText().trimmed().isEmpty());
 }
 
 void TemplateEditDialog::setScript(const QString &text)
