@@ -22,17 +22,18 @@
 #include <KSharedConfig>
 #include <KMessageBox>
 #include <KLocalizedString>
-#include <KMenu>
-#include <KFileDialog>
+#include <QMenu>
 #include <KNS3/DownloadDialog>
-
+#include <QIcon>
 
 #include <QListWidgetItem>
 #include <QPointer>
 #include <QMimeData>
 #include <QDropEvent>
+#include <QFileDialog>
 
-namespace PimCommon {
+namespace PimCommon
+{
 
 class TemplateListWidgetPrivate
 {
@@ -58,7 +59,7 @@ public:
     {
         QString templateName;
         QString templateScript;
-        if (q->addNewTemplate(templateName, templateScript) ) {
+        if (q->addNewTemplate(templateName, templateScript)) {
             createListWidgetItem(templateName, templateScript, false);
             dirty = true;
         }
@@ -68,7 +69,7 @@ public:
     {
         QString templateName;
         QString templateScript = newTemplateScript;
-        if (q->modifyTemplate(templateName, templateScript, false) ) {
+        if (q->modifyTemplate(templateName, templateScript, false)) {
             createListWidgetItem(templateName, templateScript, false);
             dirty = true;
         }
@@ -79,8 +80,9 @@ public:
         if (KMessageBox::Yes == KMessageBox::questionYesNo(q, i18n("Do you want to delete selected template?"), i18n("Delete template"))) {
             const QList<QListWidgetItem *> lstSelectedItems = q->selectedItems();
             Q_FOREACH (QListWidgetItem *item, lstSelectedItems) {
-                if (item->data(TemplateListWidget::DefaultTemplate).toBool() == false)
+                if (item->data(TemplateListWidget::DefaultTemplate).toBool() == false) {
                     delete item;
+                }
             }
             dirty = true;
         }
@@ -88,13 +90,13 @@ public:
 
     void slotModify()
     {
-        QListWidgetItem * item = q->currentItem();
+        QListWidgetItem *item = q->currentItem();
         if (item) {
             const bool defaultTemplate = item->data(TemplateListWidget::DefaultTemplate).toBool();
 
             QString templateName = item->text();
             QString templateScript = item->data(TemplateListWidget::Text).toString();
-            if (q->modifyTemplate(templateName, templateScript, defaultTemplate) ) {
+            if (q->modifyTemplate(templateName, templateScript, defaultTemplate)) {
                 if (!defaultTemplate) {
                     item->setText(templateName);
                     item->setData(TemplateListWidget::Text, templateScript);
@@ -118,7 +120,7 @@ public:
         QListWidgetItem *item = q->currentItem();
         if (item) {
             QStringList name;
-            for ( int i = 0; i < q->count(); ++i ) {
+            for (int i = 0; i < q->count(); ++i) {
                 name.append(q->item(i)->text());
             }
             QString templateName = item->text() + QString::fromLatin1(" (%1)");
@@ -127,7 +129,7 @@ public:
             do {
                 newName = templateName.arg(i);
                 i++;
-            } while(name.contains(newName));
+            } while (name.contains(newName));
 
             const QString templateScript = item->data(TemplateListWidget::Text).toString();
             createListWidgetItem(newName, templateScript, false);
@@ -137,18 +139,18 @@ public:
 
     void slotImportTemplates()
     {
-        const QString templateFile = KFileDialog::getOpenFileName();
+        const QString templateFile = QFileDialog::getOpenFileName(q);
         if (!templateFile.isEmpty()) {
-            KConfig conf(templateFile);
+            KConfig conf(templateFile, KConfig::SimpleConfig);
             loadTemplates(&conf);
         }
     }
 
     void slotExportTemplates()
     {
-        const QString templateFile = KFileDialog::getSaveFileName();
+        const QString templateFile = QFileDialog::getSaveFileName(q);
         if (!templateFile.isEmpty()) {
-            KConfig conf(templateFile);
+            KConfig conf(templateFile, KConfig::SimpleConfig);
             saveTemplates(&conf);
         }
     }
@@ -157,86 +159,89 @@ public:
     {
         const QList<QListWidgetItem *> lstSelectedItems = q->selectedItems();
         const bool listSelectedIsEmpty = lstSelectedItems.isEmpty();
-        KMenu *menu = new KMenu( q );
+        QMenu *menu = new QMenu(q);
 
         if (!listSelectedIsEmpty) {
-            menu->addAction( i18n("Insert template"), q, SLOT(slotInsertTemplate()));
+            menu->addAction(i18n("Insert template"), q, SLOT(slotInsertTemplate()));
             menu->addSeparator();
         }
 
-
-        menu->addAction( i18n("Add..."), q, SLOT(slotAdd()));
+        menu->addAction(i18n("Add..."), q, SLOT(slotAdd()));
         if (!listSelectedIsEmpty) {
             const bool defaultTemplate = lstSelectedItems.first()->data(TemplateListWidget::DefaultTemplate).toBool();
             if (lstSelectedItems.count() == 1) {
-                menu->addAction( defaultTemplate ? i18n("Show...") : i18n("Modify..."), q, SLOT(slotModify()));
-                menu->addAction( i18n("Duplicate"), q, SLOT(slotDuplicate()));
+                menu->addAction(defaultTemplate ? i18n("Show...") : i18n("Modify..."), q, SLOT(slotModify()));
+                menu->addAction(i18n("Duplicate"), q, SLOT(slotDuplicate()));
             }
             if (lstSelectedItems.count() == 1 && !defaultTemplate) {
                 menu->addSeparator();
-                menu->addAction( KIcon(QLatin1String("edit-delete")), i18n("Remove"), q, SLOT(slotRemove()));
+                menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Remove"), q, SLOT(slotRemove()));
             }
         }
         menu->addSeparator();
-        if (q->count()>0)
-            menu->addAction( i18n("Export..."), q, SLOT(slotExportTemplates()));
-        menu->addAction( i18n("Import..."), q, SLOT(slotImportTemplates()));
+        if (q->count() > 0) {
+            menu->addAction(i18n("Export..."), q, SLOT(slotExportTemplates()));
+        }
+        menu->addAction(i18n("Import..."), q, SLOT(slotImportTemplates()));
 
         if (!knewstuffConfigName.isEmpty()) {
             menu->addSeparator();
-            QAction *act = menu->addAction( i18n("Download new Templates..."), q, SLOT(slotDownloadTemplates()));
-            act->setIcon(KIcon(QLatin1String("get-hot-new-stuff")));
+            QAction *act = menu->addAction(i18n("Download new Templates..."), q, SLOT(slotDownloadTemplates()));
+            act->setIcon(QIcon::fromTheme(QStringLiteral("get-hot-new-stuff")));
         }
 
-        menu->exec( q->mapToGlobal( pos ) );
+        menu->exec(q->mapToGlobal(pos));
         delete menu;
     }
 
     void load()
     {
         q->clear();
-        const QList<PimCommon::defaultTemplate> templatesLst = q->defaultTemplates();
+        const QVector<PimCommon::defaultTemplate> templatesLst = q->defaultTemplates();
         Q_FOREACH (const PimCommon::defaultTemplate &tmp, templatesLst) {
             createListWidgetItem(tmp.name, tmp.text, true);
         }
-        loadTemplates(&(*config));
+        if (!config.data()->groupList().isEmpty()) {
+            loadTemplates(config.data());
+        }
         dirty = false;
     }
 
     void loadTemplates(KConfig *configFile)
     {
-        KConfigGroup group = configFile->group( "template" );
-        if (group.hasKey(QLatin1String("templateCount"))) {
-            const int numberTemplate = group.readEntry( "templateCount", 0 );
+        KConfigGroup group = configFile->group("template");
+        if (group.hasKey(QStringLiteral("templateCount"))) {
+            const int numberTemplate = group.readEntry("templateCount", 0);
             for (int i = 0; i < numberTemplate; ++i) {
-                KConfigGroup group = configFile->group( QString::fromLatin1( "templateDefine_%1" ).arg ( i ) );
-                const QString name = group.readEntry( "Name", QString() );
-                const QString text = group.readEntry( "Text", QString() );
+                KConfigGroup group = configFile->group(QStringLiteral("templateDefine_%1").arg(i));
+                const QString name = group.readEntry("Name", QString());
+                const QString text = group.readEntry("Text", QString());
 
                 createListWidgetItem(name, text, false);
             }
-        }   
+        } else {
+            KMessageBox::error(q, i18n("\'%1\' is not a template file", configFile->name()), i18n("Load Template"));
+        }
     }
 
     void saveTemplates(KConfig *configFile)
     {
         // clear everything
-        foreach ( const QString &group, configFile->groupList() ) {
-            configFile->deleteGroup( group );
+        foreach (const QString &group, configFile->groupList()) {
+            configFile->deleteGroup(group);
         }
-
         int numberOfTemplate = 0;
-        for ( int i = 0; i < q->count(); ++i ) {
+        for (int i = 0; i < q->count(); ++i) {
             QListWidgetItem *templateItem = q->item(i);
             if (templateItem->data(TemplateListWidget::DefaultTemplate).toBool() == false) {
-                KConfigGroup group = configFile->group( QString::fromLatin1( "templateDefine_%1" ).arg ( numberOfTemplate ) );
-                group.writeEntry( "Name", templateItem->text() );
-                group.writeEntry( "Text", templateItem->data(TemplateListWidget::Text) );
+                KConfigGroup group = configFile->group(QStringLiteral("templateDefine_%1").arg(numberOfTemplate));
+                group.writeEntry("Name", templateItem->text());
+                group.writeEntry("Text", templateItem->data(TemplateListWidget::Text));
                 ++numberOfTemplate;
             }
         }
-        KConfigGroup group = configFile->group( "template" );
-        group.writeEntry( "templateCount", numberOfTemplate );
+        KConfigGroup group = configFile->group("template");
+        group.writeEntry("templateCount", numberOfTemplate);
         configFile->sync();
     }
 
@@ -249,10 +254,11 @@ public:
 
     void save()
     {
-        if (!dirty)
+        if (!dirty) {
             return;
+        }
 
-        saveTemplates(&(*config));
+        saveTemplates(config.data());
         dirty = false;
     }
     QString knewstuffConfigName;
@@ -261,15 +267,14 @@ public:
     TemplateListWidget *q;
 };
 
-
 TemplateListWidget::TemplateListWidget(const QString &configName, QWidget *parent)
     : QListWidget(parent), d(new TemplateListWidgetPrivate(configName, this))
 {
-    setContextMenuPolicy( Qt::CustomContextMenu );
+    setContextMenuPolicy(Qt::CustomContextMenu);
     setDragDropMode(QAbstractItemView::DragDrop);
 
-    connect( this, SIGNAL(customContextMenuRequested(QPoint)),
-             SLOT(slotContextMenu(QPoint)) );
+    connect(this, SIGNAL(customContextMenuRequested(QPoint)),
+            SLOT(slotContextMenu(QPoint)));
     connect(this, SIGNAL(doubleClicked(QModelIndex)), SLOT(slotModify()));
     connect(this, SIGNAL(insertNewTemplate(QString)), SLOT(slotInsertNewTemplate(QString)));
 }
@@ -284,26 +289,26 @@ void TemplateListWidget::loadTemplates()
     d->load();
 }
 
-QList<PimCommon::defaultTemplate> TemplateListWidget::defaultTemplates()
+QVector<defaultTemplate> TemplateListWidget::defaultTemplates()
 {
-    return QList<PimCommon::defaultTemplate>();
+    return QVector<PimCommon::defaultTemplate>();
 }
 
 QStringList TemplateListWidget::mimeTypes() const
 {
     QStringList lst;
-    lst << QLatin1String( "text/plain" );
+    lst << QStringLiteral("text/plain");
     return lst;
 }
 
-QMimeData *TemplateListWidget::mimeData ( const QList<QListWidgetItem *> items ) const
+QMimeData *TemplateListWidget::mimeData(const QList<QListWidgetItem *> items) const
 {
-    if ( items.isEmpty() ) {
-        return 0;
+    if (items.isEmpty()) {
+        return Q_NULLPTR;
     }
     QMimeData *mimeData = new QMimeData();
     QListWidgetItem *item = items.first();
-    mimeData->setText( item->data(TemplateListWidget::Text).toString() );
+    mimeData->setText(item->data(TemplateListWidget::Text).toString());
     return mimeData;
 }
 
@@ -337,18 +342,18 @@ bool TemplateListWidget::modifyTemplate(QString &templateName, QString &template
     return result;
 }
 
-void TemplateListWidget::dropEvent( QDropEvent * event )
+void TemplateListWidget::dropEvent(QDropEvent *event)
 {
-    if ( event->source() == this ) {
+    if (event->source() == this) {
         event->ignore();
         return;
     }
-     if (event->mimeData()->hasText()) {
-        event->setDropAction( Qt::CopyAction );
+    if (event->mimeData()->hasText()) {
+        event->setDropAction(Qt::CopyAction);
         Q_EMIT insertNewTemplate(event->mimeData()->text());
         event->accept();
     }
-    QListWidget::dropEvent( event );
+    QListWidget::dropEvent(event);
 }
 
 void TemplateListWidget::setKNewStuffConfigFile(const QString &configName)
