@@ -1,15 +1,15 @@
 /*
   Copyright (c) 2012-2015 Montel Laurent <montel@kde.org>
-  
+
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
   published by the Free Software Foundation.
-  
+
   This program is distributed in the hope that it will be useful, but
   WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   General Public License for more details.
-  
+
   You should have received a copy of the GNU General Public License along
   with this program; if not, write to the Free Software Foundation, Inc.,
   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
@@ -19,21 +19,19 @@
 #include "translatorutil.h"
 #include "translatordebugdialog.h"
 
-#include <QDebug>
+#include "pimcommon_debug.h"
+#include <QJsonParseError>
 #include <QNetworkAccessManager>
 #include <QNetworkRequest>
 #include <QPointer>
 
-#include <qjson/parser.h>
-
-
 using namespace PimCommon;
 
 GoogleTranslator::GoogleTranslator()
     : AbstractTranslator(),
       mNetworkAccessManager(new QNetworkAccessManager(this))
 {
-    connect(mNetworkAccessManager, SIGNAL(finished(QNetworkReply*)), this, SLOT(slotTranslateFinished(QNetworkReply*)));
+    connect(mNetworkAccessManager, &QNetworkAccessManager::finished, this, &GoogleTranslator::slotTranslateFinished);
 }
 
 GoogleTranslator::~GoogleTranslator()
@@ -107,17 +105,17 @@ QMap<QString, QMap<QString, QString> > GoogleTranslator::initListLanguage(KCombo
     fullListLanguage.append(translatorUtil.pair(TranslatorUtil::cy));
     fullListLanguage.append(translatorUtil.pair(TranslatorUtil::yi));
     const int fullListLanguageSize(fullListLanguage.count());
-    for (int i=0;i<fullListLanguageSize;++i) {
+    for (int i = 0; i < fullListLanguageSize; ++i) {
         const QPair<QString, QString> currentLanguage = fullListLanguage.at(i);
-        translatorUtil.addItemToFromComboBox( from, currentLanguage );
+        translatorUtil.addItemToFromComboBox(from, currentLanguage);
 
         QMap<QString, QString> toList;
-        for (int j=0;j<fullListLanguageSize;++j) {
-            if (j!=0 && j!=i) { //don't add auto and current language
-                translatorUtil.addPairToMap( toList, fullListLanguage.at(j) );
+        for (int j = 0; j < fullListLanguageSize; ++j) {
+            if (j != 0 && j != i) { //don't add auto and current language
+                translatorUtil.addPairToMap(toList, fullListLanguage.at(j));
             }
         }
-        listLanguage.insert( currentLanguage.second, toList );
+        listLanguage.insert(currentLanguage.second, toList);
     }
 
     return listLanguage;
@@ -132,17 +130,17 @@ void GoogleTranslator::translate()
 
     mResult.clear();
 
-    QNetworkRequest request(QUrl(QLatin1String("http://www.google.com/translate_a/t")));
-    request.setHeader(QNetworkRequest::ContentTypeHeader, QLatin1String("application/x-www-form-urlencoded"));
+    QNetworkRequest request(QUrl(QStringLiteral("http://www.google.com/translate_a/t")));
+    request.setHeader(QNetworkRequest::ContentTypeHeader, QStringLiteral("application/x-www-form-urlencoded"));
 
     QUrl postData;
-    postData.addQueryItem(QLatin1String("client"), QLatin1String("t"));
-    postData.addQueryItem(QLatin1String("sl"), mFrom);
-    postData.addQueryItem(QLatin1String("tl"), mTo);
-    postData.addQueryItem(QLatin1String("text"), mInputText);
+    postData.addQueryItem(QStringLiteral("client"), QStringLiteral("t"));
+    postData.addQueryItem(QStringLiteral("sl"), mFrom);
+    postData.addQueryItem(QStringLiteral("tl"), mTo);
+    postData.addQueryItem(QStringLiteral("text"), mInputText);
 
     QNetworkReply *reply = mNetworkAccessManager->post(request, postData.encodedQuery());
-    connect(reply, SIGNAL(error(QNetworkReply::NetworkError)), this, SLOT(slotError(QNetworkReply::NetworkError)));
+    connect(reply, static_cast<void (QNetworkReply::*)(QNetworkReply::NetworkError)>(&QNetworkReply::error), this, &GoogleTranslator::slotError);
 }
 
 void GoogleTranslator::slotError(QNetworkReply::NetworkError /*error*/)
@@ -156,36 +154,35 @@ void GoogleTranslator::slotTranslateFinished(QNetworkReply *reply)
     reply->deleteLater();
     //  jsonData contains arrays like this: ["foo",,"bar"]
     //  but this is not valid JSON for QJSON, it expects empty strings: ["foo","","bar"]
-    mJsonData = mJsonData.replace(QRegExp(QLatin1String(",{3,3}")), QLatin1String(",\"\",\"\","));
-    mJsonData = mJsonData.replace(QRegExp(QLatin1String(",{2,2}")), QLatin1String(",\"\","));
-    //qDebug() << mJsonData;
+    mJsonData = mJsonData.replace(QRegExp(QStringLiteral(",{3,3}")), QStringLiteral(",\"\",\"\","));
+    mJsonData = mJsonData.replace(QRegExp(QStringLiteral(",{2,2}")), QStringLiteral(",\"\","));
+    //qCDebug(PIMCOMMON_LOG) << mJsonData;
 
-    QJson::Parser parser;
-    bool ok;
-
-    const QVariantList json = parser.parse(mJsonData.toUtf8(), &ok).toList();
-    if (!ok) {
-        Q_EMIT translateFailed(ok);
+    QJsonParseError parsingError;
+    const QJsonDocument jsonDoc = QJsonDocument::fromJson(mJsonData.toUtf8(), &parsingError);
+    if (parsingError.error != QJsonParseError::NoError || jsonDoc.isNull()) {
+        Q_EMIT translateFailed(false);
         return;
     }
-    //qDebug()<<" json"<<json;
+    const QVariantList json = jsonDoc.toVariant().toList();
+    //qCDebug(PIMCOMMON_LOG)<<" json"<<json;
     bool oldVersion = true;
     QMultiMap<int, QPair<QString, double> > sentences;
 
     // we are going recursively through the nested json-array
     // level0 contains the data of the outer array, level1 of the next one and so on
-    Q_FOREACH (const QVariant& level0, json) {
+    Q_FOREACH (const QVariant &level0, json) {
         const QVariantList listLevel0 = level0.toList();
         if (listLevel0.isEmpty()) {
             continue;
         }
-        Q_FOREACH (const QVariant& level1, listLevel0) {
+        Q_FOREACH (const QVariant &level1, listLevel0) {
             if (level1.toList().size() <= 2 || level1.toList().at(2).toList().isEmpty()) {
                 continue;
             }
             const int indexLevel1 = listLevel0.indexOf(level1);
             const QVariantList listLevel1 = level1.toList().at(2).toList();
-            foreach (const QVariant& level2, listLevel1) {
+            foreach (const QVariant &level2, listLevel1) {
                 const QVariantList listLevel2 = level2.toList();
 
                 // The JSON we get from Google has not always the same structure.
