@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013, 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -23,25 +23,35 @@
 
 #include <KLocalizedString>
 #include <QVBoxLayout>
-#include <QLineEdit>
-#include <QSpinBox>
+#include <QDialogButtonBox>
+#include <QPushButton>
 
 ServerSieveSettingsDialog::ServerSieveSettingsDialog(QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
 {
-    setCaption( i18n( "Add Server Sieve" ) );
-    setButtons( Cancel | Ok  );
+    setWindowTitle(i18nc("@title:window", "Add Sieve Server"));
 
     QWidget *w = new QWidget;
     QVBoxLayout *lay = new QVBoxLayout;
     mServerSieveSettings = new ServerSieveSettings;
-    connect(mServerSieveSettings, SIGNAL(enableOkButton(bool)), this, SLOT(enableButtonOk(bool)));
+    connect(mServerSieveSettings, &ServerSieveSettings::enableOkButton, this, &ServerSieveSettingsDialog::slotEnableButtonOk);
     lay->addWidget(mServerSieveSettings);
     lay->setMargin(0);
     w->setLayout(lay);
-    setMainWidget(w);
-    resize(400,300);
-    enableButtonOk(false);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    mainLayout->addWidget(w);
+
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    mOkButton = buttonBox->button(QDialogButtonBox::Ok);
+    mOkButton->setDefault(true);
+    mOkButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &ServerSieveSettingsDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &ServerSieveSettingsDialog::reject);
+    mainLayout->addWidget(buttonBox);
+
+    resize(400, 300);
+    mOkButton->setEnabled(false);
 }
 
 ServerSieveSettingsDialog::~ServerSieveSettingsDialog()
@@ -49,6 +59,11 @@ ServerSieveSettingsDialog::~ServerSieveSettingsDialog()
 
 }
 
+void ServerSieveSettingsDialog::slotEnableButtonOk(bool b)
+{
+    mOkButton->setEnabled(b);
+}
+
 QString ServerSieveSettingsDialog::serverName() const
 {
     return mServerSieveSettings->serverName();
