@@ -27,21 +27,26 @@
 #include <KLocalizedString>
 #include <KSharedConfig>
 
-#include <QTabWidget>
 #include <QVBoxLayout>
-#include <QListWidget>
-#include <QLabel>
 #include <QCheckBox>
+#include <KConfigGroup>
+#include <QDialogButtonBox>
+#include <QPushButton>
 #include <QGroupBox>
 
 SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
-    : KDialog(parent)
+    : QDialog(parent)
 {
-    setCaption( i18n( "Configure" ) );
-    setButtons( Cancel | Ok  );
-
-    QGroupBox *w = new QGroupBox(i18n("Server Sieve"));
-    setMainWidget(w);
+    setWindowTitle(i18n("Configure"));
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
+    QVBoxLayout *mainLayout = new QVBoxLayout;
+    setLayout(mainLayout);
+    QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+    okButton->setDefault(true);
+    okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &SieveEditorConfigureDialog::accept);
+    connect(buttonBox, &QDialogButtonBox::rejected, this, &SieveEditorConfigureDialog::reject);
+    QGroupBox *w = new QGroupBox(i18n("Sieve Server"));
 
     QVBoxLayout *layout = new QVBoxLayout;
     w->setLayout(layout);
@@ -50,6 +55,9 @@ SieveEditorConfigureDialog::SieveEditorConfigureDialog(QWidget *parent)
 
     mCloseWallet = new QCheckBox(i18n("Close wallet when close application"));
     layout->addWidget(mCloseWallet);
+
+    mainLayout->addWidget(w);
+    mainLayout->addWidget(buttonBox);
     loadServerSieveConfig();
     readConfig();
 }
@@ -69,21 +77,21 @@ void SieveEditorConfigureDialog::saveServerSieveConfig()
 {
     mServerWidget->writeConfig();
     PimCommon::ConfigureImmutableWidgetUtils::saveCheckBox(mCloseWallet, SieveEditorGlobalConfig::self()->closeWalletItem());
-    SieveEditorGlobalConfig::self()->writeConfig();
+    SieveEditorGlobalConfig::self()->save();
 }
 
 void SieveEditorConfigureDialog::readConfig()
 {
-    KConfigGroup group( KGlobal::config(), "SieveEditorConfigureDialog" );
-    const QSize size = group.readEntry( "Size", QSize(600, 400) );
-    if ( size.isValid() ) {
-        resize( size );
+    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditorConfigureDialog");
+    const QSize size = group.readEntry("Size", QSize(600, 400));
+    if (size.isValid()) {
+        resize(size);
     }
 }
 
 void SieveEditorConfigureDialog::writeConfig()
 {
-    KConfigGroup group( KGlobal::config(), "SieveEditorConfigureDialog" );
-    group.writeEntry( "Size", size() );
+    KConfigGroup group(KSharedConfig::openConfig(), "SieveEditorConfigureDialog");
+    group.writeEntry("Size", size());
     group.sync();
 }
