@@ -25,10 +25,9 @@
 #include "editor/sieveeditor.h"
 
 #include <KLocalizedString>
-
+#include <KConfigGroup>
 #include <KSharedConfig>
-#include <KTabWidget>
-#include <KGlobalSettings>
+#include <QTabWidget>
 #include <KColorScheme>
 #include <KMessageBox>
 
@@ -39,34 +38,33 @@ SieveEditorMainWidget::SieveEditorMainWidget(QWidget *parent)
     : QSplitter(parent)
 {
     mTabWidget = new SieveEditorTabWidget;
-    connect(mTabWidget, SIGNAL(tabCloseRequestedIndex(int)), this, SLOT(slotTabCloseRequested(int)));
-    connect(mTabWidget, SIGNAL(tabRemoveAllExclude(int)), this, SLOT(slotTabRemoveAllExclude(int)));
+    connect(mTabWidget, &SieveEditorTabWidget::tabCloseRequestedIndex, this, &SieveEditorMainWidget::slotTabCloseRequested);
+    connect(mTabWidget, &SieveEditorTabWidget::tabRemoveAllExclude, this, &SieveEditorMainWidget::slotTabRemoveAllExclude);
     addWidget(mTabWidget);
     mScriptManagerWidget = new SieveEditorScriptManagerWidget;
-    connect(mScriptManagerWidget, SIGNAL(createScriptPage(KUrl,QStringList,bool)), this, SLOT(slotCreateScriptPage(KUrl,QStringList,bool)));
-    connect(mScriptManagerWidget, SIGNAL(updateButtons(bool,bool,bool,bool)), SIGNAL(updateButtons(bool,bool,bool,bool)));
-    connect(mScriptManagerWidget, SIGNAL(scriptDeleted(KUrl)), this, SLOT(slotScriptDeleted(KUrl)));
-    connect(mScriptManagerWidget, SIGNAL(serverSieveFound(bool)), this, SIGNAL(serverSieveFound(bool)));
-    connect(this, SIGNAL(updateScriptList()), mScriptManagerWidget, SLOT(slotRefreshList()));
+    connect(mScriptManagerWidget, &SieveEditorScriptManagerWidget::createScriptPage, this, &SieveEditorMainWidget::slotCreateScriptPage);
+    connect(mScriptManagerWidget, &SieveEditorScriptManagerWidget::updateButtons, this, &SieveEditorMainWidget::updateButtons);
+    connect(mScriptManagerWidget, &SieveEditorScriptManagerWidget::scriptDeleted, this, &SieveEditorMainWidget::slotScriptDeleted);
+    connect(mScriptManagerWidget, &SieveEditorScriptManagerWidget::serverSieveFound, this, &SieveEditorMainWidget::serverSieveFound);
+    connect(this, &SieveEditorMainWidget::updateScriptList, mScriptManagerWidget, &SieveEditorScriptManagerWidget::slotRefreshList);
     addWidget(mScriptManagerWidget);
     setChildrenCollapsible(false);
     QList<int> splitterSizes;
     splitterSizes << 80 << 20;
-    KConfigGroup myGroup( KGlobal::config(), "SieveEditorMainWidget" );
-    setSizes(myGroup.readEntry( "mainSplitter", splitterSizes));
-    connect( KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()), this, SLOT(slotGeneralPaletteChanged()));
+    KConfigGroup myGroup(KSharedConfig::openConfig(), "SieveEditorMainWidget");
+    setSizes(myGroup.readEntry("mainSplitter", splitterSizes));
 }
 
 SieveEditorMainWidget::~SieveEditorMainWidget()
 {
-    KConfigGroup myGroup( KGlobal::config(), "SieveEditorMainWidget" );
-    myGroup.writeEntry( "mainSplitter", sizes());
+    KConfigGroup myGroup(KSharedConfig::openConfig(), "SieveEditorMainWidget");
+    myGroup.writeEntry("mainSplitter", sizes());
     myGroup.sync();
 }
 
-QWidget *SieveEditorMainWidget::hasExistingPage(const KUrl &url)
+QWidget *SieveEditorMainWidget::hasExistingPage(const QUrl &url)
 {
-    for (int i=0; i < mTabWidget->count(); ++i) {
+    for (int i = 0; i < mTabWidget->count(); ++i) {
         SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
         if (page) {
             if (page->currentUrl() == url) {
@@ -74,10 +72,10 @@ QWidget *SieveEditorMainWidget::hasExistingPage(const KUrl &url)
             }
         }
     }
-    return 0;
+    return Q_NULLPTR;
 }
 
-void SieveEditorMainWidget::slotScriptDeleted(const KUrl &url)
+void SieveEditorMainWidget::slotScriptDeleted(const QUrl &url)
 {
     QWidget *page = hasExistingPage(url);
     if (page) {
@@ -86,25 +84,26 @@ void SieveEditorMainWidget::slotScriptDeleted(const KUrl &url)
     }
 }
 
-void SieveEditorMainWidget::slotCreateScriptPage(const KUrl &url, const QStringList &capabilities, bool isNewScript)
+void SieveEditorMainWidget::slotCreateScriptPage(const QUrl &url, const QStringList &capabilities, bool isNewScript)
 {
     QWidget *page = hasExistingPage(url);
     if (page) {
         mTabWidget->setCurrentWidget(page);
     } else {
         SieveEditorPageWidget *editor = new SieveEditorPageWidget;
-        connect(editor, SIGNAL(refreshList()), this, SIGNAL(updateScriptList()));
-        connect(editor, SIGNAL(scriptModified(bool,SieveEditorPageWidget*)), this, SLOT(slotScriptModified(bool,SieveEditorPageWidget*)));
-        connect(editor, SIGNAL(modeEditorChanged(KSieveUi::SieveEditorWidget::EditorMode)), SIGNAL(modeEditorChanged(KSieveUi::SieveEditorWidget::EditorMode)));
-        connect(editor, SIGNAL(undoAvailable(bool)), SIGNAL(undoAvailable(bool)));
-        connect(editor, SIGNAL(redoAvailable(bool)), SIGNAL(redoAvailable(bool)));
-        connect(editor, SIGNAL(copyAvailable(bool)), SIGNAL(copyAvailable(bool)));
+        connect(editor, &SieveEditorPageWidget::refreshList, this, &SieveEditorMainWidget::updateScriptList);
+        connect(editor, &SieveEditorPageWidget::scriptModified, this, &SieveEditorMainWidget::slotScriptModified);
+        connect(editor, &SieveEditorPageWidget::modeEditorChanged, this, &SieveEditorMainWidget::modeEditorChanged);
+        connect(editor, &SieveEditorPageWidget::undoAvailable, this, &SieveEditorMainWidget::undoAvailable);
+        connect(editor, &SieveEditorPageWidget::redoAvailable, this, &SieveEditorMainWidget::redoAvailable);
+        connect(editor, &SieveEditorPageWidget::copyAvailable, this, &SieveEditorMainWidget::copyAvailable);
         editor->setIsNewScript(isNewScript);
         editor->loadScript(url, capabilities);
         mTabWidget->addTab(editor, url.fileName());
         mTabWidget->setCurrentWidget(editor);
-        if (isNewScript)
+        if (isNewScript) {
             editor->uploadScript(false, true);
+        }
     }
 }
 
@@ -152,18 +151,19 @@ void SieveEditorMainWidget::uploadScript()
 bool SieveEditorMainWidget::needToSaveScript()
 {
     bool scriptSaved = false;
-    for (int i=0; i < mTabWidget->count(); ++i) {
+    for (int i = 0; i < mTabWidget->count(); ++i) {
         SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(mTabWidget->widget(i));
         if (page) {
             const bool result = page->needToSaveScript();
-            if (result)
+            if (result) {
                 scriptSaved = true;
+            }
         }
     }
     return scriptSaved;
 }
 
-KTabWidget *SieveEditorMainWidget::tabWidget() const
+QTabWidget *SieveEditorMainWidget::tabWidget() const
 {
     return mTabWidget;
 }
@@ -215,7 +215,6 @@ void SieveEditorMainWidget::slotSelectAll()
     }
 }
 
-
 void SieveEditorMainWidget::slotCopy()
 {
     QWidget *w = mTabWidget->currentWidget();
@@ -359,7 +358,6 @@ void SieveEditorMainWidget::slotUncomment()
     }
 }
 
-
 void SieveEditorMainWidget::slotImport()
 {
     QWidget *w = mTabWidget->currentWidget();
@@ -404,6 +402,17 @@ void SieveEditorMainWidget::slotReverseCase()
     }
 }
 
+void SieveEditorMainWidget::slotDebugSieveScript()
+{
+    QWidget *w = mTabWidget->currentWidget();
+    if (w) {
+        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        if (page) {
+            page->debugSieveScript();
+        }
+    }
+}
+
 void SieveEditorMainWidget::slotUpperCase()
 {
     QWidget *w = mTabWidget->currentWidget();
@@ -429,23 +438,44 @@ void SieveEditorMainWidget::slotSentenceCase()
 void SieveEditorMainWidget::slotLowerCase()
 {
     QWidget *w = mTabWidget->currentWidget();
-     if (w) {
-         SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
-         if (page) {
-             page->lowerCase();
-         }
-     }
+    if (w) {
+        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        if (page) {
+            page->lowerCase();
+        }
+    }
 }
 
-
-void SieveEditorMainWidget::slotScriptModified(bool modified,SieveEditorPageWidget *page)
+void SieveEditorMainWidget::slotScriptModified(bool modified, SieveEditorPageWidget *page)
 {
     const int index = mTabWidget->indexOf(page);
     if (index >= 0) {
         if (!mScriptColor.isValid()) {
             slotGeneralPaletteChanged();
         }
-        mTabWidget->setTabTextColor(index, modified ? mModifiedScriptColor : mScriptColor);
+        mTabWidget->tabBar()->setTabTextColor(index, modified ? mModifiedScriptColor : mScriptColor);
+    }
+}
+
+void SieveEditorMainWidget::slotZoomIn()
+{
+    QWidget *w = mTabWidget->currentWidget();
+    if (w) {
+        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        if (page) {
+            page->zoomIn();
+        }
+    }
+}
+
+void SieveEditorMainWidget::slotZoomOut()
+{
+    QWidget *w = mTabWidget->currentWidget();
+    if (w) {
+        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        if (page) {
+            page->zoomOut();
+        }
     }
 }
 
@@ -455,8 +485,8 @@ void SieveEditorMainWidget::slotGeneralPaletteChanged()
     mScriptColor = pal.text().color();
     mModifiedScriptColor = pal.text().color();
 
-    const KColorScheme scheme( QPalette::Active, KColorScheme::View );
-    mModifiedScriptColor = scheme.foreground( KColorScheme::NegativeText ).color();
+    const KColorScheme scheme(QPalette::Active, KColorScheme::View);
+    mModifiedScriptColor = scheme.foreground(KColorScheme::NegativeText).color();
 }
 
 void SieveEditorMainWidget::slotTabCloseRequested(int index)
@@ -478,7 +508,7 @@ void SieveEditorMainWidget::slotTabCloseRequested(int index)
 
 void SieveEditorMainWidget::slotTabRemoveAllExclude(int index)
 {
-    for(int i = mTabWidget->count()-1; i >=0; --i) {
+    for (int i = mTabWidget->count() - 1; i >= 0; --i) {
         if (i == index) {
             continue;
         }
@@ -497,3 +527,38 @@ KSieveUi::SieveEditorWidget::EditorMode SieveEditorMainWidget::pageMode() const
     }
     return KSieveUi::SieveEditorWidget::Unknown;
 }
+
+void SieveEditorMainWidget::openBookmarkUrl(const QUrl &url)
+{
+    QWidget *w = mTabWidget->currentWidget();
+    if (w) {
+        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        if (page) {
+            page->openBookmarkUrl(url);
+        }
+    }
+}
+
+QString SieveEditorMainWidget::currentHelpTitle() const
+{
+    QWidget *w = mTabWidget->currentWidget();
+    if (w) {
+        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        if (page) {
+            return page->currentHelpTitle();
+        }
+    }
+    return QString();
+}
+
+QUrl SieveEditorMainWidget::currentHelpUrl() const
+{
+    QWidget *w = mTabWidget->currentWidget();
+    if (w) {
+        SieveEditorPageWidget *page = qobject_cast<SieveEditorPageWidget *>(w);
+        if (page) {
+            return page->currentHelpUrl();
+        }
+    }
+    return QUrl();
+}
