@@ -21,12 +21,14 @@
 #ifndef SIEVEEDITORPAGEWIDGET_H
 #define SIEVEEDITORPAGEWIDGET_H
 #include <QWidget>
-#include <KUrl>
+#include <QUrl>
 #include "ksieveui/editor/sieveeditorwidget.h"
-namespace KManageSieve {
+namespace KManageSieve
+{
 class SieveJob;
 }
-namespace KSieveUi {
+namespace KSieveUi
+{
 class SieveEditorWidget;
 }
 
@@ -34,11 +36,11 @@ class SieveEditorPageWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit SieveEditorPageWidget(QWidget *parent=0);
+    explicit SieveEditorPageWidget(QWidget *parent = Q_NULLPTR);
     ~SieveEditorPageWidget();
 
-    void loadScript(const KUrl &url, const QStringList &capabilities);
-    KUrl currentUrl() const;
+    void loadScript(const QUrl &url, const QStringList &capabilities);
+    QUrl currentUrl() const;
     void setIsNewScript(bool isNewScript);
     void uploadScript(bool showInformation = true, bool forceSave = false);
     bool needToSaveScript();
@@ -63,6 +65,20 @@ public:
     void checkSpelling();
     void share();
     void import();
+    void autoGenerateScript();
+    void checkSyntax();
+    void comment();
+    void uncomment();
+    void lowerCase();
+    void upperCase();
+    void sentenceCase();
+    void reverseCase();
+    void zoomIn();
+    void zoomOut();
+    QString currentHelpTitle() const;
+    QUrl currentHelpUrl() const;
+    void openBookmarkUrl(const QUrl &url);
+    void debugSieveScript();
 Q_SIGNALS:
     void refreshList();
     void scriptModified(bool, SieveEditorPageWidget *);
@@ -71,7 +87,7 @@ Q_SIGNALS:
     void redoAvailable(bool);
     void copyAvailable(bool);
 
-private slots:
+private Q_SLOTS:
     void slotGetResult(KManageSieve::SieveJob *, bool success, const QString &script, bool isActive);
     void slotCheckSyntaxClicked();
     void slotPutResultDebug(KManageSieve::SieveJob *, bool success, const QString &errorMsg);
@@ -80,7 +96,7 @@ private slots:
 
 private:
     void setModified(bool b);
-    KUrl mCurrentURL;
+    QUrl mCurrentURL;
     KSieveUi::SieveEditorWidget *mSieveEditorWidget;
     bool mWasActive;
     bool mIsNewScript;
