@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2015 Montel Laurent <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -18,19 +18,20 @@
 
 */
 
-
 #ifndef STORAGESERVICELOGDIALOG_H
 #define STORAGESERVICELOGDIALOG_H
 
-#include <KDialog>
-namespace PimCommon {
+#include <QDialog>
+class QPushButton;
+namespace PimCommon
+{
 class RichTextEditorWidget;
 }
-class StorageServiceLogDialog : public KDialog
+class StorageServiceLogDialog : public QDialog
 {
     Q_OBJECT
 public:
-    explicit StorageServiceLogDialog(QWidget *parent=0);
+    explicit StorageServiceLogDialog(QWidget *parent = Q_NULLPTR);
     ~StorageServiceLogDialog();
 
     void setLog(const QString &log);
@@ -38,7 +39,7 @@ public:
 Q_SIGNALS:
     void clearLog();
 
-private slots:
+private Q_SLOTS:
     void slotSaveAs();
     void slotClearLog();
     void slotTextChanged();
@@ -46,6 +47,8 @@ private:
     void readConfig();
     void writeConfig();
     PimCommon::RichTextEditorWidget *mLog;
+    QPushButton *mUser1Button;
+    QPushButton *mUser2Button;
 };
 
 #endif // STORAGESERVICELOGDIALOG_H
