@@ -23,18 +23,21 @@
 #include "storageservice/dialog/storageservicechecknamedialog.h"
 #include "storageservicemanagerglobalconfig.h"
 #include "storageservice/storageserviceprogressmanager.h"
+#include "storageservicemanager_debug.h"
 
-#include <KMenu>
-#include <KInputDialog>
+#include <QMenu>
+#include <QInputDialog>
 #include <KLocalizedString>
-#include <KFileDialog>
-#include <KGlobalSettings>
 #include <KMessageBox>
-#include <KLocale>
 
+#include <QEvent>
 #include <QPainter>
 #include <QHeaderView>
 #include <QPointer>
+#include <KSharedConfig>
+#include <KFormat>
+#include <QFontDatabase>
+#include <QFileDialog>
 
 StorageServiceTreeWidget::StorageServiceTreeWidget(PimCommon::StorageServiceAbstract *storageService, QWidget *parent)
     : PimCommon::StorageServiceTreeWidget(storageService, parent),
@@ -43,41 +46,48 @@ StorageServiceTreeWidget::StorageServiceTreeWidget(PimCommon::StorageServiceAbst
     mCapabilities = mStorageService->capabilities();
     //Single selection for the moment
     setSelectionMode(QAbstractItemView::SingleSelection);
-    connect(this, SIGNAL(fileDoubleClicked()), this, SLOT(slotFileDoubleClicked()));
-    connect( KGlobalSettings::self(), SIGNAL(kdisplayFontChanged()), this, SLOT(slotGeneralFontChanged()));
-    connect( KGlobalSettings::self(), SIGNAL(kdisplayPaletteChanged()), this, SLOT(slotGeneralPaletteChanged()));
+    connect(this, &StorageServiceTreeWidget::fileDoubleClicked, this, &StorageServiceTreeWidget::slotFileDoubleClicked);
     readConfig();
 }
 
 StorageServiceTreeWidget::~StorageServiceTreeWidget()
 {
-    qDebug()<<" StorageServiceTreeWidget::~StorageServiceTreeWidget()";
+    qCDebug(STORAGESERVICEMANAGER_LOG) << " StorageServiceTreeWidget::~StorageServiceTreeWidget()";
     writeConfig();
 }
 
+void StorageServiceTreeWidget::changeEvent(QEvent *event)
+{
+    if (event->type() == QEvent::PaletteChange) {
+        generalPaletteChanged();
+    } else if (event->type() == QEvent::FontChange) {
+        generalFontChanged();
+    }
+    QTreeWidget::changeEvent(event);
+}
 void StorageServiceTreeWidget::writeConfig()
 {
-    KConfigGroup grp( KGlobal::config(), "StorageServiceTreeWidget" );
+    KConfigGroup grp(KSharedConfig::openConfig(), "StorageServiceTreeWidget");
     grp.writeEntry(mStorageService->storageServiceName(), header()->saveState());
 }
 
 void StorageServiceTreeWidget::readConfig()
 {
-    KConfigGroup grp( KGlobal::config(), "StorageServiceTreeWidget" );
-    header()->restoreState( grp.readEntry( mStorageService->storageServiceName(), QByteArray() ) );
+    KConfigGroup grp(KSharedConfig::openConfig(), "StorageServiceTreeWidget");
+    header()->restoreState(grp.readEntry(mStorageService->storageServiceName(), QByteArray()));
 }
 
-void StorageServiceTreeWidget::slotGeneralPaletteChanged()
+void StorageServiceTreeWidget::generalPaletteChanged()
 {
     const QPalette palette = viewport()->palette();
     QColor color = palette.text().color();
-    color.setAlpha( 128 );
+    color.setAlpha(128);
     mTextColor = color;
 }
 
-void StorageServiceTreeWidget::slotGeneralFontChanged()
+void StorageServiceTreeWidget::generalFontChanged()
 {
-    setFont( KGlobalSettings::generalFont() );
+    setFont(QFontDatabase::systemFont(QFontDatabase::GeneralFont));
 }
 
 void StorageServiceTreeWidget::setIsInitialized()
@@ -88,61 +98,73 @@ void StorageServiceTreeWidget::setIsInitialized()
     }
 }
 
-void StorageServiceTreeWidget::createMenuActions(KMenu *menu)
+void StorageServiceTreeWidget::createMenuActions(QMenu *menu)
 {
     if (mInitialized) {
         createUpAction(menu);
         const PimCommon::StorageServiceTreeWidget::ItemType type = StorageServiceTreeWidget::itemTypeSelected();
         if (type != StorageServiceTreeWidget::UnKnown) {
             if (type == StorageServiceTreeWidget::File) {
-                if (mCapabilities & PimCommon::StorageServiceAbstract::MoveFileCapability)
-                    menu->addAction(KIcon(QLatin1String("edit-cut")), i18n("Cut"), this, SLOT(slotCutFile()));
-                if (mCapabilities & PimCommon::StorageServiceAbstract::CopyFileCapability)
-                    menu->addAction(KIcon(QLatin1String("edit-copy")), i18n("Copy"), this, SLOT(slotCopyFile()));
+                if (mCapabilities & PimCommon::StorageServiceAbstract::MoveFileCapability) {
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-cut")), i18n("Cut"), this, SLOT(slotCutFile()));
+                }
+                if (mCapabilities & PimCommon::StorageServiceAbstract::CopyFileCapability) {
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy"), this, SLOT(slotCopyFile()));
+                }
                 QAction *act = new QAction(menu);
                 act->setSeparator(true);
                 menu->addAction(act);
-                if (mCapabilities & PimCommon::StorageServiceAbstract::RenameFileCapabilitity)
+                if (mCapabilities & PimCommon::StorageServiceAbstract::RenameFileCapabilitity) {
                     menu->addAction(i18n("Rename File..."), this, SLOT(slotRenameFile()));
-                if (mCapabilities & PimCommon::StorageServiceAbstract::ShareLinkCapability)
+                }
+                if (mCapabilities & PimCommon::StorageServiceAbstract::ShareLinkCapability) {
                     menu->addAction(i18n("Share File"), this, SLOT(slotShareFile()));
+                }
                 act = new QAction(menu);
                 act->setSeparator(true);
                 menu->addAction(act);
-                if (mCapabilities & PimCommon::StorageServiceAbstract::DownloadFileCapability)
-                    menu->addAction(KIcon(QLatin1String("download")), i18n("Download File"), this, SIGNAL(downloadFile()));
+                if (mCapabilities & PimCommon::StorageServiceAbstract::DownloadFileCapability) {
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("download")), i18n("Download File"), this, SIGNAL(downloadFile()));
+                }
                 act = new QAction(menu);
                 act->setSeparator(true);
                 menu->addAction(act);
-                if (mCapabilities & PimCommon::StorageServiceAbstract::DeleteFileCapability)
-                    menu->addAction(KIcon(QLatin1String("edit-delete")), i18n("Delete File"), this, SLOT(slotDeleteFile()));
+                if (mCapabilities & PimCommon::StorageServiceAbstract::DeleteFileCapability) {
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Delete File"), this, SLOT(slotDeleteFile()));
+                }
             } else if (type == StorageServiceTreeWidget::Folder) {
-                if (mCapabilities & PimCommon::StorageServiceAbstract::MoveFolderCapability)
-                    menu->addAction(KIcon(QLatin1String("edit-cut")), i18n("Cut"), this, SLOT(slotCutFolder()));
-                if (mCapabilities & PimCommon::StorageServiceAbstract::CopyFolderCapability)
-                    menu->addAction(KIcon(QLatin1String("edit-copy")), i18n("Copy"), this, SLOT(slotCopyFolder()));
+                if (mCapabilities & PimCommon::StorageServiceAbstract::MoveFolderCapability) {
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-cut")), i18n("Cut"), this, SLOT(slotCutFolder()));
+                }
+                if (mCapabilities & PimCommon::StorageServiceAbstract::CopyFolderCapability) {
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("Copy"), this, SLOT(slotCopyFolder()));
+                }
                 QAction *act = new QAction(menu);
                 act->setSeparator(true);
                 menu->addAction(act);
-                if (mCapabilities & PimCommon::StorageServiceAbstract::RenameFolderCapability)
+                if (mCapabilities & PimCommon::StorageServiceAbstract::RenameFolderCapability) {
                     menu->addAction(i18n("Rename Folder..."), this, SLOT(slotRenameFolder()));
+                }
                 act = new QAction(menu);
                 act->setSeparator(true);
                 menu->addAction(act);
-                if (mCapabilities & PimCommon::StorageServiceAbstract::DeleteFolderCapability)
-                    menu->addAction(KIcon(QLatin1String("edit-delete")), i18n("Delete Folder"), this, SLOT(slotDeleteFolder()));
+                if (mCapabilities & PimCommon::StorageServiceAbstract::DeleteFolderCapability) {
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-delete")), i18n("Delete Folder"), this, SLOT(slotDeleteFolder()));
+                }
             }
         }
         QAction *act = new QAction(menu);
         act->setSeparator(true);
         menu->addAction(act);
-        if (mCapabilities & PimCommon::StorageServiceAbstract::UploadFileCapability)
+        if (mCapabilities & PimCommon::StorageServiceAbstract::UploadFileCapability) {
             menu->addAction(i18n("Upload File..."), this, SIGNAL(uploadFile()));
+        }
         act = new QAction(menu);
         act->setSeparator(true);
         menu->addAction(act);
-        if (mCapabilities & PimCommon::StorageServiceAbstract::CreateFolderCapability)
-            menu->addAction(KIcon(QLatin1String("folder-new")), i18n("Create Folder..."), this, SLOT(slotCreateFolder()));
+        if (mCapabilities & PimCommon::StorageServiceAbstract::CreateFolderCapability) {
+            menu->addAction(QIcon::fromTheme(QStringLiteral("folder-new")), i18n("Create Folder..."), this, SLOT(slotCreateFolder()));
+        }
 
         act = new QAction(menu);
         act->setSeparator(true);
@@ -151,21 +173,21 @@ void StorageServiceTreeWidget::createMenuActions(KMenu *menu)
         if (mCopyItem.moveItem) {
             if (mCopyItem.type == FileType) {
                 if (mCapabilities & PimCommon::StorageServiceAbstract::MoveFileCapability) {
-                    menu->addAction(KIcon(QLatin1String("edit-paste")), i18n("Paste"), this, SLOT(slotMoveFile()));
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-paste")), i18n("Paste"), this, SLOT(slotMoveFile()));
                 }
             } else if (mCopyItem.type == FolderType) {
                 if (mCapabilities & PimCommon::StorageServiceAbstract::MoveFolderCapability) {
-                    menu->addAction(KIcon(QLatin1String("edit-paste")), i18n("Paste"), this, SLOT(slotMoveFolder()));
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-paste")), i18n("Paste"), this, SLOT(slotMoveFolder()));
                 }
             }
         } else {
             if (mCopyItem.type == FileType) {
                 if (mCapabilities & PimCommon::StorageServiceAbstract::CopyFileCapability) {
-                    menu->addAction(KIcon(QLatin1String("edit-paste")), i18n("Paste"), this, SLOT(slotPasteFile()));
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-paste")), i18n("Paste"), this, SLOT(slotPasteFile()));
                 }
             } else if (mCopyItem.type == FolderType) {
                 if (mCapabilities & PimCommon::StorageServiceAbstract::CopyFolderCapability) {
-                    menu->addAction(KIcon(QLatin1String("edit-paste")), i18n("Paste"), this, SLOT(slotPasteFolder()));
+                    menu->addAction(QIcon::fromTheme(QStringLiteral("edit-paste")), i18n("Paste"), this, SLOT(slotPasteFolder()));
                 }
             }
         }
@@ -176,7 +198,7 @@ void StorageServiceTreeWidget::createMenuActions(KMenu *menu)
             createPropertiesAction(menu);
         }
     } else {
-        menu->addAction(KIcon(QLatin1String("view-refresh")), i18n("Refresh"), this, SLOT(refreshList()));
+        menu->addAction(QIcon::fromTheme(QStringLiteral("view-refresh")), i18n("Refresh"), this, SLOT(refreshList()));
     }
 }
 
@@ -202,7 +224,7 @@ void StorageServiceTreeWidget::slotPasteFile()
 
 void StorageServiceTreeWidget::renameItem()
 {
-    switch(itemTypeSelected()) {
+    switch (itemTypeSelected()) {
     case StorageServiceTreeWidget::Folder:
         slotRenameFolder();
         break;
@@ -218,7 +240,7 @@ void StorageServiceTreeWidget::slotRenameFolder()
 {
     const QString oldFolderName = itemIdentifierSelected();
     const QString name = currentItem()->text(0);
-    const QString folder = KInputDialog::getText(i18n("Rename Folder Name"), i18n("Folder:"), name);
+    const QString folder = QInputDialog::getText(this, i18n("Rename Folder Name"), i18n("Folder:"), QLineEdit::Normal, name);
     if (!folder.isEmpty()) {
         if (name != folder) {
             if (!checkName(folder)) {
@@ -233,7 +255,7 @@ void StorageServiceTreeWidget::slotRenameFile()
 {
     const QString oldFileName = itemIdentifierSelected();
     const QString name = currentItem()->text(0);
-    const QString filename = KInputDialog::getText(i18n("Rename Filename"), i18n("Filename:"), name);
+    const QString filename = QInputDialog::getText(this, i18n("Rename Filename"), i18n("Filename:"), QLineEdit::Normal, name);
     if (!filename.isEmpty()) {
         if (name != filename) {
             if (!checkName(filename)) {
@@ -262,18 +284,19 @@ bool StorageServiceTreeWidget::checkName(const QString &name)
 
 void StorageServiceTreeWidget::slotCreateFolder()
 {
-    const QString folder = KInputDialog::getText(i18n("Folder Name"), i18n("Folder:"));
+    const QString folder = QInputDialog::getText(this, i18nc("@title:window", "Create Folder"), i18n("Folder:"));
     if (!folder.isEmpty()) {
-        if (!checkName(folder))
+        if (!checkName(folder)) {
             return;
-        qDebug()<<" mCurrentFolder" <<mCurrentFolder;
+        }
+        qCDebug(STORAGESERVICEMANAGER_LOG) << " mCurrentFolder" << mCurrentFolder;
         mStorageService->createFolder(folder, mCurrentFolder);
     }
 }
 
 void StorageServiceTreeWidget::deleteItem()
 {
-    switch(itemTypeSelected()) {
+    switch (itemTypeSelected()) {
     case StorageServiceTreeWidget::Folder:
         deleteFolder();
         break;
@@ -300,7 +323,7 @@ void StorageServiceTreeWidget::deleteFile()
 {
     const QString filename = itemIdentifierSelected();
     const QString name = currentItem()->text(0);
-    if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("Are you sure that you want to delete \"%1\"?", name) )) {
+    if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("Are you sure that you want to delete \"%1\"?", name))) {
         if (!filename.isEmpty()) {
             mStorageService->deleteFile(filename);
         }
@@ -339,9 +362,10 @@ void StorageServiceTreeWidget::slotDownloadFile()
         if (!filename.isEmpty()) {
             QString destination = StorageServiceManagerGlobalConfig::self()->downloadDirectory();
             if (destination.isEmpty()) {
-                destination = KFileDialog::getExistingDirectory(KUrl(), this);
-                if (destination.isEmpty())
+                destination = QFileDialog::getExistingDirectory(this, QString());
+                if (destination.isEmpty()) {
                     return;
+                }
             }
             QFileInfo fileInfo(destination + QLatin1Char('/') + filename);
             if (fileInfo.exists()) {
@@ -358,18 +382,18 @@ void StorageServiceTreeWidget::slotDownloadFile()
 
 bool StorageServiceTreeWidget::uploadFileToService()
 {
-    const QString filename = KFileDialog::getOpenFileName(KUrl(), QLatin1String("*"), this);
+    const QString filename = QFileDialog::getOpenFileName(this);
     if (!filename.isEmpty()) {
         const QRegExp disallowedSymbols = mStorageService->disallowedSymbols();
         const qlonglong maximumLimit =  mStorageService->maximumUploadFileSize();
-        qDebug()<<" maximumLimit"<<maximumLimit;
+        qCDebug(STORAGESERVICEMANAGER_LOG) << " maximumLimit" << maximumLimit;
         QFileInfo info(filename);
         if (maximumLimit > 0 && (info.size() > maximumLimit)) {
-            KMessageBox::error(this, i18n("File size (%1) is larger than limit (%2)", KGlobal::locale()->formatByteSize(info.size(),1), KGlobal::locale()->formatByteSize(maximumLimit,1)));
+            KMessageBox::error(this, i18n("File size (%1) is larger than limit (%2)", KFormat().formatByteSize(info.size(), 1), KFormat().formatByteSize(maximumLimit, 1)));
             return false;
         }
         if (filename == QLatin1String(".") || filename == QLatin1String("..")) {
-            KMessageBox::error(this, i18n("You are trying to use unauthorized characters."));
+            KMessageBox::error(this, i18n("File names \".\" and \"..\" are forbidden."));
             return false;
         }
         QString newName = info.fileName();
@@ -401,26 +425,27 @@ void StorageServiceTreeWidget::canDownloadFile()
     if (itemTypeSelected() == StorageServiceTreeWidget::File) {
         Q_EMIT downloadFile();
     } else {
-        KMessageBox::error(this, i18n("Please select a file to download."), i18n("Download File"));
+        KMessageBox::error(this, i18n("Please select a file to download."),
+                           i18nc("@title:window", "Download File"));
     }
 }
 
-void StorageServiceTreeWidget::paintEvent( QPaintEvent *event )
+void StorageServiceTreeWidget::paintEvent(QPaintEvent *event)
 {
-    if ( mInitialized ) {
+    if (mInitialized) {
         PimCommon::StorageServiceTreeWidget::paintEvent(event);
     } else {
-        QPainter p( viewport() );
+        QPainter p(viewport());
 
         QFont font = p.font();
-        font.setItalic( true );
-        p.setFont( font );
+        font.setItalic(true);
+        p.setFont(font);
 
         if (!mTextColor.isValid()) {
-            slotGeneralPaletteChanged();
+            generalPaletteChanged();
         }
-        p.setPen( mTextColor );
-        p.drawText( QRect( 0, 0, width(), height() ), Qt::AlignCenter, i18n("Storage service not initialized.") );
+        p.setPen(mTextColor);
+        p.drawText(QRect(0, 0, width(), height()), Qt::AlignCenter, i18n("Storage service not initialized."));
     }
 }
 
@@ -455,7 +480,8 @@ void StorageServiceTreeWidget::slotCopyFolder()
 void StorageServiceTreeWidget::slotFileDoubleClicked()
 {
     if (mCapabilities & PimCommon::StorageServiceAbstract::DownloadFileCapability) {
-        if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("Do you want to download this file?"), i18n("Download File"))) {
+        if (KMessageBox::Yes == KMessageBox::questionYesNo(this, i18n("Do you want to download this file?"),
+                                                           i18nc("@title:window", "Download File"))) {
             Q_EMIT downloadFile();
         }
     }
