@@ -21,8 +21,8 @@
 
 using namespace TemplateParser;
 
-TemplatesTextEdit::TemplatesTextEdit( QWidget *parent )
-    : PimCommon::RichTextEditorWidget( new TemplatesTextEditor, parent )
+TemplatesTextEdit::TemplatesTextEdit(QWidget *parent)
+    : PimCommon::PlainTextEditorWidget(new TemplatesTextEditor, parent)
 {
 }
 
@@ -30,5 +30,3 @@ TemplatesTextEdit::~TemplatesTextEdit()
 {
 }
 
-
-
